#!/bin/sh
#### Patch script - GNU Emacs - version 19.32 to 19.33

#### This file contains patches to turn version 19.32 of GNU Emacs into
#### 19.33.  To apply them, cd to the top of the Emacs source tree, and
#### then type 'sh <this file>'.

#### After this script applies the patches, it will attempt to use an
#### existing Emacs to recompile the changed Emacs Lisp files.  (You may
#### use the environment variable $emacs to specify the location of the
#### binary, if it's not in your search path.)  When this is finished,
#### you can build the new Emacs version.

#### We don't include patches for Info files since you can
#### regenerate them from the Texinfo files that we do include.
#### To update the changed info files, do
#### (cd man; make)

if [ "$0" = sh -o ! -f "$0" ]; then
  echo "use \`sh PATCHKIT', not \`sh <PATCHKIT'" >&2
  exit 1
fi
if [ -d lisp ] ; then
  me=$0
elif [ -d emacs-19.32/lisp ] ; then
  cd emacs-19.32
  case $0 in /*) me=$0;; *) me=../$0;; esac
else
  (echo "$0: In order to apply this patch, the current directory"
   echo "must be the top of the Emacs distribution tree.") >&2
  exit 1
fi

### moves and renames
rm lisp/MANIFEST

tail +69 $me | patch -p1

cd lisp
for e in $emacs ../src/emacs emacs emacs19 emacs-19 ''; do
  if [ -n "$e" ]; then
    v=`$e --version </dev/null 2>/dev/null | sed -e 's/.* //' -e 's/\.[0-9]*$//'`
    case $v in 19.29*|19.[3-9][0-9]*) break;; esac
  fi
done
if [ -z "$e" ]; then
  (echo "I can't find an Emacs to execute."
   echo "You'll have to byte-compile the lisp directory by hand.") >&2
  exit 0
fi
echo "byte compiling with $e (version $v)..." >&2
loadpath=${TMPDIR-/tmp}/$$.el
trap "rm -f $loadpath; exit 1" 1 2 3 15
echo "(setq load-path (cons \"`pwd`\" load-path))" >$loadpath
# First do the new files, and any older files that might need to be compiled
# in a particular order.  Then do the rest of the directory.
list=imenu.el

for f in $list; do
  echo Compiling $f...
  $e -batch -l $loadpath -f batch-byte-compile $f
done
$e -batch -l $loadpath -f batch-byte-recompile-directory .
rm $loadpath
exit 0
# The rest of this file is the patch kit.  It's not enclosed in a
# here-document because some shells can't deal with that if it gets
# too large.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/ChangeLog emacs-19.33/ChangeLog
*** emacs-19.32/ChangeLog	Wed Jul 31 15:09:17 1996
--- emacs-19.33/ChangeLog	Sun Aug 11 03:38:23 1996
***************
*** 1,2 ****
--- 1,35 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
+ Sat Aug 10 14:50:46 1996  Marcus Daniels  <marcus@sayre.sysc.pdx.edu>
+ 
+ 	* configure.in (i[3456]86-sequent-ptx4*, i[3456]86-sequent-sysv4*):
+ 	Fix previous change.
+ 
+ Thu Aug  8 23:00:10 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* configure.in (i[3456]86-sequent-ptx4*, i[3456]86-sequent-sysv4*):
+ 	New alternative.
+ 
+ Wed Aug  7 17:58:37 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* configure.in (alpha-dec-osf*): Specify GCC_TEST_OPTIONS
+ 	and NON_GCC_TEST_OPTIONS.
+ 
+ Tue Aug  6 00:31:20 1996  Paul Eggert  <eggert@twinsun.com>
+ 
+ 	* configure.in (LOCALTIME_CACHE): Don't put a string literal
+ 	"TZ=..." in environ.
+ 
+ Sun Aug  4 16:33:35 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* make-dist (msdos): Add is_exec.c, sigaction.c to distribution.
+ 
+ Sat Aug  3 17:27:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* configure.in (*-sunos4.1.[3-9]*noshare): Move this before
+ 	the more general *-sunos4.1.[3-9]* clause.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/INSTALL emacs-19.33/INSTALL
*** emacs-19.32/INSTALL	Thu Aug  1 17:31:33 1996
--- emacs-19.33/INSTALL	Mon Aug  5 17:25:37 1996
*************** To unpack Emacs with djtar, type this co
*** 560,564 ****
  your system.)  There are a few files in the archive whose names
  collide with other files under the 8.3 DOS naming.  On native MSDOS,
! or if you have set LFN=n on Win95, djtar will ask you to supply
  alternate names for these files; you can just press `Enter' when this
  happens (which makes djtar skip these files) because they aren't
--- 560,564 ----
  your system.)  There are a few files in the archive whose names
  collide with other files under the 8.3 DOS naming.  On native MSDOS,
! or if you have set LFN=n on Windows 95, djtar will ask you to supply
  alternate names for these files; you can just press `Enter' when this
  happens (which makes djtar skip these files) because they aren't
*************** work.  Synchronous subprocesses do work.
*** 595,599 ****
  The current version of djgpp 2.0 (as of August 1996) has two bugs that
  affect Emacs.  We've included corrected versions of two files from
! djgpp in the msdos subdirectory: is-exec.c and sigaction.c.  To work
  around the bugs, compile these files and link them into temacs.  The
  next version of djgpp should have these bugs fixed.
--- 595,599 ----
  The current version of djgpp 2.0 (as of August 1996) has two bugs that
  affect Emacs.  We've included corrected versions of two files from
! djgpp in the msdos subdirectory: is_exec.c and sigaction.c.  To work
  around the bugs, compile these files and link them into temacs.  The
  next version of djgpp should have these bugs fixed.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/PROBLEMS emacs-19.33/PROBLEMS
*** emacs-19.32/PROBLEMS	Thu Aug  1 21:59:12 1996
--- emacs-19.33/PROBLEMS	Fri Aug  9 06:48:06 1996
*************** This file describes various problems tha
*** 2,5 ****
--- 2,36 ----
  in compiling, installing and running GNU Emacs.
  
+ * Emacs crashes when you use Bibtex mode.
+ 
+ This happens if your system puts a small limit on stack size.  You can
+ prevent the problem by using a suitable shell command (often `ulimit')
+ to raise the stack size limit before you run Emacs.
+ 
+ Patches to raise the stack size limit automatically in `main'
+ (src/emacs.c) on various systems would be greatly appreciated.
+ 
+ * Emacs crashes with SIGBUS or SIGSEGV on HPUX 9 after you delete a frame.
+ 
+ We think this is due to a bug in the X libraries provided by HP.  With
+ the alternative X libraries in /usr/contrib/mitX11R5/lib, the problem
+ does not happen.
+ 
+ * Posting a message with GNUS says "You appear to have a misconfigured system."
+ 
+ On some systems, primarily SunOS 4.1.x and some versions of SunOS 5,
+ the `system-name' function doesn't return a fully qualified domain
+ name.  Then Gnus/Message generates addresses that look like
+ <USER@MACHINE> with no domain name, which is invalid.
+ 
+ You can work around this by setting `user-mail-address'
+ `mail-host-address' to an appropriate value, like this:
+ 
+   (setq mail-host-address "MACHINE.DOMAIN")
+ 
+ or
+ 
+   (setq user-mail-address "USER@MACHINE.DOMAIN")
+ 
  * Problems running Perl under Emacs on Windows NT/95.
  
*************** There are two DJGPP library bugs which c
*** 92,96 ****
  
  To work around these bugs, you can use two files in the msdos
! subdirectory: `is-exec.c' and `sigaction.c'.  Compile them and link
  them into the Emacs executable `temacs'; then they will replace the
  incorrect library functions.
--- 123,127 ----
  
  To work around these bugs, you can use two files in the msdos
! subdirectory: `is_exec.c' and `sigaction.c'.  Compile them and link
  them into the Emacs executable `temacs'; then they will replace the
  incorrect library functions.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/README emacs-19.33/README
*** emacs-19.32/README	Thu Aug  1 22:02:47 1996
--- emacs-19.33/README	Mon Aug 12 21:10:26 1996
***************
*** 1,3 ****
! This directory tree holds version 19.32 of GNU Emacs, the extensible,
  customizable, self-documenting real-time display editor.
  
--- 1,3 ----
! This directory tree holds version 19.33 of GNU Emacs, the extensible,
  customizable, self-documenting real-time display editor.
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/configure emacs-19.33/configure
*** emacs-19.32/configure	Wed Jul 31 15:37:32 1996
--- emacs-19.33/configure	Sun Aug 11 03:36:36 1996
*************** case "${canonical}" in
*** 748,751 ****
--- 748,754 ----
    alpha-dec-osf* )
      machine=alpha opsys=osf1
+     # This is needed to find X11R6.1 libraries for certain tests.
+     NON_GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
+     GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
    ;;
  
*************** case "${canonical}" in
*** 1069,1072 ****
--- 1072,1081 ----
    ;;
  
+   ## Sequent Symmetry running ptx 4, which is a modified SVR4.
+   i[3456]86-sequent-ptx4* | i[3456]86-sequent-sysv4* )
+     machine=sequent-ptx opsys=ptx4
+     NON_GNU_CPP=/lib/cpp
+   ;;
+ 
    ## Sequent Symmetry running DYNIX/ptx
    ## Use the old cpp rather than the newer ANSI one.
*************** case "${canonical}" in
*** 1267,1274 ****
        i[3456]86-*-sunos4	  ) opsys=sunos4-0 ;;
        *-sunos4.0*	  ) opsys=sunos4-0 ;;
-       *-sunos4.1.[3-9]* | *-sunos4shr*)
- 		opsys=sunos4shr
- 		NON_GNU_CPP=/usr/lib/cpp
- 		;;
        *-sunos4.1.[3-9]*noshare )
  		opsys=sunos4-1-3
--- 1276,1279 ----
*************** case "${canonical}" in
*** 1277,1280 ****
--- 1282,1289 ----
  		GCC_TEST_OPTIONS=-static
  		;;
+       *-sunos4.1.[3-9]* | *-sunos4shr*)
+ 		opsys=sunos4shr
+ 		NON_GNU_CPP=/usr/lib/cpp
+ 		;;
        *-sunos4* | *-sunos )
  		opsys=sunos4-1
*************** else
*** 1575,1579 ****
  #endif
  EOF
! if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:1578: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
    ac_cv_prog_gcc=yes
  else
--- 1584,1588 ----
  #endif
  EOF
! if { ac_try='${CC-cc} -E conftest.c'; { (eval echo configure:1587: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }; } | egrep yes >/dev/null 2>&1; then
    ac_cv_prog_gcc=yes
  else
*************** else
*** 1685,1689 ****
    # not just through cpp.
    cat > conftest.$ac_ext <<EOF
! #line 1688 "configure"
  #include "confdefs.h"
  #include <assert.h>
--- 1694,1698 ----
    # not just through cpp.
    cat > conftest.$ac_ext <<EOF
! #line 1697 "configure"
  #include "confdefs.h"
  #include <assert.h>
*************** Syntax Error
*** 1691,1695 ****
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1694: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 1700,1704 ----
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1703: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
*************** else
*** 1700,1704 ****
    CPP="${CC-cc} -E -traditional-cpp"
    cat > conftest.$ac_ext <<EOF
! #line 1703 "configure"
  #include "confdefs.h"
  #include <assert.h>
--- 1709,1713 ----
    CPP="${CC-cc} -E -traditional-cpp"
    cat > conftest.$ac_ext <<EOF
! #line 1712 "configure"
  #include "confdefs.h"
  #include <assert.h>
*************** Syntax Error
*** 1706,1710 ****
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1709: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 1715,1719 ----
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1718: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
*************** test -n "$YACC" || YACC="yacc"
*** 1821,1825 ****
  echo $ac_n "checking for AIX""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 1824 "configure"
  #include "confdefs.h"
  #ifdef _AIX
--- 1830,1834 ----
  echo $ac_n "checking for AIX""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 1833 "configure"
  #include "confdefs.h"
  #ifdef _AIX
*************** if eval "test \"`echo '$''{'ac_cv_header
*** 1851,1860 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 1854 "configure"
  #include "confdefs.h"
  #include <$ac_hdr>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1859: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 1860,1869 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 1863 "configure"
  #include "confdefs.h"
  #include <$ac_hdr>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1868: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
*************** else
*** 1889,1897 ****
  else
  cat > conftest.$ac_ext <<EOF
! #line 1892 "configure"
  #include "confdefs.h"
  main(){return(0);}
  EOF
! { (eval echo configure:1896: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    ac_cv_c_cross=no
--- 1898,1906 ----
  else
  cat > conftest.$ac_ext <<EOF
! #line 1901 "configure"
  #include "confdefs.h"
  main(){return(0);}
  EOF
! { (eval echo configure:1905: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    ac_cv_c_cross=no
*************** if eval "test \"`echo '$''{'ac_cv_header
*** 1911,1915 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 1914 "configure"
  #include "confdefs.h"
  #include <stdlib.h>
--- 1920,1924 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 1923 "configure"
  #include "confdefs.h"
  #include <stdlib.h>
*************** else
*** 1919,1923 ****
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1922: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 1928,1932 ----
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:1931: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
*************** if test $ac_cv_header_stdc = yes; then
*** 1934,1938 ****
    # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
  cat > conftest.$ac_ext <<EOF
! #line 1937 "configure"
  #include "confdefs.h"
  #include <string.h>
--- 1943,1947 ----
    # SunOS 4.x string.h does not declare mem*, contrary to ANSI.
  cat > conftest.$ac_ext <<EOF
! #line 1946 "configure"
  #include "confdefs.h"
  #include <string.h>
*************** if test $ac_cv_header_stdc = yes; then
*** 1952,1956 ****
    # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
  cat > conftest.$ac_ext <<EOF
! #line 1955 "configure"
  #include "confdefs.h"
  #include <stdlib.h>
--- 1961,1965 ----
    # ISC 2.0.2 stdlib.h does not declare free, contrary to ANSI.
  cat > conftest.$ac_ext <<EOF
! #line 1964 "configure"
  #include "confdefs.h"
  #include <stdlib.h>
*************** if test "$cross_compiling" = yes; then
*** 1973,1977 ****
  else
  cat > conftest.$ac_ext <<EOF
! #line 1976 "configure"
  #include "confdefs.h"
  #include <ctype.h>
--- 1982,1986 ----
  else
  cat > conftest.$ac_ext <<EOF
! #line 1985 "configure"
  #include "confdefs.h"
  #include <ctype.h>
*************** exit (0); }
*** 1984,1988 ****
  
  EOF
! { (eval echo configure:1987: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    :
--- 1993,1997 ----
  
  EOF
! { (eval echo configure:1996: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    :
*************** if eval "test \"`echo '$''{'ac_cv_header
*** 2008,2012 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2011 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
--- 2017,2021 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2020 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
*************** struct tm *tp;
*** 2018,2022 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2021: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_header_time=yes
--- 2027,2031 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2030: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_header_time=yes
*************** if eval "test \"`echo '$''{'ac_cv_decl_s
*** 2042,2046 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2045 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
--- 2051,2055 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2054 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
*************** char *msg = *(sys_siglist + 1);
*** 2055,2059 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2058: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_decl_sys_siglist=yes
--- 2064,2068 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2067: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_decl_sys_siglist=yes
*************** fi
*** 2077,2081 ****
  echo $ac_n "checking for struct utimbuf""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 2080 "configure"
  #include "confdefs.h"
  #ifdef TIME_WITH_SYS_TIME
--- 2086,2090 ----
  echo $ac_n "checking for struct utimbuf""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 2089 "configure"
  #include "confdefs.h"
  #ifdef TIME_WITH_SYS_TIME
*************** static struct utimbuf x; x.actime = x.mo
*** 2097,2101 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2100: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""yes" 1>&6
--- 2106,2110 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2109: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""yes" 1>&6
*************** if eval "test \"`echo '$''{'ac_cv_type_s
*** 2116,2120 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2119 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
--- 2125,2129 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2128 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
*************** int i;
*** 2134,2138 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2137: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_type_signal=void
--- 2143,2147 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2146: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_type_signal=void
*************** EOF
*** 2154,2158 ****
  echo $ac_n "checking for struct timeval""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 2157 "configure"
  #include "confdefs.h"
  #ifdef TIME_WITH_SYS_TIME
--- 2163,2167 ----
  echo $ac_n "checking for struct timeval""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 2166 "configure"
  #include "confdefs.h"
  #ifdef TIME_WITH_SYS_TIME
*************** static struct timeval x; x.tv_sec = x.tv
*** 2171,2175 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2174: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""yes" 1>&6
--- 2180,2184 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2183: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""yes" 1>&6
*************** if eval "test \"`echo '$''{'ac_cv_struct
*** 2192,2196 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2195 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
--- 2201,2205 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2204 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
*************** struct tm *tp; tp->tm_sec;
*** 2201,2205 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2204: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_struct_tm=time.h
--- 2210,2214 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2213: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_struct_tm=time.h
*************** if eval "test \"`echo '$''{'ac_cv_struct
*** 2225,2229 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2228 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
--- 2234,2238 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2237 "configure"
  #include "confdefs.h"
  #include <sys/types.h>
*************** struct tm tm; tm.tm_zone;
*** 2234,2238 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2237: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_struct_tm_zone=yes
--- 2243,2247 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2246: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_struct_tm_zone=yes
*************** if eval "test \"`echo '$''{'ac_cv_var_tz
*** 2257,2261 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2260 "configure"
  #include "confdefs.h"
  #include <time.h>
--- 2266,2270 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2269 "configure"
  #include "confdefs.h"
  #include <time.h>
*************** atoi(*tzname);
*** 2268,2272 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2271: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    ac_cv_var_tzname=yes
--- 2277,2281 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2280: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    ac_cv_var_tzname=yes
*************** if eval "test \"`echo '$''{'ac_cv_c_cons
*** 2294,2298 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 2297 "configure"
  #include "confdefs.h"
  
--- 2303,2307 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 2306 "configure"
  #include "confdefs.h"
  
*************** ccp = (char const *const *) p;
*** 2344,2348 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2347: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_c_const=yes
--- 2353,2357 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2356: \"$ac_compile\") 1>&5; (eval $ac_compile) 2>&5; }; then
    rm -rf conftest*
    ac_cv_c_const=yes
*************** if test "$ac_x_includes" = NO; then
*** 2494,2503 ****
    # First, try using that file with no special directory specified.
  cat > conftest.$ac_ext <<EOF
! #line 2497 "configure"
  #include "confdefs.h"
  #include <$x_direct_test_include>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:2502: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 2503,2512 ----
    # First, try using that file with no special directory specified.
  cat > conftest.$ac_ext <<EOF
! #line 2506 "configure"
  #include "confdefs.h"
  #include <$x_direct_test_include>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:2511: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
*************** if test "$ac_x_libraries" = NO; then
*** 2566,2570 ****
    LIBS="-l$x_direct_test_library $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2569 "configure"
  #include "confdefs.h"
  
--- 2575,2579 ----
    LIBS="-l$x_direct_test_library $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2578 "configure"
  #include "confdefs.h"
  
*************** ${x_direct_test_function}()
*** 2574,2578 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2577: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    LIBS="$ac_save_LIBS"
--- 2583,2587 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2586: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    LIBS="$ac_save_LIBS"
*************** else
*** 2873,2877 ****
  LIBS="-ldnet  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2876 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
--- 2882,2886 ----
  LIBS="-ldnet  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2885 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
*************** dnet_ntoa()
*** 2885,2889 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2888: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
--- 2894,2898 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2897: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
*************** else
*** 2918,2922 ****
  LIBS="-lXbsd  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2921 "configure"
  #include "confdefs.h"
  
--- 2927,2931 ----
  LIBS="-lXbsd  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2930 "configure"
  #include "confdefs.h"
  
*************** main()
*** 2926,2930 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2929: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
--- 2935,2939 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2938: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
*************** else
*** 2953,2957 ****
  LIBS="-lpthreads  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2956 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
--- 2962,2966 ----
  LIBS="-lpthreads  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 2965 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
*************** cma_open()
*** 2965,2969 ****
  ; return 0; }
  EOF
! if { (eval echo configure:2968: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
--- 2974,2978 ----
  ; return 0; }
  EOF
! if { (eval echo configure:2977: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
*************** if test "${HAVE_X11}" = "yes"; then
*** 3020,3024 ****
      echo $ac_n "checking whether X on GNU/Linux needs -b to link""... $ac_c" 1>&6
      cat > conftest.$ac_ext <<EOF
! #line 3023 "configure"
  #include "confdefs.h"
  
--- 3029,3033 ----
      echo $ac_n "checking whether X on GNU/Linux needs -b to link""... $ac_c" 1>&6
      cat > conftest.$ac_ext <<EOF
! #line 3032 "configure"
  #include "confdefs.h"
  
*************** XOpenDisplay ("foo");
*** 3028,3032 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3031: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    xlinux_first_failure=no
--- 3037,3041 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3040: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    xlinux_first_failure=no
*************** rm -f conftest*
*** 3047,3051 ****
        LIBS="$LIBS -b i486-linuxaout"
        cat > conftest.$ac_ext <<EOF
! #line 3050 "configure"
  #include "confdefs.h"
  
--- 3056,3060 ----
        LIBS="$LIBS -b i486-linuxaout"
        cat > conftest.$ac_ext <<EOF
! #line 3059 "configure"
  #include "confdefs.h"
  
*************** XOpenDisplay ("foo");
*** 3055,3059 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3058: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    xlinux_second_failure=no
--- 3064,3068 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3067: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    xlinux_second_failure=no
*************** if eval "test \"`echo '$''{'ac_cv_func_$
*** 3088,3092 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3091 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
--- 3097,3101 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3100 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
*************** $ac_func();
*** 3112,3116 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3115: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_$ac_func=yes"
--- 3121,3125 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3124: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_$ac_func=yes"
*************** if test "${window_system}" = "x11"; then
*** 3139,3143 ****
    echo $ac_n "checking X11 version 6""... $ac_c" 1>&6
    cat > conftest.$ac_ext <<EOF
! #line 3142 "configure"
  #include "confdefs.h"
  #include <X11/Xlib.h>
--- 3148,3152 ----
    echo $ac_n "checking X11 version 6""... $ac_c" 1>&6
    cat > conftest.$ac_ext <<EOF
! #line 3151 "configure"
  #include "confdefs.h"
  #include <X11/Xlib.h>
*************** fail;
*** 3150,3154 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3153: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""6 or newer" 1>&6
--- 3159,3163 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3162: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""6 or newer" 1>&6
*************** if test "${window_system}" = "x11"; then
*** 3168,3172 ****
    echo $ac_n "checking X11 version 5""... $ac_c" 1>&6
    cat > conftest.$ac_ext <<EOF
! #line 3171 "configure"
  #include "confdefs.h"
  #include <X11/Xlib.h>
--- 3177,3181 ----
    echo $ac_n "checking X11 version 5""... $ac_c" 1>&6
    cat > conftest.$ac_ext <<EOF
! #line 3180 "configure"
  #include "confdefs.h"
  #include <X11/Xlib.h>
*************** fail;
*** 3179,3183 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3182: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""5 or newer" 1>&6
--- 3188,3192 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3191: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""5 or newer" 1>&6
*************** if test x"${USE_X_TOOLKIT}" = xmaybe; th
*** 3201,3205 ****
      echo $ac_n "checking X11 version 5 with Xaw""... $ac_c" 1>&6
      cat > conftest.$ac_ext <<EOF
! #line 3204 "configure"
  #include "confdefs.h"
  
--- 3210,3214 ----
      echo $ac_n "checking X11 version 5 with Xaw""... $ac_c" 1>&6
      cat > conftest.$ac_ext <<EOF
! #line 3213 "configure"
  #include "confdefs.h"
  
*************** int t() {
*** 3211,3215 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3214: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""5 or newer" 1>&6
--- 3220,3224 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3223: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""5 or newer" 1>&6
*************** if test "${USE_X_TOOLKIT}" != "none"; th
*** 3232,3236 ****
    echo $ac_n "checking X11 toolkit version""... $ac_c" 1>&6
    cat > conftest.$ac_ext <<EOF
! #line 3235 "configure"
  #include "confdefs.h"
  #include <X11/Intrinsic.h>
--- 3241,3245 ----
    echo $ac_n "checking X11 toolkit version""... $ac_c" 1>&6
    cat > conftest.$ac_ext <<EOF
! #line 3244 "configure"
  #include "confdefs.h"
  #include <X11/Intrinsic.h>
*************** fail;
*** 3243,3247 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3246: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""6 or newer" 1>&6
--- 3252,3256 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3255: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""6 or newer" 1>&6
*************** else
*** 3273,3277 ****
  LIBS="-lXmu  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 3276 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
--- 3282,3286 ----
  LIBS="-lXmu  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 3285 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
*************** XmuConvertStandardSelection()
*** 3285,3289 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3288: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
--- 3294,3298 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3297: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
*************** fi
*** 3315,3319 ****
  echo $ac_n "checking whether netdb declares h_errno""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 3318 "configure"
  #include "confdefs.h"
  #include <netdb.h>
--- 3324,3328 ----
  echo $ac_n "checking whether netdb declares h_errno""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 3327 "configure"
  #include "confdefs.h"
  #include <netdb.h>
*************** return h_errno;
*** 3323,3327 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3326: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""yes" 1>&6
--- 3332,3336 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3335: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""yes" 1>&6
*************** if eval "test \"`echo '$''{'ac_cv_header
*** 3344,3348 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3347 "configure"
  #include "confdefs.h"
  #include <alloca.h>
--- 3353,3357 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3356 "configure"
  #include "confdefs.h"
  #include <alloca.h>
*************** char *p = alloca(2 * sizeof(int));
*** 3352,3356 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3355: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    ac_cv_header_alloca_h=yes
--- 3361,3365 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3364: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    ac_cv_header_alloca_h=yes
*************** if eval "test \"`echo '$''{'ac_cv_func_a
*** 3376,3380 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3379 "configure"
  #include "confdefs.h"
  
--- 3385,3389 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3388 "configure"
  #include "confdefs.h"
  
*************** char *p = (char *) alloca(1);
*** 3400,3404 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3403: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    ac_cv_func_alloca=yes
--- 3409,3413 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3412: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    ac_cv_func_alloca=yes
*************** if eval "test \"`echo '$''{'ac_cv_os_cra
*** 3435,3439 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3438 "configure"
  #include "confdefs.h"
  #if defined(CRAY) && ! defined(CRAY2)
--- 3444,3448 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3447 "configure"
  #include "confdefs.h"
  #if defined(CRAY) && ! defined(CRAY2)
*************** if eval "test \"`echo '$''{'ac_cv_func_$
*** 3464,3468 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3467 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
--- 3473,3477 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3476 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
*************** $ac_func();
*** 3488,3492 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3491: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_$ac_func=yes"
--- 3497,3501 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3500: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_$ac_func=yes"
*************** else
*** 3520,3524 ****
  else
  cat > conftest.$ac_ext <<EOF
! #line 3523 "configure"
  #include "confdefs.h"
  find_stack_direction ()
--- 3529,3533 ----
  else
  cat > conftest.$ac_ext <<EOF
! #line 3532 "configure"
  #include "confdefs.h"
  find_stack_direction ()
*************** main ()
*** 3539,3543 ****
  }
  EOF
! { (eval echo configure:3542: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    ac_cv_c_stack_direction=1
--- 3548,3552 ----
  }
  EOF
! { (eval echo configure:3551: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    ac_cv_c_stack_direction=1
*************** else
*** 3567,3571 ****
  LIBS="-lm  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 3570 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
--- 3576,3580 ----
  LIBS="-lm  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 3579 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
*************** sqrt()
*** 3579,3583 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3582: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
--- 3588,3592 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3591: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
*************** if eval "test \"`echo '$''{'ac_cv_func_$
*** 3613,3617 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3616 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
--- 3622,3626 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3625 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
*************** $ac_func();
*** 3637,3641 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3640: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_$ac_func=yes"
--- 3646,3650 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3649: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_$ac_func=yes"
*************** else
*** 3672,3676 ****
  LIBS="-lncurses  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 3675 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
--- 3681,3685 ----
  LIBS="-lncurses  $LIBS"
  cat > conftest.$ac_ext <<EOF
! #line 3684 "configure"
  #include "confdefs.h"
  /* Override any gcc2 internal prototype to avoid an error.  */
*************** tparm()
*** 3684,3688 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3687: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
--- 3693,3697 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3696: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_lib_$ac_lib_var=yes"
*************** emacs_cv_localtime_cache=yes
*** 3719,3723 ****
  else
  cat > conftest.$ac_ext <<EOF
! #line 3722 "configure"
  #include "confdefs.h"
  #include <time.h>
--- 3728,3732 ----
  else
  cat > conftest.$ac_ext <<EOF
! #line 3731 "configure"
  #include "confdefs.h"
  #include <time.h>
*************** unset_TZ ()
*** 3733,3746 ****
        to++;
  }
  main()
  {
    time_t now = time ((time_t *) 0);
    int hour_GMT0, hour_unset;
!   if (putenv ("TZ=GMT0") != 0)
      exit (1);
    hour_GMT0 = localtime (&now)->tm_hour;
    unset_TZ ();
    hour_unset = localtime (&now)->tm_hour;
!   if (putenv ("TZ=PST8") != 0)
      exit (1);
    if (localtime (&now)->tm_hour == hour_GMT0)
--- 3742,3757 ----
        to++;
  }
+ char TZ_GMT0[] = "TZ=GMT0";
+ char TZ_PST8[] = "TZ=PST8";
  main()
  {
    time_t now = time ((time_t *) 0);
    int hour_GMT0, hour_unset;
!   if (putenv (TZ_GMT0) != 0)
      exit (1);
    hour_GMT0 = localtime (&now)->tm_hour;
    unset_TZ ();
    hour_unset = localtime (&now)->tm_hour;
!   if (putenv (TZ_PST8) != 0)
      exit (1);
    if (localtime (&now)->tm_hour == hour_GMT0)
*************** main()
*** 3752,3756 ****
  }
  EOF
! { (eval echo configure:3755: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    emacs_cv_localtime_cache=no
--- 3763,3767 ----
  }
  EOF
! { (eval echo configure:3766: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }
  if test -s conftest && (./conftest; exit) 2>/dev/null; then
    emacs_cv_localtime_cache=no
*************** if test "x$HAVE_TIMEVAL" = xyes; then
*** 3777,3781 ****
  echo $ac_n "checking whether gettimeofday can't accept two arguments""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 3780 "configure"
  #include "confdefs.h"
  
--- 3788,3792 ----
  echo $ac_n "checking whether gettimeofday can't accept two arguments""... $ac_c" 1>&6
  cat > conftest.$ac_ext <<EOF
! #line 3791 "configure"
  #include "confdefs.h"
  
*************** int t() {
*** 3800,3804 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3803: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""no" 1>&6
--- 3811,3815 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3814: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    echo "$ac_t""no" 1>&6
*************** if eval "test \"`echo '$''{'ac_cv_func_s
*** 3821,3825 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3824 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
--- 3832,3836 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3835 "configure"
  #include "confdefs.h"
  /* System header to define __stub macros and hopefully few prototypes,
*************** socket();
*** 3845,3849 ****
  ; return 0; }
  EOF
! if { (eval echo configure:3848: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_socket=yes"
--- 3856,3860 ----
  ; return 0; }
  EOF
! if { (eval echo configure:3859: \"$ac_link\") 1>&5; (eval $ac_link) 2>&5; }; then
    rm -rf conftest*
    eval "ac_cv_func_socket=yes"
*************** if eval "test \"`echo '$''{'ac_cv_header
*** 3870,3879 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3873 "configure"
  #include "confdefs.h"
  #include <netinet/in.h>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:3878: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 3881,3890 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3884 "configure"
  #include "confdefs.h"
  #include <netinet/in.h>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:3889: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
*************** if eval "test \"`echo '$''{'ac_cv_header
*** 3903,3912 ****
  else
    cat > conftest.$ac_ext <<EOF
! #line 3906 "configure"
  #include "confdefs.h"
  #include <arpa/inet.h>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:3911: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
--- 3914,3923 ----
  else
    cat > conftest.$ac_ext <<EOF
! #line 3917 "configure"
  #include "confdefs.h"
  #include <arpa/inet.h>
  EOF
  ac_try="$ac_cpp conftest.$ac_ext >/dev/null 2>conftest.out"
! { (eval echo configure:3922: \"$ac_try\") 1>&5; (eval $ac_try) 2>&5; }
  ac_err=`grep -v '^ *+' conftest.out`
  if test -z "$ac_err"; then
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/configure.in emacs-19.33/configure.in
*** emacs-19.32/configure.in	Wed Jul 31 13:52:38 1996
--- emacs-19.33/configure.in	Sat Aug 10 14:51:08 1996
*************** case "${canonical}" in
*** 190,193 ****
--- 190,196 ----
    alpha-dec-osf* )
      machine=alpha opsys=osf1
+     # This is needed to find X11R6.1 libraries for certain tests.
+     NON_GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
+     GCC_TEST_OPTIONS=-Wl,-rpath,/usr/X11R6/lib
    ;;
  
*************** case "${canonical}" in
*** 511,514 ****
--- 514,523 ----
    ;;
  
+   ## Sequent Symmetry running ptx 4, which is a modified SVR4.
+   i[3456]86-sequent-ptx4* | i[3456]86-sequent-sysv4* )
+     machine=sequent-ptx opsys=ptx4
+     NON_GNU_CPP=/lib/cpp
+   ;;
+ 
    ## Sequent Symmetry running DYNIX/ptx
    ## Use the old cpp rather than the newer ANSI one.
*************** case "${canonical}" in
*** 709,716 ****
        i[3456]86-*-sunos4	  ) opsys=sunos4-0 ;;
        *-sunos4.0*	  ) opsys=sunos4-0 ;;
-       *-sunos4.1.[3-9]* | *-sunos4shr*)
- 		opsys=sunos4shr
- 		NON_GNU_CPP=/usr/lib/cpp
- 		;;
        *-sunos4.1.[3-9]*noshare )
  		opsys=sunos4-1-3
--- 718,721 ----
*************** case "${canonical}" in
*** 719,722 ****
--- 724,731 ----
  		GCC_TEST_OPTIONS=-static
  		;;
+       *-sunos4.1.[3-9]* | *-sunos4shr*)
+ 		opsys=sunos4shr
+ 		NON_GNU_CPP=/usr/lib/cpp
+ 		;;
        *-sunos4* | *-sunos )
  		opsys=sunos4-1
*************** unset_TZ ()
*** 1439,1452 ****
        to++;
  }
  main()
  {
    time_t now = time ((time_t *) 0);
    int hour_GMT0, hour_unset;
!   if (putenv ("TZ=GMT0") != 0)
      exit (1);
    hour_GMT0 = localtime (&now)->tm_hour;
    unset_TZ ();
    hour_unset = localtime (&now)->tm_hour;
!   if (putenv ("TZ=PST8") != 0)
      exit (1);
    if (localtime (&now)->tm_hour == hour_GMT0)
--- 1448,1463 ----
        to++;
  }
+ char TZ_GMT0[] = "TZ=GMT0";
+ char TZ_PST8[] = "TZ=PST8";
  main()
  {
    time_t now = time ((time_t *) 0);
    int hour_GMT0, hour_unset;
!   if (putenv (TZ_GMT0) != 0)
      exit (1);
    hour_GMT0 = localtime (&now)->tm_hour;
    unset_TZ ();
    hour_unset = localtime (&now)->tm_hour;
!   if (putenv (TZ_PST8) != 0)
      exit (1);
    if (localtime (&now)->tm_hour == hour_GMT0)
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/ChangeLog emacs-19.33/etc/ChangeLog
*** emacs-19.32/etc/ChangeLog	Wed Jul 31 15:11:06 1996
--- emacs-19.33/etc/ChangeLog	Sun Aug 11 03:40:09 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/MACHINES emacs-19.33/etc/MACHINES
*** emacs-19.32/etc/MACHINES	Thu Jul 11 20:34:25 1996
--- emacs-19.33/etc/MACHINES	Thu Aug  8 23:02:09 1996
*************** Alliant FX/2800 (i860-alliant-bsd)
*** 69,73 ****
    Known to work with 19.26 and OS version 2.2, compiler version 1.3.
  
! Alpha (DEC) running OSF/1 (alpha-dec-osf1, alpha-dec-lignux)
  
    Patches merged in 19.29.  Note that the X11 libraries on GNU/Linux systems
--- 69,73 ----
    Known to work with 19.26 and OS version 2.2, compiler version 1.3.
  
! Alpha (DEC) running OSF/1 (alpha-dec-osf1, alpha-dec-linux-gnu)
  
    Patches merged in 19.29.  Note that the X11 libraries on GNU/Linux systems
*************** Honeywell XPS100 (xps100-honeywell-sysv)
*** 349,357 ****
    Config file added in version 19.
  
! Hewlett-Packard 9000 series 200 or 300 (m68k-hp-bsd or m68k-hp-hpux7.)
! 
!   Version 19 works under BSD.  The 19.26 pretest was reported
!   to work on HPUX 9.  19.31 works on HPUX 10.01, but there are
!   some problems on 10.10 which have not been resolved.
  
    These machines are 68000-series CPUs running HP/UX
--- 349,354 ----
    Config file added in version 19.
  
! Hewlett-Packard 9000 series 200 or 300 (m68k-hp-bsd or m68k-hp-hpux
! 				        or m68k-hp-netbsd)
  
    These machines are 68000-series CPUs running HP/UX
*************** Hewlett-Packard 9000 series 200 or 300 (
*** 361,364 ****
--- 358,370 ----
    Series 200 HPUX runs Emacs only if it has the "HP/UX upgrade".
  
+   Version 19 works under BSD.  The 19.26 pretest was reported
+   to work on HPUX 9.  19.31 works on HPUX 10.01, but there are
+   some problems on 10.10 which have not been resolved.
+ 
+   On HPUX 9, Emacs sometimes crashes with SIGBUS or SIGSEGV after you
+   delete a frame.  We think this is due to a bug in the X libraries
+   provided by HP.  With the alternative X libraries in
+   /usr/contrib/mitX11R5/lib, the problem does not happen.
+ 
    If you are running HP/UX release 8.0 or later, you need the optional
    "C/ANSI C" software in order to build Emacs (older releases of HP/UX
*************** Integrated Solutions `Optimum V' (m68k-i
*** 533,538 ****
  
  Intel 386 (i386-*-isc, 		i386-*-esix,	 i386-*-bsdi2,
! 	   i386-*-xenix,	i386-*-lignux,    i386-*-freebsd,
! 	   i386-*-sol2.4,	i386-intsys-sysv, i386-*-sysv3,
  	   i386-*-sysv4,	i386-*-sysv4.2,
  	   i386-*-sysv5.3,	i386-*-bsd4.2,
--- 539,544 ----
  
  Intel 386 (i386-*-isc, 		i386-*-esix,	 i386-*-bsdi2,
! 	   i386-*-xenix,	i386-*-freebsd,  i386-*-linux-gnu,
! 	   i386-*-sol2.4,	i386-*-sysv3,    i386-intsys-sysv,
  	   i386-*-sysv4,	i386-*-sysv4.2,
  	   i386-*-sysv5.3,	i386-*-bsd4.2,
*************** Intel 386 (i386-*-isc, 		i386-*-esix,	 i
*** 549,553 ****
  	i386-unknown-isc3.0 as your configuration name.
    Use i386-*-esix for Esix; Emacs runs as of version 19.6.
!   Use i386-*-lignux for GNU/Linux systems; Emacs runs as of version 19.26.
    Use i386-intsys-sysv for Integrated Solutions 386 machines.
    It may also be correct for Microport systems.
--- 555,559 ----
  	i386-unknown-isc3.0 as your configuration name.
    Use i386-*-esix for Esix; Emacs runs as of version 19.6.
!   Use i386-*-linux-gnu for GNU/Linux systems; Emacs runs as of version 19.26.
    Use i386-intsys-sysv for Integrated Solutions 386 machines.
    It may also be correct for Microport systems.
*************** Sequent Balance (ns32k-sequent-bsd4.2 or
*** 833,837 ****
    versions.
  
! Sequent Symmetry (i386-sequent-bsd, i386-sequent-ptx)
  
    Emacs 19 should work on Dynix (BSD).  However, if you compile with
--- 839,845 ----
    versions.
  
! Sequent Symmetry (i386-sequent-bsd, i386-sequent-ptx, i386-sequent-ptx4)
! 
!   19.33 has changes to support ptx 4 (a modified SVR4).
  
    Emacs 19 should work on Dynix (BSD).  However, if you compile with
*************** Sequent Symmetry (i386-sequent-bsd, i386
*** 842,852 ****
    DYNIX/ptx 1.4 and 2.1 with the native cc compiler.
  
!   Gcc can't compile src/process.c due to a non-standard Sequent asm
    keyword extension supported by cc and used for the network byte/word
!   swapping functions in the PTX /usr/include/netinet/in.h file.  Gcc
    2.5.8 includes the file <sys/byteorder.h> which can be included into
    netinet/in.h to perform these byte/word swapping functions in the
!   same manner.  Patches have been submitted to the FSF against gcc
!   2.6.0 to fix this problem and allow Emacs to be built with gcc.
  
    If your machine does not have TCP/IP installed, you will have to edit the
--- 850,860 ----
    DYNIX/ptx 1.4 and 2.1 with the native cc compiler.
  
!   GCC can't compile src/process.c due to a non-standard Sequent asm
    keyword extension supported by cc and used for the network byte/word
!   swapping functions in the PTX /usr/include/netinet/in.h file.  GCC
    2.5.8 includes the file <sys/byteorder.h> which can be included into
    netinet/in.h to perform these byte/word swapping functions in the
!   same manner.  Patches have been submitted to the FSF against GCC
!   2.6.0 to fix this problem and allow Emacs to be built with GCC.
  
    If your machine does not have TCP/IP installed, you will have to edit the
*************** Stride (m68k-stride-sysv)
*** 896,906 ****
  
  Sun 3, Sun 4 (sparc), Sun 386 (m68k-sun-sunos, sparc-sun-sunos, i386-sun-sunos,
! 			       sparc-sun-sunos4shr, sparc-sun-solaris2.*,
  			       i386-sun-solaris2.*)
! 
!   19.26 is believed to work on Sparcs and Sun 3's.  Some people report
!   that Emacs crashes immediately on startup when used with a non-X
!   terminal, but we think this is due to compiling with GCC and failing
!   to use GCC's "fixed" system header files.
  
    Some Sun versions of X windows use the clipboard, not the selections,
--- 904,920 ----
  
  Sun 3, Sun 4 (sparc), Sun 386 (m68k-sun-sunos, sparc-sun-sunos, i386-sun-sunos,
! 			       sparc-sun-sunos4.1.3noshr, sparc-sun-solaris2.*,
  			       i386-sun-solaris2.*)
!   
!   19.32 works on Solaris 2.4 and 2.5.  It works ok Sunos 4.1.x
!   provided you completely replace your C shared library
!   using one of the SunOS 4.1.x jumbo replacement patches from Sun.
!   Here are the patch numbers for Sunos 4.1.3:
!    100890-10   SunOS 4.1.3: domestic libc jumbo patch
!    100891-10   SunOS 4.1.3: international libc jumbo patch
! 
!   Some people report that Emacs crashes immediately on startup when
!   used with a non-X terminal, but we think this is due to compiling
!   with GCC and failing to use GCC's "fixed" system header files.
  
    Some Sun versions of X windows use the clipboard, not the selections,
*************** Esix
*** 1117,1127 ****
    LD_LIBRARY_PATH.  Then define C_SWITCH_X_SYSTEM -I/usr/X386/include.
  
! Lignux
  
    Most of the complete systems which use the Linux kernel are close
!   enough to the GNU system that could be considered variants of the
!   GNU system.  We use the term "Lignux" to refer to this combination
!   of the Linux kernel with the GNU system: they are "Linux-based GNU
!   systems," or "Lignux" for short.
  
    It is not coincidence that many of the other components used with
--- 1131,1139 ----
    LD_LIBRARY_PATH.  Then define C_SWITCH_X_SYSTEM -I/usr/X386/include.
  
! Linux (actually GNU/Linux)
  
    Most of the complete systems which use the Linux kernel are close
!   enough to the GNU system to be considered variant GNU systems.  We
!   call them "Linux-based GNU systems," or GNU/Linux for short.
  
    It is not coincidence that many of the other components used with
*************** Lignux
*** 1132,1136 ****
    redistributable software from some other source.
  
!   The GNU project wants users of Lignux systems to be aware of how
    these systems relate to the GNU project, because that will help
    spread the GNU idea that software should be free--and thus encourage
--- 1144,1148 ----
    redistributable software from some other source.
  
!   The GNU project wants users of GNU/Linux systems to be aware of how
    these systems relate to the GNU project, because that will help
    spread the GNU idea that software should be free--and thus encourage
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/MAILINGLISTS emacs-19.33/etc/MAILINGLISTS
*** emacs-19.32/etc/MAILINGLISTS	Wed Jun 19 23:27:01 1996
--- emacs-19.33/etc/MAILINGLISTS	Mon Aug 12 12:12:11 1996
*************** people.  Please don't send them anything
*** 43,47 ****
  to all their readers.  All GNU mailing lists are unmoderated, mail
  reflectors, except info-gnu, info-gnu-emacs, info-gcc, info-g++,
! info-gnu-fortran, info-gnu-utils, info-gnu-chess and info-gnu-shogi.
  
  All addresses below are in internet format.  Consult the mail guru for
--- 43,47 ----
  to all their readers.  All GNU mailing lists are unmoderated, mail
  reflectors, except info-gnu, info-gnu-emacs, info-gcc, info-g++,
! info-gnu-fortran, info-gnu-chess and info-gnu-shogi.
  
  All addresses below are in internet format.  Consult the mail guru for
*************** appropriate mailing list or gnUSENET new
*** 251,267 ****
  people read those.
  
! * hurd-ann-request@prep.ai.mit.edu to subscribe to hurd-ann
! ** gnUSENET newsgroup: gnu.hurd.announce
! ** Send announcements to: hurd-ann@prep.ai.mit.edu
! 
! This list distributes progress reports on the GNU Hurd.  It is also to
! ask people for various kinds of help on the Hurd.  It is NOT for general
! discussion.
  
! The list is filtered to remove items meant for hurd-ann-request, that
! can be answered by the moderator without bothering the list, or should
! have been sent to another list.
  
! See section '* General Information about info-* lists'.
  
  * bug-gnu-emacs-request@prep.ai.mit.edu to subscribe to bug-gnu-emacs
--- 251,285 ----
  people read those.
  
! * bug-hurd-request@prep.ai.mit.edu to subscribe to bug-hurd
! ** gnUSENET newsgroup: gnu.hurd.bug
! ** Hurd bug reports to: bug-hurd@prep.ai.mit.edu
  
! This list distributes bug reports for, fixes for bugs in, and
! suggestions for improvements in the GNU Hurd to its active developers.
  
! No info-gnu-hurd list is planned.  Announcements about the GNU Hurd will
! be made to the list info-gnu@prep.ai.mit.edu (see above).
! 
! See section '* General Information about bug-* lists and reporting
! program bugs'.
! 
! * help-hurd-request@prep.ai.mit.edu to subscribe to help-hurd
! ** gnUSENET newsgroup: gnu.hurd.help
! ** Send contributions to: help-hurd@prep.ai.mit.edu
! 
! This list is the place for users and installers of the GNU Hurd to ask
! for help.
! 
! No info-gnu-hurd list is planned.  Announcements about the GNU Hurd will
! be made to the list info-gnu@prep.ai.mit.edu (see above).
! 
! See section '* General Information about help-* lists'.
! 
! * hurd-ann-request@prep.ai.mit.edu IS NOW DEFUNCT
! ** gnUSENET newsgroup: NEVER EXISTED
! ** DEAD address: hurd-ann@prep.ai.mit.edu
! 
! This list is dead.  Announcements about the GNU Hurd will be made to the
! list info-gnu@prep.ai.mit.edu (see above).
  
  * bug-gnu-emacs-request@prep.ai.mit.edu to subscribe to bug-gnu-emacs
*************** reports and fixes for, and suggestions f
*** 746,751 ****
  not covered by other bug-* mailing lists/gnu.*.bug newsgroups.
  
- Subscribers to bug-gnu-utils get all info-gnu-utils messages.
- 
  See section '* General Information about bug-* lists and reporting
  program bugs'.
--- 764,767 ----
*************** bug-gnu-utils@prep.ai.mit.edu instead.
*** 763,779 ****
  See section '* General Information about help-* lists'.
  
! * info-gnu-utils-request@prep.ai.mit.edu to subscribe to info-gnu-utils
! ** gnUSENET newsgroup: gnu.utils.announce
! ** Send announcements to: info-gnu-utils@prep.ai.mit.edu
! 
! This list distributes announcements and progress reports on GNU programs
! not covered by other GNU mailing lists/gnu.* newsgroups.  It is NOT for
! general discussion; please use help-gnu-utils for that.
  
! The list is filtered to remove items meant for info-gnu-utils-request,
! that can be answered by the moderator without bothering the list, or
! should have been sent to another list.
! 
! See section '* General Information about info-* lists'.
  
  * info-cvs-request@prep.ai.mit.edu to subscribe to info-cvs.
--- 779,788 ----
  See section '* General Information about help-* lists'.
  
! * info-gnu-utils-request@prep.ai.mit.edu IS NOW DEFUNCT
! ** a gnUSENET newsgroup bever existed
! ** DEAD address: info-gnu-utils@prep.ai.mit.edu
  
! This list is dead.  Announcements about GNU Utilities will be made to the
! list info-gnu@prep.ai.mit.edu (see above).
  
  * info-cvs-request@prep.ai.mit.edu to subscribe to info-cvs.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/NEWS emacs-19.33/etc/NEWS
*** emacs-19.32/etc/NEWS	Thu Aug  1 00:58:41 1996
--- emacs-19.33/etc/NEWS	Wed Aug  7 15:50:15 1996
*************** Please send Emacs bug reports to bug-gnu
*** 6,9 ****
--- 6,18 ----
  For older news, see the file ONEWS.
  
+ * Changes in Emacs 19.33.
+ 
+ ** Bibtex mode no longer turns on Auto Fill automatically.  (No major
+ mode should do that--it is the user's choice.)
+ 
+ ** The variable normal-auto-fill-function specifies the function to
+ use for auto-fill-functyion, if and when Auto Fill is turned on.
+ Major modes can set this locally to alter how Auto Fill works.
+ 
  * Editing Changes in Emacs 19.32
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/ORDERS emacs-19.33/etc/ORDERS
*** emacs-19.32/etc/ORDERS	Tue May 21 21:25:51 1996
--- emacs-19.33/etc/ORDERS	Fri Aug  9 09:02:42 1996
***************
*** 1,5 ****
  The actual order form follows the descriptions of media contents.
  
! Most of this file is excerpted from the January 1996 GNU's Bulletin.
  
  Please send suggestions for improvements to gnu@prep.ai.mit.edu or the postal
--- 1,5 ----
  The actual order form follows the descriptions of media contents.
  
! Most of this file is excerpted from the July 1996 GNU's Bulletin.
  
  Please send suggestions for improvements to gnu@prep.ai.mit.edu or the postal
*************** Boston, MA   02111-1307	  USA		Electroni
*** 24,28 ****
  There are some sections (e.g. ``Forthcoming GNUs'' and ``How to Get GNU
  Software'') which are not in this Order Form file.  If you wish to see them,
! ask gnu@prep.ai.mit.edu for the complete June, 1995 GNU's Bulletin.
  
  
--- 24,28 ----
  There are some sections (e.g. ``Forthcoming GNUs'' and ``How to Get GNU
  Software'') which are not in this Order Form file.  If you wish to see them,
! ask gnu@prep.ai.mit.edu for the complete July, 1996 GNU's Bulletin.
  
  
*************** Table of Contents
*** 39,51 ****
  	GNU Documentation
  	GNU Software
  	Program/Package Cross Reference
- 	Tapes
- 	   Languages Tape
- 	   Lisps and Emacs Tape
- 	   Utilities Tape
- 	   Scheme Tape
- 	   X11 Tapes
- 	   Berkeley 4.4BSD-Lite Tape
- 	   VMS Emacs and VMS Compiler Tapes
  	CD-ROMs
  	   Pricing of the GNU CD-ROMs
--- 39,44 ----
  	GNU Documentation
  	GNU Software
+ 
  	Program/Package Cross Reference
  	CD-ROMs
  	   Pricing of the GNU CD-ROMs
*************** Table of Contents
*** 54,69 ****
  	   December 1993 Compiler Tools Binaries CD-ROM
  	   Source Code CD-ROMs
  	      December 1995 Source Code CD-ROMs
  	      June 1995 Source Code CD-ROM
  	      May 1994 Source Code CD-ROM
  	      November 1993 Source Code CD-ROM
! 	   MS-DOS Book with CD-ROM
! 	   Debian GNU/Linux Book with CD-ROM
! 	MS-DOS Diskettes
! 	   DJGPP Diskettes
! 	   Emacs Diskettes
! 	   Selected Utilities Diskettes
! 	   Windows Diskette
! 	Tape & CD-ROM Subscription Service
  	FSF T-shirt
  	Free Software Foundation Order Form
--- 47,56 ----
  	   December 1993 Compiler Tools Binaries CD-ROM
  	   Source Code CD-ROMs
+ 	      July 1996 Source Code CD-ROMs
  	      December 1995 Source Code CD-ROMs
  	      June 1995 Source Code CD-ROM
  	      May 1994 Source Code CD-ROM
  	      November 1993 Source Code CD-ROM
! 	CD-ROM Subscription Service
  	FSF T-shirt
  	Free Software Foundation Order Form
*************** Donations Translate Into Free Software
*** 77,238 ****
  **************************************
  
! If you appreciate Emacs, GNU CC, Ghostscript, and other free software, you
! may wish to help us make sure there is more in the future--remember,
! *donations translate into more free software!*
! 
! Your donation to us is tax-deductible in the United States.  We gladly accept
! *any* currency, although the U.S. dollar is the most convenient.
! 
! If your employer has a matching gifts program for charitable donations,
! please arrange to: add the FSF to the list of organizations for your
! employer's matching gifts program; and have your donation matched (note *Note
! Cygnus Matches Donations!::).  If you do not know, please ask your personnel
! department.
! 
! Circle amount you are donating, cut out this form, and send it with your
! donation to:
! 
! 	Free Software Foundation, Inc.
! 	59 Temple Place - Suite 330
! 	Boston, MA  02111-1307
! 	USA
! 
! 
! 	$500	 $250	  $100	   $50	   Other $________
! 
! 	Other currency:________
  
  
  You can charge a donation to any of Carte Blanche, Diner's Club, JCB,
! MasterCard, Visa, or American Express.	Charges may also be faxed to
  +1-617-542-2652.
  
! 	Card type: __________________  Expiration Date: _____________
! 
! 	Account Number: _____________________________________________
! 
! 	Cardholder's Signature: _____________________________________
! 
! 	Name: _______________________________________________________
! 
! 	Street Address: _____________________________________________
! 
! 	City/State/Province: ________________________________________
! 
! 	Zip Code/Postal Code/Country: _______________________________
! 
  
  
  Cygnus Matches Donations!
  *************************
  
! To encourage cash donations to the Free Software Foundation, Cygnus Support
! will continue to contribute corporate funds to the FSF to accompany gifts by
! its employees, and by its customers and their employees.
! 
! Donations payable to the Free Software Foundation should be sent by eligible
! persons to Cygnus Support, which will add its gifts and forward the total to
! the FSF each quarter.  The FSF will provide the contributor with a receipt to
! recognize the contribution (which is tax-deductible on U.S.  tax returns).
! For more information, please contact Cygnus:
! 
! 	Cygnus Support
! 	1937 Landings Drive
! 	Mountain View, CA   94043
! 	USA
! 
! 	Telephone: 415-903-1400
! 		   +1-800-Cygnus1 (-294-6871)
! 	Fax:	   415-903-0122
! 	Electronic-Mail: `info@cygnus.com'
! 	FTP: `ftp.cygnus.com'
! 	WWW: `http://www.cygnus.com/'
! 
  
  
  Free Software Redistributors Donate
  ***********************************
  
! The SNOW 2.1 CD producers added the words "Includes $5 donation to the FSF"
! to the front of their CD.  Potential buyers will know just how much of the
! price is for the FSF & how much is for the redistributor.
! 
! The Sun Users Group Deutschland & ASCII Corporation (Japan) have added
! donations to the FSF to the price of their next GNU software CD-ROMs.
! 
! Austin Code Works, a free software redistributor, supports free software
! development by giving the FSF 20% of the selling price for the GNU software
! CDs they produce & sell.
! 
! Walnut Creek CDROM & Info Magic, free software redistributors, are also
! giving us part of their selling price.
! 
! TOHDO-SHA is donating 400 yen to the FSF for each copy of `The GNU Emacs Lisp
! Reference Manual, Japanese Edition' sold at bookstores in Japan.
! 
! CQ Publishing made a large donation from the sales of their GAWK book in
! Japanese.
! 
! In the long run, the success of free software depends on how much new free
! software people develop.  Free software distribution offers an opportunity to
! raise funds for such development in an ethical way.  These redistributors
! have made use of the opportunity.  Many others let it go to waste.
! 
! You can help promote free software development by convincing for-a-fee
! redistributors to contribute--either by doing development themselves or by
! donating to development organizations (the FSF and others).
! 
! The way to convince distributors to contribute is to demand and expect this
! of them.  This means choosing among distributors partly by how much they give
! to free software development.  Then you can show distributors they must
! compete to be the one who gives the most.
! 
! To make this work, you must insist on numbers that you can compare, such as,
! "We will give ten dollars to the Foobar project for each disk sold." A vague
! commitment, such as "A portion of the profits is donated," doesn't give you a
! basis for comparison.  Even a precise fraction "of the profits from this
! disk" is not very meaningful, since creative accounting and unrelated
! business decisions can greatly alter what fraction of the sales price counts
! as profit.
! 
! Also, press developers for firm information about what kind of development
! they do or support.  Some kinds make much more long-term difference than
! others.	 For example, maintaining a separate version of a GNU program
! contributes very little; maintaining a program on behalf of the GNU Project
! contributes much.  Easy new ports contribute little, since someone else would
! surely do them; difficult ports such as adding a new CPU to the GNU compiler
! or Mach contribute more; major new features and programs contribute the most.
! 
! By establishing the idea that supporting further development is "the proper
! thing to do" when distributing free software for a fee, we can assure a
! steady flow of resources for making more free software.
! 
  
  
  Help from Free Software Companies
  *********************************
  
! When choosing a free software business, ask those you are considering how
! much they do to assist free software development, e.g., by contributing money
! to free software development or by writing free software improvements
! themselves for general use.  By basing your decision partially on this
! factor, you can help encourage those who profit from free software to
! contribute to its growth.
! 
! Wingnut (SRA's special GNU support group) regularly donates a part of its
! income to the FSF to support the development of new GNU programs.  Listing
! them here is our way of thanking them.	Wingnut has made a pledge to donate
! 10% of their income to the FSF, and has purchased several Deluxe Distribution
! packages in Japan.  Also see *Note Cygnus Matches Donations!::.
! 
! 	Wingnut Project
! 	Software Research Associates, Inc.
! 	1-1-1 Hirakawa-cho, Chiyoda-ku
! 	Tokyo 102, Japan
! 
! 	Phone:	(+81-3)3234-2611
! 	Fax:	(+81-3)3942-5174
! 	E-mail: `info-wingnut@sra.co.jp'
! 	WWW: `http://www.sra.co.jp/public/sra/product/wingnut/'
  
  
--- 64,238 ----
  **************************************
  
!    If you appreciate Emacs, GNU CC, Ghostscript, and other free
! software, you may wish to help us make sure there is more in the
! future--remember, *donations translate into more free software!*
! 
!    Your donation to us is tax-deductible in the United States.  We
! gladly accept *any* currency, although the U.S. dollar is the most
! convenient.
! 
!    If your employer has a matching gifts program for charitable
! donations, please arrange to: add the FSF to the list of organizations
! for your employer's matching gifts program; and have your donation
! matched (note *Note Cygnus Matches Donations!::).  If you do not know,
! please ask your personnel department.
! 
!    Circle amount you are donating, cut out this form, and send it with
! your donation to:
! 
!     
! 
!         Free Software Foundation, Inc.
!         59 Temple Place - Suite 330
!         Boston, MA  02111-1307
!         USA
  
+       $500   $250   $100   $50   Other $_____  Other currency:_____
  
  You can charge a donation to any of Carte Blanche, Diner's Club, JCB,
! MasterCard, Visa, or American Express.  Charges may also be faxed to
  +1-617-542-2652.
  
!       Card type: __________________  Expiration Date: _____________
!      
!       Account Number: _____________________________________________
!      
!       Cardholder's Signature: _____________________________________
!      
!       Name: _______________________________________________________
!      
!       Street Address: _____________________________________________
!      
!       City/State/Province: ________________________________________
!      
!       Zip Code/Postal Code/Country: _______________________________
!      
!       Telephone Number: ___________________________________________
!      
!       Email Address: ______________________________________________
  
+     
  
  Cygnus Matches Donations!
  *************************
  
!    To encourage cash donations to the Free Software Foundation, Cygnus
! Support will continue to contribute corporate funds to the FSF to
! accompany gifts by its employees, and by its customers and their
! employees.
! 
!    Donations payable to the Free Software Foundation should be sent by
! eligible persons to Cygnus Support, which will add its gifts and
! forward the total to the FSF each quarter.  The FSF will provide the
! contributor with a receipt to recognize the contribution (which is
! tax-deductible on U.S.  tax returns).  To see if your employer is a
! Cygnus customer, or for more information, please contact Cygnus:
! 
!         Cygnus Support
!         1937 Landings Drive
!         Mountain View, CA   94043
!         USA
!      
!         Telephone: 415-903-1400
!                    +1-800-Cygnus1 (-294-6871)
!         Fax:       415-903-0122
!         Electronic-Mail: `info@cygnus.com'
!         FTP: `ftp.cygnus.com'
!         World Wide Web: `http://www.cygnus.com/'
  
+     
  
  Free Software Redistributors Donate
  ***********************************
  
!    The SNOW 2.1 CD producers added the words "Includes $5 donation to
! the FSF" to the front of their CD.  Potential buyers will know just how
! much of the price is for the FSF & how much is for the redistributor.
! 
!    The Sun Users Group Deutschland has made it even clearer: their CD
! says, "Price 90 DM, + 12 DM donation to the FSF."
! 
!    ASCII Corporation (Japan) has also donated to the FSF and plans to
! add a donation to the price of their next GNU software CD-ROM.
! 
!    Austin Code Works, a free software redistributor, supports free
! software development by giving the FSF 20% of the selling price for the
! GNU software CDs they produce & sell.
! 
!    TOHDO-SHA is donating 400 yen to the FSF for each copy of `The GNU
! Emacs Lisp Reference Manual, Japanese Edition' sold at bookstores in
! Japan.
! 
!    CQ Publishing made a large donation from the sales of their GAWK
! book in Japanese, and Specialized Systems Consultants, Inc. is donating
! 3% of the profits from selling "Effective AWK Programming", by Arnold
! Robbins.  Walnut Creek CDROM gives us part of their selling price every
! month.
! 
!    In the long run, the success of free software depends on how much
! new free software people develop.  Free software distribution offers an
! opportunity to raise funds for such development in an ethical way.
! These redistributors have made use of the opportunity.  Many others let
! it go to waste.
! 
!    You can help promote free software development by convincing
! for-a-fee redistributors to contribute--either by doing development
! themselves or by donating to development organizations (the FSF and
! others).
! 
!    The way to convince distributors to contribute is to demand and
! expect this of them.  This means choosing among distributors partly by
! how much they give to free software development.  Then you can show
! distributors they must compete to be the one who gives the most.
! 
!    To make this work, you must insist on numbers that you can compare,
! such as, "We will give ten dollars to the Foobar project for each disk
! sold." A vague commitment, such as "A portion of the profits is
! donated," doesn't give you a basis for comparison.  Even a precise
! fraction "of the profits from this disk" is not very meaningful, since
! creative accounting and unrelated business decisions can greatly alter
! what fraction of the sales price counts as profit.
! 
!    Also, press developers for firm information about what kind of
! development they do or support.  Some kinds make much more long-term
! difference than others.  For example, maintaining a separate version of
! a GNU program contributes very little; maintaining a program on behalf
! of the GNU Project contributes much.  Easy new ports contribute little,
! since someone else would surely do them; difficult ports such as adding
! a new CPU to the GNU compiler or Mach contribute more; major new
! features & programs contribute the most.
! 
!    By establishing the idea that supporting further development is "the
! proper thing to do" when distributing free software for a fee, we can
! assure a steady flow of resources for making more free software.
  
+     
  
  Help from Free Software Companies
  *********************************
  
!    When choosing a free software business, ask those you are considering
! how much they do to assist free software development, e.g., by
! contributing money to free software development or by writing free
! software improvements themselves for general use.  By basing your
! decision partially on this factor, you can help encourage those who
! profit from free software to contribute to its growth.
! 
!    Wingnut (SRA's special GNU support group) regularly donates a part
! of its income to the FSF to support the development of new GNU
! programs.  Listing them here is our way of thanking them.  Wingnut has
! made a pledge to donate 10% of their income to the FSF, and has
! purchased several Deluxe Distribution packages in Japan.  Also see
! *Note Cygnus Matches Donations!::.
! 
!         Wingnut Project
!         Software Research Associates, Inc.
!         1-1-1 Hirakawa-cho, Chiyoda-ku
!         Tokyo 102, Japan
!      
!         Phone:  (+81-3)3234-2611
!         Fax:    (+81-3)3942-5174
!         E-mail: `info-wingnut@sra.co.jp'
!         WWW: `http://www.sra.co.jp/public/sra/product/wingnut/'
  
  
*************** Major Changes in GNU Software and Docume
*** 241,474 ****
  ***********************************************
  
!    * A New FSF T-shirt!	  (*Note FSF T-shirt::)
  
!      We have a new T-shirt.  This design was inspired by the cover of the
!      `GNU Emacs Lisp Reference Manual'.
  
!    * GNU Emacs 19.30   (*Note GNU Software::)
  
!      We have just released Emacs 19.30.	 New features include support for menu
!      bars on text-only terminals, a total rewrite of GNUS, multiple frames on
!      Windows NT and Windows 95, & many others.
! 
!    * New Programs on the Tapes	 (*Note GNU Software::)
! 
!      `gettext' is now on the *Note Languages Tape::.  Termutils & Midnight
!      Commander have been added to the *Note Utilities Tape::.  CLX has been
!      added to the *Note Lisps/Emacs Tape::.  Newer versions of many of our
!      programs & manuals have been placed on all the media we distribute.
! 
!    * New Source Code CD!
! 
!      We have just released the December 1995 Source Code CD-ROMs (Edition 7).
!      Due to increasing amounts of GNU Software, the Source Code CD is now a
!      two disc set--the price remains unchanged!	 The new programs included
!      are: apache, CLX, Elisp archive, `ffcall', `gettext', GN, Gnans,
!      `gnuserv', Hyperbole, Midnight Commander, Oaklisp, SIPP, SNePS, Spinner,
!      W3, and `xgrabsc'.	 *Note GNU Software::, for more information about
!      these packages.  Also on the CD-ROMs are full distributions of MIT X11R6
!      (both our Required & Optional distributions), MIT Scheme 7.3, Emacs
!      19.30, GCC 2.7.1, and current versions of all other GNU Software.	For
!      more information, see *Note December 1995 Source Code CD-ROMs::.
! 
!    * New Compiler Tools CD-ROM
! 
!      We have a new edition of the Compiler Tools Binaries CD-ROM with updated
!      versions of much of its software.	It contains executables of the GNU
!      compiler tools for some systems that don't normally come with a
!      compiler.	This allows users of those systems to compile their own
!      software without having to buy a proprietary compiler.
! 
!      We hope to include more systems with each update of this CD-ROM.  If you
!      can help build binaries for new systems or have one to suggest, please
!      contact us at either address on page 1.  For more information, see *Note
!      Compiler Tools Binaries CD-ROM::.
! 
!    * New/Updated Manuals since Last Bulletin   (*Note Documentation::)
! 
!      We have a new manual: `The GNU Emacs Lisp Reference Manual, Japanese
!      Edition' - the FSF would like to thank the team of over 30 Japanese who
!      did the translation.  These new editions include bug fixes and
!      additional information: `The GNU Emacs Lisp Reference Manual', `GNU
!      Make', `Bison', `Programming in Emacs Lisp: An Introduction', and `The
!      Termcap Manual'.
! 
!    * Older FSF CD-ROMs Available at a Reduced Price
! 
!      While supplies last, older versions of our CD-ROMs are available at a
!      reduced price.  Note that the newest version has bug fixes and
!      improvements that the older versions do not.  See the *note Free
!      Software Foundation Order Form::..
  
     * GNU Software Works on MS-DOS   (Also *note GNU Software::.)
  
!      GNU Emacs 19 and many other GNU programs have been ported to MS-DOS for
!      i386/i486/Pentium machines.  We ship binaries & sources on the *Note
!      DJGPP Diskettes::; *Note Emacs Diskettes::; *Note Selected Utilities
!      Diskettes::; & the *Note Compiler Tools Binaries CD-ROM::.	 We will ship
!      binaries & sources on the *Note MS-DOS Book with CD-ROM::, when it is
!      available.
! 
!    * The FSF Takes Credit Cards
! 
!      We take these credit cards: Carte Blanche, Diner's Club, MasterCard, JCB,
!      Visa, and American Express.  Please note that we are charged about 5% of
!      an order's total amount in credit card processing fees.  Please consider
!      paying by check instead or adding on a 5% donation to make up the
!      difference.
! 
  
  
  The Deluxe Distribution
  ***********************
  
! The Free Software Foundation has been asked repeatedly to create a package
! that provides executables for all of our software.  Normally we offer only
! sources.  In addition to providing binaries with the source code, the Deluxe
! Distribution includes a complete set of our printed manuals and reference
! cards.
! 
! The FSF Deluxe Distribution contains the binaries and sources to hundreds of
! different programs including GNU Emacs, the GNU C Compiler, the GNU Debugger,
! the complete X Window System, and all the GNU utilities.
! 
! We will make a Deluxe Distribution for most machines/operating systems.	 We
! may be able to send someone to your office to do the compilation, if we can't
! find a suitable machine close to us.  However, we can only compile the
! programs that already support your chosen machine/system - porting is a
! separate matter (to commission a port, consult the GNU Service Directory;
! details in *Note Free Software Support::).  Compiling all these programs
! takes time; a Deluxe Distribution for an unusual machine will take longer to
! produce than one for a common machine.	Please contact the FSF Office with
! any questions.
! 
! We supply the software in one of these tape formats in Unix `tar' format:
! 1600 or 6250bpi 1/2in reel, Sun DC300XLP 1/4in cartridge - QIC24, IBM RS/6000
! 1/4in c.t. - QIC 150, Exabyte 8mm c.t., or DAT 4mm c.t.	 If your computer
! cannot read any of these, please contact us to see if we can handle your
! format.
! 
! The manuals included are one each of the `Bison', `Calc', `GAWK', `GNU C
! Compiler', `GNU C Library', `GDB', `Flex', `GNU Emacs Lisp Reference',
! `Programming in Emacs Lisp: An Introduction', `Make', `Texinfo', & `Termcap'
! manuals; six copies of the `GNU Emacs' manual; and a packet of ten reference
! cards each for Emacs, Bison, Calc, Flex, & GDB.
! 
! Every Deluxe Distribution also has a copy of the latest editions of our
! CD-ROMs that have sources of our software & compiler tool binaries for some
! systems.  The MS-DOS CD is in ISO 9660 format.	The other CDs are in ISO 9660
! format with Rock Ridge extensions.
! 
! The price of the Deluxe Distribution is $5000 (shipping included).  These
! sales provide enormous financial assistance to help the FSF develop more free
! software.  To order, please fill out the "Deluxe Distribution" section on the
! *note Free Software Foundation Order Form::.  and send it to:
! 
! 	Free Software Foundation, Inc.
! 	59 Temple Place - Suite 330
! 	Boston, MA   02111-1307
! 	USA
! 
! 	Telephone: +1-617-542-5942
! 	Fax (including Japan): +1-617-542-2652
! 	Electronic mail: gnu@prep.ai.mit.edu
! 
  
  
  GNU Documentation
  *****************
  
! GNU is dedicated to having quality, easy-to-use online & printed
! documentation.	GNU manuals are intended to explain underlying concepts,
! describe how to use all the features of each program, & give examples of
! command use.  GNU manuals are distributed as Texinfo source files, which
! yield both typeset hardcopy via the TeX document formatting system and online
! hypertext display via the menu-driven Info system.  Source for these manuals
! comes with our software; here are the manuals that we publish as printed
! books.	See the *note Free Software Foundation Order Form::., to order them.
! 
! Most GNU manuals are bound as soft cover books with "lay-flat" bindings.
! This allows you to open them so they lie flat on a table without creasing the
! binding.  They have an inner cloth spine and an outer cardboard cover that
! will not break or crease as an ordinary paperback will.	 Currently, the
! `GDB', `Emacs', `Emacs Lisp Reference', `Programming in Emacs Lisp: An
! Introduction', `GAWK', `Make', `Bison', & `Texinfo' manuals have this
! binding.  The other GNU manuals also lie flat when opened, using a GBC or
! Wire-O binding.	 All our manuals are 7in by 9.25in except the 8.5in by 11in
! `Calc' manual.
! 
! The edition number of the manual and version number of the program listed
! after each manual's name were current at the time this Bulletin was published.
! 
! `Debugging with GDB' (Edition 4.12 for Version 4.14) tells how to run your
! program under GNU Debugger control, examine and alter data, modify a
! program's flow of control, and use GDB through GNU Emacs.
! 
! The `GNU Emacs Manual' (11th Edition for Version 19.29) describes editing with
! GNU Emacs.  It explains advanced features, including outline mode and regular
! expression search; how to use special programming modes to write languages
! like C++ and TeX; how to use the `tags' utility; how to compile and correct
! code; how to make your own keybindings; and other elementary customizations.
! 
! `Programming in Emacs Lisp: An Introduction' (Edition 1.04) is for people who
! are not necessarily interested in programming, but who do want to customize
! or extend their computing environment.	If you read it in Emacs under Info
! mode, you can run the sample programs directly.
! 
! `The GNU Emacs Lisp Reference Manual' (Edition 2.4 for Version 19.29) and
! `The GNU Emacs Lisp Reference, Japanese Edition' (Japanese DRAFT Revision
! 1.0, from English Edition 2.4 for Version 19.29) covers this programming
! language in depth, including data types, control structures, functions,
! macros, syntax tables, searching/matching, modes, windows, keymaps, byte
! compilation, and the operating system interface.
! 
! `The GAWK Manual' (Edition 0.16 for Version 2.16) tells how to use the GNU
! implementation of `awk'.  It is written for those who have never used `awk'
! and describes the features of this powerful string and record manipulation
  language.
  
! The `Make Manual' (Edition 0.49 for Version 3.74) describes GNU `make', a
! program used to rebuild parts of other programs.  The manual tells how to
! write "makefiles", which specify how a program is to be compiled and how its
! files depend on each other.  Included are an introductory chapter for novice
! users and a section about automatically generated dependencies.
! 
! The `Flex' manual (Edition 1.03 for Version 2.3.7) teaches you to write a
! lexical scanner definition for the `flex' program to create a C++ or C-coded
! scanner that recognizes the patterns defined.  You need no prior knowledge of
! scanners.
! 
! The `Bison' manual (December 1993 Edition for Version 1.23) teaches you how
! to write context-free grammars for the Bison program that convert into
! C-coded parsers.  You need no prior knowledge of parser generators.
! 
! `Using and Porting GNU CC' (September 1994 Edition for Version 2.6) tells how
! to run, install, and port the GNU C Compiler to new systems.  It lists new
! features and incompatibilities of GCC, but people not familiar with C will
! still need a good reference on the C programming language.  It also covers
! G++.  We are doing limited copier runs of this manual until it becomes more
! stable.
! 
! The `Texinfo' manual (Edition 2.21 for Version 3) explains the markup
! language that produces our online Info documentation & typeset hardcopies.
! It tells you how to make tables, lists, chapters, nodes, indexes, cross
! references, & how to catch mistakes.  This second edition describes over 50
! new commands.
! 
! `The Termcap Manual' (2nd Edition for Version 1.2), often described as "twice
! as much as you ever wanted to know about termcap," details the format of the
! termcap database, the definitions of terminal capabilities, and the process
! of interrogating a terminal description.  This manual is primarily for
! programmers.
! 
! The `C Library Reference Manual' (Edition 0.06 for Version 1.09) describes
! the library's facilities, including both what Unix calls "library functions"
! & "system calls."  We are doing small copier runs of this manual until it
! becomes more stable.  Please send fixes to `bug-glibc-manual@prep.ai.mit.edu'.
! 
! The `Emacs Calc Manual' (Edition 2.02 for Version 2.02) is both a tutorial
! and a reference manual.	 It tells how to do ordinary arithmetic, how to use
! Calc for algebra, calculus, and other forms of mathematics, and how to extend
! Calc.
  
  
--- 241,518 ----
  ***********************************************
  
!    * Hurd Test Release!   (Also *note What Is the Hurd::.)
  
!      We are pleased to announce the first public test release of the
!      Hurd, version 0.0; it is very preliminary, and we don't recommend
!      you try it unless you are in the mood to experiment.  We are
!      distributing it only by FTP until it becomes more stable.
! 
!      Much work remains to be done on reliability, efficiency, and on
!      user-level features to take advantage of the underlying
!      capabilities.  We're making rapid progress on these tasks, and we
!      plan to make further releases fairly often.
! 
!    * Preliminary GNU System Released!
! 
!      The first test release of the Hurd has enabled us to release a
!      complete GNU system in binary form, for 32-bit PC clones.  Like
!      the Hurd itself, this system release is preliminary, recommended
!      for experimentation only, and available only by FTP.  We have thus
!      come in sight of the goal which the GNU project was founded to
!      achieve.  We will actually reach that goal when the system becomes
!      reliable enough that we can recommend it for real use.
! 
!    * www.gnu.ai.mit.edu
! 
!      The GNU Project now has a site on the World Wide Web at URL:
!      `http://www.gnu.ai.mit.edu'.  We would like to thank Networks
!      On-Line (URL: `http://www.nol.net') for donating use of the
!      hardware & Internet connection, and their staff for setting up the
!      machine.  We would also like to thank Phil Nelson and Len Tower
!      for being the site's webmasters.  They are reachable at
!      `webmaster@www.gnu.ai.mit.edu'.
! 
!    * New Source Code CD!   (See *Note July 1996 Source Code CD-ROMs::)
! 
!      We have released the July 1996 (Edition 8) Source Code CD-ROM.
!      Once again, it is a two disk set.  It includes several new
!      programs: Automake, `enscript', Exim, `gcal', Generic NQS,
!      `geomview', GNAT, GNUMATH, ID Utils, Inetutils, Karma, Lynx,
!      Maxima, Miscfiles, Smail, TIFF, and WN.  *Note GNU Software::, for
!      more information about these packages.  Also on the CD-ROMs are
!      full distributions of X11R6.1, MIT Scheme, Emacs, GCC, and current
!      versions of all other GNU Software.
! 
!    * GNU Miscellaneous Files Distribution
! 
!      We have just released the GNU Miscellaneous Files Distribution,
!      which is a collection of non-crucial but useful files.  All the
!      files in version 1.0 have come from BSD, but files from other
!      sources are eagerly solicited.  Please send bug reports, as well as
!      suggestions about new files to include to
!      `bug-gnu-utils@prep.ai.mit.edu'.  See the entry in *Note GNU
!      Software Now Available::, for more information.
! 
!    * Give to GNU the United Way!
! 
!      As a 501(c)3 tax-exempt organization, the FSF is eligible to
!      receive United Way funds.  When donating to United Way, one can
!      specify that all or part of the donation be directed to the FSF.
!      On the donor form, check the "Specific Requests" box and include
!      the sentence, "Send my gift to the Free Software Foundation, 59
!      Temple Place, Suite 330, Boston, MA 02111."
  
!    * Tapes and MS-DOS Diskettes No Longer Available from the FSF
  
!      We no longer offer tapes or MS-DOS diskettes due to very low
!      demand.
  
     * GNU Software Works on MS-DOS   (Also *note GNU Software::.)
  
!      GNU Emacs 19 and many other GNU programs have been ported to
!      MS-DOS for i386/i486/Pentium machines.  We ship binaries & sources
!      on the *Note Compiler Tools Binaries CD-ROM::.  We will ship
!      binaries & sources on the *Note MS-DOS/Windows Book with CD-ROM::,
!      when it is available.
! 
!    * GNU Emacs 19.32   (Also *note GNU Software::.)
! 
!      We have just released Emacs 19.32.  It mostly fixes bugs, but it
!      has a few new features.  The most noticeable one is that marking a
!      region with the mouse now leaves the region highlighted at least
!      until the next input event.  Also, a new timer system lets you
!      efficiently arrange to call a Lisp function at a particular time,
!      and mouse tracking is much faster and more reliable.
! 
!      Support for MS-DOS and Windows 95 is greatly improved.  You can now
!      compile Emacs with DJGPP version 2; asynchronous subprocesses now
!      work on Windows 95; and many additional Lisp packages now work on
!      MS-DOS.
! 
!    * New Release of GNU Make
! 
!      GNU `make' 3.75 runs native on three new ports since version 3.74:
!      AmigaDOS, VMS, and Windows NT/Windows95.
! 
!    * Lynx now GPLed
! 
!      Lynx, the popular text-only Web browser is now distributed under
!      the terms of the GNU GPL.  For more information, see the Web site
!      at `http://www.ukans.edu/'.
! 
!    * New/Updated Manuals since Last Bulletin   (See *Note
!      Documentation::)
! 
!      We recently published the `GNU Awk Users' Guide' by Arnold Robbins,
!      which is a greatly expanded and rewritten version of our old `GAWK
!      Manual'.  We have a new edition of the Emacs Manual, for version
!      19.32, which describes changes since Emacs 19.29.  Our `GNU Make
!      Manual' is also a new edition with bug-fixes and additional
!      information.  Our `Using and Porting GCC' manual will soon be
!      available in a lay-flat, bound edition.
  
+     
  
  The Deluxe Distribution
  ***********************
  
!    The Free Software Foundation has been asked repeatedly to create a
! package that provides executables for all of our software.  Normally we
! offer only sources.  The Deluxe Distribution provides binaries with the
! source code and includes six T-shirts, all our CD-ROMs, printed
! manuals, & reference cards.
! 
!    The FSF Deluxe Distribution contains the binaries and sources to
! hundreds of different programs including Emacs, the GNU C/C++ Compiler,
! the GNU Debugger, the complete X Window System, and all the GNU
! utilities.
! 
!    We will make a Deluxe Distribution for most machines/operating
! systems.  We may be able to send someone to your office to do the
! compilation, if we can't find a suitable machine close to us.  However,
! we can only compile the programs that already support your chosen
! machine/system - porting is a separate matter (to commission a port,
! consult the GNU Service Directory; details in *Note Free Software
! Support::).  Compiling all these programs takes time; a Deluxe
! Distribution for an unusual machine will take longer to produce than
! one for a common machine.  Please contact the FSF Office with any
! questions.
! 
!    We supply the software on a write-once CD-ROM (in ISO 9660 format
! with "Rock Ridge" extensions), or on one of these tapes in Unix `tar'
! format: 1600 or 6250bpi 1/2in reel, Sun DC300XLP 1/4in cartridge -
! QIC24, IBM RS/6000 1/4in c.t. - QIC 150, Exabyte 8mm c.t., or DAT 4mm
! c.t.  If your computer cannot read any of these, please contact us to
! see if we can handle your format.
! 
!    The manuals included are one each of the `Bison', `Calc', `GAWK',
! `GNU C Compiler', `GNU C Library', `GDB', `Flex', `GNU Emacs Lisp
! Reference', `Programming in Emacs Lisp: An Introduction', `Make',
! `Texinfo', & `Termcap' manuals; six copies of the `GNU Emacs' manual;
! and ten reference cards each for Emacs, Bison, Calc, Flex, & GDB.
! 
!    Every Deluxe Distribution also has a copy of the latest editions of
! our CD-ROMs that have sources of our software & compiler tool binaries
! for some systems.  The CDs are in ISO 9660 format with Rock Ridge
! extensions.
! 
!    The price of the Deluxe Distribution is $5000 (shipping included).
! These sales provide enormous financial assistance to help the FSF
! develop more free software.  To order, please fill out the "Deluxe
! Distribution" section on the *note Free Software Foundation Order
! Form::.  and send it to:
! 
!         Free Software Foundation, Inc.
!         59 Temple Place - Suite 330
!         Boston, MA   02111-1307
!         USA
!      
!         Telephone: +1-617-542-5942
!         Fax (including Japan): +1-617-542-2652
!         Electronic Mail: gnu@prep.ai.mit.edu
!         World Wide Web: http://www.gnu.ai.mit.edu
  
+     
  
  GNU Documentation
  *****************
  
!    GNU is dedicated to having quality, easy-to-use online & printed
! documentation.  GNU manuals are intended to explain underlying
! concepts, describe how to use all the features of each program, & give
! examples of command use.  GNU manuals are distributed as Texinfo source
! files, which yield both typeset hardcopy via the TeX document
! formatting system and online hypertext display via the menu-driven Info
! system.  Source for these manuals comes with our software; here are the
! manuals that we publish as printed books.  See the *note Free Software
! Foundation Order Form::., to order them.
! 
!    Most GNU manuals are bound as soft cover books with "lay-flat"
! bindings.  This allows you to open them so they lie flat on a table
! without creasing the binding.  They have an inner cloth spine and an
! outer cardboard cover that will not break or crease as an ordinary
! paperback will.  Currently, the `GDB', `Emacs', `Emacs Lisp Reference',
! `Programming in Emacs Lisp: An Introduction', `GNU Awk User's Guide',
! `Make', `Bison', & `Texinfo' manuals have this binding.  The other GNU
! manuals also lie flat when opened, using a GBC binding.  All our
! manuals are 7in by 9.25in except the 8.5in by 11in `Calc' manual.
! 
!    The edition number of the manual and version number of the program
! listed after each manual's name were current at the time this Bulletin
! was published.
! 
!    `Debugging with GDB' (Edition 4.12 for Version 4.14) tells how to run
! your program under GNU Debugger control, examine and alter data, modify
! a program's flow of control, and use GDB through GNU Emacs.
! 
!    The `GNU Emacs Manual' (11th Edition for Version 19.32) describes
! editing with GNU Emacs.  It explains advanced features, including
! outline mode and regular expression search; how to use special
! programming modes to write languages like C++ and TeX; how to use the
! `tags' utility; how to compile and correct code; how to make your own
! keybindings; and other elementary customizations.
! 
!    `Programming in Emacs Lisp: An Introduction' (Edition 1.04) is for
! people who are not necessarily interested in programming, but who do
! want to customize or extend their computing environment.  If you read
! it in Emacs under Info mode, you can run the sample programs directly.
! 
!    `The GNU Emacs Lisp Reference Manual' (Edition 2.4 for Version 19.32)
! and `The GNU Emacs Lisp Reference, Japanese Edition' (Japanese DRAFT
! Revision 1.0, from English Edition 2.4 for Version 19.29) cover this
! programming language in depth, including data types, control
! structures, functions, macros, syntax tables, searching/matching, modes,
! windows, keymaps, byte compilation, and the operating system interface.
! 
!    `The GNU Awk User's Guide' (Edition 1.0 for Version 3.0.0) tells how
! to use GAWK.  It is written for those who have never used `awk' and
! describes features of this powerful string and record manipulation
  language.
  
!    `GNU Make' (Edition 0.50 for Version 3.75 Beta) describes GNU
! `make', a program used to rebuild parts of other programs.  The manual
! tells how to write "makefiles", which specify how a program is to be
! compiled and how its files depend on each other.  Included are an
! introductory chapter for novice users and a section about automatically
! generated dependencies.
! 
!    The `Flex' manual (Edition 1.03 for Version 2.3.7) teaches you to
! write a lexical scanner definition for the `flex' program to create a
! C++ or C-coded scanner that recognizes the patterns defined.  You need
! no prior knowledge of scanners.
! 
!    `The Bison Manual' (November 1995 Edition for Version 1.25) teaches
! you how to write context-free grammars for the Bison program that
! convert into C-coded parsers.  You need no prior knowledge of parser
! generators.
! 
!    `Using and Porting GNU CC' (November 1995 Edition for Version 2.7.2)
! tells how to run, install, and port the GNU C Compiler to new systems.
! It lists new features and incompatibilities of GCC, but people not
! familiar with C will still need a good reference on the C programming
! language.  It also covers G++.
! 
!    The `Texinfo' manual (Edition 2.20 for Version 3) explains the markup
! language that produces our online Info documentation & typeset
! hardcopies.  It tells you how to make tables, lists, chapters, nodes,
! indexes, cross references, & how to catch mistakes.  This second edition
! describes over 50 new commands.
! 
!    `The Termcap Manual' (3nd Edition for Version 1.3), often described
! as "twice as much as you ever wanted to know about termcap," details
! the format of the termcap database, the definitions of terminal
! capabilities, and the process of interrogating a terminal description.
! This manual is primarily for programmers.
! 
!    The `C Library Reference Manual' (Edition 0.07 for Version 1.09)
! describes the library's facilities, including both what Unix calls
! "library functions" & "system calls."  We are doing small copier runs
! of this manual until it becomes more stable.  Please send fixes to
! `bug-glibc-manual@prep.ai.mit.edu'.
! 
!    The `Emacs Calc Manual' (Edition 2.02 for Version 2.02) is both a
! tutorial and a reference manual.  It tells how to do ordinary
! arithmetic, how to use Calc for algebra, calculus, and other forms of
! mathematics, and how to extend Calc.
  
  
*************** GNU Software
*** 477,1652 ****
  ************
  
! All our software is available via FTP; see *Note How to Get GNU Software::.
! We also offer software on various media and printed documentation:
! 
!    * *Note CD-ROMs::.
! 
!    * *Note Tapes::.
! 
!    * *Note MS-DOS Diskettes::.
! 
!    * *Note Documentation::, which includes manuals and reference cards.
  
! In these articles describing the contents of each medium, the version number
! listed after each program name was current when we published this Bulletin.
! When you order a distribution tape, diskette, or newer CD-ROM, some of the
! programs may be newer and therefore the version number higher.	See the *note
! Free Software Foundation Order Form::., for ordering information.
! 
! Some of the contents of our tape and FTP distributions are compressed.	We
! have software on our tapes and FTP sites to uncompress these files.  Due to
! patent troubles with `compress', we use another compression program, `gzip'.
! (Such prohibitions on software development are fought by the League for
! Programming Freedom; *note What Is the LPF::., for details.)
! 
! GNU `make' is on several of our tapes because some system vendors supply no
! `make' utility at all and some native `make' programs lack the `VPATH'
! feature essential for using the GNU configure system to its full extent.  The
! GNU `make' sources have a shell script to build `make' itself on such systems.
! 
! We welcome all bug reports and enhancements sent to the appropriate
  electronic mailing list (*note Free Software Support::.).
  
! 
  
  Configuring GNU Software
  ------------------------
  
! We are using, Autoconf, a uniform scheme for configuring GNU software
! packages in order to compile them (see "Autoconf" below, in this article).
! The goal is to have all GNU software support the same alternatives for naming
! machine and system types.
  
! Ultimately, it will be possible to configure and build the entire system all
! at once, eliminating the need to configure each individual package separately.
! 
! You can also specify both the host and target system to build
  cross-compilation tools.  Most GNU programs now use Autoconf-generated
  configure scripts.
  
  
! 
! GNU Software currently available
! --------------------------------
  
  For future programs and features, see *Note Forthcoming GNUs::.
  
! Key to cross reference:
  
  
!     BinCD
! 	  December 1994 Binaries CD-ROM
  
!     DjgpD
! 	  Djgpp Diskettes
! 
!     DosBC
! 	  MS-DOS Book with CD-ROM
! 
!     EmcsD
! 	  Emacs Diskettes
! 
!     LangT
! 	  Languages Tape
! 
!     LiteT
! 	  4.4BSD-Lite Tape
! 
!     LspEmcT
! 	  Lisps/Emacs Tape
! 
!     SchmT
! 	  Scheme Tape
! 
!     SrcCD
! 	  December 1995 Source CD-ROMs
! 
!     UtilD
! 	  Selected Utilities Diskettes
! 
!     UtilT
! 	  Utilities Tape
! 
!     VMSCmpT
! 	  VMS Compiler Tape
! 
!     VMSEmcsT
! 	  VMS Emacs Tape
! 
!     WdwsD
! 	  Windows Diskette
! 
!     X11OptT
! 	  X11 Optional Tape
! 
!     X11ReqT
! 	  X11 Required Tape
! 
! [FSFman] shows that we sell a manual for that package.	[FSFrc] shows we sell
! a reference card for that package.  To order them, see the *note Free
! Software Foundation Order Form::..  *Note Documentation::, for more
! information on the manuals.  Source code for each manual or reference card is
! included with each package.
! 
!    * `acm'   (SrcCD, UtilT)
! 
!      `acm' is a LAN-oriented, multiplayer aerial combat simulation that runs
!      under the X Window System.	 Players engage in air to air combat against
!      one another using heat seeking missiles and cannons.  We are working on
!      a more accurate simulation of real airplane flight characteristics.
! 
!    * apache   (SrcCD)
! 
!      Apache is an HTTP server designed as a plug-in replacement for version
!      1.3 or 1.4 of the NCSA server.  It fixes numerous bugs in the NCSA
!      server and includes many frequently requested new features, and has an
!      API which allows it to be extended to meet users' needs more easily.
! 
!    * Autoconf	(SrcCD, UtilT)
! 
!      Autoconf produces shell scripts which automatically configure source code
!      packages.	These scripts adapt the packages to many kinds of Unix-like
!      systems without manual user intervention.	Autoconf creates a script for
!      a package from a template file which lists the operating system features
!      which the package can use, in the form of `m4' macro calls.  Autoconf
!      requires GNU `m4' to operate, but the resulting configure scripts it
!      generates do not.
! 
!    * BASH   (SrcCD, UtilT)
! 
!      GNU's shell, BASH (Bourne Again SHell), is compatible with the Unix `sh'
!      and offers many extensions found in `csh' and `ksh'.  BASH has job
!      control, `csh'-style command history, command-line editing (with Emacs
!      and `vi' modes built-in, and the ability to rebind keys) via the
!      `readline' library.  BASH conforms to the POSIX 1003.2-1992 standard.
! 
!    * `bc'   (DosBC, SrcCD, UtilT)
  
       `bc' is an interactive algebraic language with arbitrary precision
!      numbers.  GNU `bc' follows the POSIX 1003.2-1992 standard, with several
!      extensions including multi-character variable names, an `else'
!      statement, and full Boolean expressions.  The RPN calculator `dc' is now
!      distributed as part of the same package, but GNU `bc' is not implemented
!      as a `dc' preprocessor.
! 
!    * BFD   (BinCD, DjgpD, DosBC, LangT, SrcCD)
! 
!      The Binary File Descriptor library allows a program which operates on
!      object files (e.g., `ld' or GDB) to support many different formats in a
!      clean way.	 BFD provides a portable interface, so that only BFD needs to
!      know the details of a particular format.  One result is that all
!      programs using BFD will support formats such as a.out, COFF, and ELF.
!      BFD comes with Texinfo source for a manual (not yet published on paper).
  
       At present, BFD is not distributed separately; it is included with
       packages that use it.
  
!    * Binutils	(BinCD, DjgpD, DosBC, LangT, SrcCD; `gas' only on VMSCmpT)
  
!      Binutils includes these programs: `ar', `c++filt', `demangle', `gas',
!      `gprof', `ld', `nlmconv', `nm', `objcopy', `objdump', `ranlib', `size',
!      `strings', & `strip'.
  
       Binutils version 2 uses the BFD library.  The GNU assembler, `gas',
!      supports the a29k, Alpha, H8/300, H8/500, HP-PA, i386, i960, m68k, m88k,
!      MIPS, NS32K, SH, SPARC, Tahoe, Vax and Z8000 CPUs, and attempts to be
!      compatible with many other assemblers for UNIX and embedded systems.  It
!      can produce mixed C-and-assembly listings, and includes a macro facility
!      similar to that in some other assemblers.	GNU's linker `ld' emits
!      source-line numbered error messages for multiply-defined symbols and
!      undefined references, and interprets a superset of AT&T's Linker Command
!      Language, which gives control over where segments are placed in memory.
!      `nlmconv' converts object files into Novell NetWare Loadable Modules.
!      `objdump' can disassemble code for most of the CPUs listed above, and
!      can display other data (e.g., symbols and relocations) from any file
!      format read by BFD.
! 
!    * Bison   (BinCD,DjgpD,DosBC,LangT,SrcCD,VMSCmpT)[FSFman,FSFrc]
! 
!      Bison is an upwardly compatible replacement for the parser generator
!      `yacc'.  Texinfo source for the `Bison Manual' and reference card are
!      included.	*Note Documentation::.
! 
!      A recent policy change allows non-free programs to use Bison-generated
!      parsers.  *Note Conditions for Using Bison::.
! 
!    * C Library	 (BinCD, LangT, SrcCD) [FSFman]
! 
!      The GNU C library supports ANSI C-1989, POSIX 1003.1-1990 and most of the
!      functions in POSIX 1003.2-1992.  It is upwardly compatible with 4.4BSD
!      and includes many System V functions, plus GNU extensions.
! 
!      The C Library performs many functions of the Unix system calls in the
!      GNU/Hurd.	Mike Haertel has written a fast `malloc' which wastes less
!      memory than the old GNU version.  The GNU regular-expression functions
!      (`regex' and `rx') now nearly conform to the POSIX 1003.2 standard.
! 
!      GNU `stdio' lets you define new kinds of streams, just by writing a few
!      C functions.  The `fmemopen' function uses this to open a stream on a
!      string, which can grow as necessary.  You can define your own `printf'
!      formats to use a C function you have written.  For example, you can
!      safely use format strings from user input to implement a `printf'-like
!      function for another programming language.	 Extended `getopt' functions
!      are already used to parse options, including long options, in many GNU
!      utilities.
! 
!      The C Library runs on Sun-3 (SunOS 4.1), Sun-4 (SunOS 4.1 or Solaris 2),
!      HP 9000/300 (4.3BSD), SONY News 800 (NewsOS 3 or 4), MIPS DECstation
!      (Ultrix 4), DEC Alpha (OSF/1), i386/i486/Pentium (System V, SVR4, BSD,
!      SCO 3.2, & SCO ODT 2.0), Sequent Symmetry i386 (Dynix 3), & SGI (Irix
!      4).  *Note Forthcoming GNUs::.  Texinfo source for the
!      `GNU C Library Reference Manual' is included (*note Documentation::..
! 
!    * C++ Library   (BinCD, DjgpD, DosBC, LangT, SrcCD)
! 
!      The GNU C++ library (libg++) contains an extensive collection of C++
!      "forest" classes, an IOStream library for input/output routines, and
!      support tools for use with G++.  Supported classes include: Obstacks,
!      multiple-precision Integers and Rationals, Complex numbers, arbitrary
!      length Strings, BitSets, and BitStrings.
! 
!      The distribution also includes the libstdc++ library.  This implements
!      library facilities defined by the forthcoming ANSI/ISO C++ standard,
!      including a port of the Standard Template Library.
! 
!    * Calc   (DosBC, LspEmcT, SrcCD) [FSFman, FSFrc]
! 
!      Calc (written by Dave Gillespie in Emacs Lisp) is an extensible, advanced
!      desk calculator & mathematical tool that runs as part of GNU Emacs.  You
!      can use Calc just as a simple four-function calculator, but it has many
!      more features including: choice of algebraic or RPN (stack-based) entry;
!      logarithmic, trigonometric, & financial functions; arbitrary precision;
!      complex numbers; vectors; matrices; dates; times; infinities; sets;
!      algebraic simplification; differentiation & integration.  It outputs to
!      `gnuplot', & comes with source for a manual & reference card (*note
       Documentation::.).
  
!    * `cfengine'	  (SrcCD, UtilT)
  
!      `cfengine' is used for maintaining site-wide configuration of a
       heterogeneous Unix network using a simple high level language.  Its
!      appearance is similar to `rdist', but also allows many more operations
!      to be performed automatically.  See Mark Burgess, "A Site Configuration
!      Engine", `Computing Systems', Vol. 8, No. 3 (ask `office@usenix.org' how
!      to get a copy).
! 
!    * Chess   (SrcCD, UtilT, WdwsD)
! 
!      GNU Chess enables most modern computers to play a full game of chess.  It
!      supports a plain terminal interface, a curses interface, and a spiffy X
!      Window interface via `xboard'.
! 
!      Improvements this past year include fixes to the game analyzer, book, &
!      hash table; smartening up draw and mate; improved thinking on opponent's
!      time; Autoconf installation; a makefile for Windows NT compilation;
!      forward pruning; unlimited quiescence captures; improved evaluation;
!      improved null & time control logic; & repetition-detection.
  
!      GNU Chess was originated by Stuart Cracraft.  Improvements & rewrites are
!      from John Stanback, Cha Kong Sian, Mike McGann, and many others.
  
       Send bugs to `bug-gnu-chess@prep.ai.mit.edu' & general comments to
       `info-gnu-chess@prep.ai.mit.edu'.
  
!    * CLISP   (LspEmcT, SrcCD)
! 
!      CLISP is a Common Lisp implementation by Bruno Haible and Michael Stoll.
!      It mostly supports the Lisp described by `Common LISP: The Language (2nd
!      edition)' and the ANSI Common Lisp standard.  CLISP includes an
!      interpreter, a byte-compiler, a large subset of CLOS, a foreign language
!      interface, and, for some machines, a screen editor.  The user interface
!      language (English, German, French) is choosable at run time.  Major
!      packages that run in CLISP include CLX & Garnet.  CLISP needs only 2 MB
!      of memory & runs on many microcomputers (including MS-DOS systems, OS/2,
!      Windows NT, Amiga 500-4000, Acorn RISC PC) & Unix-like systems
!      (GNU/Linux, Sun4, SVR4, SGI, HP-UX, DEC Alpha, NeXTStep, & others).
! 
!    * Common Lisp   **Note Forthcoming GNUs::*	(LspEmcT, SrcCD)
! 
!      GNU Common Lisp (GCL, formerly known as Kyoto Common Lisp) is a compiler
!      & interpreter for Common Lisp.  GCL is very portable & extremely
!      efficient on a wide class of applications, & compares favorably in
!      performance with commercial Lisps on several large theorem-prover &
!      symbolic algebra systems.	GCL supports the CLtL1 specification but is
!      moving towards the proposed ANSI standard.
! 
!      GCL compiles to C & then uses the native optimizing C compiler (e.g.,
!      GCC).  A function with a fixed number of args & one value turns into a C
!      function of the same number of args, returning one value--so GCL is
!      maximally efficient on such calls.	 Its conservative garbage collector
!      gives great freedom to the C compiler to put Lisp values in registers.
!      It has a source level Lisp debugger for interpreted code & displays
!      source code in an Emacs window.  Its profiler (based on the C profiling
!      tools) counts function calls & the time spent in each function.
! 
!      There is now a built-in interface to the Tk widget system.	 It runs in a
!      separate process, so users may monitor progress on Lisp computations or
!      interact with running computations via a windowing interface.
! 
!      There is also an Xlib interface via C (xgcl-2).   CLX runs with GCL, as
!      does PCL (see "PCL" later in this article).  *Note Forthcoming GNUs::,
!      for plans regarding GCL or for recent developments.
  
!      GCL version 2.2 is released under the GNU Library General Public License.
  
!    * CLX   (LspEmcT, SrcCD)
  
!      CLX is an X Window interface library for GCL.
  
!    * `cpio'   (DosBC, SrcCD, UtilD, UtilT)
  
       `cpio' is an archive program with all the features of SVR4 `cpio',
!      including support for the final POSIX 1003.1 `ustar' standard.  `mt', a
!      program to position magnetic tapes, is included with `cpio'.
! 
!    * CVS   (SrcCD, UtilT)
! 
!      CVS, the Concurrent Version System, manages software revision & release
!      control at a multi-developer, multi-directory, multi-group site.  It
!      works best with RCS versions 4 and above, but will parse older RCS
!      formats, losing some of CVS's fancier features.  (See Berliner, Brian,
!      "CVS-II: Parallelizing Software Development," `Proceedings of the Winter
!      1990 USENIX Association Conference'; ask `office@usenix.org' how to get
!      a copy.)
  
!    * DejaGnu   (LangT, SrcCD)
  
!      DejaGnu is a framework to test programs with a single front end for all
!      tests.  The framework's flexibility & consistency makes it easy to write
!      tests.
! 
!      DejaGnu comes with `expect', which runs scripts to conduct dialogs with
!      programs.
! 
!    * Diffutils	 (DjgpD, DosBC, SrcCD, UtilT)
  
       GNU `diff' compares files showing line-by-line changes in several
!      flexible formats.	It is much faster than traditional Unix versions.  The
!      Diffutils package contains `diff', `diff3', `sdiff', & `cmp'.  Recent
!      improvements include more consistent handling of character sets and a
!      new `diff' option to do all input/output in binary; this is useful on
!      some non-POSIX hosts.  Plans for the Diffutils package include support
!      for internationalization (e.g., error messages in Chinese) and for some
       non-Unix PC environments.
  
!    * DJGPP   (BinCD, DjgpD, DosBC)
  
       DJ Delorie has ported GCC/G++ (see "GCC" in this article) to i386s
!      running MS-DOS.  DJGPP has a 32-bit i386 DOS extender with a symbolic
!      debugger; development libraries; & ports of Bison, `flex', & Binutils.
!      Full source code is provided.  It needs at least 5MB of hard disk space
!      to install & 512K of RAM to use.  It supports SVGA (up to 1024x768), XMS
!      & VDISK memory allocation, `himem.sys', VCPI (e.g., QEMM, DESQview, &
!      386MAX), & DPMI (e.g., Windows 3.x, OS/2, QEMM, & QDPMI).
  
!      The FSF offers it on the *Note Compiler Tools Binaries CD-ROM::, and on
!      the *Note DJGPP Diskettes::.  FTP from `oak.oakland.edu' in
!      `/simtel/vendors/djgpp/' (or another SimTel mirror site).
  
!      To join a DJGPP users mailing list, ask
!      `djgpp-request@sun.soe.clarkson.edu'.
  
!    * `dld'   (LangT, SrcCD)
  
!      `dld' is a dynamic linker written by W. Wilson Ho.	 Linking your program
!      with the `dld' library allows you to dynamically load object files into
!      the running binary.  Currently supported are VAX (Ultrix), Sun 3 (SunOS
!      3.4 & 4.0), SPARC (SunOS 4.0), Sequent Symmetry (Dynix), & Atari ST.
  
!    * `doschk'	(DosBC, SrcCD, UtilT)
  
!      This program is a utility to help software developers ensure that their
!      source file names are distinguishable on System V platforms with
!      14-character filenames and on MS-DOS systems with 8+3 character
!      filenames.
  
!    * `ecc'   (LangT, SrcCD)
  
!      `ecc' is a Reed-Solomon error correction checking program, which can
!      correct three byte errors in a block of 255 bytes and detect more severe
!      errors.  Contact `paulf@stanford.edu' for more information.
  
!    * `ed'   (SrcCD, UtilT)
  
!      `ed' is the standard text editor.	It is line-oriented and can be used
!      interactively or in scripts.
  
!    * Elib   (DosBC, LspEmcT, SrcCD)
  
!      Elib is a small library of Emacs Lisp functions, including routines for
!      using AVL trees and doubly-linked lists.
  
     * Elisp archive   (SrcCD)
  
!      This is a snapshot of Ohio State's GNU Emacs Lisp FTP Archive.  FTP it
!      from `archive.cis.ohio-state.edu' in `/pub/gnu/emacs/elisp-archive'.
  
!    * Emacs   **Note Forthcoming GNUs:: for future plans.*
  
       In 1975, Richard Stallman developed the first Emacs, an extensible,
!      customizable real-time display editor & computing environment.  GNU Emacs
!      is his second implementation.  It offers true Lisp--smoothly integrated
!      into the editor--for writing extensions & provides an interface to the X
!      Window System.  It runs on Unix, MS-DOS, & Windows NT.  In addition to
!      its powerful native command set, Emacs has extensions which emulate the
!      editors vi & EDT (Digital's VMS editor).  Emacs has many other features
!      which make it a full computing support environment.  Source for the `GNU
!      Emacs Manual' & a reference card comes with the software.	Sources for
!      the `GNU Emacs Lisp Reference Manual' & `Programming in Emacs Lisp: An
       Introduction' are distributed in separate packages.  *Note
       Documentation::.
  
!    * Emacs 18	(LspEmcT, SrcCD, VMSEmcsT) [FSFrc]
  
!      Emacs 18.59 is the last release of version 18 from the FSF.  We no longer
!      maintain it.  It supports these Unix systems that Emacs 19 doesn't
!      support (please help port Emacs 19 to these systems): Alliant FX/80,
!      Altos 3068, Amdahl (UTS), AT&T (3Bs & 7300 PC), CCI 5/32 & 6/32,
!      Celerity, Digital (VAX VMS), Dual, Encore (APC, DPC, & XPC), HLH Orion
!      (original & 1/05), ISI (Optimum V, 80386), Masscomp, NCR Tower 32 (SVR2
!      & SVR3), Nixdorf Targon 31, Nu (TI & LMI), pfa50, Plexus, Prime EXL,
!      Stride (system rel. 2), Tahoe, Tandem Integrity S2, Tektronix 16000,
!      Triton 88, Ustation E30 (SS5E), Whitechapel (MG1), & Wicat.
! 
!    * Emacs 19	(DosBC, EmcsD, LspEmcT, SrcCD) [FSFman(s), FSFrc]
! 
!      Emacs 19 works with character-only terminals & with the X Window System
!      (with or without an X toolkit).  New features in Emacs 19 include:
!      multiple X windows ("frames" to Emacs), with a separate X window for the
!      minibuffer or a minibuffer attached to each X window; property lists
!      associated with regions of text in a buffer; multiple fonts & colors
!      defined by those properties; simplified/improved processing of function
!      keys, mouse clicks, and mouse movement; X selection processing,
!      including clipboard selections; hooks to be run if the point or mouse
!      moves outside a certain range; menu bars and popup menus defined by
!      keymaps; scrollbars; before- and after-change hooks; a source-level
!      debugger for Emacs Lisp programs; floating point numbers; improved
!      buffer allocation, including returning storage to the system when a
!      buffer is killed; interfacing with the X resource manager; many updated
!      libraries; integrated support for version control systems (RCS, CVS, &
!      SCCS); Autoconf based configuration; and support for European character
       sets.
  
!      Recent features include the ability to open frames on more than one X
!      display from a single Emacs job, operation on MS-DOS, MS Windows, and
!      Windows NT, displaying multiple views of an outline at the same time,
!      support for the Athena & Motif widgets, version control support for CVS
!      and for multiple branches, text properties for formatting text, commands
!      to edit text properties and save them in files, and GNU-standard
!      long-named command line options.
! 
!      Emacs 19.30 works on: Acorn RISC (RISCiX); Alliant FX/2800 (BSD); Alpha
!      (OSF/1); Apollo (DomainOS); Bull DPX/2 2nn & 3nn (SysV.3) & sps7
!      (SysV.2); Clipper; Convex (BSD); Cubix QBx (SysV); Data General Aviion
!      (DGUX); DEC MIPS (Ultrix 4.2, OSF/1, not VMS); Elxsi 6400 (SysV); Gould
!      Power Node & NP1 (4.2 & 4.3BSD); Harris Night Hawk 1200, 3000, 4000 &
!      5000 (cxux); Honeywell XPS100 (SysV); HP 9000 series 200, 300, 700, 800
!      (but not 500) (4.3BSD; HP-UX 7, 8, 9); Intel i386/i486/Pentium
!      (GNU/Linux, 386BSD, AIX, BSDI/386, FreeBSD, Esix, ISC, MS-DOS (*note
!      MS-DOS Diskettes::., & *Note MS-DOS Book with CD-ROM::), NetBSD,
!      SCO3.2v4, Solaris, SysV, Xenix, WindowsNT); IBM RS/6000 (AIX 3.2) &
!      RT/PC (AIX, BSD); Motorola Delta 147 & 187 (SysV.3, SysV.4, m88kbcs);
!      National Semiconductor 32K (Genix); NeXT (BSD, Mach 2 w/ NeXTStep 3.0);
!      Paragon (OSF/1); Prime EXL (SysV); Pyramid (BSD); Sequent Symmetry (BSD,
!      ptx); Siemens RM400 & RM600 (SysV); SGI Iris 4D (Irix 4.x & 5.x); Sony
!      News/RISC (NewsOS); Stardent i860 (SysV); Sun 3 & 4, SPARC 1, 1+, 2, 10,
!      Classic (SunOS 4.0, 4.1, Solaris 2.0-2.3); Tadpole 68k (SysV); Tektronix
!      XD88 (SysV.3) & 4300 (BSD); & Titan P2 & P3 (SysV).
! 
!      Other configurations supported by Emacs 18 should work with few changes
!      in Emacs 19; as users tell us more about their experiences with different
!      systems, we will augment the list.	 Also see *Note Forthcoming GNUs::.
! 
!    * `es'   (SrcCD, UtilT)
! 
!      `es' is an extensible shell (based on `rc') with first class functions,
!      lexical scope, exceptions and rich return values (i.e., functions can
!      return values other than just numbers).  `es''s extensibility comes from
!      the ability to modify and extend the shell's built-in services, such as
!      path searching and redirection.  Like `rc', it is great for both
!      interactive use and scripting, particularly since its quoting rules are
!      much less baroque than the C and Bourne shells.
! 
!    * `f2c'   (LangT, SrcCD)
! 
!      `f2c' converts Fortran-77 source into C or C++, which can be compiled
!      with GCC or G++.  Get bug fixes by FTP from site `netlib.att.com' or by
!      email from `netlib@research.att.com'.  See the file
!      `/netlib/f2c/readme.Z' for a summary.  Also see the GNU Fortran item
!      later in this article, and in *Note Forthcoming GNUs::.
  
!    * `ffcall'	(SrcCD)
  
       `ffcall' is a C library for implementing foreign function calls in
       embedded interpreters by Bill Triggs and Bruno Haible.  It allows C
!      functions with arbitrary argument lists and return types to be called or
!      emulated (callbacks).
! 
!    * Fileutils	 (DosBC, SrcCD, UtilT)
  
!      The Fileutils work on files: `chgrp', `chmod', `chown', `cp', `dd', `df',
!      `dir', `du', `install', `ln', `ls', `mkdir', `mkfifo', `mknod', `mv',
!      `rm', `rmdir', `sync', `touch', & `vdir'.
  
!    * Findutils	 (DosBC, SrcCD, UtilT)
! 
!      `find' is frequently used both interactively and in shell scripts to
!      find files which match certain criteria and perform arbitrary operations
!      on them.  Also included are `locate', which scans a database for file
!      names that match a pattern, and `xargs', which applies a command to a
!      list of files.
! 
!    * Finger   (SrcCD, UtilT)
! 
!      GNU Finger has more features than other finger programs.  For sites with
!      many hosts, a single host may be designated as the finger "server" host
!      and other hosts at that site configured as finger "clients".  The server
!      host collects information about who is logged in on the clients.  To
!      finger a user at a GNU Finger site, a query to any of its client hosts
!      gets useful information.  GNU Finger supports many customization
!      features, including user output filters and site programmable output for
!      special target names.
! 
!    * `flex'   (BinCD, DjgpD, DosBC, LangT, SrcCD, UtilD) [FSFman, FSFrc]
! 
!      `flex' is a replacement for the `lex' scanner generator.  `flex' was
!      written by Vern Paxson of the Lawrence Berkeley Laboratory and generates
!      far more efficient scanners than `lex' does.  Sources for the `Flex
!      Manual' and reference card are included (*note Documentation::.).
  
!    * Fortran (`g77')   **Note Forthcoming GNUs::*   (LangT, SrcCD)
  
!      GNU Fortran (`g77'), developed by Craig Burley, is available for public
!      beta testing on the Internet.  For now, `g77' produces code that is
!      mostly object-compatible with `f2c' & uses the same run-time library
!      (`libf2c').
  
!    * Fontutils	 (SrcCD, UtilT)
  
!      The Fontutils convert between font formats, create fonts for use with
!      Ghostscript or TeX (starting with a scanned type image & converting the
!      bitmaps to outlines), et al.  It includes: `bpltobzr', `bzrto',
!      `charspace', `fontconvert', `gsrenderfont', `imageto', `imgrotate',
!      `limn', & `xbfe'.
  
!    * GAWK   (DosBC, LangT, SrcCD) [FSFman]
  
!      GAWK is upwardly compatible with the latest POSIX specification of
!      `awk'.  It also provides several useful extensions not found in other
!      `awk' implementations.  Texinfo source for the `GAWK Manual' comes with
!      the software  (*note Documentation::.).
  
!    * GCC   (BinCD, DjgpD, DosBC, LangT, SrcCD, VMSCmpT) [FSFman]
  
       Version 2 of the GNU C Compiler supports the languages C, C++, and
!      Objective-C; the source file name suffix or a compiler option selects
!      the language.  Objective-C support was donated by NeXT.  The runtime
!      support needed to run Objective-C programs is now distributed with GCC
!      (this does not include any Objective-C classes aside from `object', but
!      see "GNUStep" in *Note Forthcoming GNUs::).  As much as possible, G++ is
!      kept compatible with the evolving draft ANSI standard, but not with
!      `cfront' (AT&T's compiler), which has been diverging from ANSI.
! 
!      The GNU C Compiler is a fairly portable optimizing compiler which
!      performs automatic register allocation, common sub-expression
!      elimination, invariant code motion from loops, induction variable
!      optimizations, constant propagation and copy propagation, delayed
!      popping of function call arguments, tail recursion elimination,
!      integration of inline functions and frame pointer elimination,
!      instruction scheduling, loop unrolling, filling of delay slots, leaf
!      function optimization, optimized multiplication by constants, a certain
!      amount of common subexpression elimination (CSE) between basic blocks
!      (though not all of the supported machine descriptions provide for
!      scheduling or delay slots), a feature for assigning attributes to
!      instructions, and many local optimizations that are automatically
!      deduced from the machine description.
  
       GCC can open-code most arithmetic on 64-bit values (type `long long
!      int').  It supports extended floating point (type `long double') on the
!      68k; other machines will follow.
  
!      GCC supports full ANSI C, traditional C, & GNU C extensions (including:
!      nested functions support, nonlocal gotos, & taking the address of a
!      label).
! 
!      GCC can generate a.out, COFF, ELF, & OSF-Rose files when used with a
!      suitable assembler.  It can produce debugging information in these
!      formats: BSD stabs, COFF, ECOFF, ECOFF with stabs, & DWARF.
! 
!      GCC generates code for many CPUs, including the a29k, Alpha  ARM  AT&T
!      DSP1610 Clipper Convex cN Elxsi Fujitsu Gmicro i370, i860, i960,
!      MIL-STD-1750a, MIPS, ns32k, PDP-11, Pyramid, ROMP, RS/6000, SH, SPUR,
!      Tahoe, VAX, & we32k.  Position-independent code is generated for the
!      Clipper, Hitachi H8/300, HP-PA (1.0 & 1.1), i386/i486/Pentium, m68k,
!      m88k, SPARC, & SPARClite.
! 
!      Operating systems supported include: GNU/Hurd, GNU/Linux, ACIS, AIX, AOS,
!      BSD, Clix, Concentrix, Ctix, DG/UX, Dynix, FreeBSD, Genix, HP-UX, Irix,
!      ISC, Luna, LynxOS, Minix, NetBSD, NewsOS, NeXTStep, OS/2, OSF, OSF-Rose,
!      RISCOS, SCO, Solaris 2, SunOS 4, System/370, SysV, Ultrix, Unos, VMS, &
!      Windows/NT.
! 
!      Using the configuration scheme for GCC, building a cross-compiler is as
!      easy as building a native compiler.
  
       Version 1 of GCC, G++, & libg++ are no longer maintained.
  
!      Texinfo source for the `Using and Porting GNU CC' manual, is included
!      with GCC (*note Documentation::.).
! 
!      *Note Forthcoming GNUs::, for plans for later releases of GCC.
  
!    * GDB   (BinCD, DjgpD, DosBC, LangT, SrcCD) [FSFman, FSFrc]
  
!      GDB, the GNU DeBugger, is a source-level debugger for C, C++, & Fortran.
  
!      GDB can debug both C and C++ programs, and will work with executables
!      produced by many different compilers; however, C++ debugging will have
!      some limitations if you do not use GCC.
! 
!      GDB has a command line user interface, and Emacs has a GDB mode.  Two X
!      interfaces (not distributed or maintained by the FSF) are: `gdbtk' (FTP
!      it from `ftp.cygnus.com' in directory `/pub/gdb'); and `xxgdb' (FTP it
!      from `ftp.x.org' in directory `/contrib/utilities').
! 
!      Executable files and symbol tables are read via the BFD library, which
!      allows a single copy of GDB to debug programs with multiple object file
!      formats (e.g., a.out, COFF, ELF).	Other features include a rich command
!      language, remote debugging over serial lines or TCP/IP, and watchpoints
!      (breakpoints triggered when the value of an expression changes).
! 
!      GDB uses a standard remote interface to a simulator library which (so
!      far) has simulators for the Hitachi H8/300, H8/500, Super-H, & Zilog
!      Z8001/2.
! 
!      GDB can perform cross-debugging.  To say that GDB "targets" a platform
!      means it can perform native or cross-debugging for it.  To say that GDB
!      can "host" a given platform means that it can be built on it, but cannot
!      necessarily debug native programs.
  
       GDB can:
  
! 	* "target" & "host": Amiga 3000 (Amix), DEC Alpha (OSF/1), DECstation
! 	  3100 & 5000 (Ultrix), HP 9000/300 (BSD, HP-UX), HP 9000/700 (HP-UX
! 	  9, 10), i386 (GNU/Hurd, GNU/Linux, BSD, FreeBSD, LynxOS, NetBSD,
! 	  SCO), IBM RS/6000 (AIX, LynxOS), Motorola Delta m88k (System V,
! 	  CX/UX), PC532 (NetBSD), Motorola m68k MVME-167 (LynxOS), NCR 3000
! 	  (SVR4), SGI (Irix V3, V4, V5), SONY News (NewsOS 3.x), SPARC
! 	  (LynxOS, NetBSD, Solaris, & SunOS 4.1 ) Sun-3 (SunOS 4.1), &
! 	  Ultracomputer (a29k running Sym1).
! 
! 	* "target", but not "host": AMD 29000 (COFF & a.out), Hitachi H8/300,
! 	  Hitachi SH, i386 (a.out, COFF, OS/9000), i960 (Nindy, VxWorks),
! 	  m68k/m68332 (a.out, COFF, VxWorks), MIPS (ELF, IDT ecoff), Fujitsu
! 	  SPARClite (a.out, COFF), & Z8000.
  
! 	* "host", but not "target": IBM RT/PC (AIX), HP/Apollo 68k (BSD), &
! 	  Apple Macintosh (MacOS).
  
!      Sources for the manual, `Debugging with GDB', and a reference card are
!      included (*note Documentation::.).
  
!    * `gdbm'   (LangT, SrcCD, UtilD)
  
       `gdbm' is the GNU replacement for the traditional `dbm' and `ndbm'
!      libraries.	 It implements a database using quick lookup by hashing.
!      `gdbm' does not ordinarily make sparse files (unlike its Unix and BSD
!      counterparts).
! 
!    * `gettext'	 (LangT, SrcCD)
! 
!      The GNU `gettext' tool set contains everything maintainers need to
!      internationalize a package for messages, tools that help translators
!      localize messages to their native language, once a package has been
!      internationalized.	 *Note Help the GNU Translation Project::.
! 
!    * Ghostscript   (DosBC, SrcCD, UtilT)
! 
!      The GNU release of Ghostscript is an interpreter for the Postscript
!      graphics language (*note Forthcoming GNUs::., for future plans).
! 
!      The current version of GNU Ghostscript is 2.6.2.  Features include the
!      ability to use the fonts provided by the platform on which Ghostscript
!      runs (X Window System & Microsoft (MS) Windows), resulting in much
!      better-looking screen displays; improved text file printing (like
!      `enscript'); a utility to extract the text from a Postscript language
!      document; a much more reliable (and faster) MS Windows implementation;
!      support for MS C/C++ 7.0; drivers for many new printers ( e.g. the
!      SPARCprinter), & for TIFF/F (Fax) file format; many more Postscript Level
!      2 facilities, including most of the color space facilities (but not
!      patterns); & the ability to switch between Level 1 & Level 2
!      dynamically.  Version 2.6.2 adds a LaserJet 4 driver & several important
!      bug fixes to version 2.6.1.
  
       Ghostscript executes commands in the Postscript language by writing
!      directly to a printer, drawing on an X window, or writing to files for
!      printing later or manipulating with other graphics programs.
! 
!      Ghostscript includes a C-callable graphics library (for client programs
!      that do not want to deal with the Postscript language).  It also supports
!      i386/i486/Pentiums running MS-DOS with EGA, VGA or SuperVGA graphics (but
!      please do *not* ask the FSF staff any questions about this; we do not
!      use MS-DOS).
! 
!    * Ghostview	 (DosBC, SrcCD, UtilT)
! 
!      Tim Theisen, `ghostview@cs.wisc.edu', created Ghostview, a previewer for
!      multi-page files with an X Window interface.  Ghostview & Ghostscript
!      work together; Ghostview creates a viewing window & Ghostscript draws in
!      it.
! 
!    * GIT   (SrcCD, UtilT)
! 
!      GIT is a set of interactive tools: an extensible file system browser, an
!      ASCII/hex file viewer, a process viewer/killer, & other related
!      utilities & shell scripts.	 It can be used to increase the speed &
!      efficiency of many daily tasks, such as copying & moving files &
!      directories, invoking editors, compressing/uncompressing files, creating
!      & expanding archives, compiling programs, sending mail, etc.  It looks
!      nice, has colors (if the standard ANSI color sequences are supported), &
!      is user-friendly.
! 
!    * `gmp'    **Note Forthcoming GNUs::*   (LangT, SrcCD)
! 
!      GNU `mp' is a library for arbitrary precision arithmetic on signed
!      integers and rational numbers.  It has a rich set of functions with a
!      regular interface.
! 
!    * GN	  (SrcCD)
  
!      GN is a gopher/HTTP server.  It recognizes whether the request came from
!      an HTTP (World Wide Web) or gopher client and responds accordingly.
  
     * Gnans    (SrcCD)
  
       Gnans is a program (and language) for the numerical study of
!      deterministic and stochastic dynamical systems.  The dynamical systems
!      may evolve in continuous or discrete time.	 Gnans has graphical &
!      command line interfaces.
! 
!    * GNATS   (SrcCD, UtilT)
! 
!      GNATS (GNats: A Tracking System, not to be confused with GNAT, The GNU
!      Ada Translator) is a bug-tracking system.	It is based upon the paradigm
!      of a central site or organization which receives problem reports and
!      negotiates their resolution by electronic mail.  Although it has been
!      used primarily as a software bug-tracking system so far, it is
!      sufficiently generalized that it could be used for handling system
!      administration issues, project management, or any number of other
!      applications.
  
!    * `gnuplot'	 (SrcCD, UtilT, WdwsD)
  
       `gnuplot' is an interactive program for plotting mathematical
!      expressions and data.  It plots both curves (2 dimensions) & surfaces (3
!      dimensions).  Curiously, it was neither written nor named for the GNU
!      Project; the name is a coincidence.  Various GNU programs use `gnuplot'.
! 
!    * `gnuserv'	 (LspEmcT, SrcCD)
! 
!      `gnuserv' is a enhanced version of Emacs' `emacsclient' program.  It
!      lets the user direct a running Emacs to edit files or evaluate arbitrary
!      Emacs Lisp constructs from another process.
! 
!    * GnuGo   (SrcCD, UtilT)
! 
!      GnuGo plays the game of Go (Wei-Chi); version 1.2 was released with minor
!      changes for portability,  but it is not yet very sophisticated.
! 
!    * `gperf'   (LangT, SrcCD)
! 
!      `gperf' generates perfect hash tables.  The C version is in package
!      cperf.  The C++ version is in libg++.  Both produce hash functions in
!      either C or C++.
! 
!    * Graphics	(SrcCD, UtilT)
! 
!      GNU Graphics produces x-y plots from ASCII or binary data.	 It outputs
!      in Postscript, Tektronix 4010 compatible, and Unix device-independent
!      "plot" formats.  It has a previewer for the X Window System.  Features
!      include a `spline' interpolation program; examples of shell scripts
!      using `graph' and `plot'; a statistics toolkit; and output in TekniCAD
!      TDA and ln03 file formats.	 Email bugs or queries to Rich Murphey,
!      `Rich@lamprey.utmb.edu'.
! 
!    * grep   (DosBC, SrcCD, UtilT)
! 
!      This package has GNU `grep', `egrep', and `fgrep', which find lines that
!      match entered patterns.  They are much faster than the traditional Unix
!      versions.
! 
!    * Groff   (DjgpD, DosBC, SrcCD, UtilT)
! 
!      Groff is a document formatting system based on a device-independent
!      version of `troff' & includes: `eqn', `nroff', `pic', `refer', `tbl',
!      `troff'; the `man', `ms', & `mm' macros; & drivers for Postscript, TeX
!      `dvi' format, and typewriter-like devices.	 Groff's `mm' macro package
!      is almost compatible with the DWB `mm' macros with several extensions.
!      Also included is a modified version of the Berkeley `me' macros and an
!      enhanced version of the X11 `xditview' previewer.	A driver for the
!      LaserJet 4 series of printers is currently in test.  Written in C++,
!      these programs can be compiled with GNU C++ Version 2.5 or later.
! 
!      Groff users are encouraged to contribute enhancements.  Most needed are
!      complete Texinfo documentation, a `grap' emulation (a `pic' preprocessor
!      for typesetting graphs), a page-makeup postprocessor similar to `pm'
!      (see `Computing Systems', Vol. 2, No. 2; ask `office@usenix.org' how to
!      get a copy), and an ASCII output class for `pic' to integrate `pic' with
!      Texinfo.  Questions and bug reports from users who have read the
!      documentation provided with Groff can be sent to
!      `bug-groff@prep.ai.mit.edu'.
  
!    * `gzip'   (DjgpD, DosBC, LangT, LspEmcT, SrcCD, UtilT)
  
       `gzip' can expand LZW-compressed files but uses another, unpatented
!      algorithm for compression which generally produces better results.	 It
!      also expands files compressed with System V's `pack' program.
  
!    * `hello'   (DosBC, SrcCD, UtilT)
  
       The GNU `hello' program produces a familiar, friendly greeting.  It
!      allows non-programmers to use a classic computer science tool which would
!      otherwise be unavailable to them.	Because it is protected by the GNU
!      General Public License, users are free to share and change it.  `hello'
!      is also a good example of a program that meets the GNU coding standards.
  
!      Like any truly useful program, `hello' contains a built-in mail reader.
! 
!    * `hp2xx'   (SrcCD, UtilT)
  
       GNU `hp2xx' reads HP-GL files, decomposes all drawing commands into
!      elementary vectors, and converts them into a variety of vector and raster
!      output formats.  It is also an HP-GL previewer.  Currently supported
!      vector formats include encapsulated Postscript, Uniplex RGIP, Metafont,
!      various special TeX-related formats, and simplified HP-GL (line drawing
!      only) for imports.	 Raster formats supported include IMG, PBM, PCX, &
!      HP-PCL (including Deskjet & DJ5xxC support).  Previewers work under X11
!      (Unix), OS/2 (PM & full screen), & MS-DOS (SVGA, VGA, & HGC).
! 
!    * HylaFAX   (SrcCD, UtilT)
! 
!      HylaFAX (once named FlexFAX) is a facsimile system for Unix systems.  It
!      supports sending, receiving, & polled retrieval of facsimile, as well as
!      transparent shared data use of the modem.
  
       Details are available on the World Wide Web at:
       `http://www.vix.com/hylafax/'.
  
!    * Hyperbole	 (LspEmcT, SrcCD)
  
!      Hyperbole, written by Bob Weiner in Emacs Lisp, is an open, efficient,
!      programmable information management & hypertext system, intended for
!      everyday work on any platform supported by Emacs.
! 
!    * `indent'	(DosBC, LangT, SrcCD, UtilD)
! 
!      GNU `indent' formats C source code into the GNU indentation style.	 It
!      also has options to output BSD, K&R, or your own special style.  GNU
!      `indent' is more robust & provides more functionality than other such
!      programs, including handling C++ comments.	 It runs on a number of
!      systems, including DOS & VMS.
  
       The next version will also format C++ source code.
  
!    * Ispell   (DosBC, SrcCD, UtilT)
  
!      Ispell is an interactive spell checker that suggests "near misses" to
!      replace unrecognized words.  System & user-maintained dictionaries for
!      multiple languages can be used.  Standalone & Emacs interfaces are
!      available.
! 
!      Previously, the FSF had its own version of Ispell ("Ispell 4.0"), but
!      has dropped it for a parallel branch that has had more development
!      ("Ispell 3.1").  (Ispell 3 was an earlier release by the original Ispell
!      author, but others have since made it more sophisticated.)
  
     * JACAL   *Not available from the FSF except by FTP*
  
       JACAL is a symbolic mathematics system for the manipulation and
!      simplification of algebraic equations and expressions.  New in JACAL is
!      multivariate factoring from Michael Thomas `(mjt@octavia.anu.edu.au)'.
!      See JACAL's documentation at `http://www-swiss.ai.mit.edu/~jaffer/'.
! 
!      JACAL is written in Scheme using the SLIB portable Scheme Library.	 It
!      comes with SCM, an IEEE P1178 & R4RS compliant version of Scheme written
!      in C.  SCM runs on Amiga, Atari-ST, MS-DOS, OS/2, NOS/VE, Unicos, VMS,
!      Unix, & similar systems.
! 
!      The FSF is not distributing JACAL on any physical media.  To get an IBM
!      PC floppy disk with the freely redistributable source & executable
!      files, send $99.00 to:
! 
! 	  Aubrey Jaffer
! 	  84 Pleasant Street
! 	  Wakefield, MA	  01880-1846
! 	  USA
  
!    * `less'   (DosBC, SrcCD, UtilD, UtilT)
  
       `less' is a display paginator similar to `more' and `pg', but with
!      various features (such as the ability to scroll backwards) that most
!      pagers lack.
  
!    * `m4'   (DosBC, SrcCD, UtilD, UtilT)
  
!      GNU `m4' is an implementation of the traditional Unix macro processor.
!      It is mostly SVR4 compatible, although it has some extensions (e.g.,
!      handling more than 9 positional parameters to macros).  `m4' also has
!      built-in functions for including files, running shell commands, doing
!      arithmetic, etc.
! 
!    * `make' (BinCD,DjgpD,DosBC,LangT,LspEmcT,SrcCD,UtilD,UtilT)[FSFman]
! 
!      GNU `make' supports POSIX 1003.2 and has all but a few obscure features
!      of the BSD and System V versions of `make'.  GNU extensions include long
!      options, parallel compilation, flexible implicit pattern rules,
!      conditional execution, & powerful text manipulation functions.  Texinfo
!      source for the `Make Manual' comes with the program (*note
!      Documentation::.).
  
!    * MandelSpawn   (SrcCD, UtilT)
  
       A parallel Mandelbrot generation program for the X Window System.
  
!    * Midnight Commander (`mc')	 (SrcCD, UtilT)
! 
!      The Midnight Commander is a user friendly and colorful Unix file manager
!      and shell, useful to novice and guru alike.  It has a built-in virtual
!      file system that allows the user to manipulate files inside tar files
!      (both regular and compressed) or files on remote machines using the FTP
!      protocol.
! 
!    * `mkisofs'	 (SrcCD, UtilT)
! 
!      `mkisofs' is a pre-mastering program to generate an ISO 9660 file system.
!      It takes a snapshot of a directory tree, and makes a binary image which
!      corresponds to an ISO 9660 file system when written to a block device.
  
!      It can also generate the System Use Sharing Protocol records of the Rock
!      Ridge Interchange Protocol (used to further describe the files in an ISO
!      9660 file system to a Unix host; it provides information such as longer
!      filenames, uid/gid, permissions, and device nodes).
  
!      Also included is `cdwrite', which can take an image from `mkisofs' and
!      write it to a Phillips CD recorder system attached to a GNU/Linux system.
  
!    * mtools   (SrcCD, UtilT)
  
!      mtools is a set of public domain programs to allow Unix systems to read,
!      write, and manipulate files on an MS-DOS file system (usually a
!      diskette).
! 
!    * MULE   (DosBC, EmcsD, LspEmcT, SrcCD)
! 
!      MULE is a MULtilingual Enhancement to GNU Emacs.  MULE text buffers can
!      contain a mix of characters from many languages including: Japanese,
!      Chinese, Korean, Vietnamese, Thai, modern European languages (including
!      Greek & Russian), Arabic, & Hebrew.  MULE also provides input methods
!      for all of them.  MULE is being merged into GNU Emacs.  *Note GNU &
!      Other Free Software in Japan::, for more information about MULE.
! 
!    * `ncurses'	 (LangT, SrcCD)
  
       `ncurses' is an implementation of the Unix `curses' library for
!      developing screen based programs that are terminal independent.
  
!    * NetHack   (SrcCD, UtilT)
  
!      NetHack is a Rogue-like adventure game supporting character & X displays.
  
!    * NIH Class Library	 (LangT, SrcCD)
  
!      The NIH Class Library (once known as "OOPS", Object-Oriented Program
!      Support) is a portable collection of C++ classes (similar to those in
!      Smalltalk-80) written in C++ by Keith Gorlen of the National Institutes
!      of Health (NIH).
! 
!    * `nvi'   (SrcCD, UtilT)
! 
!      `nvi' is a free implementation of the `vi'/`ex' Unix editor.  It has
!      most of the functionality of the original `vi'/`ex', except "open" mode
!      & the `lisp' option, which will be added.	Enhancements over `vi'/`ex'
!      include split screens with multiple buffers, handling 8-bit data,
!      infinite file & line lengths, tag stacks, infinite undo, & extended
!      regular expressions.  It runs under GNU/Linux, BSD, NetBSD, FreeBSD,
!      BSDI, AIX, HP-UX, DGUX, IRIX, PSF, PTX, Solaris, SunOS, Ultrix, and
!      Unixware, & should port easily to other systems.
! 
!    * Oaklisp	(SrcCD)
! 
!      Oaklisp is a fast, portable, object-oriented Scheme with first class
!      types.
! 
!    * Objective-C Library   **Note Forthcoming GNUs::*	(LangT, SrcCD)
! 
!      Our Objective-C Class Library (`libobjects') has general-purpose,
!      non-graphical Objective-C objects written by Andrew McCallum & other
!      volunteers.  It includes collection classes for using groups of objects
!      & C types, I/O streams, coders for formatting objects & C types to
!      streams, ports for network packet transmission, distributed objects
!      (remote object messaging), string classes, exceptions, pseudo-random
!      number generators, & time handling facilities.  It also includes the
!      foundation classes for the GNUStep project; over 70 of them have already
!      been implemented.	The library is known to work on i386/i486/Pentiums,
!      m68k, SPARC, MIPS, HPPA, & RS/6000.  Send queries & bug reports to
!      `mccallum@gnu.ai.mit.edu'.
  
!    * OBST   (LangT, SrcCD)
  
       OBST is a persistent object management system with bindings to C++.
       OBST supports incremental loading of methods.  Its graphical tools
!      require the X Window System.  It features a hands-on tutorial including
!      sample programs.  It compiles with G++, and should install easily on
!      most Unix platforms.
! 
!    * Octave   (LangT, SrcCD)
! 
!      Octave is a high-level language similar to MATLAB, primarily intended
!      for numerical computations.  It has a convenient command line interface
!      for solving linear & nonlinear problems numerically.
! 
!      Octave does arithmetic for real and complex scalars and matrices, solves
!      sets of nonlinear algebraic equations, integrates systems of ordinary
!      differential & differential-algebraic equations, and integrates
!      functions over finite & infinite intervals.  Two- & three-dimensional
!      plotting is available using `gnuplot'.
  
!      Send queries and bug reports to: `bug-octave@bevo.che.wisc.edu'.
  
       Texinfo source is included for a 220+ page Octave manual, not yet
       published by the FSF.
  
!    * Oleo   (SrcCD, UtilT)
  
!      Oleo is a spreadsheet program (better for you than the more expensive
!      spreadsheets).  It supports the X Window System and character-based
!      terminals, and can output Embedded Postscript renditions of spreadsheets.
!      Keybindings should be familiar to Emacs users and are configurable.
!      Oleo supports multiple variable-width fonts when used under the X Window
!      System or outputting to Postscript devices.
  
!    * `p2c'   (LangT, SrcCD)
  
!      `p2c' is Dave Gillespie's Pascal-to-C translator.	It inputs many
!      different dialects (HP, ISO, Turbo, VAX, et al.) and generates readable,
       maintainable, portable C.
  
!    * `patch'   (DosBC, SrcCD, UtilT)
  
!      `patch' is our version of Larry Wall's program to take `diff''s output
!      and apply those differences to an original file to generate the modified
!      version.
  
!    * PCL   (LspEmcT, SrcCD)
  
!      PCL is a free implementation of a large subset of CLOS, the Common Lisp
!      Object System.  It runs under both GCL and CLISP, mentioned above.
  
!    * `perl'   (DosBC, LangT, SrcCD)
  
!      Larry Wall's `perl' combines the features and capabilities of `sed',
!      `awk', `sh', and C.  It also provides interfaces to the Unix system
!      calls and many C library routines.
  
!    * `pine'   (SrcCD, UtilT)
  
       `pine' is a friendly menu-driven electronic mail manager and user
       interface .
  
!    * `ptx'    **Note Forthcoming GNUs::*   (SrcCD, UtilD, UtilT)
  
!      GNU `ptx' is our version of the traditional permuted index generator.
!      It handles multiple input files at once, produces TeX compatible output,
!      and generates readable "KWIC" (KeyWords In Context) indexes without
!      using `nroff'.
  
!      It does not yet handle input files that do not fit in memory all at once.
  
!    * `rc'   (SrcCD, UtilT)
  
!      `rc' is a shell that features a C-like syntax (much more so than `csh')
!      and far cleaner quoting rules than the C or Bourne shells.	 It's
!      intended to be used interactively, but is also great for writing
!      scripts.  It inspired the shell `es'.
  
!    * RCS   (SrcCD, UtilD, UtilT)
  
       RCS, the Revision Control System, is used for version control &
!      management of software projects.  Used with GNU `diff', RCS can handle
!      binary files (executables, object files, 8-bit data, etc).	 RCS now
!      conforms to GNU configuration standards and to POSIX 1003.1b-1993.	 Also
!      see the CVS item above.
! 
!    * `recode'	 **Note Forthcoming GNUs::*   (SrcCD, UtilT)
! 
!      GNU `recode' converts files between character sets and usages.  When
!      exact transliterations are not possible, it may delete the offending
!      characters or fall back on approximations.	 This program recognizes or
!      outputs nearly 150 different character sets and is able to transliterate
!      files between almost any pair.  Most RFC 1345 character sets are
!      supported.
  
!    * `regex'   (LangT, SrcCD)
  
       The GNU regular expression library supports POSIX.2, except for
!      internationalization features.  It is included in many GNU programs which
!      do regular expression matching & is available separately.	An alternate
!      regular expression package, `rx', is faster than `regex' in most cases &
!      will replace `regex' over time.
! 
!    * `rx'   (LangT, SrcCD)
! 
!      Tom Lord has written `rx', a new regular expression library which is
!      faster than the older GNU `regex' library.	 It is now being distributed
!      with `sed' and `tar'.  `rx' will be used in the next releases of `m4'
!      and `ptx'.
! 
!    * SAOimage	(SrcCD, UtilT)
! 
!      SAOimage is an X-based astronomical image viewer.	It reads data images
!      and displays them with a pseudocolor colormap.  There is full interactive
!      control of the colormap, reading, and writing of colormaps, etc.
! 
!    * Scheme   *For more information, see *Note Scheme Tape::*	(SrcCD, SchmT)
! 
!    * `screen'	(SrcCD, UtilT)
! 
!      `screen' is a terminal multiplexer that runs several separate "screens"
!      (ttys) on a single character-based terminal.  Each virtual terminal
!      emulates a DEC VT100 plus several ISO 2022 and ISO 6429 (ECMA 48, ANSI
!      X3.64) functions, including color.	 Arbitrary keyboard input translation
!      is also supported.	 `screen' sessions can be detached and resumed later
!      on a different terminal type.  Output in detached sessions is saved for
!      later viewing.
! 
!    * `sed'   (DjgpD, DosBC, SrcCD, UtilD, UtilT)
! 
!      `sed' is a stream-oriented version of `ed'.  It comes with the `rx'
!      library.
! 
!    * Sharutils	 (SrcCD, UtilT)
! 
!      `shar' makes so-called shell archives out of many files, preparing them
!      for transmission by electronic mail services; `unshar' helps unpack
!      these shell archives after reception.  `uuencode' and `uudecode' are
!      POSIX compliant implementations of a pair of programs to transform files
!      into a format that can be safely transmitted across a 7-bit ASCII link.
! 
!    * Shellutils	  (DosBC, SrcCD, UtilT)
! 
!      They are: `basename', `date', `dirname', `echo', `env', `expr', `false',
!      `groups', `hostname', `id', `logname', `nice', `nohup', `pathchk',
!      `printenv', `printf', `pwd', `sleep', `stty', `su', `tee', `test',
!      `true', `tty', `uname', `users', `who', `whoami', & `yes'.
! 
!    * Shogi   (SrcCD, UtilT)
! 
!      Shogi is a Japanese game similar to Chess; a major difference is that
!      captured pieces can be returned into play.
! 
!      GNU Shogi is a variant of GNU Chess; it implements the same features &
!      similar heuristics.  As a new feature, sequences of partial board
!      patterns can be introduced to help the program play toward specific
!      opening patterns.	It has both character and X display interfaces.
  
       It is primarily supported by Matthias Mutz on behalf of the FSF.
--- 521,1824 ----
  ************
  
!    All our software is available via FTP; see *Note How to Get GNU
! Software::.  We also offer *Note CD-ROMs::, and printed *Note
! Documentation::, which includes manuals and reference cards.  In the
! articles describing the contents of each medium, the version number
! listed after each program name was current when we published this
! Bulletin.  When you order a newer CD-ROM, some of the programs may be
! newer and therefore the version number higher.  See the *note Free
! Software Foundation Order Form::., for ordering information.
! 
!    Some of the contents of our FTP distributions are compressed.  We
! have software on our FTP sites to uncompress these files.  Due to
! patent troubles with `compress', we use another compression program,
! `gzip'.  (Such prohibitions on software development are fought by the
! League for Programming Freedom; *note What Is the LPF::., for details.)
! 
!    You may need to build GNU `make' before you build our other software.
! Some vendors supply no `make' utility at all and some native `make'
! programs lack the `VPATH' feature essential for using the GNU configure
! system to its full extent.  The GNU `make' sources have a shell script
! to build `make' itself on such systems.
  
!    We welcome all bug reports and enhancements sent to the appropriate
  electronic mailing list (*note Free Software Support::.).
  
!     
  
  Configuring GNU Software
  ------------------------
  
! We are using Autoconf, a uniform scheme for configuring GNU software
! packages in order to compile them (see "Autoconf" and "Automake" below,
! in this article).  The goal is to have all GNU software support the same
! alternatives for naming machine and system types.
! 
!    Ultimately, it will be possible to configure and build the entire
! system all at once, eliminating the need to configure each individual
! package separately.
  
!    You can also specify both the host and target system to build
  cross-compilation tools.  Most GNU programs now use Autoconf-generated
  configure scripts.
  
+     
  
! GNU Software Now Available
! --------------------------
  
  For future programs and features, see *Note Forthcoming GNUs::.
  
!    Key to cross reference:
  
+         BinCD        December 1995 Binaries CD-ROM
+         SrcCD        July 1996 Source CD-ROMs
  
! [FSFman] shows that we sell a manual for that package.  [FSFrc] shows
! we sell a reference card for that package.  To order them, see the
! *note Free Software Foundation Order Form::..  *Note Documentation::,
! for more information on the manuals.  Source code for each manual or
! reference card is included with each package.
! 
!    * `acm'   (SrcCD)
! 
!      `acm' is a LAN-oriented, multiplayer, aerial combat simulation that
!      runs under the X Window System.  Players engage in air to air
!      combat against one another using heat seeking missiles and cannons.
!      We are working on a more accurate simulation of real airplane
!      flight characteristics.
! 
!    * Apache   (SrcCD)
! 
!      Apache is an HTTP server designed as a plug-in replacement for
!      version 1.3 or 1.4 of the NCSA server.  It fixes many bugs in the
!      NCSA server, includes many frequently requested new features, and
!      has an API which allows it to be extended to meet users' needs
!      more easily.
! 
!    * Autoconf   (SrcCD)
! 
!      Autoconf produces shell scripts which automatically configure
!      source code packages.  These scripts adapt the packages to many
!      kinds of Unix-like systems without manual user intervention.
!      Autoconf creates a script for a package from a template file which
!      lists the operating system features which the package can use, in
!      the form of `m4' macro calls.  Autoconf requires GNU `m4' to
!      operate, but the resulting configure scripts it generates do not.
! 
!    * Automake   (SrcCD)
! 
!      Automake is a tool for generating `Makefile.in's for use with
!      Autoconf.  The generated makefiles are compliant with GNU Makefile
!      standards.
! 
!    * BASH   (SrcCD)
! 
!      GNU's shell, BASH (Bourne Again SHell), is compatible with the
!      Unix `sh' and offers many extensions found in `csh' and `ksh'.
!      BASH has job control, `csh'-style command history, command-line
!      editing (with Emacs and `vi' modes built-in), and the ability to
!      rebind keys via the `readline' library.  BASH conforms to the
!      POSIX 1003.2-1992 standard.
  
!    * `bc'   (SrcCD)
  
       `bc' is an interactive algebraic language with arbitrary precision
!      numbers.  GNU `bc' follows the POSIX 1003.2-1992 standard with
!      several extensions, including multi-character variable names, an
!      `else' statement, and full Boolean expressions.  The RPN
!      calculator `dc' is now distributed as part of the same package,
!      but GNU `bc' is not implemented as a `dc' preprocessor.
! 
!    * BFD   (BinCD, SrcCD)
! 
!      The Binary File Descriptor library allows a program which operates
!      on object files (e.g., `ld' or GDB) to support many different
!      formats in a clean way.  BFD provides a portable interface, so
!      that only BFD needs to know the details of a particular format.
!      One result is that all programs using BFD will support formats
!      such as a.out, COFF, and ELF.  BFD comes with Texinfo source for a
!      manual (not yet published on paper).
  
       At present, BFD is not distributed separately; it is included with
       packages that use it.
  
!    * Binutils   (BinCD, SrcCD)
  
!      Binutils includes these programs: `ar', `c++filt', `demangle',
!      `gas', `gprof', `ld', `nlmconv', `nm', `objcopy', `objdump',
!      `ranlib', `size', `strings', & `strip'.
  
       Binutils version 2 uses the BFD library.  The GNU assembler, `gas',
!      supports the a29k, Alpha, H8/300, H8/500, HP-PA, i386, i960, m68k,
!      m88k, MIPS, NS32K, SH, SPARC, Tahoe, Vax, and Z8000 CPUs, and
!      attempts to be compatible with many other assemblers for Unix and
!      embedded systems.  It can produce mixed C and assembly listings,
!      and includes a macro facility similar to that in some other
!      assemblers.  GNU's linker, `ld', emits source-line numbered error
!      messages for multiply-defined symbols and undefined references,
!      and interprets a superset of AT&T's Linker Command Language, which
!      gives control over where segments are placed in memory.  `nlmconv'
!      converts object files into Novell NetWare Loadable Modules.
!      `objdump' can disassemble code for most of the CPUs listed above,
!      and can display other data (e.g., symbols and relocations) from
!      any file format read by BFD.
! 
!    * Bison   (BinCD, SrcCD)   [FSFman, FSFrc]
! 
!      Bison is an upwardly compatible replacement for the parser
!      generator `yacc'.  Texinfo source for the `Bison Manual' and
!      reference card are included; see *Note Documentation::.
! 
!      A recent policy change allows non-free programs to use
!      Bison-generated parsers.
! 
!    * C Library   *See *Note Forthcoming GNUs::*   (BinCD, SrcCD)  
!      [FSFman]
! 
!      The GNU C library supports ANSI C-1989, POSIX 1003.1-1990 and most
!      of the functions in POSIX 1003.2-1992.  It is upwardly compatible
!      with 4.4BSD and includes many System V functions, plus GNU
!      extensions.
! 
!      When used with the GNU Hurd, the C Library performs many functions
!      of the Unix system calls directly.  Mike Haertel has written a
!      fast `malloc' which wastes less memory than the old GNU version.
!      The GNU regular-expression functions (`regex' and `rx') now nearly
!      conform to the POSIX 1003.2 standard.
! 
!      GNU `stdio' lets you define new kinds of streams, just by writing a
!      few C functions.  The `fmemopen' function uses this to open a
!      stream on a string, which can grow as necessary.  You can define
!      your own `printf' formats to use a C function you have written.
!      For example, you can safely use format strings from user input to
!      implement a `printf'-like function for another programming
!      language.  Extended `getopt' functions are already used to parse
!      options, including long options, in many GNU utilities.  Texinfo
!      source for the `GNU C Library Reference Manual' is included (*note
       Documentation::.).
  
!      It runs on Sun-3 (SunOS 4.1), Sun-4 (SunOS 4.1 or Solaris 2), HP
!      9000/300 (4.3BSD), SONY News 800 (NewsOS 3 or 4), MIPS DECstation
!      (Ultrix 4), DEC Alpha (OSF/1), i386/i486/Pentium (GNU/Hurd,
!      GNU/Linux, System V, SVR4, BSD, SCO 3.2, & SCO ODT 2.0), Sequent
!      Symmetry i386 (Dynix 3), & SGI (Irix 4).
! 
!    * C++ Library   (BinCD, SrcCD)
! 
!      The GNU C++ library (libg++) contains an extensive collection of
!      container and utility classes, including Obstacks,
!      multiple-precision Integers and Rationals, Complex numbers,
!      BitSets, and BitStrings.
! 
!      The distribution also includes the libstdc++ library.  This
!      implements library facilities defined by the forthcoming ANSI/ISO
!      C++ standard, including strings, the iostream library, and a port
!      of the Standard Template Library.
! 
!    * Calc   (SrcCD)   [FSFman, FSFrc]
! 
!      Calc (written by Dave Gillespie in Emacs Lisp) is an extensible,
!      advanced desk calculator & mathematical tool that runs as part of
!      GNU Emacs.  You can use Calc as a simple four-function calculator,
!      but it has many more features including: choice of algebraic or
!      RPN (stack-based) entry; logarithmic, trigonometric, & financial
!      functions; arbitrary precision; complex numbers; vectors;
!      matrices; dates; times; infinities; sets; algebraic
!      simplification; & differentiation & integration.  It outputs to
!      `gnuplot', & comes with source for a manual & reference card
!      (*note Documentation::.).
  
!    * `cfengine'   (SrcCD)
! 
!      `cfengine' is used to maintain site-wide configuration of a
       heterogeneous Unix network using a simple high level language.  Its
!      appearance is similar to `rdist', but allows many more operations
!      to be performed automatically.  See Mark Burgess, "A Site
!      Configuration Engine", `Computing Systems', Vol. 8, No. 3 (ask
!      `office@usenix.org' how to get a copy).
! 
!    * Chess   (SrcCD)
! 
!      GNU Chess lets most modern computers play a full game of chess.  It
!      has a plain terminal interface, a curses interface, & `xboard''s
!      spiffy X Window interface.
! 
!      Recent improvements include fixes to the game analyzer, book, &
!      hash table; smartening up draw & mate; improved thinking on
!      opponent's time; Autoconf installation; a makefile for Windows NT
!      compilation; forward pruning; unlimited quiescence captures;
!      improved evaluation; improved null & time control logic; &
!      repetition-detection.
  
!      Stuart Cracraft started GNU Chess.  Improvements & rewrites are
!      from John Stanback, Cha Kong Sian, Mike McGann, et al.
  
       Send bugs to `bug-gnu-chess@prep.ai.mit.edu' & general comments to
       `info-gnu-chess@prep.ai.mit.edu'.
  
!    * CLISP   (SrcCD)
  
!      CLISP is a Common Lisp implementation by Bruno Haible and Michael
!      Stoll.  It mostly supports the Lisp described by `Common LISP: The
!      Language (2nd edition)' and the ANSI Common Lisp standard.  CLISP
!      includes an interpreter, a byte-compiler, a large subset of CLOS,
!      a foreign language interface, and, for some machines, a screen
!      editor.  The user interface language (English, German, French) can
!      be chosen at run time.  Major packages that run in CLISP include
!      CLX & Garnet.  CLISP needs only 2 MB of memory & runs on many
!      microcomputers (including MS-DOS systems, OS/2, Windows NT, Amiga
!      500-4000, and Acorn RISC PC) & Unix-like systems (GNU/Linux, Sun4,
!      SVR4, SGI, HP-UX, DEC Alpha, NeXTStep, & others).
! 
!    * Common Lisp   *Also *note Forthcoming GNUs::.*   (SrcCD)
! 
!      GNU Common Lisp (GCL, formerly known as Kyoto Common Lisp) is a
!      compiler & interpreter for Common Lisp.  GCL is very portable &
!      extremely efficient on a wide class of applications, & compares
!      favorably in performance with commercial Lisps on several large
!      theorem-prover & symbolic algebra systems.  GCL supports the CLtL1
!      specification but is moving towards the proposed ANSI standard.
! 
!      GCL compiles to C & then uses the native optimizing C compiler
!      (e.g., GCC).  A function with a fixed number of args & one value
!      turns into a C function of the same number of args, returning one
!      value--so GCL is maximally efficient on such calls.  Its
!      conservative garbage collector gives great freedom to the C
!      compiler to put Lisp values in registers.  It has a source level
!      Lisp debugger for interpreted code & displays source code in an
!      Emacs window.  Its profiler (based on the C profiling tools)
!      counts function calls & the time spent in each function.
! 
!      There is now a built-in interface to the Tk widget system.  It runs
!      in a separate process, so users may monitor progress on Lisp
!      computations or interact with running computations via a windowing
!      interface.
! 
!      There is also an Xlib interface via C (xgcl-2)  CLX runs with
!      GCL, as does PCL (see "PCL" later in this article).
! 
!      GCL version 2.2 is released under the GNU Library General Public
!      License.
  
!    * CLX   (SrcCD)
  
!      CLX is an X Window interface library for GCL.  This is separate
!      from the built-in TK interface.
  
!    * `cpio'   (SrcCD)
  
       `cpio' is an archive program with all the features of SVR4 `cpio',
!      including support for the final POSIX 1003.1 `ustar' standard.
!      `mt', a program to position magnetic tapes, is included with
!      `cpio'.
! 
!    * CVS   (SrcCD)
! 
!      CVS is a version control system (like RCS or SCCS) which allows
!      you to keep old versions of files (usually source code), keep a
!      log of who, when, and why changes occurred, etc.  It handles
!      multiple developers, multiple directories, triggers to
!      enable/log/control various operations, and can work over a wide
!      area network.  It does not handle build management or
!      bug-tracking; these are handled by `make' and GNATS, respectively.
! 
!    * DejaGnu   (SrcCD)
! 
!      DejaGnu is a framework to test programs with a single front end
!      for all tests.  DejaGnu's flexibility & consistency makes it easy
!      to write tests.
  
!      DejaGnu comes with `expect', which runs scripts to conduct dialogs
!      with programs.
  
!    * Diffutils   (SrcCD)
  
       GNU `diff' compares files showing line-by-line changes in several
!      flexible formats.  It is much faster than traditional Unix
!      versions.  The Diffutils package contains `diff', `diff3',
!      `sdiff', & `cmp'.  Recent improvements include more consistent
!      handling of character sets and a new `diff' option to do all
!      input/output in binary; this is useful on some non-POSIX hosts.
!      Plans for the Diffutils package include support for
!      internationalization (e.g., error messages in Chinese) and for some
       non-Unix PC environments.
  
!    * DJGPP   (BinCD)
  
       DJ Delorie has ported GCC/G++ (see "GCC" in this article) to i386s
!      running MS-DOS.  DJGPP has a 32-bit i386 DOS extender with a
!      symbolic debugger, development libraries, & ports of Bison,
!      `flex', & Binutils.  Full source code is provided.  It needs at
!      least 5MB of hard disk space to install & 512K of RAM to use.  It
!      supports SVGA (up to 1024x768), XMS & VDISK memory allocation,
!      `himem.sys', VCPI (e.g., QEMM, DESQview, & 386MAX), & DPMI (e.g.,
!      Windows 3.x, OS/2, QEMM, & QDPMI).  DJGPP Version 2 was released
!      in Feb 1996, & needs a DPMI environment; a free DPMI server is
!      included.
  
!      FTP from `ftp.simtel.net' in `/pub/simtelnet/gnu/djgpp/' (or
!      another SimTel mirror site).
  
!      Ask `listserv@delorie.com', to join a DJGPP users mailing list.
  
!    * `dld'   (SrcCD)
  
!      `dld' is a dynamic linker written by W. Wilson Ho.  Linking your
!      program with the `dld' library allows you to dynamically load
!      object files into the running binary.  `dld' supports a.out object
!      types on the following platforms: Convex C-Series (BSD),
!      i386/i486/Pentium (Linux), Sequent Symmetry i386 (Dynix 3), Sun-3
!      (SunOS 3 & 4), Sun-4 (SunOS 4), & VAX (Ultrix).
  
!    * `doschk'   (SrcCD)
  
!      This program is a utility to help software developers ensure that
!      their source file names are distinguishable on System V platforms
!      with 14-character filenames and on MS-DOS systems with 8+3
!      character filenames.
  
!    * `ecc'   (SrcCD)
  
!      `ecc' is a Reed-Solomon error correction checking library and
!      sample program, which can correct three byte errors in a block of
!      255 bytes and detect more severe errors.  Contact `fclim@acm.org'
!      for more information.
  
!    * `ed'   (SrcCD)
  
!      `ed' is the standard text editor.  It is line-oriented and can be
!      used interactively or in scripts.
  
!    * Elib   (SrcCD)
  
!      Elib is a small library of Emacs Lisp functions, including
!      routines for using AVL trees and doubly-linked lists.
  
     * Elisp archive   (SrcCD)
  
!      This is a snapshot of Ohio State's GNU Emacs Lisp FTP Archive.
!      FTP it from `archive.cis.ohio-state.edu' in
!      `/pub/gnu/emacs/elisp-archive'.
  
!    * Emacs   *Also *note Forthcoming GNUs::.*   [FSFman(s), FSFrc]
  
       In 1975, Richard Stallman developed the first Emacs, an extensible,
!      customizable real-time display editor & computing environment.
!      GNU Emacs is his second implementation.  It offers true
!      Lisp--smoothly integrated into the editor--for writing extensions
!      & provides an interface to the X Window System.  It runs on Unix,
!      MS-DOS, & Windows NT or 95.  In addition to its powerful native
!      command set, Emacs can emulate the editors vi & EDT (Digital's VMS
!      editor).  Emacs has many other features which make it a full
!      computing support environment.  Source for the `GNU Emacs Manual' &
!      a reference card comes with the software.  Sources for the `GNU
!      Emacs Lisp Reference Manual', & `Programming in Emacs Lisp: An
       Introduction' are distributed in separate packages.  *Note
       Documentation::.
  
!    * Emacs 19   (SrcCD)   [FSFman(s), FSFrc]
  
!      Emacs 19 works with character-only terminals & with the X Window
!      System (with or without an X toolkit).  New Emacs 19 features
!      include: multiple X windows ("frames" to Emacs), with a separate X
!      window for the minibuffer or a minibuffer attached to each X
!      window; use of the X toolkit; interfacing with the X resource
!      manager; property lists associated with regions of text in a
!      buffer; multiple fonts & colors defined by those properties;
!      simplified/improved processing of function keys, mouse movement &
!      clicks; X selection processing, including clipboard selections;
!      hooks to be run if the point or mouse moves outside a certain
!      range; menu bars & popup menus defined by keymaps; scrollbars;
!      before- & after-change hooks; a source-level debugger for Emacs
!      Lisp programs; floating point numbers; improved buffer allocation,
!      including returning storage to the system when a buffer is killed;
!      many updated libraries; Autoconf-based configuration; support for
!      version control systems (CVS, RCS, & SCCS); & European character
       sets.
  
!      Recent features include the ability to open frames on more than
!      one X display from a single Emacs job, operation under MS-DOS, MS
!      Windows, and Windows NT, displaying multiple views of an outline
!      at the same time, Lisp-level timers for real time and idle time,
!      version control support for CVS and for multiple branches, text
!      properties for formatting text, commands to edit text properties
!      and save them in files, and GNU-standard long-named command line
!      options.  Also see *Note Forthcoming GNUs::.
! 
!      Emacs 19.32 works on: Acorn RISC (RISCiX); Alliant FX/2800 (BSD);
!      Alpha (OSF/1 or GNU/Linux); Apollo (DomainOS); Bull DPX/2 2nn &
!      3nn (SysV.3) & sps7 (SysV.2); Clipper; Convex (BSD); Cubix QBx
!      (SysV); Data General Aviion (DGUX); DEC MIPS (Ultrix 4.2, OSF/1,
!      not VMS); Elxsi 6400 (SysV); Gould Power Node & NP1 (4.2 & 4.3BSD);
!      Harris Night Hawk 1200, 3000, 4000 & 5000 (cxux); Harris Night
!      Hawk Power PC (powerunix); Honeywell XPS100 (SysV); HP 9000 series
!      200, 300, 700, 800 (but not 500) (4.3BSD; HP-UX 7, 8, 9; NextStep);
!      Intel i386/i486/Pentium (GNU/Hurd, GNU/Linux, 386BSD, AIX,
!      BSDI/386, FreeBSD, Esix, ISC, MS-DOS, NetBSD, SCO3.2v4, Solaris,
!      SysV, Xenix, WindowsNT, Windows95); IBM RS/6000 (AIX 3.2) & RT/PC
!      (AIX, BSD); Motorola Delta 147 & 187 (SysV.3, SysV.4, m88kbcs);
!      National Semiconductor 32K (Genix); NeXT (BSD, Mach 2 w/ NeXTStep
!      3.0); Paragon (OSF/1); Prime EXL (SysV); Pyramid (BSD); Sequent
!      Symmetry (BSD, ptx); Siemens RM400 & RM600 (SysV); SGI Iris 4D
!      (Irix 4.x & 5.x); Sony News/RISC (NewsOS); Stardent i860 (SysV);
!      Sun 3 & 4, SPARC 1, 1+, 2, 10, Classic (SunOS 4.0, 4.1, Solaris
!      2.0-2.3); Tadpole 68k (SysV); Tektronix XD88 (SysV.3) & 4300
!      (BSD); & Titan P2 & P3 (SysV).
! 
!    * Emacs 18   (SrcCD)   [FSFrc]
! 
!      Emacs 18 is several years old.  We no longer maintain it, but still
!      distribute it for those using platforms which Emacs 19 does not
!      support: Alliant FX/80, Altos 3068, Amdahl (UTS), AT&T (3Bs & 7300
!      PC), CCI 5/32 & 6/32, Celerity, Digital (VAX VMS), Dual, Encore
!      (APC, DPC, & XPC), HLH Orion (original & 1/05), ISI (Optimum V,
!      80386), Masscomp, NCR Tower 32 (SVR2 & SVR3), Nixdorf Targon 31,
!      Nu (TI & LMI), pfa50, Plexus, Prime EXL, Stride (system rel. 2),
!      Tahoe, Tandem Integrity S2, Tektronix 16000, Triton 88, Ustation
!      E30 (SS5E), Whitechapel (MG1), & Wicat.
! 
!    * `es'   (SrcCD)
! 
!      `es' is an extensible shell (based on `rc') with first-class
!      functions, lexical scope, exceptions, and rich return values (i.e.,
!      functions can return values other than just numbers).  `es''s
!      extensibility comes from the ability to modify and extend the
!      shell's built-in services, such as path searching and redirection.
!      Like `rc', it is great for both interactive use and scripting,
!      particularly since its quoting rules are much less baroque than
!      the C and Bourne shells.
! 
!    * `enscript'   (SrcCD)
! 
!      `enscript' is an upwardly-compatible replacement for the Adobe
!      `enscript' program.  It formats ASCII files (outputting in
!      Postscript) and stores generated output to a file or sends it
!      directly to the printer.
! 
!    * Exim   (SrcCD)
! 
!      Exim is a new, somewhat experimental mail transfer agent, patterned
!      after some of the lessons learned during the development of Smail.
!      Exim can handle relatively high volume mail systems, caching of
!      mail delivery, header rewriting, multiple local domains from one
!      mail system, and control over which hosts/nets may use it as a
!      relay.
! 
!    * `f2c'   (SrcCD)
! 
!      `f2c' converts Fortran-77 source into C or C++, which can be
!      compiled with GCC or G++.  Get bug fixes by FTP from site
!      `netlib.bell-labs.com' or by email from
!      `netlib@netlib.bell-labs.com'.  For a summary, see the file
!      `/netlib/f2c/readme.Z'.  Also see the Fortran items later in this
!      article, and in *Note Forthcoming GNUs::.
  
!    * `ffcall'   (SrcCD)
  
       `ffcall' is a C library for implementing foreign function calls in
       embedded interpreters by Bill Triggs and Bruno Haible.  It allows C
!      functions with arbitrary argument lists and return types to be
!      called or emulated (callbacks).
  
!    * Fileutils   (SrcCD)
  
!      The Fileutils are: `chgrp', `chmod', `chown', `cp', `dd', `df',
!      `dir', `dircolors', `du', `install', `ln', `ls', `mkdir', `mkfifo',
!      `mknod', `mv', `rm', `rmdir', `sync', `touch', & `vdir'.
! 
!    * Findutils   (SrcCD)
! 
!      `find' is frequently used both interactively and in shell scripts
!      to find files which match certain criteria and perform arbitrary
!      operations on them.  Also included are `locate', which scans a
!      database for file names that match a pattern, and `xargs', which
!      applies a command to a list of files.
! 
!    * Finger   (SrcCD)
! 
!      GNU Finger has more features than other finger programs.  For
!      sites with many hosts, a single host may be designated as the
!      finger "server" host and other hosts at that site configured as
!      finger "clients".  The server host collects information about who
!      is logged in on the clients.  To finger a user at a GNU Finger
!      site, a query to any of its client hosts gets useful information.
!      GNU Finger supports many customization features, including user
!      output filters and site-programmable output for special target
!      names.
! 
!    * `flex'   (BinCD, SrcCD)   [FSFman, FSFrc]
! 
!      `flex' is a replacement for the `lex' scanner generator.  `flex'
!      was written by Vern Paxson of the Lawrence Berkeley Laboratory and
!      generates far more efficient scanners than `lex' does.  Sources
!      for the `Flex Manual' and reference card are included (*note
!      Documentation::.).
  
!    * Fortran (`g77')   *Also *note Forthcoming GNUs::.*   (SrcCD)
  
!      GNU Fortran (`g77'), developed by Craig Burley, is available for
!      public beta testing on the Internet.  For now, `g77' produces code
!      that is mostly object-compatible with `f2c' & uses the same
!      run-time library (`libf2c').
! 
!    * Fontutils   (SrcCD)
! 
!      The Fontutils convert between font formats, create fonts for use
!      with Ghostscript or TeX (starting with a scanned type image &
!      converting the bitmaps to outlines), etc.  It includes: `bpltobzr',
!      `bzrto', `charspace', `fontconvert', `gsrenderfont', `imageto',
!      `imgrotate', `limn', & `xbfe'.
  
!    * GAWK   (SrcCD)   [FSFman]
  
!      GAWK is upwardly compatible with the latest POSIX specification of
!      `awk'.  It also provides several useful extensions not found in
!      other `awk' implementations.  Texinfo source for the `The GNU Awk
!      User's Guide' comes with the software (*note Documentation::.).
  
!    * `gcal'   (SrcCD)
  
!      `gcal' is a program for printing calendars.  It displays different
!      styled calendar sheets, eternal holiday lists, and fixed date
!      warning lists.
  
!    * GCC   *Also *note Forthcoming GNUs::.*   (BinCD, SrcCD)   [FSFman]
  
       Version 2 of the GNU C Compiler supports the languages C, C++, and
!      Objective-C; the source file name suffix or a compiler option
!      selects the language.  Objective-C support was donated by NeXT.
!      The runtime support needed to run Objective-C programs is now
!      distributed with GCC (this does not include any Objective-C
!      classes aside from `object', but see "GNUstep" in *Note
!      Forthcoming GNUs::).  As much as possible, G++ is kept compatible
!      with the evolving draft ANSI standard, but not with `cfront'
!      (AT&T's compiler), which has been diverging from ANSI.
! 
!      GCC is a fairly portable optimizing compiler which performs
!      automatic register allocation, common sub-expression elimination
!      (CSE) (including a certain amount of CSE between basic blocks -
!      though not all the supported machine descriptions provide for
!      scheduling or delay slots), invariant code motion from loops,
!      induction variable optimizations, constant propagation, copy
!      propagation, delayed popping of function call arguments, tail
!      recursion elimination, integration of inline functions & frame
!      pointer elimination, instruction scheduling, loop unrolling,
!      filling of delay slots, leaf function optimization, optimized
!      multiplication by constants, the ability to assign attributes to
!      instructions, & many local optimizations automatically deduced
!      from the machine description.
  
       GCC can open-code most arithmetic on 64-bit values (type `long long
!      int').  It supports extended floating point (type `long double') on
!      the 68k; other machines will follow.  GCC supports full ANSI C,
!      traditional C, & GNU C extensions (including: nested functions
!      support, nonlocal gotos, & taking the address of a label).
! 
!      GCC can generate a.out, COFF, ELF, & OSF-Rose files when used with
!      a suitable assembler.  It can produce debugging information in
!      these formats: BSD stabs, COFF, ECOFF, ECOFF with stabs, & DWARF.
! 
!      GCC generates code for many CPUs, including the a29k, Alpha, ARM,
!      AT&T, DSP1610, Clipper, Convex cN, Elxsi, Fujitsu Gmicro, i370,
!      i860, i960, MIL-STD-1750a, MIPS, ns32k, PDP-11, Pyramid, ROMP,
!      RS/6000, SH, SPUR, Tahoe, VAX, & we32k.
! 
!      Position-independent code is generated for the Clipper, Hitachi
!      H8/300, HP-PA (1.0 & 1.1), i386/i486/Pentium, m68k, m88k, SPARC, &
!      SPARClite.
! 
!      Operating systems supported include: GNU/Hurd, GNU/Linux, ACIS,
!      AIX, AOS, BSD, Clix, Concentrix, Ctix, DG/UX, Dynix, FreeBSD,
!      Genix, HP-UX, Irix, ISC, Luna, LynxOS, Minix, NetBSD, NewsOS,
!      NeXTStep, OS/2, OSF, OSF-Rose, RISCOS, SCO, Solaris 2, SunOS 4,
!      System/370, SysV, Ultrix, Unos, VMS, & Windows/NT.
  
!      Using the configuration scheme for GCC, building a cross-compiler
!      is as easy as building a native compiler.
  
       Version 1 of GCC, G++, & libg++ are no longer maintained.
  
!      Texinfo source for the `Using and Porting GNU CC' manual is
!      included with GCC (*note Documentation::.).
  
!    * GDB   (BinCD, SrcCD)   [FSFman, FSFrc]
  
!      GDB, the GNU DeBugger, is a source-level debugger for C, C++, and
!      Fortran.
  
!      GDB can debug both C and C++ programs, and will work with
!      executables produced by many different compilers; however, C++
!      debugging will have some limitations if you do not use GCC.
! 
!      GDB has a command line user interface, and Emacs has GDB mode as an
!      interface.  Two X interfaces (not distributed or maintained by the
!      FSF) are: `gdbtk' (FTP it from `ftp.cygnus.com' in directory
!      `/pub/gdb'); and `xxgdb' (FTP it from `ftp.x.org' in directory
!      `/contrib/utilities').
! 
!      Executable files and symbol tables are read via the BFD library,
!      which allows a single copy of GDB to debug programs with multiple
!      object file formats (e.g., a.out, COFF, ELF).  Other features
!      include a rich command language, remote debugging over serial
!      lines or TCP/IP, and watchpoints (breakpoints triggered when the
!      value of an expression changes).
! 
!      GDB uses a standard remote interface to a simulator library which
!      (so far) has simulators for the ARM, Hitachi H8/300, Hitachi
!      H8/500, Hitachi Super-H, PowerPC, WDC 65816, & Zilog Z8001/2.
! 
!      GDB can perform cross-debugging.  To say that GDB "targets" a
!      platform means it can perform native or cross-debugging for it.
!      To say that GDB can "host" a given platform means that it can be
!      built on it, but cannot necessarily debug native programs.
  
       GDB can:
  
!         * "target" & "host": Amiga 3000 (Amix, NetBSD), DEC Alpha
!           (OSF/1), DECstation 3100 & 5000 (Ultrix), HP 9000/300 (BSD,
!           HP-UX), HP 9000/700 (HP-UX 9, 10), i386 (GNU/Hurd, GNU/Linux,
!           BSD, FreeBSD, LynxOS, NetBSD, SCO, Windows NT), IBM RS/6000
!           (AIX 3.x, AIX 4.x, LynxOS), Motorola Delta m88k (System V,
!           CX/UX), PC532 (NetBSD), Motorola m68k MVME-167 (LynxOS), NCR
!           3000 (SVR4), PowerPC (AIX 4.x, MacOS, Windows NT), SGI (Irix
!           V3, V4, V5), SONY News (NewsOS 3.x), SPARC (LynxOS, NetBSD,
!           Solaris 2.x, & SunOS 4.1 ) Sun-3 (SunOS 4.1), & Ultracomputer
!           (a29k running Sym1).
! 
!         * "target", but not "host": AMD 29000 (COFF & a.out), ARM (RDP),
!           Hitachi H8/300, Hitachi SH (CMON, SH3, E7000), HP PA Pro
!           (Winbond, Oki), i386 (a.out, COFF, OS/9000), i960 (MON960,
!           Nindy, VxWorks), m68k/m68332 (a.out, COFF, CPU32BUG, EST,
!           ROM68K, VxWorks), MIPS (ELF, IDT ecoff, PMON, VxWorks),
!           PowerPC (PPCBug), Matra Sparclet, Fujitsu SPARClite (a.out,
!           COFF), WDC 65816, & Z8000.
  
!         * "host", but not "target": IBM RT/PC (AIX), HP/Apollo 68k
!           (BSD), & m68k Apple Macintosh (MacOS).
  
!      Sources for the manual, `Debugging with GDB', and a reference card
!      are included (*note Documentation::.).
  
!    * `gdbm'   (SrcCD)
  
       `gdbm' is the GNU replacement for the traditional `dbm' and `ndbm'
!      libraries.  It implements a database using quick lookup by
!      hashing.  `gdbm' does not ordinarily make sparse files (unlike its
!      Unix and BSD counterparts).
! 
!    * `gettext'    *Also *note Help the GNU Translation Project::.*  
!      (SrcCD)
! 
!      The GNU `gettext' tool set has everything maintainers need to
!      internationalize a package's user messages.  Once a package has
!      been internationalized, `gettext''s many tools help translators
!      localize messages to their native language and automate handling
!      the translation files.
! 
!    * Generic NQS   (SrcCD)
! 
!      Generic NQS is a network queuing system for spreading batch jobs
!      across a network of machines.  It is designed to be simple to
!      install on a heterogeneous network of machines, and has
!      optimizations for running on the high end, symmetric
!      multiprocessing servers that are currently on the market.  It
!      inter-operates with other NQS systems, including Cray's NQE.
! 
!    * `geomview'   (SrcCD)
! 
!      `geomview' is an interactive geometry viewing program.  It allows
!      multiple independently controllable objects and cameras.
!      `geomview' provides interactive control for motion, appearances
!      (including lighting, shading, and materials), picking on an
!      object, edge or vertex level, and snapshots in SGI image file or
!      Renderman RIB format.  Adding or deleting objects is provided
!      through direct mouse manipulation, control panels, and keyboard
!      shortcuts.  External programs can drive desired aspects of the
!      viewer (such as continually loading changing geometry or
!      controlling the motion of certain objects) while allowing
!      interactive control of everything else.
! 
!    * Ghostscript   *Also *note Forthcoming GNUs::.*   (SrcCD)
! 
!      Ghostscript is an interpreter for the Postscript and PDF graphics
!      languages.
! 
!      The current version of GNU Ghostscript is 3.33.  This version
!      includes nearly a full Postscript Level 2 interpreter and also a
!      PDF 1.0 interpreter.  Significant new features include: support
!      for anti-aliased characters; the ability to scan a directory and
!      register all the fonts in it; support for Type 0 (Japanese /
!      Chinese / Korean) fonts; and the ability to compile all the
!      external initialization files into the executable.  This version
!      can also run as a 32-bit MS Windows application.
! 
!      Thanks to the generosity of URW++ (Hamburg, Germany), the
!      low-quality bitmap-derived fonts distributed with older versions
!      have been replaced with commercial-quality, hinted outline fonts.
!      *Note GNUs Flashes::.
  
       Ghostscript executes commands in the Postscript language by writing
!      directly to a printer, drawing on an X window, or writing to files
!      for printing later or manipulating with other graphics programs.
  
!      Ghostscript includes a C-callable graphics library (for client
!      programs that do not want to deal with the Postscript language).
!      It also supports i386/i486/Pentiums running DOS with EGA, VGA or
!      SuperVGA graphics (but please do *not* ask the FSF staff any
!      questions about this; we do not use DOS).
! 
!    * Ghostview   (SrcCD)
! 
!      Tim Theisen, `ghostview@cs.wisc.edu', created Ghostview, a
!      previewer for multi-page files with an X Window interface.
!      Ghostview & Ghostscript work together; Ghostview creates a viewing
!      window & Ghostscript draws in it.
! 
!    * GIT   (SrcCD)
! 
!      The GNU Interactive Tools package includes: an extensible file
!      system browser, an ASCII/hex file viewer, a process viewer/killer,
!      & other related utilities & shell scripts.  It can be used to
!      increase the speed & efficiency of many daily tasks, such as
!      copying & moving files & directories, invoking editors,
!      compressing/uncompressing files, creating & expanding archives,
!      compiling programs, sending mail, etc.  It looks nice, has colors
!      (if the standard ANSI color sequences are supported), & is
!      user-friendly.
! 
!    * `gmp'   (SrcCD)
! 
!      GNU `mp' is a library for arithmetic on arbitrary precision
!      integers, rational numbers, and floating-point numbers.  It has a
!      rich set of functions with a regular interface.
! 
!      A major new release, version 2.0, is now out.  Compared to previous
!      versions, it is much faster, & contains lots of new functions.
!      The main new feature is support for arbitrary precision
!      floating-point numbers.
  
     * Gnans    (SrcCD)
  
       Gnans is a program (and language) for the numerical study of
!      deterministic and stochastic dynamical systems.  The dynamical
!      systems may evolve in continuous or discrete time.  Gnans has
!      graphical & command line interfaces.
! 
!    * GNAT: The GNU Ada Translator   (SrcCD)
! 
!      A front end for much of Ada 95 (GNAT: The GNU Ada Translator) is
!      available via anonymous FTP from `cs.nyu.edu' in `/pub/gnat'.  SGI
!      and Digital have chosen GNU Ada as the Ada compiler for certain
!      systems.  News about GNAT is posted to the USENET newsgroup
!      `comp.lang.ada'.
! 
!    * GNATS   (SrcCD)
! 
!      GNATS (GNats: A Tracking System, not to be confused with GNAT, The
!      GNU Ada Translator) is a bug-tracking system.  It is based upon
!      the paradigm of a central site or organization which receives
!      problem reports and negotiates their resolution by electronic
!      mail.  Although it has been used primarily as a software
!      bug-tracking system so far, it is sufficiently generalized that it
!      could be used for handling system administration issues, project
!      management, or any number of other applications.
! 
!    * GNUMATH (`gnussl')   (SrcCD)
! 
!      GNUMATH is a library (`gnussl') designed to simplify scientific
!      programming.  Its focus is on problems that can be solved by a
!      straight-forward application of numerical, linear algebra.  It
!      also handles plotting.  GNUMATH is in beta release; it is expected
!      to grow more versatile and offer a wider scope in time.
  
!    * `gnuplot'   (SrcCD)
  
       `gnuplot' is an interactive program for plotting mathematical
!      expressions and data.  It plots both curves (2 dimensions) &
!      surfaces (3 dimensions).  It was neither written nor named for the
!      GNU Project; the name is a coincidence.  Various GNU programs use
!      `gnuplot'.
! 
!    * `gnuserv'   (SrcCD)
! 
!      `gnuserv' is an enhanced version of Emacs' `emacsclient' program.
!      It lets the user direct a running Emacs to edit files or evaluate
!      arbitrary Emacs Lisp constructs from another process.
! 
!    * GnuGo   (SrcCD)
! 
!      GnuGo plays the game of Go (Wei-Chi); version 1.2 was released
!      with minor changes for portability,  but it is not yet very
!      sophisticated.
! 
!    * `gperf'   (SrcCD)
! 
!      `gperf' generates perfect hash tables.  The C version is in
!      package cperf.  The C++ version is in libg++.  Both produce hash
!      functions in either C or C++.
! 
!    * Graphics   (SrcCD)
! 
!      GNU Graphics produces x-y plots from ASCII or binary data.  It
!      outputs in Postscript, Tektronix 4010 compatible, and Unix
!      device-independent "plot" formats.  It has a previewer for the X
!      Window System.  Features include a `spline' interpolation program;
!      examples of shell scripts using `graph' and `plot'; a statistics
!      toolkit; and output in TekniCAD TDA and ln03 file formats.  Email
!      bugs or queries to Rich Murphey, `Rich@lamprey.utmb.edu'.
! 
!    * grep   (SrcCD)
! 
!      This package has GNU `grep', `egrep', and `fgrep', which find
!      lines that match entered patterns.  They are much faster than the
!      traditional Unix versions.
! 
!    * Groff   (SrcCD)
! 
!      Groff is a document formatting system based on a
!      device-independent version of `troff', & includes: `eqn', `nroff',
!      `pic', `refer', `tbl', `troff'; the `man', `ms', & `mm' macros; &
!      drivers for Postscript, TeX `dvi' format, the LaserJet 4 series of
!      printers, and typewriter-like devices.  Groff's `mm' macro package
!      is almost compatible with the DWB `mm' macros with several
!      extensions.  Also included is a modified version of the Berkeley
!      `me' macros and an enhanced version of the X11 `xditview'
!      previewer.  Written in C++, these programs can be compiled with
!      GNU C++ Version 2.7.2 or later.
! 
!      Groff users are encouraged to contribute enhancements.  Most needed
!      are complete Texinfo documentation, a `grap' emulation (a `pic'
!      preprocessor for typesetting graphs), a page-makeup postprocessor
!      similar to `pm' (see `Computing Systems', Vol. 2, No. 2; ask
!      `office@usenix.org' how to get a copy), and an ASCII output class
!      for `pic' to integrate `pic' with Texinfo.  Questions and bug
!      reports from users who have read the documentation provided with
!      Groff can be sent to `bug-groff@prep.ai.mit.edu'.
  
!    * `gzip'   (SrcCD)
  
       `gzip' can expand LZW-compressed files but uses another, unpatented
!      algorithm for compression which generally produces better results.
!      It also expands files compressed with System V's `pack' program.
  
!    * `hello'   (SrcCD)
  
       The GNU `hello' program produces a familiar, friendly greeting.  It
!      allows non-programmers to use a classic computer science tool
!      which would otherwise be unavailable to them.  Because it is
!      protected by the GNU General Public License, users are free to
!      share and change it.  `hello' is also a good example of a program
!      that meets the GNU coding standards.  Like any truly useful
!      program, `hello' contains a built-in mail reader.
  
!    * `hp2xx'   (SrcCD)
  
       GNU `hp2xx' reads HP-GL files, decomposes all drawing commands into
!      elementary vectors, and converts them into a variety of vector and
!      raster output formats.  It is also an HP-GL previewer.  Currently
!      supported vector formats include encapsulated Postscript, Uniplex
!      RGIP, Metafont, various special TeX-related formats, and
!      simplified HP-GL (line drawing only) for imports.  Raster formats
!      supported include IMG, PBM, PCX, & HP-PCL (including Deskjet &
!      DJ5xxC support).  Previewers work under X11 (Unix), OS/2 (PM &
!      full screen), & MS-DOS (SVGA, VGA, & HGC).
! 
!    * HylaFAX   (SrcCD)
! 
!      HylaFAX (once named FlexFAX) is a facsimile system for Unix
!      systems.  It supports sending, receiving, & polled retrieval of
!      facsimile, as well as transparent shared data use of the modem.
  
       Details are available on the World Wide Web at:
       `http://www.vix.com/hylafax/'.
  
!    * Hyperbole   (SrcCD)
  
!      Hyperbole, written by Bob Weiner in Emacs Lisp, is an open,
!      efficient, programmable information management & hypertext system,
!      intended for everyday work on any platform supported by Emacs.
! 
!    * ID Utils   (SrcCD)
! 
!      ID Utils is a package of simple, fast, high-capacity,
!      language-independent identifier database tools.  Actually, the term
!      "identifier" is too limiting - ID Utils stores tokens, be they
!      program identifiers of any form, literal numbers, or words of
!      human-readable text.  Database queries can be issued from the
!      command-line, or from within Emacs, serving as an augmented tags
!      facility.
! 
!    * `indent'   (SrcCD)
! 
!      GNU `indent' formats C source code into the GNU indentation style.
!      It also has options to output BSD, K&R, or your own special
!      style.  GNU `indent' is more robust & provides more functionality
!      than other such programs, including handling C++ comments.  It
!      runs on a number of systems, including DOS & VMS.
  
       The next version will also format C++ source code.
  
!    * Inetutils   (SrcCD)
! 
!      Inetutils is an interim distribution of common networking utilities
!      and servers.
! 
!      This release is intended mainly to support the GNU Hurd, which is
!      source compatible with BSD in many ways, and will probably only
!      work on systems that are similarly compatible.
! 
!    * Ispell   (SrcCD)
  
!      Ispell is an interactive spell checker that suggests "near misses"
!      to replace unrecognized words.  System & user-maintained
!      dictionaries for multiple languages can be used.  Standalone &
!      Emacs interfaces are available.
  
     * JACAL   *Not available from the FSF except by FTP*
  
       JACAL is a symbolic mathematics system for the manipulation and
!      simplification of algebraic equations and expressions.  It is
!      written in Scheme using the SLIB portable Scheme Library.  JACAL
!      comes with SCM, an IEEE P1178 & R4RS compliant Scheme
!      implementation written in C  SCM runs on Amiga, Atari-ST, MS-DOS,
!      OS/2, NOS/VE, Unicos, VMS, Unix, & similar systems.  New in JACAL
!      is multivariate factoring from Michael Thomas
!      `(mjt@octavia.anu.edu.au)'.  See JACAL's documentation at
!      `http://www-swiss.ai.mit.edu/~jaffer/JACAL.html'.
! 
!      The FSF is not distributing JACAL on any physical media.  You can
!      FTP it or get it from the Web site listed above.
! 
!    * Karma   (SrcCD)
! 
!      Karma is a signal and image processing library that provides
!      interprocess communications, authentication, graphics display, and
!      user interface to and manipulation of the Karma network data
!      structure. Several foreign data formats are also supported.  Karma
!      comes packaged with a number of standard tools, including a
!      general-purpose image/movie display tool and a volume rendering
!      tool.
  
!    * `less'   (SrcCD)
  
       `less' is a display paginator similar to `more' and `pg', but with
!      various features (such as the ability to scroll backwards) that
!      most pagers lack.
  
!    * Lynx   (SrcCD)
  
!      Lynx is a text-based World Wide Web browser for people running
!      under "dumb" character-only terminals.  For more information about
!      Lynx, consult the URL `http://www.ukans.edu/'.
! 
!    * `m4'   (SrcCD)
! 
!      GNU `m4' is an implementation of the traditional Unix macro
!      processor.  It is mostly SVR4 compatible, although it has some
!      extensions (e.g., handling more than 9 positional parameters to
!      macros).  `m4' also has built-in functions for including files,
!      running shell commands, doing arithmetic, etc.
! 
!    * `make'   *See *Note Forthcoming GNUs::* (BinCD, SrcCD) [FSFman]
! 
!      GNU `make' supports POSIX 1003.2 and has all but a few obscure
!      features of the BSD and System V versions of `make', and runs on
!      MS-DOS, AmigaDOS, VMS, & Windows NT or 95, as well as all
!      Unix-compatible systems.  GNU extensions include long options,
!      parallel compilation, flexible implicit pattern rules, conditional
!      execution, & powerful text manipulation functions.  Source for the
!      `Make Manual' comes with the program (*note Documentation::.).
  
!    * MandelSpawn   (SrcCD)
  
       A parallel Mandelbrot generation program for the X Window System.
  
!    * Maxima   (SrcCD)
  
!      Maxima is a Common Lisp implementation of MIT's Macsyma system for
!      computer based algebra.
  
!    * Midnight Commander (`mc')   (SrcCD)
  
!      The Midnight Commander is a user friendly & colorful Unix file
!      manager & shell, useful to novice & guru alike.  It has a built-in
!      virtual file system that manipulates files inside tar files or
!      files on remote machines using the FTP protocol.  This mechanism
!      is extendable with external Unix programs.
! 
!    * Miscellaneous Files Distribution   (SrcCD)
! 
!      The GNU Miscellaneous Files Distribution includes non-crucial
!      files which have come to be common on various systems over the
!      years, including word lists, airport codes, ZIP codes and more.
! 
!    * `mkisofs'   (SrcCD)
! 
!      `mkisofs' is a pre-mastering program to generate an ISO 9660 file
!      system.  It takes a snapshot of a directory tree, and makes a
!      binary image which corresponds to an ISO 9660 file system when
!      written to a block device.
! 
!      It can also generate the System Use Sharing Protocol records of
!      the Rock Ridge Interchange Protocol (used to further describe the
!      files in an ISO 9660 file system to a Unix host; it provides
!      information such as longer filenames, uid/gid, permissions, and
!      device nodes).
! 
!      The `mkisofs' program is frequently used with `cdwrite'.
!      `cdwrite' works by taking the image that `mkisofs' generates and
!      driving a cdwriter to actually burn the disk.  `cdwrite' works
!      under Linux, and supports popular cdwriters.  Older versions of
!      `cdwrite' were included with older versions of `mkisofs'; check
!      `sunsite.unc.edu' & get
!      `/pub/Linux/utils/disk-management/cdwrite-2.0.tar.gz' for the
!      latest version.
! 
!    * `mtools'   (SrcCD)
! 
!      `mtools' is a set of public domain programs to allow Unix systems
!      to read, write, and manipulate files on an MS-DOS file system
!      (usually a diskette).
! 
!    * MULE   (SrcCD)
! 
!      MULE is a MULtilingual Enhancement to GNU Emacs.  MULE text
!      buffers can contain a mix of characters from many languages
!      including: Japanese, Chinese, Korean, Vietnamese, Thai, modern
!      European languages (including Greek & Russian), Arabic, & Hebrew.
!      MULE also provides input methods for all of them.  MULE is being
!      merged into GNU Emacs.  *Note GNU & Other Free Software in
!      Japan::, for more information about MULE.
  
!    * `ncurses'   (SrcCD)
  
       `ncurses' is an implementation of the Unix `curses' library for
!      developing screen-based programs that are terminal independent.
  
!    * NetHack   (SrcCD)
  
!      NetHack is a Rogue-like adventure game supporting character & X
!      displays.
  
!    * NIH Class Library   (SrcCD)
  
!      The NIH Class Library (once known as "OOPS", Object-Oriented
!      Program Support) is a portable collection of C++ classes (similar
!      to those in Smalltalk-80) written in C++ by Keith Gorlen of the
!      National Institutes of Health (NIH).
! 
!    * `nvi'   (SrcCD)
! 
!      `nvi' is a freely redistributable implementation of the `vi'/`ex'
!      Unix editor.  It has almost all the functionality of the original
!      `vi'/`ex', except "open" mode & the `lisp' option.  Enhancements
!      include multiple buffers, command-line editing & path completion,
!      integrated Perl5 & Tcl scripting languages, Cscope support & tag
!      stacks, 8-bit data support, infinite file/line lengths, infinite
!      undo, message catalogs, incremental search, and extended regular
!      expressions.  It uses Autoconf for configuration and runs on any
!      Unix-like system.
! 
!    * Oaklisp    (SrcCD)
! 
!      Oaklisp is a fast, portable, object-oriented Scheme with first
!      class types.
! 
!    * Objective-C Library *See "GNUstep" in *Note Forthcoming GNUs::*
!      (SrcCD)
! 
!      Our Objective-C Class Library (`gstep-base.tar.gz',
!      `libgnustep-base') has general-purpose, non-graphical Objective-C
!      objects written by Andrew McCallum & other volunteers.  It includes
!      collection classes for maintaining groups of objects, I/O streams,
!      coders for formatting objects & C types to streams, ports for
!      network packet transmission, distributed objects (remote object
!      messaging), string classes, invocations, notifications, event
!      loops, timers, exceptions, pseudo-random number generators, & time
!      handling facilities.  It has the base classes for the GNUstep
!      project; over 80 of them have already been written.  Send queries
!      & bugs to `mccallum@gnu.ai.mit.edu'.
  
!    * OBST   (SrcCD)
  
       OBST is a persistent object management system with bindings to C++.
       OBST supports incremental loading of methods.  Its graphical tools
!      require the X Window System.  It features a hands-on tutorial
!      including sample programs.  It compiles with G++, and should
!      install easily on most Unix platforms.
! 
!    * Octave   (SrcCD)
! 
!      Octave is a high-level language similar to MATLAB, primarily
!      intended for numerical computations.  It has a convenient command
!      line interface for solving linear & nonlinear problems numerically.
! 
!      Octave does arithmetic for real and complex scalars and matrices,
!      solves sets of nonlinear algebraic equations, integrates systems
!      of ordinary differential & differential-algebraic equations, and
!      integrates functions over finite & infinite intervals.
!      Two- & three-dimensional plotting is available using `gnuplot'.
  
!      Send queries & bugs to: `bug-octave@bevo.che.wisc.edu'.
  
       Texinfo source is included for a 220+ page Octave manual, not yet
       published by the FSF.
  
!    * Oleo     (SrcCD)
  
!      Oleo is a spreadsheet program (better for you than the more
!      expensive spreadsheets).  It supports the X Window System and
!      character-based terminals, and can output Embedded Postscript
!      renditions of spreadsheets.  Keybindings should be familiar to
!      Emacs users and are configurable.  Oleo supports multiple
!      variable-width fonts when used under the X Window System or
!      outputting to Postscript devices.
  
!    * `p2c'   (SrcCD)
  
!      `p2c' is Dave Gillespie's Pascal-to-C translator.  It inputs many
!      dialects (HP, ISO, Turbo, VAX, etc.)  & generates readable,
       maintainable, portable C.
  
!    * `patch'   (SrcCD)
  
!      `patch' is our version of Larry Wall's program to take `diff''s
!      output and apply those differences to an original file to generate
!      the modified version.
  
!    * PCL   (SrcCD)
  
!      PCL is a free implementation of a large subset of CLOS, the Common
!      Lisp Object System.  It runs under both GCL and CLISP, mentioned
!      above.
  
!    * `perl'   (SrcCD)
  
!      Larry Wall's `perl' combines the features & capabilities of C,
!      `sed', `awk', & `sh', and provides interfaces to the Unix system
!      calls & many C library routines.
  
!    * `pine'   *Also *note Some Bad News about Pine::.*   (SrcCD)
  
       `pine' is a friendly menu-driven electronic mail manager and user
       interface .
  
!    * `ptx'    *Also *note Forthcoming GNUs::.*   (SrcCD)
  
!      GNU `ptx' is our version of the traditional permuted index
!      generator.  It handles multiple input files at once, has TeX
!      compatible output, & outputs readable "KWIC" (KeyWords In Context)
!      indexes without using `nroff'.
  
!      It does not yet handle input files that do not fit in memory all at
!      once.
  
!    * `rc'   (SrcCD)
  
!      `rc' is a shell that features a C-like syntax (much more so than
!      `csh') and far cleaner quoting rules than the C or Bourne shells.
!      It's intended to be used interactively, but is also great for
!      writing scripts.  It inspired the shell `es'.
  
!    * RCS   (SrcCD)
  
       RCS, the Revision Control System, is used for version control &
!      management of software projects.  Used with GNU `diff', RCS can
!      handle binary files (8-bit data, executables, object files, etc).
!      RCS now conforms to GNU configuration standards & to POSIX
!      1003.1b-1993.  Also see the CVS item above.
! 
!    * `recode'    *Also *note Forthcoming GNUs::.*   (SrcCD)
! 
!      GNU `recode' converts files between character sets and usages.
!      When exact transliterations are not possible, it may delete the
!      offending characters or fall back on approximations.  This program
!      recognizes or outputs nearly 150 different character sets and is
!      able to transliterate files between almost any pair.  Most RFC
!      1345 character sets are supported.
  
!    * `regex'   (SrcCD)
  
       The GNU regular expression library supports POSIX.2, except for
!      internationalization features.  It is included in many GNU
!      programs which do regular expression matching & is available
!      separately.  An alternate regular expression package, `rx', is
!      faster than `regex' in most cases & will replace `regex' over time.
! 
!    * `rx'   (SrcCD)
! 
!      Tom Lord has written `rx', a new regular expression library which
!      is faster than the older GNU `regex' library.  It is now being
!      distributed with `sed' and `tar'.  `rx' will be used in the next
!      releases of `m4' and `ptx'.
! 
!    * SAOimage   (SrcCD)
! 
!      SAOimage is an X-based astronomical image viewer.  It reads data
!      images and displays them with a pseudocolor colormap.  There is
!      full interactive control of the colormap, reading, and writing of
!      colormaps, etc.
! 
!    * Scheme   (SrcCD)
! 
!      Scheme is a simplified, lexically-scoped dialect of Lisp.  It was
!      designed at MIT and other universities to teach students the art
!      of programming and to research new parallel programming constructs
!      and compilation techniques.
! 
!      We now distribute MIT Scheme 7.3, which conforms to the "Revised^4
!      Report On the Algorithmic Language Scheme" (MIT AI Lab Memo 848b),
!      for which TeX source is included.  It is written partly in C, but
!      is presently hard to bootstrap.  Binaries to bootstrap it exist
!      for: HP9000 series 300, 400, 700, & 800 (running HP-UX 9.0), NeXT
!      (NeXT OS 2 or 3.2), DEC Alpha (OSF/1), IBM RS/6000 (AIX), Sun-3 or
!      Sun-4 (SunOS 4.1), DECstation 3100/5100 (Ultrix 4.0), Sony
!      NeWS-3250 (NEWS OS 5.01), & Intel i386 (MS-DOS, Windows 3.1 or NT).
!      If your system isn't on this list & you don't enjoy the bootstrap
!      challenge, see the "JACAL" item earlier in this article.
! 
!    * `screen'   (SrcCD)
! 
!      `screen' is a terminal multiplexer that runs several separate
!      "screens" (ttys) on a single character-based terminal.  Each
!      virtual terminal emulates a DEC VT100 plus several ISO 2022 and
!      ISO 6429 (ECMA 48, ANSI X3.64) functions, including color.
!      Arbitrary keyboard input translation is also supported.  `screen'
!      sessions can be detached and resumed later on a different terminal
!      type.  Output in detached sessions is saved for later viewing.
! 
!    * `sed'   (SrcCD)
! 
!      `sed' is a stream-oriented version of `ed'.  It comes with the
!      `rx' library.
! 
!    * Sharutils   (SrcCD)
! 
!      `shar' makes so-called shell archives out of many files, preparing
!      them for transmission by electronic mail services; `unshar' helps
!      unpack these shell archives after reception.  `uuencode' and
!      `uudecode' are POSIX compliant implementations of a pair of
!      programs which transform files into a format that can be safely
!      transmitted across a 7-bit ASCII link.
! 
!    * Shellutils   (SrcCD)
! 
!      The Shellutils are: `basename', `chroot', `date', `dirname',
!      `echo', `env', `expr', `factor', `false', `groups', `hostname',
!      `id', `logname', `nice', `nohup', `pathchk', `printenv', `printf',
!      `pwd', `seq', `sleep', `stty', `su', `tee', `test', `true', `tty',
!      `uname', `uptime', `users', `who', `whoami', & `yes'.
! 
!    * Shogi   (SrcCD)
! 
!      Shogi is a Japanese game similar to Chess; a major difference is
!      that captured pieces can be returned into play.
! 
!      GNU Shogi is a variant of GNU Chess; it implements the same
!      features & similar heuristics.  As a new feature, sequences of
!      partial board patterns can be introduced to help the program play
!      toward specific opening patterns.  It has both character and X
!      display interfaces.
  
       It is primarily supported by Matthias Mutz on behalf of the FSF.
*************** included with each package.
*** 1654,3087 ****
     * SIPP    (SrcCD)
  
!      SIPP is a library for creating photorealistic renderings of 3D scenes.
!      A scene is built up of objects which can be transformed with rotation,
!      translation, and scaling.	The objects form hierarchies where each object
!      can have arbitrarily many subobjects and subsurfaces.  A surface is a
!      number of connected polygons which are rendered with either Phong,
!      Gouraud, or flat shading.	The library supports programmable shaders and
!      texture mapping with textures in up to 3 dimensions and automatic
!      interpolation of texture coordinates.  A scene can be illuminated by an
!      arbitrary number of light sources.	 The lights from some of them are
!      capable of casting shadows of objects.
! 
!    * Smalltalk	 *Also see *Note Forthcoming GNUs::*   (LangT,SrcCD)
! 
!      GNU Smalltalk is an interpreted object-oriented programming language
!      system written in highly portable C.  It has been ported to many Unix,
!      DOS, & other OSes.	 Features include a binary image save capability, the
!      ability to call user-written C code with parameters, an Emacs editing
!      mode, a version of the X protocol invocable from Smalltalk, optional
!      byte-code compilation and/or execution tracing, & automatically loaded
!      per-user initialization files.  It implements all of the classes &
!      protocol in the book "Smalltalk-80: The Language", except for the
!      graphic user interface (GUI) related classes.
  
     * SNePS    (SrcCD)
  
       SNePS is the Semantic Network Processing System.  It is an
!      implementation of a fully intensional theory of propositional knowledge
!      representation and reasoning.  SNePS runs under CLISP or GCL.
  
     * Spinner   (SrcCD)
  
!      Spinner is a modularized, object oriented, non-forking World Wide Web
!      server with high performance and throughput.
  
!    * Superopt	(LangT, SrcCD)
  
       Superopt is a function sequence generator that uses an exhaustive
!      generate-and-test approach to find the shortest instruction sequence for
!      a given function.	You provide a function as input, a CPU to generate
!      code for, and how many instructions you want.  Its use in GCC is
!      described in the `ACM SIGPLAN PLDI'92 Proceedings'.  It supports: SPARC,
!      m68k, m68020, m88k, IBM POWER and PowerPC, AMD 29k, Intel x86 and 960,
!      Pyramid, DEC Alpha, Hitachi SH, & HP-PA.
! 
!    * `tar'   (DosBC, SrcCD, UtilT)
! 
!      GNU `tar' includes multi-volume support, the ability to archive sparse
!      files, compression/decompression, remote archives, and special features
!      that allow `tar' to be used for incremental and full backups.  GNU `tar'
!      uses an early draft of the POSIX 1003.1 `ustar' format which is
!      different from the final version.	This will be corrected in the future.
! 
!    * Termcap Library   (SrcCD, UtilT) [FSFman]
! 
!      The GNU Termcap library is a drop-in replacement for `libtermcap.a' on
!      any system.  It does not place an arbitrary limit on the size of Termcap
!      entries, unlike most other Termcap libraries.  Included is source for the
!      `Termcap Manual' in Texinfo format (*note Documentation::.).
  
!    * Termutils	 (SrcCD, UtilT)
  
       The Termutils package contains programs for controlling terminals.
       `tput' is a portable way for shell scripts to use special terminal
!      capabilities.  `tabs' is a program to set hardware terminal tab settings.
  
!    * TeX   (DosBC, SrcCD)
  
       TeX is a document formatting system that handles complicated
!      typesetting, including mathematics.  It is GNU's standard text formatter.
  
!      The University of Washington maintains & supports a tape distribution of
!      TeX for Unix systems.  The core material is Karl Berry's `web2c' TeX
!      package.  Sources are available via anonymous ftp; retrieval
!      instructions are in `/pub/tex/unixtex.ftp' on `ftp.cs.umb.edu'.  If you
!      receive any installation support from the University of Washington,
!      consider sending them a donation.
  
       To order a full distribution written in `tar' on either a 1/4inch
       4-track QIC-24 cartridge or a 4mm DAT cartridge, send $210.00 to:
  
! 	  Pierre A. MacKay
! 	  Department of Classics
! 	  DH-10, Denny Hall 218
! 	  University of Washington
! 	  Seattle, WA	98195
! 	  USA
! 
! 	  Electronic-Mail: `mackay@cs.washington.edu'
! 	  Telephone: +1-206-543-2268
! 
!      Please make checks payable to: `University of Washington'.	 Do not
!      specify any other payee.  That causes accounting problems.	 Checks must
!      be in U.S. dollars, drawn on a U.S. bank.	Only prepaid orders can be
!      handled.  Overseas sites: please add to the base cost $20.00 to ship via
!      air parcel post or $30.00 to ship via courier.  Please check with the
!      above for current prices & formats.
  
!    * Texinfo   (DjgpD,DosBC,LangT,LspEmcT,SrcCD,UtilD,UtilT)[FSFman]
  
       Texinfo is a set of utilities (`makeinfo', `info', `texi2dvi',
       `texindex', `tex2patch', & `fixfonts') which generate both printed
!      manuals & online hypertext documentation (called "Info"), & can read
!      online Info documents.  Version 3 has both Emacs Lisp & standalone
!      programs written in C or shell script.  Texinfo mode for Emacs enables
!      easy editing & updating of Texinfo files.	Source for the `Texinfo
!      Manual' is included (*note Documentation::.).
  
!    * Textutils	 (DosBC, SrcCD, UtilT)
  
!      The Textutils programs manipulate textual data.  They include: `cat',
!      `cksum', `comm', `csplit', `cut', `expand', `fmt', `fold', `head',
!      `join', `md5sum', `nl', `od', `paste', `pr', `sort', `split', `sum',
!      `tac', `tail', `tr', `unexpand', `uniq', and `wc'.
  
!    * Tile Forth	  (LangT, SrcCD)
  
!      Tile Forth is a 32-bit implementation of the Forth-83 standard written
!      in C, allowing it to be easily ported to new systems and extended with
!      any C-function (graphics, windowing, etc).
  
!      Many documented Forth libraries are available, including ones for
!      top-down parsing, multi-threads, & object oriented programming.
  
!    * `time'   (SrcCD, UtilT)
  
!      `time' reports (usually from a shell) the user, system, & real time used
!      by a process.  On some systems it also reports memory usage, page
!      faults, etc.
  
!    * `ucblogo'	 (LangT, SrcCD)
! 
!      `ucblogo' implements the classic teaching language, Logo.
! 
!    * UUCP   (SrcCD, UtilT)
! 
!      GNU's UUCP system (written by Ian Lance Taylor) supports the `f', `g',
!      `v' (all window & packet sizes), `G', `t', `e', Zmodem, & two new
!      bidirectional (`i' & `j') protocols.  With a BSD sockets library, it can
!      make TCP connections.  With TLI libraries, it can make TLI connections.
!      Source is included for a manual (not yet published by the FSF).
! 
!    * W3	  (LspEmcT, SrcCD)
! 
!      W3 (written by William Perry in Emacs Lisp) is an extensible, advanced
!      World Wide Web browser that runs as part of GNU Emacs.  It understands
!      many protocols: FTP, gopher, HTML, SMTP, Telnet, WAIS, et al.
! 
!    * `wdiff'   (DosBC, SrcCD, UtilT)
! 
!      `wdiff' is a front-end to GNU `diff'.  It compares two files, finding
!      the words deleted or added to the first to make the second.  It has many
!      output formats and works well with terminals and pagers.  `wdiff' is
!      very useful when two texts differ only by a few words and paragraphs
!      have been refilled.
! 
!    * X11   *For details, see *Note X11 Tapes::*	  (SrcCD, X11OptT, X11ReqT)
! 
!    * `xboard', `xshogi'	  (SrcCD, UtilT)
! 
!      `xboard' is an X Window interface to GNU Chess.  `xshogi' is an X Window
!      interface to GNU Shogi.  They use the R4 Athena widgets and Xt
!      Intrinsics to provide an interactive referee for managing a game between
!      a user & a computer opponent, or between two computers.  You can also use
!      `xboard' without GNU Chess to play through games in files or to play
!      through games manually (force mode); in this case, moves aren't
!      validated.
! 
!    * `xgrabsc'	 (SrcCD)
! 
!      `xgrabsc' is a screen capture program similar to `xwd' but providing
!      more ways of selecting the part of the screen to capture and different
!      types of output: Postscript, color Postscript, xwd, bitmap, pixmap, and
!      puzzle.
! 
!    * `Ygl'   (SrcCD, UtilT)
! 
!      `Ygl' emulates a subset of SGI's GL (Graphics Language) library under
!      X11 on GNU/Linux with XFree, AIX 3.2, ConvexOS, HP-UX, SunOS, et al.  It
!      has most two-dimensional graphics routines, the queue device & query
!      routines, double buffering, RGB mode with dithering, FORTRAN bindings,
!      at al.
  
  
  
! Program/Package Cross Reference
! *******************************
! 
! Here is a list of what package each GNU program or library is in.  You can FTP
! the current list in the file `/pub/gnu/ProgramIndex' from a GNU FTP host
! (listed in *Note How to Get GNU Software::).
! 
! 	* a2p perl
! 	* a2x xopt
! 	* ac bsd44
! 	* accton bsd44
! 	* ackpfd phttpd
! 	* acl bsd44
! 	* acm acm
! 	* acms acm
! 	* addftinfo Groff
! 	* adventure bsd44
! 	* afm2tfm TeX
! 	* amd bsd44
! 	* ansitape bsd44
! 	* AnswerGarden xopt
! 	* apply bsd44
! 	* appres xreq
! 	* apropos bsd44
! 	* ar Binutils
! 	* arithmetic bsd44
! 	* arp bsd44
! 	* atc bsd44
! 	* autoconf Autoconf
! 	* autoheader Autoconf
! 	* autoreconf Autoconf
! 	* autoscan Autoconf
! 	* autoupdate Autoconf
! 	* auto_box xopt
! 	* auto_box xreq
! 
! 	* b2m Emacs
! 	* backgammon bsd44
! 	* bad144 bsd44
! 	* badsect bsd44
! 	* banner bsd44
! 	* basename Shellutils
! 	* bash BASH
! 	* battlestar bsd44
! 	* bc bc
! 	* bcd bsd44
! 	* bdes bsd44
! 	* bdftops Ghostscript
! 	* beach_ball xopt
! 	* beach_ball xreq
! 	* beach_ball2 xopt
! 	* bibtex TeX
! 	* biff bsd44
! 	* bison Bison
! 	* bitmap xreq
! 	* boggle bsd44
! 	* bpltobzr Fontutils
! 	* bugfiler bsd44
! 	* buildhash Ispell
! 	* bzrto Fontutils
! 
! 	* c++ GCC
! 	* c++filt Binutils
! 	* c2ph perl
! 	* ca100 xopt
! 	* caesar bsd44
! 	* cal bsd44
! 	* calendar bsd44
! 	* canfield bsd44
! 	* cat Textutils
! 	* cbars wdiff
! 	* cc GCC
! 	* cc1 GCC
! 	* cc1obj GCC
! 	* cc1plus GCC
! 	* cccp GCC
! 	* cdwrite mkisofs
! 	* cfengine cfengine
! 	* cgi Spinner
! 	* charspace Fontutils
! 	* checknr bsd44
! 	* chess bsd44
! 	* chflags bsd44
! 	* chgrp Fileutils
! 	* ching bsd44
! 	* chmod Fileutils
! 	* chown Fileutils
! 	* chpass bsd44
! 	* chroot bsd44
! 	* ci RCS
! 	* cksum Textutils
! 	* cktyps g77
! 	* clisp CLISP
! 	* clri bsd44
! 	* cmail xboard
! 	* cmmf TeX
! 	* cmodext xopt
! 	* cmp Diffutils
! 	* co RCS
! 	* col bsd44
! 	* colcrt bsd44
! 	* colrm bsd44
! 	* column bsd44
! 	* comm Textutils
! 	* compress bsd44
! 	* comsat bsd44
! 	* connectd bsd44
! 	* cp Fileutils
! 	* cpicker xopt
! 	* cpio cpio
! 	* cpp GCC
! 	* cppstdin perl
! 	* cribbage bsd44
! 	* crock xopt
! 	* csh bsd44
! 	* csplit Textutils
! 	* ctags Emacs
! 	* ctwm xopt
! 	* cu UUCP
! 	* cut Textutils
! 	* cvs CVS
! 	* cvscheck CVS
! 	* cvtmail Emacs
! 	* cxterm xopt
! 
! 	* d Fileutils
! 	* date Shellutils
! 	* dc bc
! 	* dd Fileutils
! 	* ddd DDD
! 	* delatex TeX
! 	* demangle Binutils
! 	* descend CVS
! 	* detex TeX
! 	* df Fileutils
! 	* dhtppd phttpd
! 	* diff Diffutils
! 	* diff3 Diffutils
! 	* digest-doc Emacs
! 	* dipress bsd44
! 	* dir Fileutils
! 	* dirname Shellutils
! 	* dish xopt
! 	* disklabel bsd44
! 	* diskpart bsd44
! 	* dld dld
! 	* dm bsd44
! 	* dmesg bsd44
! 	* doschk doschk
! 	* dox xopt
! 	* du Fileutils
! 	* dump bsd44
! 	* dump mkisofs
! 	* dumpfs bsd44
! 	* dvi2tty TeX
! 	* dvicopy TeX
! 	* dvips TeX
! 	* dvitype TeX
! 
! 	* ecc ecc
! 	* echo Shellutils
! 	* ed ed
! 	* edit-pr GNATS
! 	* editres xreq
! 	* edquota bsd44
! 	* eeprom bsd44
! 	* egrep grep
! 	* emacs Emacs
! 	* emacsclient Emacs
! 	* emacsserver Emacs
! 	* emacstool Emacs
! 	* emu xopt
! 	* env Shellutils
! 	* eqn Groff
! 	* error bsd44
! 	* es es
! 	* esdebug es
! 	* etags Emacs
! 	* ex nvi
! 	* expand Textutils
! 	* expect DejaGnu
! 	* expr Shellutils
! 	* exterm xopt
! 
! 	* f2c f2c
! 	* factor bsd44
! 	* fakemail Emacs
! 	* false Shellutils
! 	* fastboot bsd44
! 	* fax2ps HylaFAX
! 	* faxalter HylaFAX
! 	* faxanswer HylaFAX
! 	* faxcover HylaFAX
! 	* faxd HylaFAX
! 	* faxd.recv HylaFAX
! 	* faxmail HylaFAX
! 	* faxquit HylaFAX
! 	* faxrcvd HylaFAX
! 	* faxrm HylaFAX
! 	* faxstat HylaFAX
! 	* fc f2c
! 	* fdraw xopt
! 	* ffe g77
! 	* fgrep grep
! 	* file bsd44
! 	* find Findutils
! 	* find2perl perl
! 	* finger Finger
! 	* fingerd Finger
! 	* fish bsd44
! 	* fixfonts Texinfo
! 	* fixinc.svr4 GCC
! 	* fixincludes GCC
! 	* flex flex
! 	* flex++ flex
! 	* fmt bsd44
! 	* fold Textutils
! 	* font2c Ghostscript
! 	* fontconvert Fontutils
! 	* forth Tile Forth
! 	* forthicon Tile Forth
! 	* forthtool Tile Forth
! 	* fortune bsd44
! 	* fpr bsd44
! 	* freq Ispell
! 	* freqtbl Ispell
! 	* from bsd44
! 	* fsck bsd44
! 	* fsplit bsd44
! 	* fstat bsd44
! 	* ftp bsd44
! 	* ftpd bsd44
! 
! 	* g++ GCC
! 	* gas Binutils
! 	* gawk GAWK
! 	* gcc GCC
! 	* gcore bsd44
! 	* gdb GDB
! 	* genclass libg++
! 	* gettext gettext
! 	* getty bsd44
! 	* gftodvi TeX
! 	* gftopk TeX
! 	* gftype TeX
! 	* ghostview Ghostview
! 	* git GIT
! 	* gitaction GIT
! 	* gitcmp GIT
! 	* gitkeys GIT
! 	* gitmatch GIT
! 	* gitmount GIT
! 	* gitps GIT
! 	* gitredir GIT
! 	* gitrgrep GIT
! 	* gitview GIT
! 	* gitwipe GIT
! 	* gn GN
! 	* gnans Gnans
! 	* gnanslator Gnans
! 	* gnats GNATS
! 	* gnuchess Chess
! 	* gnuchessc Chess
! 	* gnuchessn Chess
! 	* gnuchessr Chess
! 	* gnuchessx Chess
! 	* gnuclient gnuserv
! 	* gnudoit gnuserv
! 	* gnupdisp Shogi
! 	* gnuplot gnuplot
! 	* gnuplot_x11 gnuplot
! 	* gnuserv gnuserv
! 	* gnushogi Shogi
! 	* gnushogir Shogi
! 	* gnushogix Shogi
! 	* go GnuGo
! 	* gpc xopt
! 	* gpc xreq
! 	* gperf cperf
! 	* gperf libg++
! 	* gprof Binutils
! 	* graph Graphics
! 	* grep grep
! 	* grodvi Groff
! 	* groff Groff
! 	* grops Groff
! 	* grotty Groff
! 	* groups Shellutils
! 	* gs Ghostscript
! 	* gsbj Ghostscript
! 	* gsdj Ghostscript
! 	* gslj Ghostscript
! 	* gslp Ghostscript
! 	* gsnd Ghostscript
! 	* gsrenderfont Fontutils
! 	* gunzip gzip
! 	* gwm xopt
! 	* gzexe gzip
! 	* gzip gzip
! 
! 	* h2ph perl
! 	* h2pl perl
! 	* hack bsd44
! 	* hangman bsd44
! 	* head Textutils
! 	* hello hello
! 	* hexdump bsd44
! 	* hexl Emacs
! 	* hostname Shellutils
! 	* hp2xx hp2xx
! 	* hterm xopt
! 	* htmlencode phttpd
! 	* httpd apache
! 	* httpdecode phttpd
! 
! 	* i18nOlwmV2 xopt
! 	* i2mif xopt
! 	* ico xopt
! 	* ico xreq
! 	* id Shellutils
! 	* ident RCS
! 	* ifconfig bsd44
! 	* ifnames Autoconf
! 	* ImageMagick xopt
! 	* imageto Fontutils
! 	* iman xopt
! 	* imgrotate Fontutils
! 	* indent indent
! 	* indxbib Groff
! 	* inetd bsd44
! 	* info Texinfo
! 	* inimf TeX
! 	* init bsd44
! 	* initex TeX
! 	* inn bsd44
! 	* install Fileutils
! 	* iostat bsd44
! 	* isodiag mkisofs
! 	* isodump mkisofs
! 	* ispell Ispell
! 	* ixterm xopt
! 	* ixx xopt
! 
! 	* join Textutils
! 	* jot bsd44
! 	* jove bsd44
! 
! 	* kdestroy bsd44
! 	* kdump bsd44
! 	* kermit bsd44
! 	* kgames xopt
! 	* kgmon bsd44
! 	* kill bsd44
! 	* kinit bsd44
! 	* kinput2 xopt
! 	* klist bsd44
! 	* kpasswdd bsd44
! 	* ksrvtgt bsd44
! 	* kterm xopt
! 	* ktrace bsd44
! 
! 	* lam bsd44
! 	* larn bsd44
! 	* lasergnu gnuplot
! 	* last bsd44
! 	* lastcomm bsd44
! 	* latex TeX
! 	* lclock xopt
! 	* ld Binutils
! 	* leave bsd44
! 	* less less
! 	* lesskey less
! 	* libavcall.a ffcall
! 	* libbfd.a Binutils
! 	* libbfd.a GDB
! 	* libbzr.a Fontutils
! 	* libc.a C Library
! 	* libcompat.a bsd44
! 	* libcurses.a bsd44
! 	* libcurses.a ncurses
! 	* libdcurses.a ncurses
! 	* libedit.a bsd44
! 	* libF77.a f2c
! 	* libF77.a g77
! 	* libg++.a libg++
! 	* libgdbm.a gdbm
! 	* libgf.a Fontutils
! 	* libgmp.a gmp
! 	* libgnanslib Gnans
! 	* libI77.a f2c
! 	* libI77.a g77
! 	* libkvm.a bsd44
! 	* libm.a bsd44
! 	* libncurses.a ncurses
! 	* libnihcl.a NIHCL
! 	* libnihclmi.a NIHCL
! 	* libnihclvec.a NIHCL
! 	* libnls.a xreq
! 	* libobjects.a libobjects
! 	* liboctave.a Octave
! 	* liboldX.a xreq
! 	* libpbm.a Fontutils
! 	* libPEXt.a xopt
! 	* libpk.a Fontutils
! 	* libresolv.a bsd44
! 	* librpc.a bsd44
! 	* libsipp.a SIPP
! 	* libtcl.a DejaGnu
! 	* libtelnet.a bsd44
! 	* libterm.a bsd44
! 	* libtermcap.a Termcap
! 	* libtfm.a Fontutils
! 	* libutil.a bsd44
! 	* libvacall.a ffcall
! 	* libWc.a xopt
! 	* libwidgets.a Fontutils
! 	* libX.a xreq
! 	* libXau.a xreq
! 	* libXaw.a xreq
! 	* libXcp.a xopt
! 	* libXcu.a xopt
! 	* libXdmcp.a xreq
! 	* libXmp.a xopt
! 	* libXmu.a xreq
! 	* libXO.a xopt
! 	* libXop.a xopt
! 	* libXp.a xopt
! 	* libXpex.a xopt
! 	* libXt.a xopt
! 	* libXt.a xreq
! 	* libXwchar.a xopt
! 	* liby.a bsd44
! 	* libYgl.a Ygl
! 	* limn Fontutils
! 	* listres xopt
! 	* listres xreq
! 	* lkbib Groff
! 	* ln Fileutils
! 	* locate Findutils
! 	* lock bsd44
! 	* logcvt-ip2n phttpd
! 	* logger bsd44
! 	* login bsd44
! 	* logname Shellutils
! 	* logo ucblogo
! 	* lookbib Groff
! 	* lorder bsd44
! 	* lpr bsd44
! 	* ls Fileutils
! 
! 	* m4 m4
! 	* mail bsd44
! 	* mail-files Sharutils
! 	* mailshar Sharutils
! 	* make make
! 	* make-docfile Emacs
! 	* make-path Emacs
! 	* makeindex TeX
! 	* makeinfo Texinfo
! 	* MakeTeXPK TeX
! 	* man bsd44
! 	* man-macros Groff
! 	* mattrib mtools
! 	* maze xopt
! 	* maze xreq
! 	* mazewar xopt
! 	* mc mc
! 	* mcd mtools
! 	* mcopy mtools
! 	* mcserv mc
! 	* mdel mtools
! 	* mdir mtools
! 	* me-macros Groff
! 	* merge RCS
! 	* mesg bsd44
! 	* mf TeX
! 	* mformat mtools
! 	* mft TeX
! 	* mgdiff xopt
! 	* mh bsd44
! 	* mille bsd44
! 	* mkcache GN
! 	* mkdep bsd44
! 	* mkdir Fileutils
! 	* mkfifo Fileutils
! 	* mkisofs mkisofs
! 	* mklocale bsd44
! 	* mkmanifest mtools
! 	* mkmf bsd44
! 	* mkmodules CVS
! 	* mknod Fileutils
! 	* mkstr bsd44
! 	* mlabel mtools
! 	* mm-macros Groff
! 	* mmd mtools
! 	* monop bsd44
! 	* more bsd44
! 	* morse bsd44
! 	* mount bsd44
! 	* mountd bsd44
! 	* movemail Emacs
! 	* mprof bsd44
! 	* mrd mtools
! 	* mread mtools
! 	* mren mtools
! 	* ms-macros Groff
! 	* msgcmp gettext
! 	* msgfmt gettext
! 	* msgmerge gettext
! 	* msgs bsd44
! 	* msgunfmt gettext
! 	* mst Smalltalk
! 	* mt cpio
! 	* mterm xopt
! 	* mtree bsd44
! 	* mtype mtools
! 	* mule MULE
! 	* muncher xopt
! 	* mv Fileutils
! 	* mvdir Fileutils
! 	* mwrite mtools
! 
! 	* nethack NetHack
! 	* netstat bsd44
! 	* newfs bsd44
! 	* nfsd bsd44
! 	* nfsiod bsd44
! 	* nfsstat bsd44
! 	* nice Shellutils
! 	* nl Textutils
! 	* nlmconv Binutils
! 	* nm Binutils
! 	* nohup Shellutils
! 	* notify HylaFAX
! 	* nroff Groff
! 	* number bsd44
! 
! 	* objc GCC
! 	* objcopy Binutils
! 	* objdump Binutils
! 	* objective-c GCC
! 	* obst-boot OBST
! 	* obst-CC OBST
! 	* obst-cct OBST
! 	* obst-cgc OBST
! 	* obst-cmp OBST
! 	* obst-cnt OBST
! 	* obst-cpcnt OBST
! 	* obst-csz OBST
! 	* obst-dir OBST
! 	* obst-dmp OBST
! 	* obst-gen OBST
! 	* obst-gsh OBST
! 	* obst-init OBST
! 	* obst-scp OBST
! 	* obst-sil OBST
! 	* obst-stf OBST
! 	* oclock xreq
! 	* octave Octave
! 	* od Textutils
! 	* oleo Oleo
! 	* ora-examples xopt
! 
! 	* p2c p2c
! 	* pagesize bsd44
! 	* palette xopt
! 	* pascal bsd44
! 	* passwd bsd44
! 	* paste Textutils
! 	* patch patch
! 	* patgen TeX
! 	* pathalias bsd44
! 	* pathchk Shellutils
! 	* pax bsd44
! 	* pbmplus xopt
! 	* perl perl
! 	* pfbtops Groff
! 	* phantasia bsd44
! 	* phttpd phttpd
! 	* pic Groff
! 	* pico pine
! 	* pig bsd44
! 	* pine pine
! 	* ping bsd44
! 	* pixedit xopt
! 	* pixmap xopt
! 	* pktogf TeX
! 	* pktype TeX
! 	* plaid xopt
! 	* plot2fig Graphics
! 	* plot2plot Graphics
! 	* plot2ps Graphics
! 	* plot2tek Graphics
! 	* pltotf TeX
! 	* pollrcvd HylaFAX
! 	* pom bsd44
! 	* pooltype TeX
! 	* portmap bsd44
! 	* ppt bsd44
! 	* pr Textutils
! 	* pr-addr GNATS
! 	* pr-edit GNATS
! 	* primes bsd44
! 	* printenv Shellutils
! 	* printf Shellutils
! 	* protoize GCC
! 	* proxygarb Spinner
! 	* ps bsd44
! 	* ps2ascii Ghostscript
! 	* ps2epsi Ghostscript
! 	* ps2fax HylaFAX
! 	* psbb Groff
! 	* pstat bsd44
! 	* psycho xopt
! 	* ptester phttpd
! 	* ptx ptx
! 	* pubdic+ xopt
! 	* puzzle xopt
! 	* puzzle xreq
! 	* pwd Shellutils
! 	* pyramid xopt
! 
! 	* query-pr GNATS
! 	* quiz bsd44
! 	* quot bsd44
! 	* quota bsd44
! 	* quotacheck bsd44
! 	* quotaon bsd44
! 
! 	* rain bsd44
! 	* random bsd44
! 	* ranlib Binutils
! 	* rbootd bsd44
! 	* rc rc
! 	* rcp bsd44
! 	* rcs RCS
! 	* rcs-to-cvs CVS
! 	* rcs2log Emacs
! 	* rcsdiff RCS
! 	* rcsfreeze RCS
! 	* rcsmerge RCS
! 	* rdist bsd44
! 	* reboot bsd44
! 	* recode recode
! 	* recvstats HylaFAX
! 	* red ed
! 	* refer Groff
! 	* remsync Sharutils
! 	* renice bsd44
! 	* repquota bsd44
! 	* restore bsd44
! 	* rev bsd44
! 	* rexecd bsd44
! 	* rlog RCS
! 	* rlogin bsd44
! 	* rlogind bsd44
! 	* rm Fileutils
! 	* rmail bsd44
! 	* rmdir Fileutils
! 	* rmt cpio
! 	* rmt tar
! 	* robots bsd44
! 	* rogue bsd44
! 	* route bsd44
! 	* routed bsd44
! 	* rr xopt
! 	* rs bsd44
! 	* rsh bsd44
! 	* rshd bsd44
! 	* runtest DejaGnu
! 	* runtest.exp DejaGnu
! 	* ruptime bsd44
! 	* rwho bsd44
! 	* rwhod bsd44
! 
! 	* s2p perl
! 	* sail bsd44
! 	* saoimage SAOimage
! 	* savecore bsd44
! 	* sc bsd44
! 	* sccs bsd44
! 	* sccs2rcs CVS
! 	* scdisp xopt
! 	* screen screen
! 	* script bsd44
! 	* scsiformat bsd44
! 	* sctext xopt
! 	* sdiff Diffutils
! 	* sed sed
! 	* send-pr GNATS
! 	* sendfax HylaFAX
! 	* sendmail bsd44
! 	* sgi2fax HylaFAX
! 	* sgn GN
! 	* sh bsd44
! 	* shar Sharutils
! 	* shinbun xopt
! 	* shogi Shogi
! 	* showfont xopt
! 	* showmount bsd44
! 	* shutdown bsd44
! 	* size Binutils
! 	* sj3 xopt
! 	* sjxa xopt
! 	* slattach bsd44
! 	* sleep Shellutils
! 	* sliplogin bsd44
! 	* snake bsd44
! 	* snftobdf xopt
! 	* soelim Groff
! 	* sort Textutils
! 	* sos2obst OBST
! 	* spider xopt
! 	* split Textutils
! 	* startslip bsd44
! 	* stf OBST
! 	* strings Binutils
! 	* strip Binutils
! 	* stty Shellutils
! 	* su Shellutils
! 	* sum Textutils
! 	* superopt Superopt
! 	* swapon bsd44
! 	* sync bsd44
! 	* sysctl bsd44
! 	* syslogd bsd44
! 	* systat bsd44
! 
! 	* tabs Termutils
! 	* tac Textutils
! 	* tail Textutils
! 	* taintperl perl
! 	* talk bsd44
! 	* talkd bsd44
! 	* tangle TeX
! 	* tar tar
! 	* tbl Groff
! 	* tcl DejaGnu
! 	* tclsh DejaGnu
! 	* tcopy bsd44
! 	* tcp Emacs
! 	* tee Shellutils
! 	* tek2plot Graphics
! 	* telnet bsd44
! 	* telnetd bsd44
! 	* test Shellutils
! 	* test-g++ DejaGnu
! 	* test-tool DejaGnu
! 	* tetris bsd44
! 	* tex TeX
! 	* tex3patch Texinfo
! 	* texi2dvi Texinfo
! 	* texindex Texinfo
! 	* texspell TeX
! 	* textfmt HylaFAX
! 	* tfmtodit Groff
! 	* tftopl TeX
! 	* tftp bsd44
! 	* tftpd bsd44
! 	* tgrind TeX
! 	* time time
! 	* timed bsd44
! 	* timer Emacs
! 	* timex xopt
! 	* tip bsd44
! 	* tkpostage xopt
! 	* tn3270 bsd44
! 	* touch Fileutils
! 	* tput Termutils
! 	* tr Textutils
! 	* traceroute bsd44
! 	* transcript HylaFAX
! 	* transfig xopt
! 	* trek bsd44
! 	* trn3 bsd44
! 	* troff Groff
! 	* trpt bsd44
! 	* trsp bsd44
! 	* true Shellutils
! 	* tset bsd44
! 	* tsort bsd44
! 	* tty Shellutils
! 	* ttygnans Gnans
! 	* tunefs bsd44
! 	* tupdate gettext
! 	* tvtwm xopt
! 	* twm xreq
! 
! 	* ul bsd44
! 	* ulpc Spinner
! 	* umount bsd44
! 	* uname Shellutils
! 	* uncompress gzip
! 	* unexpand Textutils
! 	* unifdef bsd44
! 	* unify wdiff
! 	* uniq Textutils
! 	* unprotoize GCC
! 	* unshar Sharutils
! 	* unvis bsd44
! 	* update bsd44
! 	* updatedb Findutils
! 	* users Shellutils
! 	* uuchk UUCP
! 	* uucico UUCP
! 	* uuconv UUCP
! 	* uucp UUCP
! 	* uucpd bsd44
! 	* uudecode Sharutils
! 	* uudir UUCP
! 	* uuencode Sharutils
! 	* uulog UUCP
! 	* uuname UUCP
! 	* uupick UUCP
! 	* uurate UUCP
! 	* uusched UUCP
! 	* uustat UUCP
! 	* uuto UUCP
! 	* uux UUCP
! 	* uuxqt UUCP
! 
! 	* v Fileutils
! 	* vacation bsd44
! 	* vandal xopt
! 	* vcdiff Emacs
! 	* vdir Fileutils
! 	* vftovp TeX
! 	* vgrind bsd44
! 	* vi nvi
! 	* viewres xopt
! 	* viewres xreq
! 	* vine xopt
! 	* vipw bsd44
! 	* virmf TeX
! 	* virtex TeX
! 	* vis bsd44
! 	* vmstat bsd44
! 	* vptovf TeX
! 
! 	* w bsd44
! 	* waisgn GN
! 	* wakeup Emacs
! 	* wall bsd44
! 	* wargames bsd44
! 	* wc Textutils
! 	* wdiff wdiff
! 	* weave TeX
! 	* what bsd44
! 	* whatis bsd44
! 	* whereis bsd44
! 	* who Shellutils
! 	* whoami Shellutils
! 	* whois bsd44
! 	* window bsd44
! 	* winterp xopt
! 	* wish DejaGnu
! 	* worm bsd44
! 	* worms bsd44
! 	* write bsd44
! 	* wump bsd44
! 
! 	* x11perf xreq
! 	* x2p perl
! 	* xalarm xopt
! 	* xancur xopt
! 	* xargs Findutils
! 	* xauth xreq
! 	* xbfe Fontutils
! 	* xbiff xopt
! 	* xbiff xreq
! 	* xboard xboard
! 	* xboing xopt
! 	* xbuffy3 xopt
! 	* xcalc xopt
! 	* xcalc xreq
! 	* xcalendar xopt
! 	* xcdplayer xopt
! 	* xcell xopt
! 	* xclipboard xreq
! 	* xclock xreq
! 	* xcmdmenu xopt
! 	* xcms xopt
! 	* xcmsdb xreq
! 	* xcmstest xreq
! 	* xco xopt
! 	* xcolorize xopt
! 	* xcolors xopt
! 	* xconsole xreq
! 	* xcrtca xopt
! 	* xdaliclock xopt
! 	* xdiary xopt
! 	* xditview Groff
! 	* xditview xopt
! 	* xditview xreq
! 	* xdm xreq
! 	* xdpyinfo xreq
! 	* xdu xopt
! 	* xdvi TeX
! 	* xdvi xopt
! 	* xdvorak xopt
! 	* xearth xopt
! 	* xed xopt
! 	* xedit xopt
! 	* xedit xreq
! 	* xev xopt
! 	* xev xreq
! 	* xexit xopt
! 	* xeyes xopt
! 	* xeyes xreq
! 	* xfd xreq
! 	* xfed xopt
! 	* xfedor xopt
! 	* xfeoak xopt
! 	* xferstats HylaFAX
! 	* xfig xopt
! 	* xfontsel xopt
! 	* xfontsel xreq
! 	* xforecast xopt
! 	* xgas xopt
! 	* xgas xreq
! 	* xgc xopt
! 	* xgc xreq
! 	* xgettext gettext
! 	* xhearts xopt
! 	* xhelp xopt
! 	* xhost xreq
! 	* xinit xreq
! 	* xkeycaps xopt
! 	* xkill xreq
! 	* xlax xopt
! 	* xlayout xopt
! 	* xlbiff xopt
! 	* xless xopt
! 	* xload xopt
! 	* xload xreq
! 	* xlogin xopt
! 	* xlogo xreq
! 	* xlsatoms xreq
! 	* xlsclients xreq
! 	* xlsfonts xreq
! 	* xmag xreq
! 	* xmail xopt
! 	* xmailbox xopt
! 	* xmailwatcher xopt
! 	* xman xopt
! 	* xman xreq
! 	* xmandel xopt
! 	* xmessage xopt
! 	* xmeter xopt
! 	* xmh xreq
! 	* xmh-icons xopt
! 	* xmh.editor xopt
! 	* xmodmap xreq
! 	* xmon xopt
! 	* xmove xopt
! 	* xmphone xopt
! 	* xpd xopt
! 	* xphoon xopt
! 	* xpipeman xopt
! 	* xplot Graphics
! 	* xpostit xopt
! 	* xpr xopt
! 	* xpr xreq
! 	* xprompt xopt
! 	* xproof xopt
! 	* xprop xreq
! 	* xpserv xopt
! 	* xrdb xreq
! 	* xrefresh xreq
! 	* xrsh xopt
! 	* xrubik xopt
! 	* xrunclient xopt
! 	* xscope xopt
! 	* xscreensaver xopt
! 	* xsession xopt
! 	* xset xreq
! 	* xsetroot xreq
! 	* xshogi xshogi
! 	* xstdcmap xreq
! 	* xstr bsd44
! 	* xtalk xopt
! 	* xterm xreq
! 	* xterm_color xopt
! 	* xtetris xopt
! 	* xTeXcad.13 xopt
! 	* xtiff xopt
! 	* xtree xopt
! 	* xtv xopt
! 	* xwd xreq
! 	* xwininfo xreq
! 	* xwud xreq
! 
! 	* yacc bsd44
! 	* yes Shellutils
! 	* youbin xopt
! 	* yow Emacs
! 
! 	* zcat gzip
! 	* zcmp gzip
! 	* zdiff gzip
! 	* zforce gzip
! 	* zgrep gzip
! 	* zmore gzip
! 	* znew gzip
! 
! 	* [ Shellutils
! 
! 
! 
! Tapes
! *****
! 
! We offer Unix source code on tapes in `tar' format on these media:
! 
!    * 4mm DAT cartridge tape.
! 
!    * 8mm Exabyte cartridge tape.
! 
!    * Sun DC300XLP QIC-24 1/4in cartridge (readable on some other systems).
! 
!    * Hewlett-Packard 16-track DC600HC 1/4in cartridge tape.
! 
!    * IBM RS/6000 QIC-150 1/4in cartridge (readable on some other systems).
! 
!    * 1600bpi 9-track 1/2in reel tape.
! 
! The contents of the various tapes for Unix systems are the same; only the
! media are different.  For prices, see the *note Free Software Foundation
! Order Form::..	Source code for the manuals & reference cards is included
! (*note Documentation::.).
! 
! Some of the files on the tapes are compressed with `gzip' to allow more files
! on each tape.  Refer to the top-level `README' file at the beginning of each
! tape for instructions on uncompressing them.  `uncompress' and `unpack' *do
! not work*!
! 
! 
! 
! Languages Tape
! --------------
! 
! This tape contains programming tools: compilers, interpreters and, related
! programs (parsers, translators, debuggers, linkers, etc.).
! 
! 	* Binutils 2.6
! 	* Bison 1.24
! 	* C Library 1.09
! 	* cperf 2.1a
! 	* DejaGnu 1.2
! 	* dld 3.2.3
! 	* ecc 1.2.1
! 	* f2c 1995.02.24
! 	* flex 2.5.2
! 	* g77 0.5.17
! 	* GAWK 2.15.6
! 	* GCC/G++/Objective-C 2.7.2
! 	* GDB 4.15.1
! 	* gdbm 1.7.3
! 	* gettext 0.10
! 	* gmp 1.3.2
! 	* gzip 1.2.4
! 	* indent 1.9.1
! 	* libg++ 2.7.1
! 	* libobjects 0.1.3
! 	* make 3.74
! 	* ncurses 1.9.4
! 	* NIHCL 3.1.4
! 	* OBST 3.4.3
! 	* Octave 1.1.1
! 	* p2c 1.20
! 	* perl 4.036
! 	* perl 5.001
! 	* regex 0.12
! 	* rx 0.05
! 	* Smalltalk 1.1.1
! 	* Superopt 2.5
! 	* Texinfo 3.6
! 	* Tile Forth 2.1
! 	* ucblogo 3.3
! 
! 
! 
! Lisps/Emacs Tape
! ----------------
! 
! This tape has Common Lisp systems and libraries, GNU Emacs, assorted
! extensions that work with Emacs, manuals, & a few other important utilities.
! 
! 	* Calc 2.02c
! 	* CLISP 1995.12.04
! 	* CLX 5.02
! 	* Common Lisp 2.2
! 	* Elib 0.06
! 	* Emacs 18.59
! 	* Emacs 19.28
! 	* Emacs 19.30
! 	* GNU Emacs Lisp Reference Manual Ed. 1.03 for Version 18
! 	* GNU Emacs Lisp Reference Manual Ed. 2.4 for Version 19.29
! 	* gnuserv 2.1alpha
! 	* gzip 1.2.4
! 	* Hyperbole 4.01
! 	* make 3.74
! 	* MULE 2.3
! 	* PCL 2.2
! 	* Programming in Emacs Lisp: An Introduction Ed. 1.04
! 	* Texinfo 3.6
! 	* W3 2.2.25
! 
! 
! 
! Utilities Tape
! --------------
! 
! This tape consists mostly of smaller utilities and miscellaneous applications.
! 
! 	* acm 4.7
! 	* Autoconf 2.7
! 	* BASH 1.14.5
! 	* bc 1.03
! 	* cfengine 1.2.14
! 	* cfengine 1.2.22
! 	* Chess 4.0.pl75
! 	* cpio 2.3
! 	* CVS 1.6
! 	* Diffutils 2.7
! 	* doschk 1.1
! 	* ed 0.2
! 	* es 0.84
! 	* Fileutils 3.12
! 	* Findutils 4.1
! 	* Finger 1.37
! 	* Fontutils 0.6
! 	* Ghostscript 2.6.2
! 	* Ghostview 1.5
! 	* Ghostview for Windows 1.0
! 	* GIT 4.3.6
! 	* GNATS 3.2
! 	* GnuGo 1.2
! 	* gnuplot 3.5
! 	* Graphics 0.17
! 	* grep 2.0
! 	* Groff 1.10
! 	* gzip 1.2.4
! 	* hello 1.3
! 	* hp2xx 3.1.4
! 	* HylaFAX 3.0.0
! 	* Ispell 3.1.20
! 	* less 2.9.0
! 	* m4 1.4
! 	* make 3.74
! 	* MandelSpawn 0.07
! 	* mc 3.0
! 	* mkisofs 1.04
! 	* mm 1.07
! 	* mtools 2.0.7
! 	* NetHack 3.1.3
! 	* nvi 1.34
! 	* Oleo 1.6
! 	* patch 2.1
! 	* pine 3.91
! 	* ptx 0.4
! 	* rc 1.4
! 	* RCS 5.7
! 	* readline 2.0
! 	* recode 3.4
! 	* SAOimage 1.16
! 	* screen 3.7.1
! 	* sed 2.05
! 	* Sharutils 4.2
! 	* Shellutils 1.12
! 	* Shogi 1.2.3
! 	* tar 1.11.8
! 	* Termcap 1.3
! 	* Termutils 2.0
! 	* Texinfo 3.6
! 	* Textutils 1.13
! 	* time 1.6
! 	* UUCP 1.06.1
! 	* wdiff 0.5
! 	* xboard 3.4.pl0
! 	* xshogi 1.2.03
! 	* Ygl 3.0.3
  
  
  
! Scheme Tape
! -----------
  
! Scheme is a simplified, lexically-scoped dialect of Lisp.  It was designed at
! MIT and other universities to teach students the art of programming and to
! research new parallel programming constructs and compilation techniques.
  
! This tape now has MIT Scheme 7.3, which conforms to the "Revised^4 Report On
! the Algorithmic Language Scheme" (MIT AI Lab Memo 848b), for which TeX source
! is included.  It is written partly in C, but is presently hard to bootstrap.
! Binaries that can be used to bootstrap it exist for: HP 9000 series 300, 400,
! 700, & 800 (running HP-UX 9.0), NeXT (NeXT OS 2 or 3.2), DEC Alpha (OSF/1),
! IBM RS/6000 (AIX), Sun-3 or Sun-4 (SunOS 4.1), DECstation 3100/5100 (Ultrix
! 4.0), Sony NeWS-3250 (NEWS OS 5.01), & Intel i386 (MS-DOS, Windows 3.1 or NT).
! If your system is not on this list & you don't enjoy the bootstrap challenge,
! see "JACAL" in *Note GNU Software::.
  
  
  
! X11 Tapes
! ---------
  
! The two X11 tapes contain Version 11, Release 6 of the X Window System.	 The
! first tape has all of the core software, documentation, & some contributed
! clients.  We call this the "required" X tape since it is necessary for
! running X or Emacs under X.  The second, "optional" tape has contributed
! libraries & toolkits, the Andrew User Interface System, games, etc.
  
! The X11 Required tape also contains all fixes and patches released to date.
! We update this tape as new fixes and patches are released for programs on
! both tapes.  *Note Tape & CD-ROM Subscription Service::.
  
! While supplies last, we will distribute X11R5 on the *Note November 1993
! Source Code CD-ROM::.
  
  
  
! Berkeley 4.4BSD-Lite Tape
! -------------------------
  
! The "4.4BSD-Lite" release is the last from the Computer Systems Research
! Group at the University of California at Berkeley.  It has most of the BSD
! software system, except for a few files that remain proprietary.  It is much
! more complete than the previous "Net2" release.
  
  
  
! VMS Emacs and VMS Compiler Tapes
! --------------------------------
  
! We offer two VMS tapes.	 One has just GNU Emacs 18.59 (none of the other
! software on the *Note Lisps/Emacs Tape::, is included).	 The other has GCC
! 2.3.3, Bison 1.19 (to compile GCC), `gas' 1.38 (to assemble GCC's output), and
! some library and include files (none of the other software on the *Note
! Languages Tape::, is included).	 We are not aware of a GDB port for VMS.
! Both VMS tapes have DEC VAX executables from which you can bootstrap, as the
! DEC VMS C compiler cannot compile GCC.	We do not have executables for DEC
! Alpha VMS systems.  Please do not ask us to devote effort to VMS support,
! because it is peripheral to the GNU Project.
  
  
  
  CD-ROMs
--- 1826,3128 ----
     * SIPP    (SrcCD)
  
!      SIPP is a library for photorealisticly rendering 3D scenes.
!      Scenes can be illuminated by an arbitrary number of light sources;
!      they are built up of object hierarchies, with arbitrarily many
!      subobjects and subsurfaces.  Surfaces can be rendered with either
!      Phong, Gouraud, or flat shading.  The library supports
!      programmable shaders and texture mapping.
! 
!    * Smail   (SrcCD)
! 
!      Smail is a mail transport system, designed as a compatible drop-in
!      replacement for `sendmail'.  It uses a much simpler configuration
!      format than `sendmail' and is designed to be setup with minimal
!      effort.
! 
!    * Smalltalk   *Also *note Forthcoming GNUs::.*   (SrcCD)
! 
!      GNU Smalltalk is an interpreted object-oriented programming
!      language system written in highly portable C  It has been ported
!      to DOS, many Unix, & other OSes.  Features include a binary image
!      save capability, the ability to call user-written C code with
!      parameters, an Emacs editing mode, a version of the X protocol
!      invocable from Smalltalk, optional byte-code compilation and/or
!      execution tracing, & automatically loaded per-user initialization
!      files.  It implements all of the classes & protocol in the book
!      "Smalltalk-80: The Language", except for the graphic user
!      interface (GUI) related classes.
  
     * SNePS    (SrcCD)
  
       SNePS is the Semantic Network Processing System.  It is an
!      implementation of a fully intensional theory of propositional
!      knowledge representation and reasoning.  SNePS runs under CLISP or
!      GCL.
  
     * Spinner   (SrcCD)
  
!      Spinner is a modularized, object-oriented, non-forking World Wide
!      Web server with high performance and throughput.
  
!    * Superopt   (SrcCD)
  
       Superopt is a function sequence generator that uses an exhaustive
!      generate-and-test approach to find the shortest instruction
!      sequence for a given function.  You provide a function as input, a
!      CPU to generate code for, and how many instructions you want.  Its
!      use in GCC is described in the `ACM SIGPLAN PLDI'92 Proceedings'.
!      It supports: SPARC, m68k, m68020, m88k, IBM POWER and PowerPC, AMD
!      29k, Intel x86 & 960, Pyramid, DEC Alpha, Hitachi SH, & HP-PA.
! 
!    * `tar'   (SrcCD)
! 
!      GNU `tar' includes multi-volume support, the ability to archive
!      sparse files, compression/decompression, remote archives, and
!      special features that allow `tar' to be used for incremental and
!      full backups.  GNU `tar' uses an early draft of the POSIX 1003.1
!      `ustar' format which is different from the final version.  This
!      will be corrected in the future.
! 
!    * Termcap Library   (SrcCD)   [FSFman]
! 
!      The GNU Termcap library is a drop-in replacement for
!      `libtermcap.a' on any system.  It does not place an arbitrary
!      limit on the size of Termcap entries, unlike most other Termcap
!      libraries.  Included is source for the `Termcap Manual' in Texinfo
!      format (*note Documentation::.).
  
!    * Termutils   (SrcCD)
  
       The Termutils package contains programs for controlling terminals.
       `tput' is a portable way for shell scripts to use special terminal
!      capabilities.  `tabs' is a program to set hardware terminal tab
!      settings.
  
!    * TeX   (SrcCD)
  
       TeX is a document formatting system that handles complicated
!      typesetting, including mathematics.  It is GNU's standard text
!      formatter.
  
!      The University of Washington maintains & supports a tape
!      distribution of TeX for Unix systems.  The core material is Karl
!      Berry's `web2c' TeX package.  Sources are available via anonymous
!      FTP; retrieval instructions are in `/pub/tex/unixtex.ftp' on
!      `ftp.cs.umb.edu'.  If you receive any installation support from
!      the University of Washington, consider sending them a donation.
  
       To order a full distribution written in `tar' on either a 1/4inch
       4-track QIC-24 cartridge or a 4mm DAT cartridge, send $210.00 to:
  
!           Pierre A. MacKay
!           Department of Classics
!           DH-10, Denny Hall 218
!           University of Washington
!           Seattle, WA   98195
!           USA
!           
!           Electronic-Mail: `mackay@cs.washington.edu'
!           Telephone: +1-206-543-2268
! 
!      Please make checks payable to: `University of Washington'.  Do not
!      specify any other payee.  That causes accounting problems.  Checks
!      must be in U.S. dollars, drawn on a U.S. bank.  Only prepaid
!      orders can be handled.  Overseas sites: please add to the base
!      cost $20.00 to ship via air parcel post or $30.00 to ship via
!      courier.  Please check with the above for current prices & formats.
  
!    * Texinfo   (SrcCD)   [FSFman]
  
       Texinfo is a set of utilities (`makeinfo', `info', `texi2dvi',
       `texindex', `tex2patch', & `fixfonts') which generate both printed
!      manuals & online hypertext documentation (called "Info"), & can
!      read online Info documents.  Version 3 has both Emacs Lisp &
!      standalone programs written in C or shell script.  Texinfo mode
!      for Emacs enables easy editing & updating of Texinfo files.  Source
!      for the `Texinfo Manual' is included (*note Documentation::.).
  
!    * Textutils   (SrcCD)
  
!      The Textutils programs manipulate textual data.  They include:
!      `cat', `cksum', `comm', `csplit', `cut', `expand', `fmt', `fold',
!      `head', `join', `md5sum', `nl', `od', `paste', `pr', `sort',
!      `split', `sum', `tac', `tail', `tr', `unexpand', `uniq', and `wc'.
  
!    * TIFF library   (SrcCD)
  
!      The TIFF library, `libtiff', is a library for manipulating Tagged
!      Image File Format files, a commonly used bitmap graphics format.
  
!    * Tile Forth   (SrcCD)
  
!      Tile Forth is a 32-bit implementation of the Forth-83 standard
!      written in C, allowing it to be easily ported to new systems &
!      extended with any C-function (graphics, windowing, etc).
  
!      Many documented Forth libraries are available, e.g. top-down
!      parsing, multi-threads, & object-oriented programming.
  
!    * `time'   (SrcCD)
  
+      `time' reports (usually from a shell) the user, system, & real time
+      used by a process.  On some systems it also reports memory usage,
+      page faults, etc.
  
+    * `ucblogo'   (SrcCD)
  
!      `ucblogo' implements the classic teaching language, Logo.
  
+    * UUCP   (SrcCD)
  
+      GNU's UUCP system (written by Ian Lance Taylor) supports the `f',
+      `g' (all window & packet sizes), `v', `G', `t', `e', Zmodem, & two
+      new bidirectional (`i' & `j') protocols.  With a BSD sockets
+      library, it can make TCP connections.  With TLI libraries, it can
+      make TLI connections.  Source is included for a manual (not yet
+      published by the FSF).
  
!    * W3   (SrcCD)
  
!      W3 (written by William Perry in Emacs Lisp) is an extensible,
!      advanced World Wide Web browser that runs as part of Emacs.  It
!      understands many protocols & file formats: FTP, gopher, HTML,
!      SMTP, Telnet, WAIS, etc.
  
!    * `wdiff'   (SrcCD)
  
+      `wdiff' is a front-end to GNU `diff'.  It compares two files,
+      finding the words deleted or added to the first to make the
+      second.  It has many output formats and works well with terminals
+      and pagers.  `wdiff' is very useful when two texts differ only by
+      a few words and paragraphs have been refilled.
  
+    * WN   (SrcCD)
  
!      WN is a World Wide Web server designed to be secure and flexible.
!      It offers many different capabilities in pre-parsing files before
!      passing them to the client, and has a very different design from
!      Apache and the NCSA server.
  
!    * X11   (SrcCD)
  
!      We distribute Version 11, Release 6.1 of the X Window System with
!      the latest patches and bug fixes.  X11 includes all of the core
!      software, documentation, contributed clients, contributed
!      libraries & toolkits, the Andrew User Interface System, games, etc.
  
!      While supplies last, we will distribute X11R5 on the *Note
!      November 1993 Source Code CD-ROM::.
  
+    * `xboard', `xshogi'   (SrcCD)
  
+      `xboard' is an X Window interface to GNU Chess.  `xshogi' is an X
+      Window interface to GNU Shogi.  They use the R4 Athena widgets and
+      Xt Intrinsics to provide an interactive referee for managing a
+      game between a user & a computer opponent, or between two
+      computers.  You can also use `xboard' without GNU Chess to play
+      through games in files or to play through games manually (force
+      mode); in this case, moves aren't validated.
  
!    * `xgrabsc'   (SrcCD)
  
!      `xgrabsc' is a screen capture program similar to `xwd' but with a
!      graphical user interface, more ways of selecting the part of the
!      screen to capture, & different types of output: Postscript, color
!      Postscript, xwd, bitmap, pixmap, & puzzle.
  
+    * `Ygl'   (SrcCD)
  
+      `Ygl' emulates a subset of SGI's GL (Graphics Language) library
+      under X11 on most platforms with an ANSI C compiler (GCC is OK).
+      It has most two-dimensional graphics routines, the queue device &
+      query routines, double buffering, RGB mode with dithering, FORTRAN
+      bindings, etc.
  
!     
  
! Program/Package Cross Reference
! *******************************
  
+    Here is a list of the package each GNU program or library is in.
+ You can FTP the current list in the file `/pub/gnu/ProgramIndex' from a
+ GNU FTP host (listed in *Note How to Get GNU Software::).
+ 
+         * 4dview geomview
+      
+         * a2p perl
+         * a2x xopt
+         * ac bsd44
+         * accton bsd44
+         * ackpfd phttpd
+         * acl bsd44
+         * acm acm
+         * acms acm
+         * addbbox geomview
+         * addftinfo Groff
+         * adventure bsd44
+         * afm2tfm TeX
+         * aid ID Utils
+         * amd bsd44
+         * ansitape bsd44
+         * AnswerGarden xopt
+         * apply bsd44
+         * appres xreq
+         * apropos bsd44
+         * ar Binutils
+         * arithmetic bsd44
+         * arp bsd44
+         * atc bsd44
+         * authwn WN
+         * autoconf Autoconf
+         * autoheader Autoconf
+         * automake Automake
+         * autoreconf Autoconf
+         * autoscan Autoconf
+         * autoupdate Autoconf
+         * auto_box xopt
+         * auto_box xreq
+      
+         * b2m Emacs
+         * backgammon bsd44
+         * bad144 bsd44
+         * badsect bsd44
+         * banner bsd44
+         * basename Shellutils
+         * bash BASH
+         * battlestar bsd44
+         * bc bc
+         * bcd bsd44
+         * bdes bsd44
+         * bdftops Ghostscript
+         * beach_ball xopt
+         * beach_ball xreq
+         * beach_ball2 xopt
+         * bibtex TeX
+         * biff bsd44
+         * bison Bison
+         * bitmap xreq
+         * boggle bsd44
+         * bpltobzr Fontutils
+         * bugfiler bsd44
+         * buildhash Ispell
+         * bzrto Fontutils
+      
+         * c++ GCC
+         * c++filt Binutils
+         * c2ph perl
+         * ca100 xopt
+         * caesar bsd44
+         * cal bsd44
+         * calendar bsd44
+         * canfield bsd44
+         * cat Textutils
+         * cbars wdiff
+         * cc GCC
+         * cc1 GCC
+         * cc1obj GCC
+         * cc1plus GCC
+         * cccp GCC
+         * cdwrite mkisofs
+         * cfengine cfengine
+         * cgi Spinner
+         * charspace Fontutils
+         * checknr bsd44
+         * chess bsd44
+         * chflags bsd44
+         * chgrp Fileutils
+         * ching bsd44
+         * chmod Fileutils
+         * chown Fileutils
+         * chpass bsd44
+         * chroot bsd44
+         * ci RCS
+         * cksum Textutils
+         * cktyps g77
+         * clisp CLISP
+         * clri bsd44
+         * cmail xboard
+         * cmmf TeX
+         * cmodext xopt
+         * cmp Diffutils
+         * co RCS
+         * col bsd44
+         * colcrt bsd44
+         * colrm bsd44
+         * column bsd44
+         * comm Textutils
+         * compress bsd44
+         * comsat bsd44
+         * connectd bsd44
+         * cp Fileutils
+         * cpicker xopt
+         * cpio cpio
+         * cpp GCC
+         * cppstdin perl
+         * cribbage bsd44
+         * crock xopt
+         * csh bsd44
+         * csplit Textutils
+         * ctags Emacs
+         * ctwm xopt
+         * cu UUCP
+         * cut Textutils
+         * cvs CVS
+         * cvscheck CVS
+         * cvtmail Emacs
+         * cxterm xopt
+      
+         * d Fileutils
+         * date Shellutils
+         * dc bc
+         * dd Fileutils
+         * ddd DDD
+         * defid ID Utils
+         * delatex TeX
+         * demangle Binutils
+         * descend CVS
+         * detex TeX
+         * df Fileutils
+         * dhtppd phttpd
+         * diff Diffutils
+         * diff3 Diffutils
+         * diffpp enscript
+         * digest-doc Emacs
+         * dipress bsd44
+         * dir Fileutils
+         * dircolors Fileutils
+         * dirname Shellutils
+         * dish xopt
+         * disklabel bsd44
+         * diskpart bsd44
+         * dld dld
+         * dm bsd44
+         * dmesg bsd44
+         * doschk doschk
+         * dox xopt
+         * du Fileutils
+         * dump bsd44
+         * dump mkisofs
+         * dumpfs bsd44
+         * dvi2tty TeX
+         * dvicopy TeX
+         * dvips TeX
+         * dvitype TeX
+      
+         * ecc ecc
+         * echo Shellutils
+         * ed ed
+         * edit-pr GNATS
+         * editres xreq
+         * edquota bsd44
+         * eeprom bsd44
+         * egrep grep
+         * eid ID Utils
+         * emacs Emacs
+         * emacsclient Emacs
+         * emacsserver Emacs
+         * emacstool Emacs
+         * emu xopt
+         * enscript enscript
+         * env Shellutils
+         * eqn Groff
+         * error bsd44
+         * es es
+         * esdebug es
+         * etags Emacs
+         * ex nvi
+         * example geomview
+         * exicyclog Exim
+         * exigrep Exim
+         * exim Exim
+         * eximon Exim
+         * eximon Exim
+         * eximstats Exim
+         * exinext Exim
+         * exiwhat Exim
+         * expand Textutils
+         * expect DejaGnu
+         * expr Shellutils
+         * exterm xopt
+      
+         * f2c f2c
+         * factor bsd44
+         * fakemail Emacs
+         * false Shellutils
+         * fastboot bsd44
+         * fax2ps HylaFAX
+         * faxalter HylaFAX
+         * faxanswer HylaFAX
+         * faxcover HylaFAX
+         * faxd HylaFAX
+         * faxd.recv HylaFAX
+         * faxmail HylaFAX
+         * faxquit HylaFAX
+         * faxrcvd HylaFAX
+         * faxrm HylaFAX
+         * faxstat HylaFAX
+         * fc f2c
+         * fdraw xopt
+         * ffe g77
+         * fgrep grep
+         * fid ID Utils
+         * file bsd44
+         * find Findutils
+         * find2perl perl
+         * finger Finger
+         * fingerd Finger
+         * fish bsd44
+         * fixfonts Texinfo
+         * fixinc.svr4 GCC
+         * fixincludes GCC
+         * flex flex
+         * flex++ flex
+         * flythrough geomview
+         * fmt bsd44
+         * fnid ID Utils
+         * fold Textutils
+         * font2c Ghostscript
+         * fontconvert Fontutils
+         * forth Tile Forth
+         * forthicon Tile Forth
+         * forthtool Tile Forth
+         * fortune bsd44
+         * fpr bsd44
+         * freq Ispell
+         * freqtbl Ispell
+         * from bsd44
+         * fsck bsd44
+         * fsplit bsd44
+         * fstat bsd44
+         * ftp bsd44
+         * ftp Inetutils
+         * ftpd bsd44
+         * ftpd Inetutils
+      
+         * g++ GCC
+         * gas Binutils
+         * gawk GAWK
+         * gcal gcal
+         * gcc GCC
+         * gcore bsd44
+         * gdb GDB
+         * genclass libg++
+         * geomstuff geomview
+         * gettext gettext
+         * getty bsd44
+         * gftodvi TeX
+         * gftopk TeX
+         * gftype TeX
+         * ghostview Ghostview
+         * gid ID Utils
+         * ginsu geomview
+         * git GIT
+         * gitaction GIT
+         * gitcmp GIT
+         * gitkeys GIT
+         * gitmatch GIT
+         * gitmount GIT
+         * gitps GIT
+         * gitredir GIT
+         * gitrgrep GIT
+         * gitview GIT
+         * gitwipe GIT
+         * gn GN
+         * gnans Gnans
+         * gnanslator Gnans
+         * gnats GNATS
+         * gnuchess Chess
+         * gnuchessc Chess
+         * gnuchessn Chess
+         * gnuchessr Chess
+         * gnuchessx Chess
+         * gnuclient gnuserv
+         * gnudoit gnuserv
+         * gnupdisp Shogi
+         * gnuplot gnuplot
+         * gnuplot_x11 gnuplot
+         * gnuserv gnuserv
+         * gnushogi Shogi
+         * gnushogir Shogi
+         * gnushogix Shogi
+         * go GnuGo
+         * gpc xopt
+         * gpc xreq
+         * gperf cperf
+         * gperf libg++
+         * gprof Binutils
+         * graffiti geomview
+         * graph Graphics
+         * grep grep
+         * grodvi Groff
+         * groff Groff
+         * grops Groff
+         * grotty Groff
+         * groups Shellutils
+         * gs Ghostscript
+         * gsbj Ghostscript
+         * gsdj Ghostscript
+         * gslj Ghostscript
+         * gslp Ghostscript
+         * gsnd Ghostscript
+         * gsrenderfont Fontutils
+         * gunzip gzip
+         * gvclock geomview
+         * gwm xopt
+         * gzexe gzip
+         * gzip gzip
+      
+         * h2ph perl
+         * h2pl perl
+         * hack bsd44
+         * hangman bsd44
+         * head Textutils
+         * hello hello
+         * hexdump bsd44
+         * hexl Emacs
+         * hinge geomview
+         * hostname Shellutils
+         * hp2xx hp2xx
+         * hterm xopt
+         * htmlencode phttpd
+         * httpd apache
+         * httpdecode phttpd
+      
+         * i18nOlwmV2 xopt
+         * i2mif xopt
+         * ico xopt
+         * ico xreq
+         * id Shellutils
+         * ident RCS
+         * ifconfig bsd44
+         * ifnames Autoconf
+         * ImageMagick xopt
+         * imageto Fontutils
+         * iman xopt
+         * imgrotate Fontutils
+         * indent indent
+         * indxbib Groff
+         * inetd bsd44
+         * inetd Inetutils
+         * info Texinfo
+         * inimf TeX
+         * init bsd44
+         * initex TeX
+         * inn bsd44
+         * install Fileutils
+         * iostat bsd44
+         * isodiag mkisofs
+         * isodump mkisofs
+         * ispell Ispell
+         * ixterm xopt
+         * ixx xopt
+      
+         * join Textutils
+         * jot bsd44
+         * jove bsd44
+      
+         * kdestroy bsd44
+         * kdump bsd44
+         * kermit bsd44
+         * kgames xopt
+         * kgmon bsd44
+         * kill bsd44
+         * kinit bsd44
+         * kinput2 xopt
+         * klist bsd44
+         * kpasswdd bsd44
+         * ksrvtgt bsd44
+         * kterm xopt
+         * ktrace bsd44
+      
+         * lam bsd44
+         * larn bsd44
+         * lasergnu gnuplot
+         * last bsd44
+         * lastcomm bsd44
+         * latex TeX
+         * lclock xopt
+         * ld Binutils
+         * leave bsd44
+         * less less
+         * lesskey less
+         * libavcall.a ffcall
+         * libbfd.a Binutils
+         * libbfd.a GDB
+         * libbzr.a Fontutils
+         * libc.a C Library
+         * libcompat.a bsd44
+         * libcurses.a bsd44
+         * libcurses.a ncurses
+         * libdcurses.a ncurses
+         * libedit.a bsd44
+         * libF77.a f2c
+         * libF77.a g77
+         * libg++.a libg++
+         * libgdbm.a gdbm
+         * libgf.a Fontutils
+         * libgmp.a gmp
+         * libgnanslib.a Gnans
+         * libgnussl.a gnussl
+         * libI77.a f2c
+         * libI77.a g77
+         * libkvm.a bsd44
+         * libm.a bsd44
+         * libncurses.a ncurses
+         * libnihcl.a NIHCL
+         * libnihclmi.a NIHCL
+         * libnihclvec.a NIHCL
+         * libnls.a xreq
+         * libobjects.a libobjects
+         * liboctave.a Octave
+         * liboldX.a xreq
+         * libpbm.a Fontutils
+         * libPEXt.a xopt
+         * libpk.a Fontutils
+         * libresolv.a bsd44
+         * librpc.a bsd44
+         * libsipp.a SIPP
+         * libtcl.a DejaGnu
+         * libtelnet.a bsd44
+         * libterm.a bsd44
+         * libtermcap.a Termcap
+         * libtfm.a Fontutils
+         * libtiff.a tiff
+         * libutil.a bsd44
+         * libvacall.a ffcall
+         * libWc.a xopt
+         * libwidgets.a Fontutils
+         * libX.a xreq
+         * libXau.a xreq
+         * libXaw.a xreq
+         * libXcp.a xopt
+         * libXcu.a xopt
+         * libXdmcp.a xreq
+         * libXmp.a xopt
+         * libXmu.a xreq
+         * libXO.a xopt
+         * libXop.a xopt
+         * libXp.a xopt
+         * libXpex.a xopt
+         * libXt.a xopt
+         * libXt.a xreq
+         * libXwchar.a xopt
+         * liby.a bsd44
+         * libYgl.a Ygl
+         * lid ID Utils
+         * limn Fontutils
+         * listres xopt
+         * listres xreq
+         * lkbib Groff
+         * ln Fileutils
+         * locate Findutils
+         * lock bsd44
+         * logcvt-ip2n phttpd
+         * logger bsd44
+         * login bsd44
+         * logname Shellutils
+         * logo ucblogo
+         * lookbib Groff
+         * lorder bsd44
+         * lpr bsd44
+         * ls Fileutils
+         * lynx lynx
+      
+         * m4 m4
+         * mail bsd44
+         * mail-files Sharutils
+         * mailq smail
+         * mailshar Sharutils
+         * make make
+         * make-docfile Emacs
+         * make-path Emacs
+         * makeindex TeX
+         * makeinfo Texinfo
+         * MakeTeXPK TeX
+         * man bsd44
+         * man-macros Groff
+         * maniview geomview
+         * mattrib mtools
+         * maze xopt
+         * maze xreq
+         * mazewar xopt
+         * mc mc
+         * mcd mtools
+         * mcopy mtools
+         * mcserv mc
+         * md5sum Textutils
+         * mdel mtools
+         * mdir mtools
+         * me-macros Groff
+         * medit2gv geomview
+         * merge RCS
+         * mesg bsd44
+         * mf TeX
+         * mformat mtools
+         * mft TeX
+         * mgdiff xopt
+         * mh bsd44
+         * mille bsd44
+         * mkafmmap enscript
+         * mkcache GN
+         * mkdep bsd44
+         * mkdir Fileutils
+         * mkfifo Fileutils
+         * mkid ID Utils
+         * mkisofs mkisofs
+         * mklocale bsd44
+         * mkmanifest mtools
+         * mkmf bsd44
+         * mkmodules CVS
+         * mknod Fileutils
+         * mkstr bsd44
+         * mlabel mtools
+         * mm-macros Groff
+         * mmd mtools
+         * monop bsd44
+         * more bsd44
+         * morse bsd44
+         * mount bsd44
+         * mountd bsd44
+         * movemail Emacs
+         * mprof bsd44
+         * mrd mtools
+         * mread mtools
+         * mren mtools
+         * ms-macros Groff
+         * msgcmp gettext
+         * msgfmt gettext
+         * msgmerge gettext
+         * msgs bsd44
+         * msgunfmt gettext
+         * mst Smalltalk
+         * mt cpio
+         * mterm xopt
+         * mtree bsd44
+         * mtype mtools
+         * mule MULE
+         * muncher xopt
+         * mv Fileutils
+         * mvdir Fileutils
+         * mwrite mtools
+      
+         * NDview geomview
+         * nethack NetHack
+         * netstat bsd44
+         * newfs bsd44
+         * nfsd bsd44
+         * nfsiod bsd44
+         * nfsstat bsd44
+         * nice Shellutils
+         * nl Textutils
+         * nlmconv Binutils
+         * nm Binutils
+         * nohup Shellutils
+         * nose geomview
+         * notify HylaFAX
+         * nroff Groff
+         * number bsd44
+      
+         * objc GCC
+         * objcopy Binutils
+         * objdump Binutils
+         * objective-c GCC
+         * obst-boot OBST
+         * obst-CC OBST
+         * obst-cct OBST
+         * obst-cgc OBST
+         * obst-cmp OBST
+         * obst-cnt OBST
+         * obst-cpcnt OBST
+         * obst-csz OBST
+         * obst-dir OBST
+         * obst-dmp OBST
+         * obst-gen OBST
+         * obst-gsh OBST
+         * obst-init OBST
+         * obst-scp OBST
+         * obst-sil OBST
+         * obst-stf OBST
+         * oclock xreq
+         * octave Octave
+         * od Textutils
+         * oleo Oleo
+         * ora-examples xopt
+      
+         * p2c p2c
+         * pagesize bsd44
+         * palette xopt
+         * pascal bsd44
+         * passwd bsd44
+         * paste Textutils
+         * patch patch
+         * patgen TeX
+         * pathalias bsd44
+         * pathchk Shellutils
+         * pathto smail
+         * pax bsd44
+         * pbmplus xopt
+         * perl perl
+         * pfbtops Groff
+         * phantasia bsd44
+         * phttpd phttpd
+         * pic Groff
+         * pico pine
+         * pig bsd44
+         * pine pine
+         * ping bsd44
+         * pixedit xopt
+         * pixmap xopt
+         * pktogf TeX
+         * pktype TeX
+         * plaid xopt
+         * plot2fig Graphics
+         * plot2plot Graphics
+         * plot2ps Graphics
+         * plot2tek Graphics
+         * pltotf TeX
+         * pollrcvd HylaFAX
+         * pom bsd44
+         * pooltype TeX
+         * portmap bsd44
+         * ppt bsd44
+         * pr Textutils
+         * pr-addr GNATS
+         * pr-edit GNATS
+         * primes bsd44
+         * printenv Shellutils
+         * printf Shellutils
+         * protoize GCC
+         * proxygarb Spinner
+         * ps bsd44
+         * ps2ascii Ghostscript
+         * ps2epsi Ghostscript
+         * ps2fax HylaFAX
+         * psbb Groff
+         * pstat bsd44
+         * psycho xopt
+         * ptester phttpd
+         * ptx ptx
+         * pubdic+ xopt
+         * puzzle xopt
+         * puzzle xreq
+         * pwd Shellutils
+         * pyramid xopt
+      
+         * query-pr GNATS
+         * quiz bsd44
+         * quot bsd44
+         * quota bsd44
+         * quotacheck bsd44
+         * quotaon bsd44
+      
+         * rain bsd44
+         * random bsd44
+         * ranlib Binutils
+         * rbootd bsd44
+         * rc rc
+         * rcp bsd44
+         * rcp Inetutils
+         * rcs RCS
+         * rcs-to-cvs CVS
+         * rcs2log Emacs
+         * rcsdiff RCS
+         * rcsfreeze RCS
+         * rcsmerge RCS
+         * rdist bsd44
+         * reboot bsd44
+         * recode recode
+         * recvstats HylaFAX
+         * red ed
+         * refer Groff
+         * remsync Sharutils
+         * renice bsd44
+         * repquota bsd44
+         * restore bsd44
+         * rev bsd44
+         * rexecd bsd44
+         * rexecd Inetutils
+         * rlog RCS
+         * rlogin bsd44
+         * rlogin Inetutils
+         * rlogind bsd44
+         * rlogind Inetutils
+         * rm Fileutils
+         * rmail bsd44
+         * rmdir Fileutils
+         * rmt cpio
+         * rmt tar
+         * robots bsd44
+         * rogue bsd44
+         * route bsd44
+         * routed bsd44
+         * rr xopt
+         * rs bsd44
+         * rsh bsd44
+         * rsh Inetutils
+         * rshd bsd44
+         * rshd Inetutils
+         * rsmtp smail
+         * runq smail
+         * runtest DejaGnu
+         * runtest.exp DejaGnu
+         * ruptime bsd44
+         * rwho bsd44
+         * rwhod bsd44
+      
+         * s2p perl
+         * sail bsd44
+         * saoimage SAOimage
+         * savecore bsd44
+         * sc bsd44
+         * sccs bsd44
+         * sccs2rcs CVS
+         * scdisp xopt
+         * screen screen
+         * script bsd44
+         * scsiformat bsd44
+         * sctext xopt
+         * sdiff Diffutils
+         * sed sed
+         * send-pr GNATS
+         * sendfax HylaFAX
+         * sendmail bsd44
+         * sgi2fax HylaFAX
+         * sgn GN
+         * sh bsd44
+         * shar Sharutils
+         * shinbun xopt
+         * shogi Shogi
+         * showfont xopt
+         * showmount bsd44
+         * shutdown bsd44
+         * size Binutils
+         * sj3 xopt
+         * sjxa xopt
+         * slattach bsd44
+         * sleep Shellutils
+         * sliplogin bsd44
+         * smail smail
+         * smtpd smail
+         * snake bsd44
+         * snftobdf xopt
+         * soelim Groff
+         * sort Textutils
+         * sos2obst OBST
+         * spider xopt
+         * split Textutils
+         * startslip bsd44
+         * stereo geomview
+         * stf OBST
+         * strings Binutils
+         * strip Binutils
+         * stty Shellutils
+         * su Shellutils
+         * sum Textutils
+         * superopt Superopt
+         * swapon bsd44
+         * sweep geomview
+         * sync bsd44
+         * sysctl bsd44
+         * syslog Inetutils
+         * syslogd bsd44
+         * syslogd Inetutils
+         * systat bsd44
+      
+         * tabs Termutils
+         * tac Textutils
+         * tackdown geomview
+         * tail Textutils
+         * taintperl perl
+         * talk bsd44
+         * talk Inetutils
+         * talkd bsd44
+         * talkd Inetutils
+         * tangle TeX
+         * tar tar
+         * tbl Groff
+         * tcal gcal
+         * tcl DejaGnu
+         * tclsh DejaGnu
+         * tcopy bsd44
+         * tcp Emacs
+         * tee Shellutils
+         * tek2plot Graphics
+         * telnet bsd44
+         * telnet Inetutils
+         * telnetd bsd44
+         * telnetd Inetutils
+         * test Shellutils
+         * test-g++ DejaGnu
+         * test-tool DejaGnu
+         * tetris bsd44
+         * tex TeX
+         * tex3patch Texinfo
+         * texi2dvi Texinfo
+         * texindex Texinfo
+         * texspell TeX
+         * textfmt HylaFAX
+         * tfmtodit Groff
+         * tftopl TeX
+         * tftp bsd44
+         * tftp Inetutils
+         * tftpd bsd44
+         * tftpd Inetutils
+         * tgrind TeX
+         * time time
+         * timed bsd44
+         * timer Emacs
+         * timex xopt
+         * tip bsd44
+         * tkpostage xopt
+         * tn3270 bsd44
+         * togeomview geomview
+         * touch Fileutils
+         * tput Termutils
+         * tr Textutils
+         * traceroute bsd44
+         * transcript HylaFAX
+         * transfig xopt
+         * transformer geomview
+         * trek bsd44
+         * trigrp geomview
+         * trn3 bsd44
+         * troff Groff
+         * trpt bsd44
+         * trsp bsd44
+         * true Shellutils
+         * tset bsd44
+         * tsort bsd44
+         * tty Shellutils
+         * ttygnans Gnans
+         * tunefs bsd44
+         * tupdate gettext
+         * tvtwm xopt
+         * twm xreq
+      
+         * ul bsd44
+         * ulpc Spinner
+         * umount bsd44
+         * uname Shellutils
+         * uncompress gzip
+         * unexpand Textutils
+         * unifdef bsd44
+         * unify wdiff
+         * uniq Textutils
+         * unprotoize GCC
+         * unshar Sharutils
+         * unvis bsd44
+         * update bsd44
+         * updatedb Findutils
+         * users Shellutils
+         * uuchk UUCP
+         * uucico UUCP
+         * uuconv UUCP
+         * uucp UUCP
+         * uucpd bsd44
+         * uucpd Inetutils
+         * uudecode Sharutils
+         * uudir UUCP
+         * uuencode Sharutils
+         * uulog UUCP
+         * uuname UUCP
+         * uupath smail
+         * uupick UUCP
+         * uurate UUCP
+         * uusched UUCP
+         * uustat UUCP
+         * uuto UUCP
+         * uux UUCP
+         * uuxqt UUCP
+      
+         * v Fileutils
+         * vacation bsd44
+         * vandal xopt
+         * vcdiff Emacs
+         * vdir Fileutils
+         * vftovp TeX
+         * vgrind bsd44
+         * vi nvi
+         * viewres xopt
+         * viewres xreq
+         * vine xopt
+         * vipw bsd44
+         * virmf TeX
+         * virtex TeX
+         * vis bsd44
+         * vmstat bsd44
+         * vptovf TeX
+      
+         * w bsd44
+         * waisgn GN
+         * wakeup Emacs
+         * wall bsd44
+         * wargames bsd44
+         * wc Textutils
+         * wdiff wdiff
+         * weave TeX
+         * what bsd44
+         * whatis bsd44
+         * whereis bsd44
+         * who Shellutils
+         * whoami Shellutils
+         * whois bsd44
+         * window bsd44
+         * winterp xopt
+         * wish DejaGnu
+         * wn WN
+         * wndex WN
+         * worm bsd44
+         * worms bsd44
+         * write bsd44
+         * wump bsd44
+      
+         * x11perf xreq
+         * x2p perl
+         * xalarm xopt
+         * xancur xopt
+         * xargs Findutils
+         * xauth xreq
+         * xbfe Fontutils
+         * xbiff xopt
+         * xbiff xreq
+         * xboard xboard
+         * xboing xopt
+         * xbuffy3 xopt
+         * xcalc xopt
+         * xcalc xreq
+         * xcalendar xopt
+         * xcdplayer xopt
+         * xcell xopt
+         * xclipboard xreq
+         * xclock xreq
+         * xcmdmenu xopt
+         * xcms xopt
+         * xcmsdb xreq
+         * xcmstest xreq
+         * xco xopt
+         * xcolorize xopt
+         * xcolors xopt
+         * xconsole xreq
+         * xcrtca xopt
+         * xdaliclock xopt
+         * xdiary xopt
+         * xditview Groff
+         * xditview xopt
+         * xditview xreq
+         * xdm xreq
+         * xdpyinfo xreq
+         * xdu xopt
+         * xdvi TeX
+         * xdvi xopt
+         * xdvorak xopt
+         * xearth xopt
+         * xed xopt
+         * xedit xopt
+         * xedit xreq
+         * xev xopt
+         * xev xreq
+         * xexit xopt
+         * xeyes xopt
+         * xeyes xreq
+         * xfd xreq
+         * xfed xopt
+         * xfedor xopt
+         * xfeoak xopt
+         * xferstats HylaFAX
+         * xfig xopt
+         * xfontsel xopt
+         * xfontsel xreq
+         * xforecast xopt
+         * xgas xopt
+         * xgas xreq
+         * xgc xopt
+         * xgc xreq
+         * xgettext gettext
+         * xhearts xopt
+         * xhelp xopt
+         * xhost xreq
+         * xinit xreq
+         * xkeycaps xopt
+         * xkill xreq
+         * xlax xopt
+         * xlayout xopt
+         * xlbiff xopt
+         * xless xopt
+         * xload xopt
+         * xload xreq
+         * xlogin xopt
+         * xlogo xreq
+         * xlsatoms xreq
+         * xlsclients xreq
+         * xlsfonts xreq
+         * xmag xreq
+         * xmail xopt
+         * xmailbox xopt
+         * xmailwatcher xopt
+         * xman xopt
+         * xman xreq
+         * xmandel xopt
+         * xmessage xopt
+         * xmeter xopt
+         * xmh xreq
+         * xmh-icons xopt
+         * xmh.editor xopt
+         * xmodmap xreq
+         * xmon xopt
+         * xmove xopt
+         * xmphone xopt
+         * xpd xopt
+         * xphoon xopt
+         * xpipeman xopt
+         * xplot Graphics
+         * xpostit xopt
+         * xpr xopt
+         * xpr xreq
+         * xprompt xopt
+         * xproof xopt
+         * xprop xreq
+         * xpserv xopt
+         * xrdb xreq
+         * xrefresh xreq
+         * xrsh xopt
+         * xrubik xopt
+         * xrunclient xopt
+         * xscope xopt
+         * xscreensaver xopt
+         * xsession xopt
+         * xset xreq
+         * xsetroot xreq
+         * xshogi xshogi
+         * xstdcmap xreq
+         * xstr bsd44
+         * xtalk xopt
+         * xterm xreq
+         * xterm_color xopt
+         * xtetris xopt
+         * xTeXcad.13 xopt
+         * xtiff xopt
+         * xtokid ID Utils
+         * xtree xopt
+         * xtv xopt
+         * xwd xreq
+         * xwininfo xreq
+         * xwud xreq
+      
+         * yacc bsd44
+         * yes Shellutils
+         * youbin xopt
+         * yow Emacs
+      
+         * zcat gzip
+         * zcmp gzip
+         * zdiff gzip
+         * zforce gzip
+         * zgrep gzip
+         * zmore gzip
+         * znew gzip
+      
+         * [ Shellutils
  
+  
  
  CD-ROMs
*************** We offer these CD-ROMs:
*** 3092,3954 ****
     * Several editions of our *Note Source Code CD-ROMs::.
  
!    * *Note December 1995 Compiler Tools Binaries CD-ROM::.
! 
!    * *Note December 1994 Compiler Tools Binaries CD-ROM::.
! 
!    * *Note December 1993 Compiler Tools Binaries CD-ROM::.
! 
!    * *Note MS-DOS Book with CD-ROM::.
! 
!    * *Note Debian GNU/Linux Book with CD-ROM::.
  
! Our CD-ROMs are in ISO 9660 format & can be mounted as a read-only file
! system on most computers.  If your driver supports it you can mount each CD
! with "Rock Ridge" extensions (the MS-DOS CD-ROM is only in ISO 9660 format),
! & it will look just like an ordinary Unix file system, rather than one full
! of truncated & otherwise mangled names that fit vanilla ISO 9660.
  
! You can build most of the software without copying the sources off the CD.
! You only need enough disk space for object files and intermediate build
! targets.
  
  
  
  Pricing of the GNU CD-ROMs
  --------------------------
  
! If a business or organization is ultimately paying, the December 1995 Source
! CDs costs $240.	 It costs $60 if you, an individual, are paying out of your
! own pocket.  The December 1995 Compiler Tools Binaries CD-ROM costs $220 for
! a business or organization, and $55 for an individual.
! 
! 
! 
! What do the individual and company prices mean?
! ...............................................
! 
! The software on our disks is free; anyone can copy it and anyone can run it.
! What we charge for is the physical disk and the service of distribution.
! 
! We charge two different prices depending on who is buying.  When a company or
! other organization buys the December 1995 Source CD-ROMs, we charge $240.
! When an individual buys the same CD-ROM, we charge just $60.  This
! distinction is not a matter of who is allowed to use the software.  In either
! case, once you have a copy, you can distribute as many copies as you wish and
! there's no restriction on who can have or run them.  The price distinction is
! entirely a matter of what kind of entity pays for the CD.
  
! You, the reader, are certainly an individual, not a company.  If you are
! buying a disk "in person", then you are probably doing so as an individual.
! But if you expect to be reimbursed by your employer, then the disk is really
! for the company; so please pay the company price and get reimbursed for it.
! We won't try to check up on you--we use the honor system--so please cooperate.
  
! Buying CDs at the company price is very helpful for GNU; just
! 140 Source CDs at that price support an FSF programmer or tech writer for a
! year.
! 
! 
! 
! Why is there an individual price?
  .................................
  
! In the past, our distribution tapes have been ordered mainly by companies.
! The CD at the price of $240 provides them with all of our software for a much
! lower price than they would previously have paid for six different tapes.  To
! lower the price more would cut into the FSF's funds very badly and decrease
! the software development we can do.
! 
! However, for individuals, $240 is too high a price; hardly anyone could
! afford that.  So we decided to make CDs available to individuals at the lower
! price of $60.
  
  
! 
! Is there a maximum price?
  .........................
  
! Our stated prices are minimum prices.  Feel free to pay a higher price if you
! wish to support GNU development more.  The sky's the limit; we will accept as
! high a price as you can offer.	Or simply give a donation (tax-deductible in
! the U.S.) to the Free Software Foundation, a tax-exempt public charity.
! 
  
  
  December 1995 Compiler Tools Binaries CD-ROM
  --------------------------------------------
  
! We now have the third edition of our CD-ROM that has binaries and complete
! sources for GNU compiler tools for some systems which lack a compiler.	This
! enables the people who use these systems to compile GNU and other free
! software without having to buy a proprietary compiler.	You can also use
! these GNU tools to compile your own C/C++/Objective-C programs.	 Older
! editions of this CD are available while supplies last at a reduced price; see
! the *note Free Software Foundation Order Form::..
! 
! We hope to have more systems on each update of this CD.	 If you can help
! build binaries for new systems (especially those that don't come with a C
! compiler), or have one to suggest, please contact us at the addresses on page
! 1.
  
  These packages:
  
! 	* DJGPP 1.12m4 from GCC 2.6.3
! 	* GCC/G++/Objective-C 2.7.1
! 	* GNU C Library 1.09
! 	* GDB 4.15.1
! 	* Binutils 2.6
! 	* Bison 1.24
! 	* Emacs 19.29 (MS-DOS only)
! 	* Flex 2.5.2
! 	* Make 3.74
! 	* libg++ 2.7.1
  
  On these platforms:
  
! 	* `i386-msdos'
! 	* `hppa1.0-hp-hpux9'
! 	* `sparc-sun-solaris2'
! 	* `sparc-sun-sunos4.1'
! 
! 
! 
! December 1994 Compiler Tools Binaries CD-ROM
! --------------------------------------------
! 
! We still have the 2nd edition of our CD-ROM that contains executables for GNU
! compiler tools for some systems which lack a compiler.	This enables the
! people who use these systems to compile GNU and other free software without
! having to buy a proprietary compiler.  You can also use the GNU compilation
! system to compile your own C/C++/Objective-C programs.
! 
! We hope to have more systems on each update of this CD.	 If you can help
! build binaries for new systems (especially those that don't come with a C
! compiler), or have one to suggest, please contact us at the addresses on
! page 1.
! 
! These packages:
! 
! 	* DJGPP 1.12.m2 from GCC 2.6.0
! 	* GCC/G++/Objective-C 2.6.2
! 	* GNU C Library 1.09
! 	* GDB 4.13
! 	* Binutils 2.5.2
! 	* Bison 1.22
! 	* Emacs 19.26 (MS-DOS only)
! 	* Flex 2.4.7
! 	* Make 3.72.1
! 	* libg++ 2.6.1
! 
! On these platforms:
! 
! 	* `i386-msdos'
! 	* `hppa1.1-hp-hpux9'
! 	* `sparc-sun-solaris2'
! 	* `sparc-sun-sunos4.1'
! 
! 
! 
! December 1993 Compiler Tools Binaries CD-ROM
! ---------------------------------------------
! 
! We still have the 1st edition of our CD-ROM that contains executables for GNU
! compiler tools for some systems which lack a compiler.	This will allow users
! of those systems to compile GNU and other free software without having to buy
! a proprietary compiler.
! 
! The CD-ROM is in ISO 9660 format and can be mounted as a read-only file
! system on most operating systems.  If your driver supports it you can mount
! the CD-ROM with "Rock Ridge" extensions and it will look just like an
! ordinary Unix file system, rather than one full of truncated and otherwise
! mangled names that fit the vanilla ISO 9660 specifications.
! 
! We hope to have more systems included with each update of this CD-ROM.	If
! you can help build binaries for new systems (especially for systems that
! don't come with a C compiler), or have a system to suggest, please contact us
! at either address on the front cover.
! 
! These programs:
! 
!    * DJGPP 1.11.m1
! 
!    * GCC/G++/Objective C 2.5.7
! 
!    * GDB 4.11
! 
!    * GAS 2.2
! 
!    * Binutils 2.3
! 
!    * Bison 1.22
! 
!    * Flex 2.4.5
  
!    * Make 3.70
  
!    * libg++ 2.5.3
  
! For these platforms:
  
!    * `i386-msdos'
! 
!    * `hppa1.1-hp-hpux9'
! 
!    * `sparc-sun-solaris2'
! 
!    * `sparc-sun-sunos4.1'
  
  
  
  Source Code CD-ROMs
  -------------------
  
! We have several versions of our Source Code CD-ROMs available, including:
  
!    * *Note December 1995 Source Code CD-ROMs::, the newest release, has
       programs, bug fixes, & improvements not on the other CDs.
  
!    * *Note June 1995 Source Code CD-ROM::.
  
!    * *Note May 1994 Source Code CD-ROM::..
  
!    * *Note November 1993 Source Code CD-ROM::.
  
!    * May 1993 Source Code CD-ROM, see the *note Free Software Foundation
!      Order Form::..
  
!    * October 1992 Source Code CD-ROM, see the *note Free Software Foundation
!      Order Form::..
  
! The older Source CDs are available while supplies last at a reduced price
! (please note that the December 1994 Source CD is permanently out of stock).
! All the Source CDs have Texinfo source for the GNU manuals listed in *Note
! Documentation::.
! 
! The VMS tapes' contents are *not* included.  Many programs that are only on
! MS-DOS diskettes & not on the tapes are also *not* included.  The MIT Scheme
! & X11 Optional tapes' contents are *not* on the older Source CDs.  *Note
! Tapes:: & *Note MS-DOS Diskettes::.
! 
! There are no precompiled programs on these Source CDs.	You will need a C
! compiler (programs which need some other interpreter or compiler normally
! provide the C source for a bootstrapping program).  We ship C compiler
! binaries for some systems on the *Note Compiler Tools Binaries CD-ROM::.
  
  
  
  December 1995 Source Code CD-ROMs
  .................................
  
! The 7th edition of our Source CD is out!  Due to increasing amounts of GNU
! Software, the Source Code CD is now a two disc set--the price remains
! unchanged!  It contains these packages, & some manuals that are not part of
! packages:
! 
! 	* acm 4.7
! 	* apache 0.8.8
! 	* Autoconf 2.7
! 	* BASH 1.14.5
! 	* bc 1.03
! 	* Binutils 2.5.2
! 	* Binutils 2.6
! 	* Bison 1.24
! 	* C Library 1.09
! 	* Calc 2.02c
! 	* cfengine 1.2.21
! 	* Chess 4.0.pl75
! 	* CLISP 1995.08.12
! 	* Common Lisp 2.2
! 	* cperf 2.1a
! 	* cpio 2.3
! 	* CVS 1.6
! 	* DDD 1.3b
! 	* DejaGnu 1.2.9
! 	* Diffutils 2.7
! 	* dld 3.2.3
! 	* doschk 1.1
! 	* ecc 1.2.1
! 	* ed 0.2
! 	* Elib 0.07
! 	* Elisp archive
! 	* Emacs 18.59
! 	* Emacs 19.28
! 	* Emacs 19.29
! 	* Emacs 19.30
! 	* es 0.84
! 	* f2c 1995.11.18
! 	* ffcall 1.0
! 	* Fileutils 3.12
! 	* Findutils 4.1
! 	* Finger 1.37
! 	* flex 2.5.2
! 	* Fontutils 0.6
! 	* g77 0.5.17
! 	* GAWK 2.15.6
! 	* GCC/G++/Objective C 2.7.1
! 	* GDB 4.15.1
! 	* gdbm 1.7.3
! 	* gettext 0.9a
! 	* Ghostscript 2.6.2
! 	* Ghostview 1.5
! 	* Ghostview for Windows 1.0
! 	* GIT 4.3.7
! 	* gmp 1.3.2
! 	* GN 2.23
! 	* Gnans 1.5
! 	* GNATS 3.2
! 	* GNU Emacs Lisp Reference Manual, Ed. 1.03 for Version 18.59
! 	* GNU Emacs Lisp Reference Manual, Ed. 2.4 for Version 19.29
! 	* GnuGo 1.2
! 	* gnuplot 3.5
! 	* gnuserv 2.1alpha
! 	* Graphics 0.17
! 	* grep 2.0
! 	* Groff 1.09
! 	* gzip 1.2.4
! 	* hello 1.3
! 	* hp2xx 3.1.4
! 	* HylaFAX v3.0pl0
! 	* Hyperbole 4.01
! 	* indent 1.9.1
! 	* Ispell 3.1.20
! 	* less 290
! 	* libg++ 2.7.1
! 	* libobjects 0.1.3
! 	* m4 1.4
! 	* make 3.74
! 	* mc 3.0
! 	* MIT Scheme 7.3
! 	* mkisofs 1.04GNU
! 	* mtools 2.0.7
! 	* MULE 2.3
! 	* ncurses 1.9.7a
! 	* NetHack 3.1.3
! 	* NIHCL 3.1.4
! 	* nvi 1.34
! 	* Oaklisp 93.07.23
! 	* OBST 3.4.3
! 	* Octave 1.1.1
! 	* Oleo 1.6
! 	* p2c 1.20
! 	* patch 2.1
! 	* perl 4.036
! 	* perl 5.001
! 	* phttpd 0.99.68
! 	* pine 3.91
! 	* Programming in Emacs Lisp: An Introduction, Ed. 1.04
! 	* ptx 0.4
! 	* rc 1.4
! 	* RCS 5.7
! 	* recode 3.4
! 	* regex 0.12
! 	* rx 0.05
! 	* SAOimage 1.08
! 	* screen 3.7.1
! 	* sed 2.05
! 	* Sharutils 4.1
! 	* Shellutils 1.12
! 	* Shogi 1.2p03
! 	* SIPP 3.1
! 	* Smalltalk 1.1.1
! 	* SNePS 2.3.1
! 	* Spinner 1.0b11
! 	* Superopt 2.5
! 	* tar 1.11.8
! 	* Termcap 1.3
! 	* TeX 3.145
! 	* Texinfo 3.6
! 	* Textutils 1.13
! 	* Tile Forth 2.1
! 	* time 1.6
! 	* tput 1.0
! 	* ucblogo 3.3
! 	* UUCP 1.06.1
! 	* W3 2.2.25
! 	* wdiff 0.5
! 	* X11R6
! 	* xboard 3.3.pl3
! 	* xgrabsc 2.41
! 	* xshogi 1.2p03
! 	* Ygl 3.0.2
! 
! 
! 
! June 1995 Source Code CD-ROM
! ............................
! 
! We still have the 6th edition of our Source CD at a reduced price while
! supplies last.	Not all FSF distributed software is included (*note Source
! Code CD-ROMs::.).  It contains these packages, and some manuals that are not
! part of packages:
! 
! 	* acm 4.7
! 	* Autoconf 2.4
! 	* BASH 1.14.5
! 	* bc 1.03
! 	* Binutils 2.5.2
! 	* Bison 1.24
! 	* C Library 1.09
! 	* Calc 2.02c
! 	* cfengine 1.0.4
! 	* Chess 4.0.pl74
! 	* CLISP 1995.04.25
! 	* Common Lisp 2.1
! 	* cperf 2.1a
! 	* cpio 2.3
! 	* CVS 1.3
! 	* DejaGnu 1.2
! 	* Diffutils 2.7
! 	* dld 3.2.3
! 	* doschk 1.1
! 	* ecc 1.2.1
! 	* ed 0.2
! 	* elib 0.06
! 	* Emacs 18.59
! 	* Emacs 19.28
! 	* Emacs 19.29
! 	* GNU Emacs Lisp Reference Manual Ed. 1.03 for Version 18
! 	* GNU Emacs Lisp Reference Manual Ed. 2.4 for Version 19.29
! 	* es 0.84
! 	* f2c 1995.02.24
! 	* Fileutils 3.12
! 	* Findutils 4.1
! 	* Finger 1.37
! 	* flex 2.5.2
! 	* Fontutils 0.6
! 	* g77 0.5.15
! 	* GAWK 2.15.6
! 	* GCC/G++/Objective C 2.6.3
! 	* GCC/G++/Objective C 2.7.0
! 	* GDB 4.14
! 	* gdbm 1.7.3
! 	* Ghostscript 2.6.2
! 	* Ghostview 1.5
! 	* Ghostview for Windows 1.0
! 	* GIT 4.3.6
! 	* gmp 1.3.2
! 	* GNATS 3.2
! 	* GnuGo 1.1
! 	* gnuplot 3.5
! 	* Graphics 0.17
! 	* grep 2.0
! 	* Groff 1.09
! 	* gzip 1.2.4
! 	* hello 1.3
! 	* hp2xx 3.1.4
! 	* HylaFAX 3.0.pl0
! 	* indent 1.9.1
! 	* Ispell 3.1.18
! 	* less 2.90
! 	* libg++ 2.6.2
! 	* libg++ 2.7.0
! 	* libobjects 0.1.3
! 	* m4 1.4
! 	* make 3.74
! 	* MandelSpawn 0.07
! 	* mkisofs 1.03GNU
! 	* mtools 2.0.7
! 	* MULE 2.2
! 	* ncurses 1.9.1
! 	* NetHack 3.1.3
! 	* NIHCL 3.1.4
! 	* nvi 1.34
! 	* OBST 3.4.3
! 	* Octave 1.1.1
! 	* Oleo 1.6
! 	* p2c 1.20
! 	* patch 2.1
! 	* PCL 2.1
! 	* perl 4.036
! 	* perl 5.001
! 	* pine 3.91
! 	* Programming in Emacs Lisp: An Introduction Ed. 1.03 for Version 19
! 	* ptx 0.4
! 	* rc 1.4
! 	* RCS 5.7
! 	* recode 3.4
! 	* regex 0.12
! 	* rx 0.05
! 	* screen 3.6.2
! 	* sed 2.05
! 	* Sharutils 4.1
! 	* Shellutils 1.12
! 	* Shogi 1.2p03
! 	* Smalltalk 1.1.1
! 	* Superopt 2.5
! 	* tar 1.11.8
! 	* Termcap 1.2
! 	* TeX 3.1415
! 	* Texinfo 3.6
! 	* Textutils 1.12
! 	* Tile Forth 2.1
! 	* time 1.6
! 	* tput 1.0
! 	* ucblogo
! 	* UUCP 1.05
! 	* wdiff 0.5
! 	* X11R6
! 	* xboard 3.2.pl2
! 	* xshogi 1.2p03
! 	* Ygl 2.9.5
! 
! 
! 
! May 1994 Source Code CD-ROM
! ...........................
! 
! We still have the 4th edition of our Source CD, at a reduced price.	This
! CD has Edition 2.3 for version 19 of the `GNU Emacs Lisp Reference Manual' &
! some additional software; not all FSF distributed software is included (see
! ``Source Code CD-ROMs'').  It contains the following packages:
! 	* acm 4.5
! 	* Autoconf 1.10
! 	* BASH 1.13.5
! 	* bc 1.02
! 	* Binutils 2.3
! 	* Bison 1.22
! 	* C Library 1.08
! 	* Calc 2.02c
! 	* Chess 4.0.69
! 	* CLISP 1994.01.08
! 	* Common Lisp 1.0
! 	* cpio 2.3
! 	* CVS 1.3
! 	* dc 0.2
! 	* DejaGnu 1.2
! 	* Diffutils 2.6
! 	* dld 3.2.3
! 	* doschk 1.1
! 	* ecc 1.2.1
! 	* ed 0.1
! 	* elib 0.06
! 	* Emacs 18.59
! 	* Emacs 19.23
! 	* es 0.84
! 	* f2c 1994.04.14
! 	* Fileutils 3.9
! 	* find 3.8
! 	* finger 1.37
! 	* flex 2.4.6
! 	* Fontutils 0.6
! 	* GAS 1.36.utah
! 	* GAS 2.2
! 	* Gawk 2.15.4
! 	* GCC 2.5.8
! 	* GDB 4.12
! 	* gdbm 1.7.1
! 	* Ghostscript 2.6.1
! 	* Ghostview 1.5
! 	* Ghostview for Windows 1.0
! 	* gmp 1.3.2
! 	* GNATS 3.2
! 	* GnuGo 1.1
! 	* gnuplot 3.5
! 	* gperf 2.1a
! 	* Graphics 0.17
! 	* grep 2.0
! 	* Groff 1.09
! 	* gzip 1.2.4
! 	* hello 1.3
! 	* hp2xx 3.1.4
! 	* indent 1.9.1
! 	* ispell 4.0
! 	* libg++ 2.5.3
! 	* m4 1.1
! 	* Make 3.71
! 	* MandelSpawn 0.07
! 	* mtools 2.0.7
! 	* MULE 1.0
! 	* NetFax 3.2.1
! 	* Nethack 3.1.3
! 	* NIHCL 3.0
! 	* nvi 1.11
! 	* Octave 1.0
! 	* Oleo 1.5
! 	* p2c 1.20
! 	* patch 2.1
! 	* PCL 1993.03.18
! 	* perl 4.036
! 	* ptx 0.3
! 	* rc 1.4
! 	* RCS 5.6.0.1
! 	* recode 3.3
! 	* regex 0.12
! 	* screen 3.5.2
! 	* sed 2.05
! 	* shellutils 1.9.4
! 	* Shogi 1.1.02
! 	* Smalltalk 1.1.1
! 	* Superopt 2.3
! 	* tar 1.11.2
! 	* Termcap 1.2
! 	* TeX 3.1
! 	* Texinfo 3.1
! 	* Textutils 1.9.1
! 	* Tile Forth 2.1
! 	* time 1.6
! 	* tput 1.0
! 	* UUCP 1.05
! 	* uuencode 1.0
! 	* wdiff 0.04
! 	* X11R6
! 	* xboard 3.0.9
! 	* xshogi 1.2.02
! 
  
  
  November 1993 Source Code CD-ROM
  ................................
  
! We still have the 3rd edition of our Source CD, at a reduced price, while
! supplies last.	It was the last Source Code CD to contain X11R5.  This CD has
! Edition 2.2 for version 19 of the `GNU Emacs Lisp Reference Manual' & some
! additional software; not all FSF distributed software is included (*note
! Source Code CD-ROMs::.).  It contains these packages:
! 
! 	* acm 3.1
! 	* Autoconf 1.7
! 	* BASH 1.13.4
! 	* bc 1.02
! 	* Binutils 1.9 2.3
! 	* Bison 1.22
! 	* C Library 1.06.7
! 	* Calc 2.02b
! 	* Chess 4.0p62
! 	* CLISP 93.11.08
! 	* cpio 2.3
! 	* CVS 1.3
! 	* dc 0.2
! 	* DejaGnu 1.0.1
! 	* Diffutils 2.6
! 	* dld 3.2.3
! 	* doschk 1.1
! 	* ecc 1.2.1
! 	* elib 0.06
! 	* Emacs 18.59
! 	* Emacs 19.21
! 	* es 0.84
! 	* f2c 1993.04.28
! 	* Fileutils 3.9
! 	* find 3.8
! 	* Finger 1.37
! 	* flex 2.3.8
! 	* Fontutils 0.6
! 	* GAS 1.36.utah
! 	* GAS 1.38.1
! 	* GAS 2.2
! 	* GAWK 2.15.3
! 	* GCC/G++/Objective C 2.5.4
! 	* GDB 4.11
! 	* gdbm 1.7.1
! 	* Ghostscript 2.6.1
! 	* Ghostview 1.5
! 	* Ghostview for Windows 1.0
! 	* gmp 1.3.2
! 	* GNATS 3.01
! 	* GnuGo 1.1
! 	* gnuplot 3.5
! 	* cperf 2.1a
! 	* Graphics 0.17
! 	* grep 2.0
! 	* Groff 1.08
! 	* gzip 1.2.4
! 	* hello 1.3
! 	* hp2xx 3.1.3a
! 	* indent 1.8
! 	* Ispell 4.0
! 	* less 177
! 	* libg++ 2.5.1
! 	* m4 1.1
! 	* make 3.69.1
! 	* MandelSpawn 0.06
! 	* mtools 2.0.7
! 	* MULE 1.0
! 	* NetFax 3.2.1
! 	* NetHack 3.1.3
! 	* NIHCL 3.0
! 	* Oleo 1.5
! 	* p2c 1.20
! 	* patch 2.1
! 	* PCL 93.03.18
! 	* perl 4.036
! 	* ptx 0.3
! 	* rc 1.4
! 	* RCS 5.6.0.1
! 	* recode 3.2.4
! 	* regex 0.12
! 	* screen 3.5.2
! 	* sed 1.18 2.03
! 	* Shellutils 1.9.1
! 	* Shogi 1.1p02
! 	* Smalltalk 1.1.1
! 	* Superopt 2.3
! 	* tar 1.11.2
! 	* Termcap 1.2
! 	* TeX 3.1
! 	* Texinfo 3.1
! 	* Tile Forth 2.1
! 	* time 1.6
! 	* time 1.6
! 	* tput 1.0
! 	* UUCP 1.04
! 	* uuencode 1.0
! 	* wdiff 0.04
! 	* X11R5
! 
! 
! 
! MS-DOS Book with CD-ROM
! -----------------------
! 
! We are working on our first book describing GNU Software for MS-DOS, but we
! do not know when it will be finished.  It will include a CD-ROM with all the
! sources & binaries on the MS-DOS Diskettes and more.
! 
! Please do NOT contact us about this book until we announce it on our mailing
! lists (to subscribe, ask `info-gnu-request@prep.ai.mit.edu'), because it just
! slows us down.
! 
! 
! 
! Debian GNU/Linux Book with CD-ROM
! ---------------------------------
! 
! We are working on our first book describing Debian GNU/Linux but we do not
! know when it will be finished.	Please do NOT contact us about this book
! until we announce it on our mailing lists (ask
! `info-gnu-request@prep.ai.mit.edu' to subscribe), because it just slows us
! down.
! 
! A CD will be inside the book with sources & binaries for Debian GNU/Linux,
! which is a complete operating system for i386/i486/Pentium.  It is a
! GNU/Linux system--that is to say, a variant GNU system which uses Linux as
! the kernel.  (All the systems now available that use the Linux kernel are
! GNU/Linux systems, see item "Linux" in *Note Free Software for
! Microcomputers::.)
! 
! Debian is being developed by Ian Murdock and the Debian Association in
! conjunction with the Free Software Foundation.	We are distributing it as an
! interim measure until the GNU kernel (the Hurd) is ready for users.
! 
! For details on Debian & how to help, see URL: `http://www.debian.org/' or
! FTP, `/pub/gnu/GNUinfo/DEBIAN' from a GNU FTP host (*note How to Get GNU
! Software::.).  FTP Debian under `/debian' from `ftp.debian.org'.
! 
! 
! 
! MS-DOS Diskettes
! ****************
! 
! The FSF distributes some of the GNU software ported to MS-DOS, on 3.5inch
! 1.44MB diskettes.  These disks have both sources and executables.
! 
! 
! 
! DJGPP Diskettes
! ---------------
! 
! We offer DJGPP on 30 diskettes.	 For further details, see *Note GNU
! Software::.  The DJGPP diskettes contain the following:
! 
! 	* Binutils 2.5.2
! 	* Bison 1.22
! 	* Diffutils 2.6
! 	* DJGPP 1.12m4
! 	* flex 2.4.7
! 	* GCC/G++ 2.6.3
! 	* GDB 4.12
! 	* Groff 1.09
! 	* gzip 1.24
! 	* libg++ 2.6.2
! 	* make 3.71
! 	* patch 2.1
! 	* sed 1.18
! 	* Texinfo 3.1
! 
! 
! 
! Emacs Diskettes
! ---------------
! 
! Two versions of GNU Emacs are included on the Emacs diskettes we distribute:
! GNU Emacs version 19.29 handles 8-bit character sets; the other, MULE version
! 2.2, handles 16-bit character sets including Kanji.
! 
! 
! 
! Selected Utilities Diskettes
! ----------------------------
! 
! The GNUish MS-DOS Project ported GNU software to PC compatibles.  Though
! GNUish is no longer active, users still ask for these ports done some years
! ago.  We offer these ports on five diskettes.  In general, the ports run on
! 8086/80286-based 16-bit machines; an 80386 is not required.  Some are
! necessarily missing features.
! 
! Included are: `cpio', `diff', `find', `flex', `gdbm', `grep', `indent',
! `less', `m4', `make', `ptx', RCS, `sed', `shar', `sort', & Texinfo.
! 
! 
! 
! Windows Diskette
! ----------------
! 
! We offer GNU Chess and `gnuplot' for Microsoft Windows on a single diskette.
! 
! 
! 
! Tape & CD-ROM Subscription Service
! **********************************
! 
! If you do not have net access, our subscription service enables you to stay
! current with the latest GNU developments.  For a one-time cost equivalent to
! three tapes or CD-ROMs (plus shipping in some cases), we will ship you four
! new versions of the tape of your choice or the Source Code CD-ROM.  The tapes
! are sent each quarter; the CD-ROMs are sent as they are issued (currently
! twice a year, but we hope to make it more frequent).
! 
! Regularly, we will send you a new version of a Lisps/Emacs, Languages,
! Utilities, or X Window System (X11R6) Required tape, or the Source CD-ROM.
! The MIT Scheme and X Window System Optional tapes are not changed often
! enough to warrant quarterly updates.  We do not yet know if we will be
! offering subscriptions to the Compiler Tools Binaries or our new Books with
! CD-ROM.
! 
! Since Emacs 19 is on the Lisps/Emacs Tape and the Source CD-ROM, a
! subscription to either is an easy way to keep current with Emacs 19 as it
! evolves.
! 
! A subscription is an easy way to keep up with the regular bug fixes to the X
! Window System.	We update the X11R6 Required tape as fixes and patches are
! issued throughout the year.  Each edition of the *Note Source Code CD-ROMs::,
! also has updated sources for the required part of the X Window System.
! 
! Please note: In two cases, you must pay 4 times the normal shipping required
! for a single order when you pay for each subscription.	If you're in Alaska,
! Hawaii, or Puerto Rico you must add $20.00 for shipping for each
! subscription.  If you're outside of U.S., Canada, and Puerto Rico, you must
! add $80.00 for each subscription.  See "Unix and VMS Software" and "Shipping
! Instructions" on the *note Free Software Foundation Order Form::..
! 
  
  
  FSF T-shirt
  ***********
  
! There is a GNU & improved T-shirt.  The front has the GNU Emacs Lisp code
! `(USE 'GNU)' with "`()'" being the dancing parentheses from the cover of our
! `GNU Emacs Lisp Reference Manual' (drawn by Berkeley, CA artist Etienne
! Suvasa).  The back of the shirt is still imprinted with the Preamble to the
! GNU General Public License.
! 
! These shirts come in two colors, Natural & Black.  Natural is an off-white,
! unbleached, undyed, environment-friendly cotton, printed with black ink, & is
! great for tye-dyeing or displaying as is.  Black is printed with white ink &
! is perfect for late night hacking.  All shirts are thick 100% cotton, & come
! in sizes M, L, XL, & XXL.  GNU shirts often create spontaneous friendships at
! technical conferences and on major university campuses!	 (They also make
! great gifts!)
! 
  
  
  Free Software Foundation Order Form
--- 3133,3749 ----
     * Several editions of our *Note Source Code CD-ROMs::.
  
!    * December 1995 *Note Compiler Tools Binaries CD-ROM::.
  
!    * December 1994 Compiler Tools Binaries CD-ROM, see the *note Free
!      Software Foundation Order Form::..
  
!    * December 1993 Compiler Tools Binaries CD-ROM, see the *note Free
!      Software Foundation Order Form::..
  
+ Our CD-ROMs are in ISO 9660 format and can be mounted as a read-only
+ file system on most computers.  If your driver supports it, you can
+ mount each CD with "Rock Ridge" extensions and it will look just like
+ an ordinary Unix file system, rather than one full of truncated and
+ otherwise mangled names that fit vanilla ISO 9660.
+ 
+    You can build most of the software without copying the sources off
+ the CD.  You only need enough disk space for object files and
+ intermediate build targets.
  
+     
  
  Pricing of the GNU CD-ROMs
  --------------------------
  
!    If a business or organization is ultimately paying, the July 1996
! Source CD set costs $240.  The set costs $60 if you, an individual, are
! paying out of your own pocket.  The December 1995 Compiler Tools
! Binaries CD-ROM costs $220 for a business or organization, and $55 for
! an individual.
! 
!     
! 
! What Do the Different Prices Mean?
! ..................................
! 
!    The software on our disks is free; anyone can copy it and anyone can
! run it.  What we charge for is the physical disk and the service of
! distribution.
! 
!    We charge two different prices depending on who is buying.  When a
! company or other organization buys the July 1996 Source CD-ROMs, we
! charge $240.  When an individual buys the same CD-ROMs, we charge just
! $60.  This distinction is not a matter of who is allowed to use the
! software.  In either case, once you have a copy, you can distribute as
! many copies as you wish and there's no restriction on who can have or
! run them.  The price distinction is entirely a matter of what kind of
! entity pays for the CDs.
! 
!    You, the reader, are certainly an individual, not a company.  If you
! are buying a disk "in person", then you are probably doing so as an
! individual.  But if you expect to be reimbursed by your employer, then
! the disk is really for the company; so please pay the company price and
! get reimbursed for it.  We won't try to check up on you--we use the
! honor system--so please cooperate.
! 
!    Buying CDs at the company price is very helpful for GNU; just
! 140 Source CDs at that price support an FSF programmer or tech writer
! for a year.
  
!     
  
! Why Is There an Individual Price?
  .................................
  
!    In the past, our distribution tapes were ordered mainly by companies.
! The CD at the price of $240 provides them with all of our software for a
! much lower price than they would previously have paid for six different
! tapes.  To lower the price more would cut into the FSF's funds very
! badly and decrease the software development we can do.
! 
!    However, for individuals, $240 is too high a price; hardly anyone
! could afford that.  So we decided to make CDs available to individuals
! at the lower price of $60.
  
+     
  
! Is There a Maximum Price?
  .........................
  
!    Our stated prices are minimum prices.  Feel free to pay a higher
! price if you wish to support GNU development more.  The sky's the
! limit; we will accept as high a price as you can offer.  Or simply give
! a donation (tax-deductible in the U.S.) to the Free Software
! Foundation, a tax-exempt public charity.
  
+     
  
  December 1995 Compiler Tools Binaries CD-ROM
  --------------------------------------------
  
!    We have the third edition of our CD-ROM that has binaries and
! complete sources for GNU compiler tools for some systems which lack a
! compiler.  This enables the people who use these systems to compile GNU
! and other free software without having to buy a proprietary compiler.
! You can also use these GNU tools to compile your own C/C++/Objective-C
! programs.  Older editions of this CD are available while supplies last
! at a reduced price; see the *note Free Software Foundation Order
! Form::..
! 
!    We hope to have more systems on each update of this CD.  If you can
! help build binaries for new systems (especially those that don't come
! with a C compiler), or have one to suggest, please contact us at the
! addresses on the top menu.
  
  These packages:
  
!         * DJGPP 1.12m4 from GCC 2.6.3
!         * GCC/G++/Objective-C 2.7.1
!         * GNU C Library 1.09
!         * GDB 4.15.1
!         * Binutils 2.6
!         * Bison 1.24
!         * Emacs 19.29 (MS-DOS only)
!         * Flex 2.5.2
!         * Make 3.74
!         * libg++ 2.7.1
  
  On these platforms:
  
!         * `i386-msdos'
!         * `hppa1.0-hp-hpux9'
!         * `sparc-sun-solaris2'
!         * `sparc-sun-sunos4.1'
  
!     
  
! MS-DOS/Windows Book with CD-ROM
! -------------------------------
  
!    We are working on our first book on GNU Software for DOS/Windows,
! but we do not know when it will be finished.  It will include a CD-ROM
! with the sources & binaries for much of the GNU software.
  
!    Because it just slows us down, please do NOT contact us about this
! book until we announce it on our electronic mailing lists (to
! subscribe, ask `info-gnu-request@prep.ai.mit.edu').
  
+     
  
+     
  
  Source Code CD-ROMs
  -------------------
  
!    We have several versions of our Source Code CD-ROMs available,
! including:
  
!    * *Note July 1996 Source Code CD-ROMs::, the newest release, has
       programs, bug fixes, & improvements not on the other CDs.
  
!    * *Note December 1995 Source Code CD-ROMs::.
  
!    * June 1995 Source Code CD-ROM, see the *note Free Software
!      Foundation Order Form::..
  
!    * May 1994 Source Code CD-ROM, see the *note Free Software
!      Foundation Order Form::..
  
!    * *Note November 1993 Source Code CD-ROM::.
  
!    * May 1993 Source Code CD-ROM, see the *note Free Software
!      Foundation Order Form::..
  
!    * October 1992 Source Code CD-ROM, see the *note Free Software
!      Foundation Order Form::..
  
+ The older Source CDs are available while supplies last at a reduced
+ price (please note that the December 1994 Source CD is permanently out
+ of stock).  All the Source CDs have Texinfo source for the GNU manuals
+ listed in *Note Documentation::.
+ 
+    MIT Scheme & much of X11 is *not* on the older Source CDs.
+ 
+    There are no precompiled programs on these Source CDs.  You will
+ need a C compiler (programs which need some other interpreter or
+ compiler normally provide the C source for a bootstrapping program).
+ We ship C compiler binaries for some systems on the *Note Compiler
+ Tools Binaries CD-ROM::.
+ 
+     
+ 
+ July 1996 Source Code CD-ROMs
+ .............................
+ 
+    The 8th edition of our Source Code CD is out with two CD-ROM disks.
+ It has programs, bug fixes, & improvements not on the older Source CDs.
+ It has these packages, & some manuals that are not part of packages:
+ 
+ 
+         * acm 4.7
+         * apache 1.1
+         * Autoconf 2.10
+         * Automake 1.0
+         * BASH 1.14.6
+         * bc 1.03
+         * Binutils 2.7
+         * Bison 1.25
+         * C Library 1.93
+         * Calc 2.02d
+         * cfengine 1.3.7
+         * Chess 4.0.pl77
+         * CLISP 1996.05.30
+         * Common Lisp 2.2
+         * cperf 2.1a
+         * cpio 2.4.2
+         * CVS 1.8.1
+         * DejaGnu 1.3
+         * Diffutils 2.7
+         * dld 3.3
+         * doschk 1.1
+         * ed 0.2
+         * Elib 1.0
+         * elisp archive
+         * Emacs 18.59
+         * Emacs 19.31
+         * Emacs 19.32
+         * enscript 1.4.0
+         * es 0.84
+         * Exim 0.53
+         * f2c 1996.07.23
+         * ffcall 1.0
+         * Fileutils 3.13
+         * Findutils 4.1
+         * Finger 1.37
+         * flex 2.5.3
+         * Fontutils 0.6
+         * g77 0.5.18
+         * GAWK 3.0.0
+         * gcal 1.01
+         * GCC/G++/Objective-C 2.7.2
+         * GCC 2.7.3
+         * GDB 4.16
+         * gdbm 1.7.3
+         * Generic NQS 3.50.0
+         * geomview 1.5.0
+         * gettext 0.10
+         * Ghostscript 3.33
+         * Ghostview 1.5
+         * Ghostview for Windows 1.0
+         * GIT 4.3.11
+         * gmp 2.0.2
+         * GN 2.24
+         * Gnans 1.5.1
+         * gnat 3.05
+         * GNATS 3.2
+         * GNU Emacs Lisp Reference Manual 1.03
+         * GNU Emacs Lisp Reference Manual 2.4
+         * GnuGo 1.2
+         * gnuplot 3.5
+         * gnuserv 2.1alpha
+         * gnussl 0.2
+         * Graphics 0.17
+         * grep 2.0
+         * Groff 1.10
+         * gzip 1.2.4
+         * hello 1.3
+         * hp2xx 3.1.4
+         * HylaFAX 4.0b018
+         * ID Utils 3.1
+         * indent 1.9.1
+         * Inetutils 1.0
+         * Ispell 3.1.20
+         * karma 1.4
+         * less 321
+         * libg++ 2.7.2
+         * libobjects 0.1.19
+         * lynx 2.5
+         * m4 1.4
+         * make 3.75
+         * MandelSpawn 0.07
+         * maxima 5.2
+         * mc 3.2.1
+         * miscfiles 1.0
+         * mkisofs 1.05GNU
+         * mm 1.07
+         * mtools 3.0
+         * MULE 2.3
+         * ncurses 1.9.9e
+         * NetHack 3.2.1
+         * NIHCL 3.1.4
+         * nvi 1.71
+         * Oaklisp 930720
+         * OBST 3.4.3
+         * Octave 1.1.1
+         * Oleo 1.6
+         * p2c 1.20
+         * patch 2.1
+         * perl 4.036
+         * perl 5.003
+         * phttpd 0.99.72.1
+         * pine 3.91
+         * Programming in Emacs Lisp an Introduction 1.04
+         * ptx 0.4
+         * rc 1.4
+         * RCS 5.7
+         * readline 2.0
+         * regex 0.12
+         * rx 1.0
+         * SAOimage 1.18
+         * screen 3.7.1
+         * sed 2.05
+         * Sharutils 4.2
+         * Shellutils 1.12
+         * Shogi 1.2p03
+         * SIPP 3.1
+         * smail 3.2
+         * Smalltalk 1.1.1
+         * Spinner 1.0b14
+         * Superopt 2.5
+         * tar 1.11.8
+         * Termcap 1.3
+         * Termutils 2.0
+         * TeX 3.145
+         * Texinfo 3.7
+         * Textutils 1.19
+         * tiff 3.4b035
+         * Tile Forth 2.1
+         * time 1.7
+         * ucblogo 3.3
+         * UUCP 1.06.1
+         * W3 2.2.26
+         * wdiff 0.5
+         * WN 1.15.3
+         * X11R6.1
+         * xboard 3.4.pl1
+         * xgrabsc 2.41
+         * xshogi 1.2p03
+         * Ygl 3.1
  
+     
  
  December 1995 Source Code CD-ROMs
  .................................
  
!    We still have copies of the 7th edition of our Source CD available.
! This was the first two-disk edition of our Source Code CD.  It contains
! these packages, & some manuals that are not part of packages:
! 
!         * acm 4.7
!         * apache 0.8.8
!         * Autoconf 2.7
!         * BASH 1.14.5
!         * bc 1.03
!         * Binutils 2.5.2
!         * Binutils 2.6
!         * Bison 1.24
!         * C Library 1.09
!         * Calc 2.02c
!         * cfengine 1.2.21
!         * Chess 4.0.pl75
!         * CLISP 1995.08.12
!         * Common Lisp 2.2
!         * cperf 2.1a
!         * cpio 2.3
!         * CVS 1.6
!         * DDD 1.3b
!         * DejaGnu 1.2.9
!         * Diffutils 2.7
!         * dld 3.2.3
!         * doschk 1.1
!         * ecc 1.2.1
!         * ed 0.2
!         * Elib 0.07
!         * Elisp archive
!         * Emacs 18.59
!         * Emacs 19.28
!         * Emacs 19.29
!         * Emacs 19.30
!         * es 0.84
!         * f2c 1995.11.18
!         * ffcall 1.0
!         * Fileutils 3.12
!         * Findutils 4.1
!         * Finger 1.37
!         * flex 2.5.2
!         * Fontutils 0.6
!         * g77 0.5.17
!         * GAWK 2.15.6
!         * GCC/G++/Objective C 2.7.1
!         * GDB 4.15.1
!         * gdbm 1.7.3
!         * gettext 0.9a
!         * Ghostscript 2.6.2
!         * Ghostview 1.5
!         * Ghostview for Windows 1.0
!         * GIT 4.3.7
!         * gmp 1.3.2
!         * GN 2.23
!         * Gnans 1.5
!         * GNATS 3.2
!         * GNU Emacs Lisp Reference Manual, Ed. 1.03 for Version 18.59
!         * GNU Emacs Lisp Reference Manual, Ed. 2.4 for Version 19.29
!         * GnuGo 1.2
!         * gnuplot 3.5
!         * gnuserv 2.1alpha
!         * Graphics 0.17
!         * grep 2.0
!         * Groff 1.09
!         * gzip 1.2.4
!         * hello 1.3
!         * hp2xx 3.1.4
!         * HylaFAX v3.0pl0
!         * Hyperbole 4.01
!         * indent 1.9.1
!         * Ispell 3.1.20
!         * less 290
!         * libg++ 2.7.1
!         * libobjects 0.1.3
!         * m4 1.4
!         * make 3.74
!         * mc 3.0
!         * MIT Scheme 7.3
!         * mkisofs 1.04GNU
!         * mtools 2.0.7
!         * MULE 2.3
!         * ncurses 1.9.7a
!         * NetHack 3.1.3
!         * NIHCL 3.1.4
!         * nvi 1.34
!         * Oaklisp 93.07.23
!         * OBST 3.4.3
!         * Octave 1.1.1
!         * Oleo 1.6
!         * p2c 1.20
!         * patch 2.1
!         * perl 4.036
!         * perl 5.001
!         * phttpd 0.99.68
!         * pine 3.91
!         * Programming in Emacs Lisp: An Introduction, Ed. 1.04
!         * ptx 0.4
!         * rc 1.4
!         * RCS 5.7
!         * recode 3.4
!         * regex 0.12
!         * rx 0.05
!         * SAOimage 1.08
!         * screen 3.7.1
!         * sed 2.05
!         * Sharutils 4.1
!         * Shellutils 1.12
!         * Shogi 1.2p03
!         * SIPP 3.1
!         * Smalltalk 1.1.1
!         * SNePS 2.3.1
!         * Spinner 1.0b11
!         * Superopt 2.5
!         * tar 1.11.8
!         * Termcap 1.3
!         * TeX 3.145
!         * Texinfo 3.6
!         * Textutils 1.13
!         * Tile Forth 2.1
!         * time 1.6
!         * tput 1.0
!         * ucblogo 3.3
!         * UUCP 1.06.1
!         * W3 2.2.25
!         * wdiff 0.5
!         * X11R6
!         * xboard 3.3.pl3
!         * xgrabsc 2.41
!         * xshogi 1.2p03
!         * Ygl 3.0.2
  
+     
  
  November 1993 Source Code CD-ROM
  ................................
  
!    We still have the 3rd edition of our Source CD, at a reduced price,
! while supplies last.  It was the last Source Code CD to contain X11R5.
! This CD has Edition 2.2 for version 19 of the `GNU Emacs Lisp Reference
! Manual' & some additional software; not all FSF distributed software is
! included (*note Source Code CD-ROMs::.).  It contains these packages:
! 
!         * acm 3.1
!         * Autoconf 1.7
!         * BASH 1.13.4
!         * bc 1.02
!         * Binutils 1.9
!         * Binutils 2.3
!         * Bison 1.22
!         * C Library 1.06.7
!         * Calc 2.02b
!         * Chess 4.0p62
!         * CLISP 93.11.08
!         * cpio 2.3
!         * CVS 1.3
!         * dc 0.2
!         * DejaGnu 1.0.1
!         * Diffutils 2.6
!         * dld 3.2.3
!         * doschk 1.1
!         * ecc 1.2.1
!         * Elib 0.06
!         * Emacs 18.59
!         * Emacs 19.21
!         * es 0.84
!         * f2c 1993.04.28
!         * Fileutils 3.9
!         * find 3.8
!         * Finger 1.37
!         * flex 2.3.8
!         * Fontutils 0.6
!         * GAS 1.36.utah
!         * GAS 1.38.1
!         * GAS 2.2
!         * GAWK 2.15.3
!         * GCC/G++/Objective-C 2.5.4
!         * GDB 4.11
!         * gdbm 1.7.1
!         * Ghostscript 2.6.1
!         * Ghostview 1.5
!         * Ghostview for Windows 1.0
!         * gmp 1.3.2
!         * GNATS 3.01
!         * GnuGo 1.1
!         * gnuplot 3.5
!         * gperf 2.1a
!         * Graphics 0.17
!         * grep 2.0
!         * Groff 1.08
!         * gzip 1.2.4
!         * hello 1.3
!         * hp2xx 3.1.3a
!         * indent 1.8
!         * Ispell 4.0
!         * less 177
!         * libg++ 2.5.1
!         * m4 1.1
!         * make 3.69.1
!         * MandelSpawn 0.06
!         * mtools 2.0.7
!         * MULE 1.0
!         * NetFax 3.2.1
!         * NetHack 3.1.3
!         * NIHCL 3.0
!         * Oleo 1.5
!         * p2c 1.20
!         * patch 2.1
!         * PCL 93.03.18
!         * perl 4.036
!         * ptx 0.3
!         * rc 1.4
!         * RCS 5.6.0.1
!         * recode 3.2.4
!         * regex 0.12
!         * screen 3.5.2
!         * sed-1.18 2.03
!         * shellutils 1.9.1
!         * Shogi 1.1p02
!         * Smalltalk 1.1.1
!         * Superopt 2.3
!         * tar 1.11.2
!         * Termcap 1.2
!         * TeX 3.1
!         * Texinfo 3.1
!         * tileforth 2.1
!         * time 1.6
!         * tput 1.0
!         * UUCP 1.04
!         * uuencode 1.0
!         * wdiff 0.04
!         * X11R5
! 
!     
! 
! CD-ROM Subscription Service
! ***************************
! 
!    Our subscription service enables you to stay current with the latest
! GNU developments.  For a one-time cost equivalent to three Source
! CD-ROMs (plus shipping in some cases), we will ship you four new
! versions of the *Note Source Code CD-ROMs::.  The CD-ROMs are sent as
! they are issued (currently twice a year, but we hope to make it more
! frequent).  We do not yet know if we will be offering subscriptions to
! the Compiler Tools Binaries CD or our DOS/Windows Book with CD-ROM when
! it is available.
! 
!    A subscription is an easy way to keep up with the regular bug fixes
! to the X Window System.  Each edition of the *Note Source Code
! CD-ROMs::, has updated sources for the X Window System.
! 
!    Please note: In two cases, you must pay 4 times the normal shipping
! required for a single order when you pay for each subscription.  If
! you're in Alaska, Hawaii, or Puerto Rico you must add $20.00 for
! shipping for each subscription.  If you're outside of the U.S., Canada,
! and Puerto Rico, you must add $80.00 for each subscription.  See
! "CD-ROMs" and "Tax and Shipping Costs" on the *note Free Software
! Foundation Order Form::..
  
+     
  
  FSF T-shirt
  ***********
  
!    The front of our T-shirt has the GNU Emacs Lisp code `(USE 'GNU)'
! with "`()'" being the dancing parentheses from the cover of our `GNU
! Emacs Lisp Reference Manual' (drawn by Berkeley, CA artist Etienne
! Suvasa).  The shirt's back is imprinted with the Preamble to the GNU
! General Public License.
! 
!    These shirts come in black, purple, red, pink, burgundy, blue, and
! natural (off-white).  When you order, please give 3 choices.  Black and
! purple are printed in white; the other colors are printed in black.
! All shirts are thick 100% cotton, and come in sizes S, M, L, XL, and
! XXL (but they run small so you may want a larger size than usual).
! 
!    GNU T-shirts often create spontaneous friendships at conferences &
! on university campuses.  They also make great gifts for friends &
! family, including children!
  
+     
  
  Free Software Foundation Order Form
*************** Free Software Foundation Order Form
*** 3957,3961 ****
  All items are distributed with permission to copy and to redistribute.
  Texinfo source for each manual and source for each reference card is on
! the appropriate tape, diskette, or CD-ROM; the prices for these magnetic
  media do not include printed documentation.  All items are provided on
  an ``as is'' basis, with no warranty of any kind.  Please allow six
--- 3752,3756 ----
  All items are distributed with permission to copy and to redistribute.
  Texinfo source for each manual and source for each reference card is on
! the appropriate CD-ROM; the prices for these magnetic
  media do not include printed documentation.  All items are provided on
  an ``as is'' basis, with no warranty of any kind.  Please allow six
*************** weeks for delivery (though it won't usua
*** 3963,4033 ****
  
  
!      PRICE AND CONTENTS MAY CHANGE WITHOUT NOTICE AFTER June 30, 1996.
! 
! 
! 
! Unix and VMS Software
! ---------------------
! 
! These tapes in the formats indicated (*note Tapes::., for contents):
! 
! 	Please circle the dollar amount for each tape you order.
! 
! 		Reel to	  Sun (1)   HP	      IBM (2)	Exabyte	 DAT
! 		reel			      RS/6000
! 		Unix tar  Unix tar  Unix tar  Unix tar	Unix tar Unix tar
! 		9-track	  QIC-24    16-track  QIC-150
! 		1600 bpi  DC300XLP  DC600HC   DC600A
! 		1/2" reel 1/4" c.t. 1/4" c.t. 1/4" c.t. 8mm c.t. 4mm c.t.
! 
!     (c.t. = cartridge tape)
  
- Lisps/Emacs	$200	  $210	    $230      $215	$205	 $225
  
- Languages	$200	  $210	    $230      $215	$205	 $225
  
! Utilities	$200	  $210	    $230      $215	$205	 $225
  
- 4.4BSD-Lite	$200	  $210	    $230      $215	$205	 $225
- 
- Scheme		$200	  $210	    $230      $215	$205	 $225
- 
- X11R6-Required	$200	  $210	    $230      $215	$205	 $225
- 
- X11R6-Optional	$200	  $210	    $230      $215	$205	 $225
- 
- 	 (1) Sun tapes can be read on some other Unix systems.
- 	 (2) IBM RS/6000 tapes can be read on some other Unix systems.
- 
- 
- Subscriptions, 4 updates for one year (*note Tape & CD-ROM Subscription Service::.):
- 
- Emacs		$600	  $630	    $690      $645	$615	 $675
- 
- Languages	$600	  $630	    $690      $645	$615	 $675
- 
- Utilities	$600	  $630	    $690      $645	$615	 $675
- 
- X11R6-Required	$600	  $630	    $690      $645	$615	 $675
- 
-       Subtotal $ ______	 Please put total of the above circled amounts here.
- 
- 
- These 1600 bpi reel-to-reel 9 track 1/2" tapes, in VMS BACKUP format (aka
- interchange format) (*note VMS Emacs and VMS Compiler Tapes::.):
- 
- ____ @ $195  = $ ______	  VMS Emacs, GNU Emacs source & executables only.
- 
- ____ @ $195  = $ ______	  VMS Compiler, GCC, GAS, and Bison source and
- 			   executables only.
  
  
  FSF Deluxe Distribution
  .......................
! (Please call with any questions.  *note Deluxe Distribution::. for machine,
! operating system, and media types.):
  
  
! ____ @ $5000 = $ ______	  The Deluxe Distribution, with manuals, etc.
  
  Machine: _____________________________________________________________________
--- 3758,3777 ----
  
  
!      PRICE AND CONTENTS MAY CHANGE WITHOUT NOTICE AFTER January 31, 1997.
  
  
  
! Unix Software
! -------------
  
  
  
  FSF Deluxe Distribution
  .......................
! (Please contact us with any questions.  *note Deluxe Distribution::.
! for machine, operating system, and media types.)
  
  
! ____ @ $5000 = $ ______   The Deluxe Distribution, with manuals, etc.
  
  Machine: _____________________________________________________________________
*************** Operating system: ______________________
*** 4037,4041 ****
  Media type: __________________________________________________________________
  
! Version of X Windows System to build: _______________________________________
  
  
--- 3781,3785 ----
  Media type: __________________________________________________________________
  
! Version of X Window System to build: _________________________________________
  
  
*************** CD-ROMs, in ISO 9660 format (*note CD-RO
*** 4045,4061 ****
  
  
! GNU Source Code CD-ROMs, Version 7 with X11R6 (*note December 1995 Source Code CD-ROMs::.):
  
! ____ @ $240  = $ ______	  for corporations and other organizations.
  
! ____ @ $ 60  = $ ______	  for individuals.
  
  
  Subscriptions, next 4 updates, of the Source Code CD-ROM, in ISO 9660 format
! (*note Tape & CD-ROM Subscription Service::.):
  
! ____ @ $720  = $ ______	  for corporations and other organizations.
  
! ____ @ $180  = $ ______	  for individuals.
  
  
--- 3789,3805 ----
  
  
! GNU Source Code CD-ROMs, Version 8 with X11R6.1 (*note July 1996 Source Code CD-ROMs::.):
  
! ____ @ $240  = $ ______   for corporations and other organizations.
  
! ____ @ $ 60  = $ ______   for individuals.
  
  
  Subscriptions, next 4 updates, of the Source Code CD-ROM, in ISO 9660 format
! (*note CD-ROM Subscription Service::.):
  
! ____ @ $720  = $ ______   for corporations and other organizations.
  
! ____ @ $180  = $ ______   for individuals.
  
  
*************** GNU Compiler Tools Binaries CD-ROM, Vers
*** 4063,4088 ****
  (*note Compiler Tools Binaries CD-ROM::.):
  
! ____ @ $220  = $ ______	  for corporations and other organizations.
  
! ____ @	$55  = $ ______	  for individuals.
  
  
  
! MS-DOS Software
! ---------------
! 
! The following sources and executables for MS-DOS, on 3.5" 1.44MB diskettes
! (*note MS-DOS Diskettes::.):
! 
! ____ @ $ 90  = $ ______	  Emacs diskettes, GNU Emacs, for 80386 and up.
  
! ____ @ $ 80  = $ ______	  DJGPP diskettes, GCC version 2, and other tools
! 			   for 80386 and up (also on the
! 			   *note Compiler Tools Binaries CD-ROM::.).
  
! ____ @ $ 85  = $ ______	  Selected Utilities diskettes, 8086 and up.
  
- ____ @ $ 40  = $ ______	  Windows diskette: GNU Chess and gnuplot for
- 			   Microsoft Windows.
  
  
--- 3807,3825 ----
  (*note Compiler Tools Binaries CD-ROM::.):
  
! ____ @ $220  = $ ______   for corporations and other organizations.
  
! ____ @  $55  = $ ______   for individuals.
  
  
  
! Proceedings
! -----------
  
! *Note First Conference on Freely Redistributable Software::
  
! ____ @ $ 25  = $ ______   The Proceedings of the First Conference
!                           on Freely Redistributable Software - only
!                           available while supplies last.
  
  
  
*************** Manuals
*** 4090,4123 ****
  -------
  
! These manuals (*note Documentation::.).	 The latest version of each manual
! will be shipped.  Please call if you want a specific version.
  
! ____ @ $ 25  = $ ______	  GNU Emacs version manual, with a reference card.
  
! ____ @ $ 50  = $ ______	  GNU Emacs Lisp Reference manual, in two volumes.
  
! ____ @ $ 60  = $ ______	  GNU Emacs Lisp Reference, Japanese Edition.
  
! ____ @ $ 50  = $ ______	  Using and Porting GNU CC.
  
! ____ @ $ 50  = $ ______	  GNU C Library Reference Manual.
  
! ____ @ $ 50  = $ ______	  GNU Emacs Calc manual, with a reference card.
  
! ____ @ $ 20  = $ ______	  Programming in Emacs Lisp: An Introduction.
  
! ____ @ $ 20  = $ ______	  Debugging with GDB, with a reference card.
  
! ____ @ $ 25  = $ ______	  GAWK manual.
  
! ____ @ $ 20  = $ ______	  Make manual.
  
! ____ @ $ 20  = $ ______	  Bison manual, with a reference card.
  
! ____ @ $ 20  = $ ______	  Flex manual, with a reference card.
  
! ____ @ $ 20  = $ ______	  Texinfo manual.
  
! ____ @ $ 15  = $ ______	  Termcap manual.
  
  
--- 3827,3860 ----
  -------
  
! These manuals (*note Documentation::.).  The latest version of each manual
! will be shipped.  Please contact us if you want a specific version.
  
! ____ @ $ 25  = $ ______   GNU Emacs version manual, with a reference card.
  
! ____ @ $ 50  = $ ______   GNU Emacs Lisp Reference manual, in two volumes.
  
! ____ @ $ 60  = $ ______   GNU Emacs Lisp Reference, Japanese Edition.
  
! ____ @ $ 50  = $ ______   Using and Porting GNU CC.
  
! ____ @ $ 50  = $ ______   GNU C Library Reference Manual.
  
! ____ @ $ 50  = $ ______   GNU Emacs Calc manual, with a reference card.
  
! ____ @ $ 20  = $ ______   Programming in Emacs Lisp: An Introduction.
  
! ____ @ $ 20  = $ ______   Debugging with GDB, with a reference card.
  
! ____ @ $ 25  = $ ______   GAWK manual.
  
! ____ @ $ 20  = $ ______   Make manual.
  
! ____ @ $ 20  = $ ______   Bison manual, with a reference card.
  
! ____ @ $ 20  = $ ______   Flex manual, with a reference card.
  
! ____ @ $ 20  = $ ______   Texinfo manual.
  
! ____ @ $ 15  = $ ______   Termcap manual.
  
  
*************** Reference Cards
*** 4127,4141 ****
  
  The following reference cards, in packets of ten.  For single copies please
! call.
  
! ____ @ $ 10  = $ ______	  GNU Emacs version 19 reference cards.
  
! ____ @ $ 10  = $ ______	  GNU Emacs Calc reference cards.
  
! ____ @ $ 10  = $ ______	  GDB reference cards.
  
! ____ @ $ 10  = $ ______	  Bison reference cards.
  
! ____ @ $ 10  = $ ______	  Flex reference cards.
  
  
--- 3864,3878 ----
  
  The following reference cards, in packets of ten.  For single copies please
! contact us.
  
! ____ @ $ 10  = $ ______   GNU Emacs version 19 reference cards.
  
! ____ @ $ 10  = $ ______   GNU Emacs Calc reference cards.
  
! ____ @ $ 10  = $ ______   GDB reference cards.
  
! ____ @ $ 10  = $ ______   Bison reference cards.
  
! ____ @ $ 10  = $ ______   Flex reference cards.
  
  
*************** T-shirts
*** 4144,4156 ****
  --------
  
! GNU/FSF T-shirts, thick 100% cotton (*note FSF T-shirt::.):
  
! ____ @ $ 15  = $ ______	  Size M     ____ natural  ____ black.
  
! ____ @ $ 15  = $ ______	  Size L     ____ natural  ____ black.
  
! ____ @ $ 15  = $ ______	  Size XL    ____ natural  ____ black.
  
! ____ @ $ 15  = $ ______	  Size XXL   ____ natural  ____ black.
  
  
--- 3881,3904 ----
  --------
  
! GNU/FSF T-shirts, thick 100% cotton in sizes: M, L, XL, & XXL (they run
! small); and in colors: black, purple, red, pink, burgundy, blue, &
! natural (off-white); please list 1st, 2nd, and 3rd choice of color
! (*note FSF T-shirt::.):
! 
! ____ @ $ 15  = $ ______   Size _____
! 
!                           Color choice: 1st _______ 2nd _______ 3rd _______
! 
! ____ @ $ 15  = $ ______   Size _____
! 
!                           Color choice: 1st _______ 2nd _______ 3rd _______
  
! ____ @ $ 15  = $ ______   Size  _____
  
!                           Color choice: 1st _______ 2nd _______ 3rd _______
  
! ____ @ $ 15  = $ ______   Size _____
  
!                           Color choice: 1st _______ 2nd _______ 3rd _______
  
  
*************** Older Items
*** 4161,4180 ****
  Older items are only available while supplies last.
  
! ____ @ $  5  = $ ______	  GNU Emacs version 18 reference cards, in packets
! 			   of ten.
  
  
  Please fill in the number of each older CD-ROM you order:
  
! 						for		for
! 						corporations	individuals:
! 						and other
! 						organizations:
  
  GNU Compiler Tools Binaries CD-ROM
! 	December 1994 Edition (Version 2)	____________	____________
  
  GNU Compiler Tools Binaries CD-ROM
! 	December 1993 Edition (Version 1)	____________	____________
  
  
--- 3909,3931 ----
  Older items are only available while supplies last.
  
! ____ @ $  5  = $ ______   GNU Emacs version 18 reference cards, in packets
!                            of ten.
  
  
  Please fill in the number of each older CD-ROM you order:
  
!                                                 for             for
!                                                 corporations    individuals:
!                                                 and other
!                                                 organizations:
  
  GNU Compiler Tools Binaries CD-ROM
!         December 1995 (Version 3)               ____________    ____________
  
  GNU Compiler Tools Binaries CD-ROM
!         December 1994 (Version 2)               ____________    ____________
! 
! GNU Compiler Tools Binaries CD-ROM
!         December 1993 (Version 1)               ____________    ____________
  
  
*************** Please note that the December 1994 Sourc
*** 4182,4207 ****
  
  GNU Source Code CD-ROM
! 	June 1995 edition with X11R6		____________	____________
  
  GNU Source Code CD-ROM
! 	May 1994 edition with X11R6		____________	____________
  
  GNU Source Code CD-ROM
! 	November 1993 edition with X11R5	____________	____________
  
  GNU Source Code CD-ROM
! 	May 1993 edition with X11R5		____________	____________
  
  GNU Source Code CD-ROM
! 	October 1992 edition with X11R5		____________	____________
  
  
  Please put the total count and cost of the above older CD-ROMs here:
  
! ____ @ $ 80  = $ ______	  for corporations and other organizations.
  
! ____ @ $ 20  = $ ______	  for individuals.
  
! 		 ======
  
        Subtotal $ ______
--- 3933,3962 ----
  
  GNU Source Code CD-ROM
!         December 1995 (Version 7) with X11R6    ____________    ____________
! 
! GNU Source Code CD-ROM
!         June 1995 (Version 6) with X11R6        ____________    ____________
  
  GNU Source Code CD-ROM
!         May 1994 (Version 4) with X11R6         ____________    ____________
  
  GNU Source Code CD-ROM
!         November 1993 (Version 3) with X11R5    ____________    ____________
  
  GNU Source Code CD-ROM
!         May 1993 (Version 2) with X11R5         ____________    ____________
  
  GNU Source Code CD-ROM
!         October 1992 (Version 1) with X11R5     ____________    ____________
! 
  
  
  Please put the total count and cost of the above older CD-ROMs here:
  
! ____ @ $ 80  = $ ______   for corporations and other organizations.
  
! ____ @ $ 20  = $ ______   for individuals.
  
!                  ======
  
        Subtotal $ ______
*************** ____ @ $ 20  = $ ______	  for individual
*** 4209,4247 ****
  
  
- 
  Tax and Shipping Costs
  ----------------------
  
! 	     + $ ______	  For addresses in Massachusetts: add 5% sales tax
! 			  or give tax exempt number.  There is no sales tax
! 			  on T-shirts.
! 	     + $ ______	  Shipping fee for addresses in Alaska, Hawaii, or
! 			  Puerto Rico:
! 			    $  5.00 base charge;
! 			  + $  5.00 for *each* Emacs Calc or Emacs Lisp
! 			    Reference manual ($ 5.00 * #ofMans);
! 			  + $ 20.00 for *each* tape subscription or CD
! 			    subscription ($20.00 * #ofSubs);
! 			  + $  1.00 for *each* item other then the above
! 			    (shipping for all other items =
! 						     $ 1.00 * #ofOtherItems).
! 	     + $ ______	  Shipping fee for most Foreign Destinations: (Please
! 			  do *not* use this formula for addresses in China,
! 			  Guam, Indonesia, Israel, Malaysia, New Zealand,
! 			  Philippines, and Thailand.  Please fax,
! 			  or call for an exact shipping quote.)
! 			    $ 20.00 base charge for orders to other
! 			      addresses outside of U.S., Canada, & Puerto Rico:
! 			  + $ 80.00 for *each* tape subscription or CD
! 			    subscription ($ 80.00 * #ofSubs);
! 			  + $ 10.00 for *each* of the other items in the
! 			    order ($ 10.00 * #ofItems).
! 	     + $ ______	  Optional (tax-deductible in the U.S.) donation.
! 		 ------	  We suggest 5% if paying by credit card.
! 
! 	 TOTAL $ ______	  We pay for shipping via UPS ground transportation in
! 			  the contiguous 48 states and Canada.	For very
! 			  large orders, ask about actual shipping costs for
! 			  that order.
  
  
--- 3964,4001 ----
  
  
  Tax and Shipping Costs
  ----------------------
  
!              + $ ______   For addresses in Massachusetts: add 5% sales tax
!                           or give tax exempt number.  There is no sales tax
!                           on T-shirts.
!              + $ ______   Shipping fee for addresses in Alaska, Hawaii, or
!                           Puerto Rico:
!                             $  5.00 base charge;
!                           + $  5.00 for *each* Emacs Calc or Emacs Lisp
!                             Reference manual ($ 5.00 * #ofMans);
!                           + $ 20.00 for *each* CD-ROM subscription
!                                              ($20.00 * #ofSubs);
!                           + $  1.00 for *each* item other then the above
!                             (shipping for all other items =
!                                                      $ 1.00 * #ofOtherItems).
!              + $ ______   Shipping fee for most Foreign Destinations: (Please
!                           do *not* use this formula for addresses in China,
!                           Guam, Indonesia, Israel, Malaysia, New Zealand,
!                           Philippines, and Thailand.  Please fax,
!                           or contact us for an exact shipping quote.)
!                             $ 20.00 base charge for orders to other
!                               addresses outside of U.S., Canada, & Puerto Rico:
!                           + $ 80.00 for *each*  CD-ROM subscription
!                                   ($ 80.00 * #ofSubs);
!                           + $ 10.00 for *each* of the other items in the
!                             order ($ 10.00 * #ofItems).
!              + $ ______   Optional (tax-deductible in the U.S.) donation.
!                  ------   We suggest 5% if paying by credit card.
! 
!          TOTAL $ ______   We pay for shipping via UPS ground transportation in
!                           the contiguous 48 states and Canada.  For very
!                           large orders, ask about actual shipping costs for
!                           that order.
  
  
*************** Telephone number in case of a problem wi
*** 4265,4276 ****
  For international orders, please include a Fax number. _______________________
  
  
  ------------------------------------------------------------------------------
! |									     |
  |  Orders filled only upon receipt of check, money order, or credit card     |
  |  order in U.S. dollars.  Unpaid orders will be returned to the sender.     |
  |  We do not have the staff to handle the billing of unpaid orders.  Please  |
  |  help keep our lives simple by including your payment with your order.     |
! |									     |
  ------------------------------------------------------------------------------
  
--- 4019,4032 ----
  For international orders, please include a Fax number. _______________________
  
+ E-mail Address: ______________________________________________________________
+ 
  
  ------------------------------------------------------------------------------
! |                                                                            |
  |  Orders filled only upon receipt of check, money order, or credit card     |
  |  order in U.S. dollars.  Unpaid orders will be returned to the sender.     |
  |  We do not have the staff to handle the billing of unpaid orders.  Please  |
  |  help keep our lives simple by including your payment with your order.     |
! |                                                                            |
  ------------------------------------------------------------------------------
  
*************** For orders from outside the U.S.:
*** 4280,4291 ****
  ---------------------------------
  
! You are responsible for paying all duties, tariffs, and taxes.	If you
  refuse to pay the charges, the shipper will return or abandon the order.
  
  
   ---------------------------------------------------------------------------
!  |									   |
!  |	Please make checks payable to the ``Free Software Foundation''.	   |
!  |									   |
   ---------------------------------------------------------------------------
  
--- 4036,4049 ----
  ---------------------------------
  
! You are responsible for paying all duties, tariffs, and taxes.  If you
  refuse to pay the charges, the shipper will return or abandon the order.
  
  
   ---------------------------------------------------------------------------
!  |                                                                         |
!  |      Please make checks payable to the ``Free Software Foundation''.    |
!  |                                                                         |
!  |           Checks must be in U.S. dollars, drawn on a U.S. bank.         |
!  |                                                                         |
   ---------------------------------------------------------------------------
  
*************** Cardholder's Signature: ________________
*** 4314,4331 ****
  
  ------------------------------------------------------------------------------
! |									     |
! |     If you wish to pay by wire transfer or you are a reseller, please	     |
! |     call or write us for details.					     |
! |									     |
  ------------------------------------------------------------------------------
  
  
! 		Please mail orders to:	Free Software Foundation
! 					59 Temple Place -- Suite 330
! 					Boston, MA   02111
! PRICES AND CONTENTS MAY CHANGE		+1-617-542-5942
! WITHOUT NOTICE AFTER June 30, 1996.	Fax (including Japan): +1-617-542-2652
  
! Version: January 1996 ASCII etc/ORDERS
  
  -----------------------------------------------------------------------------
--- 4072,4089 ----
  
  ------------------------------------------------------------------------------
! |                                                                            |
! |     If you wish to pay by wire transfer or you are a reseller, please      |
! |     contact us or write us for details.                                    |
! |                                                                            |
  ------------------------------------------------------------------------------
  
  
!                 Please mail orders to:  Free Software Foundation
!                                         59 Temple Place - Suite 330
!                                         Boston, MA   02111
! PRICES AND CONTENTS MAY CHANGE          +1-617-542-5942
! WITHOUT NOTICE AFTER January 31, 1997   Fax (including Japan): +1-617-542-2652
  
! Version: July 1996 ASCII etc/ORDERS
  
  -----------------------------------------------------------------------------
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/SERVICE emacs-19.33/etc/SERVICE
*** emacs-19.32/etc/SERVICE	Fri Jul 26 10:22:05 1996
--- emacs-19.33/etc/SERVICE	Thu Aug  8 16:25:58 1996
*************** I am willing to travel for sufficiently 
*** 111,124 ****
  Updated: 1996-06-24
  
- Giuseppe Attardi	<attardi@di.unipi.it>
- Dipartimento di Informatica
- Corso Italia 40
- I-56125 Pisa, Italy
- +39 50 887-244
  
- GNU: help on obtaining GNU, for italian sites.
- 
- Updated: 1994-04-05
- 
  			Basis Technology Corp.
  		     One Kendall Square, Bldg 200
--- 111,115 ----
*************** Contacts:
*** 156,160 ****
  
  Entered:  1996-07-15
! ^_
  Laurent Bernardin
  16, rue Dicks
--- 147,151 ----
  
  Entered:  1996-07-15
! 
  Laurent Bernardin
  16, rue Dicks
*************** Rates: ~60 US$ / hour (Flux 2000.-)
*** 171,175 ****
  
  Entered:  1996-07-16
! ^_
  Paul Black                                      <paulb@triode.apana.org.au>
  Sydney, Australia
--- 162,166 ----
  
  Entered:  1996-07-16
! 
  Paul Black                                      <paulb@triode.apana.org.au>
  Sydney, Australia
*************** on the nature of the work, my indicative
*** 190,194 ****
  
  Entered: 1996-07-10
! ^_
  Keith Bostic
  
--- 181,185 ----
  
  Entered: 1996-07-10
! 
  Keith Bostic
  
*************** Keith Bostic
*** 198,202 ****
  
  Entered:  1996-07-15
! ^_
  Philip Brown
  <phil@mitre.org>
--- 189,193 ----
  
  Entered:  1996-07-15
! 
  Philip Brown
  <phil@mitre.org>
*************** Statement:
*** 228,232 ****
  
  Entered:  1996-07-15
! ^_
  James Craig Burley
  97 Arrowhead Circle
--- 219,223 ----
  
  Entered:  1996-07-15
! 
  James Craig Burley
  97 Arrowhead Circle
*************** educational institutions, add taxes and 
*** 301,325 ****
  Updated:  1996-06-26
  
- Contributed Software
- Graefestr. 76
- 10967 Berlin, Germany
- phone:	  (+49 30) 694 69 07
- FAX:	  (+49 30) 694 68 09
- modems:	  (+49 30) 694 60 55 (5xZyXEL )
- modems:	  (+49 30) 693 40 51 (8xUSR DS)
- email:	  <info@contrib.de>
- internet: uropax.contrib.de [192.109.39.2], login as 'guest'.
- 
- We distribute, install, port, teach and support free software
- in general, i.e. X11, GNU, khoros etc. Rates are ECU 80,-- plus
- tax per hour. We offer maintenance and support contracts for full
- customer satisfaction.
- Highlights are transparent development environments for multi-platform
- sites and configuration management.  Traveling is no problem.
- 
- Free Archive login for downloading on above modem numbers.
- 
- Updated: 1994-04-05
- ^_
  Kevin Cosgrove  	<kevinc@dOink.COM>
  
--- 292,295 ----
*************** Sample prices: USD50/hour commercial, US
*** 348,352 ****
  
  Entered:  1996-07-15
! ^-
  Stuart Cracraft		<cracraft@ai.mit.edu>
  25682 Cresta Loma
--- 318,322 ----
  
  Entered:  1996-07-15
! 
  Stuart Cracraft		<cracraft@ai.mit.edu>
  25682 Cresta Loma
*************** Customized programming also available.
*** 367,371 ****
  
  Updated: 1996-06-26
! ^_
  Cygnus Support			<info@cygnus.com>
  1937 Landings Drive		...uunet!cygint!info
--- 337,351 ----
  
  Updated: 1996-06-26
! 
! Noel Cragg                      <noel@rain.org>
! 1129 State St. Ste. A6
! Santa Barbara, CA 93101
! 805-899-4695
! 
! I'll do installation, debugging, and extension of GNU tools on a
! contract basis for anyone willing to hire me.
! 
! Altered:  1996-08-05
! 
  Cygnus Support			<info@cygnus.com>
  1937 Landings Drive		...uunet!cygint!info
*************** configurations.
*** 390,394 ****
  
  Updated: 2Feb95
! ^_
  Marcus G. Daniels              <marcus@sysc.pdx.edu>
  31060 S. Kaufman Rd.           <marcusd@gnu.ai.mit.edu>
--- 370,374 ----
  
  Updated: 2Feb95
! 
  Marcus G. Daniels              <marcus@sysc.pdx.edu>
  31060 S. Kaufman Rd.           <marcusd@gnu.ai.mit.edu>
*************** Rates:		Variable depending upon contract
*** 522,525 ****
--- 502,518 ----
  Updated: 1996-06-26
  
+ Michael P. Deignan
+ Ideamation, Inc.
+ 136 Nelson Street
+ Providence, RI 02908
+ (401) 331-3708
+ (401) 272-6449 fax.
+ 
+ Rate:	Varies depending on complexity of task.
+ 	Hourly and fixed-rate contracts are available.
+ Programs Supported:	All
+ 
+ Updated: 1996-08-08
+ 
  Interactive Information Limited
  
*************** UTICA  NY  13502
*** 569,574 ****
  (315) 734-3600
  
! CONTACTS: Alan Piszcz (peesh)      <apiszcz@utica1.kaman.com>
!         : Dennis Fitzgerald        <dennis@utica.kaman.com>
  
  Kaman Sciences has performed a GNU port for a custom RISC processor.
--- 562,567 ----
  (315) 734-3600
  
! CONTACTS: Dennis Fitzgerald        <dfitzgerald@utica.kaman.com> 
!         : Paul Antonik		   <pantonik@utica.kaman.com>
  
  Kaman Sciences has performed a GNU port for a custom RISC processor.
*************** and modification of the necessary descri
*** 578,582 ****
  and gld and other binutils.  Kaman also has services for installation and
  setup of GNU tools, (GAWK, GCC, EMACS, etc.) on Sun workstations.
! 
  Work is on a "service contract" basis and development is charged either
  hourly or as a fixed price contract.
--- 571,575 ----
  and gld and other binutils.  Kaman also has services for installation and
  setup of GNU tools, (GAWK, GCC, EMACS, etc.) on Sun workstations.
!  
  Work is on a "service contract" basis and development is charged either
  hourly or as a fixed price contract.
*************** hourly or as a fixed price contract.
*** 584,589 ****
  Consulting rates: $70 to $200 per hour.
  
! Entered: 1995-01-13
! ^_
  Ehud Karni      <kehud@simonwiesel.net.il>
  
--- 577,582 ----
  Consulting rates: $70 to $200 per hour.
  
! Updated: 1996-08-05
! 
  Ehud Karni      <kehud@simonwiesel.net.il>
  
*************** for non-profit organizations and educati
*** 629,650 ****
  
  Entered: 1996-07-24
! ^_
! Scott J. Kramer		<sjk@aura.nbn.com>
! P.O. Box 620207
! Woodside, CA  94062
! +1 415-941-0755
! 
! GNU Software:	Tutoring, installations/upgrades, Emacs Lisp customizations,
! 		general troubleshooting/support.  Prefer that work I do
! 		becomes part integrated into official Free Software Foundation
! 		distributions.
! 
! Systems Administration:	 Sun (SunOS & Solaris) and SGI (IRIX)
! 			 UNIX hardware/software platforms.
! 
! Rate:	Task- and time-dependent; non-monetary offers accepted.
! 
! Updated: 1994-04-12
! ^_
  Bradley M. Kuhn
  <bkuhn@acm.org>
--- 622,626 ----
  
  Entered: 1996-07-24
! 
  Bradley M. Kuhn
  <bkuhn@acm.org>
*************** available for purchasers of LEMIS CD-ROM
*** 709,728 ****
  Updated: 1996-07-06
  
- Marty Leisner	   <leisner@sdsp.mc.xerox.com>
- 332 Shaftsbury Road
- Rochester, New York  14610
- Home:(716) 654-7931
- 
- Experience: 12 years C/Unix, 7 years DOS.
- 	    Extensive experience with GNU binary tools, cross-compilers,
- 	    embedded/hosted systems, realtime.
- Degree :    BS CS, Cornell University
- Rates:	    $75/hr
- 
- marty
- <leisner@sdsp.mc.xerox.com>  <leisner@eso.mc.xerox.com>
- 
- Updated: 1994-04-15
- ^_
  Rohan Lenard                		<rjl@wr.com.au>
  32 Holtermann St,
--- 685,688 ----
*************** Rates:      AUS $75+/hr neg.
*** 746,750 ****
  
  Entered: 1996-07-17
! ^_
  Reuven M. Lerner		<reuven@netvision.net.il>
  17 Disraeli Street
--- 706,710 ----
  
  Entered: 1996-07-17
! 
  Reuven M. Lerner		<reuven@netvision.net.il>
  17 Disraeli Street
*************** non-profit organizations.
*** 853,857 ****
  
  Entered:  1996-07-15
! ^_
  Andrew McCallum
  6623 Dalzell Place
--- 813,817 ----
  
  Entered:  1996-07-15
! 
  Andrew McCallum
  6623 Dalzell Place
*************** Rates:		$90-$150 / hour, negotiable, dep
*** 881,905 ****
  
  Entered: 1996-07-15
- ^_
- Roland McGrath		<roland@frob.com>
- 545 Tech Sq, Rm 426
- Cambridge, MA  02139
- Work: (617) 253-8568
- 
- Co-author of GNU Make (with Richard Stallman); maintainer of GNU Make.
- Author and maintainer of the GNU C Library and co-author of the GNU Hurd.
- Author of several GNU Emacs Lisp packages and parts of GNU Emacs 19.
- FSF employee summer 1989, fall 1990 to the present.
- 
- Installation, maintenance, porting, enhancement of all GNU software.  I can
- install GNU software and maintain its installation on call via the Internet.
- 
- Fees negotiable; $75-$100/hour, higher for very short term projects.  I can
- work anywhere in the Boston or SF Bay Area, or anywhere on the Internet.  I
- am working full-time for the FSF on the GNU Hurd, so I am likely to take on
- only jobs that either can be done entirely via the Internet and are
- short-term, or that are very interesting.
- 
- Updated: 1995-01-21
  
  Erik Naggum		<erik@naggum.no>
--- 841,844 ----
*************** I accept VISA and Mastercard, preferred 
*** 929,933 ****
  
  Updated: 1996-06-28
! ^_
  NET-Community                   <sales@net-community.com>
  38403 Pelton Road               http://www.net-community.com
--- 868,872 ----
  
  Updated: 1996-06-28
! 
  NET-Community                   <sales@net-community.com>
  38403 Pelton Road               http://www.net-community.com
*************** CD-ROM sales go towards additional devel
*** 947,951 ****
  
  Entered: 1996-07-25
! ^_
    Open Systems Consultants a.s
    St. Olavsgt. 24
--- 886,890 ----
  
  Entered: 1996-07-25
! 
    Open Systems Consultants a.s
    St. Olavsgt. 24
*************** range.  Fixed-priced projects are also a
*** 965,969 ****
  
  Entered:  1996-07-17
! ^_
  Francesco Potorti` <F.Potorti@cnuce.cnr.it>
  Via S.Stefano, 8
--- 904,908 ----
  
  Entered:  1996-07-17
! 
  Francesco Potorti` <F.Potorti@cnuce.cnr.it>
  Via S.Stefano, 8
*************** Qualifications: Electronic Engineering d
*** 989,993 ****
  
  Entered: 1996-07-10
! ^_
  Dipl.-Inform. Klaus Kdmpf		<kkaempf@progis.de>
  proGIS Software
--- 928,932 ----
  
  Entered: 1996-07-10
! 
  Dipl.-Inform. Klaus Kdmpf		<kkaempf@progis.de>
  proGIS Software
*************** installation. Larger projects are negoti
*** 1012,1016 ****
  
  Entered: 1996-07-25
! ^_
  Quiotix Corporation
  Menlo Park, CA
--- 951,955 ----
  
  Entered: 1996-07-25
! 
  Quiotix Corporation
  Menlo Park, CA
*************** Rates: For software items, request our p
*** 1080,1094 ****
  Updated: 1996-06-26
  
- Small Business Systems, Inc.		<postmaster@anomaly.sbs.com>
- Box 17220, Route 104
- Esmond, RI  02917
- 401.273.4669
- 
- Rate:	Varies depending on complexity of task.
- 	Hourly and fixed-rate contracts are available.
- Programs Supported:	All
- 
- Updated: 1994-04-14
- ^_
  Jon Solomon                     <jsol@gnu.ai.mit.edu>
  235 Main St., Apt 3C-1
--- 1019,1022 ----
*************** I can make tapes for you if you need tha
*** 1106,1110 ****
  
  Entered: 1996-04-09
! ^_
  Julian H. Stacey.	<jhs@freebsd.org>	http://www.freebsd.org/~jhs/
  Tel. +49 89 268616 (089 268616)			Time zone: +01:00
--- 1034,1038 ----
  
  Entered: 1996-04-09
! 
  Julian H. Stacey.	<jhs@freebsd.org>	http://www.freebsd.org/~jhs/
  Tel. +49 89 268616 (089 268616)			Time zone: +01:00
*************** Rates: $6/min or $250/hr.
*** 1165,1194 ****
  Updated: 1996-06-26
  
- JoS-Ware Comp Tech	Johan Svensson <support@spird.jos.ec.lu.se>
- Box 739
- 220 07 LUND
- SWEDEN
- Tel +46-46-104505 (Dept. of Economics, University of LUND)
- Fax +46-46-188445 (JoS-Ware Comp Tech)
- 
- What:	We offer consulting services regarding installation,
- 	customization, troubleshooting, porting and integration
- 	of all free software, including GNU software.
- 
- Spec.:	Network integration, integration of public domain software
- 	into commercial systems, WorldWideWeb, C, X-Windows, Linux,
- 	networked information systems
- 
- How:	Remote login over internet, email, modem, phone, personal
- 	visits (in southern Sweden mainly)
- 
- Rates:	550SEK (+ tax) per hour within Sweden
- 	370SEK (+ tax) per hour within Sweden for educational org.
- 	US $90 per hour outside Sweden
- 	US $70 per hour outside Sweden for educational org.
- 	Note: fees may vary and special arrangements may be considered
- 
- Entered: 1994-04-07
- 
  Kayvan Sylvan <kayvan@sylvan.com>
  Sylvan Associates
--- 1093,1096 ----
*************** For consulting, $60-120/hour, depending 
*** 1249,1253 ****
  
  Entered:  1996-07-15
! ^_
  Leonard H. Tower Jr.	<tower@prep.ai.mit.edu>
  36 Porter Street
--- 1151,1155 ----
  
  Entered:  1996-07-15
! 
  Leonard H. Tower Jr.	<tower@prep.ai.mit.edu>
  36 Porter Street
*************** I would like to provide unpaid support f
*** 1320,1370 ****
  
  Entered:  1996-07-15
! ^_
! Joe Wells <jbw@cs.bu.edu>
! Postal Address:
!   care of: Boston University Computer Science Department
!   111 Cummington Street, Room 138
!   Boston, Massachusetts 02215
! Work Telephone: (617) 353-3381 (sorry, but no answering machine or voice mail)
! Home Telephone: (617) 739-7456 (until August 1995)
! Finger "jbw@cs.bu.edu" for up-to-date contact information.
! 
! Experience:
!     I have B.A. and M.A. degrees in Computer Science and have completed
!     all but the dissertation for a Ph.D. in C.S.  My research for my
!     Ph.D.  is in the areas of logic, type systems, and programming
!     language theory.  My primary programming languages are Emacs Lisp,
!     Perl, and Bourne shell, but of course I can program in any language.
!     I have written numerous Emacs Lisp packages.  I started the USENET
!     "List of Frequently Asked Questions about GNU Emacs with Answers" and
!     maintained it for more than two years.  Most of my work has been
!     related to the telephone system (modems, voice mail, etc.), but I am
!     not limited to that.  Send e-mail for my complete resume or curriculum
!     vita.
! 
! Programs supported:
!     GNU Emacs and Taylor UUCP:
!       Installation, training, customization, bug fixing, troubleshooting,
!       extension, development, porting, or answering any kind of question.
!     Any other GNU program:
!       The same things, but I don't necessarily have huge amounts of
!       experience with the particular program.
! 
! Working conditions:
!     I am usually available for part-time work (less than 20 hours per week
!     including any travel time).  I can sometimes make time for full-time
!     work for a month or two; please inquire.  I can either work in or near
!     Boston or via the Internet or via telephone; travel outside the Boston
!     metropolitan area can be negotiated.  My schedule is very flexible.
!     Any programs I write will normally have the copying conditions of the
!     GNU General Public License; this is negotiable.
! 
! Rates: $65/hour as an independent contractor.
!        travel and telephone expenses.
!        higher rates if extensive travel is required.
! 
! Updated: 1994-09-27
! ^_
! 
  Arne Wichmann
  
--- 1222,1226 ----
  
  Entered:  1996-07-15
! 
  Arne Wichmann
  
*************** hour, negotiable, plus a per diem for ou
*** 1398,1428 ****
  
  Entered:  1996-07-15
- ^_
- Herb Wood
- phone: 1-415-789-7173
- email: <ru@ccnext.ucsf.edu>
- 
- I'm a better "planner" than I am a hacker.  A really good hacker will be able
- to keep many pieces of information in their short-term memory and to memorize
- new pieces of information at a fast rate.  This is not my strong point.
- Rather, I excel in domains that require knowledge of the slightly more
- theoretical parts of computer science --for example, logic, formal methods of
- program development, and functional programming.  I can write, and I have
- "tutoring" (teaching one-on-one) experience, and, unlike some programmers,
- I enjoy doing these things.
- 
- I have spend a lot of time looking at the Emacs Lisp sources and customizing
- Emacs and VM.  I think I can customize Emacs and its packages quickly and
- effectively.
- 
- Entered: 1995-07-30
- 
- Yggdrasil Computing, Inc./ Freesoft, Inc.	<info@yggdrasil.com>
- 4880 Stevens Creek Blvd. Ste. 205
- San Jose, CA  95129
- (408) 261-6630
- (800) 261 6630
- 
- Updated: 1994-04-14
  
  Lige Zhou
--- 1254,1257 ----
*************** time-consuming.
*** 1441,1445 ****
  
  Entered:  1996-07-15
! ^_
  
  For a current copy of this directory, or to have yourself listed, ask:
--- 1270,1274 ----
  
  Entered:  1996-07-15
! 
  
  For a current copy of this directory, or to have yourself listed, ask:
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/etc/TODO emacs-19.33/etc/TODO
*** emacs-19.32/etc/TODO	Sat Jul 27 20:34:33 1996
--- emacs-19.33/etc/TODO	Fri Aug  9 07:01:33 1996
***************
*** 3,6 ****
--- 3,14 ----
    and then parse the output to find out about each file.
  
+ * Change bibtex.el not to use very complicated regexps
+   which do lots of backtracking.  Currently bibtex.el
+   makes Emacs crash on some systems due to stack overflow.
+   Making Emacs prevent the stack overflow (by detecting an error
+   itself before the stack can overflow) would just make bibtex,el
+   fail on ALL systems.  The only way out is to rewrite bibtex.el
+   so it does not need too much stack.
+ 
  * Change the Windows NT menu code
    so that it handles the deep_p argument and avoids
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lib-src/ChangeLog emacs-19.33/lib-src/ChangeLog
*** emacs-19.32/lib-src/ChangeLog	Wed Jul 31 15:11:28 1996
--- emacs-19.33/lib-src/ChangeLog	Sun Aug 11 03:39:28 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
*************** Wed Nov 22 14:01:11 1995  Geoff Voelker 
*** 323,327 ****
  
  	* makefile.nt (DOC, clean): Don't use switches to del not
! 	supported by Win95.
  
  Mon Nov 13 21:59:08 1995  Richard Stallman  <rms@mole.gnu.ai.mit.edu>
--- 327,331 ----
  
  	* makefile.nt (DOC, clean): Don't use switches to del not
! 	supported by Windows 95.
  
  Mon Nov 13 21:59:08 1995  Richard Stallman  <rms@mole.gnu.ai.mit.edu>
*************** Tue Nov  7 02:43:26 1995  Kevin Gallo  <
*** 338,342 ****
  	* makefile.nt (DOC): Include strings from w32term.c, w32xfns.c,
  	w32fns.c, w32faces.c, w32select.c, w32menu.c, w32reg.c; remove
! 	Win95 conditional.
  
  Mon Nov  6 13:03:32 1995  Francesco Potorti`  (pot@cnuce.cnr.it)
--- 342,346 ----
  	* makefile.nt (DOC): Include strings from w32term.c, w32xfns.c,
  	w32fns.c, w32faces.c, w32select.c, w32menu.c, w32reg.c; remove
! 	Windows 95 conditional.
  
  Mon Nov  6 13:03:32 1995  Francesco Potorti`  (pot@cnuce.cnr.it)
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/ChangeLog emacs-19.33/lisp/ChangeLog
*** emacs-19.32/lisp/ChangeLog	Thu Aug  1 18:38:40 1996
--- emacs-19.33/lisp/ChangeLog	Sun Aug 11 17:02:20 1996
***************
*** 1,2 ****
--- 1,51 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
+ 	* cc-mode.el (c-fill-paragraph): Fix regexp for finding C++ comment
+ 	paragraphs.
+ 
+ Sat Aug 10 20:19:06 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* isearch.el (isearch-whitespace-chars): If isearch-invalid-regexp,
+ 	insert just a space.
+ 
+ Wed Aug  7 15:44:08 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* iso-acc.el (iso-languages, french): Remove non-French combinations.
+ 	Add ~c, "e, "i, `u.
+ 
+ 	* simple.el (normal-auto-fill-function): New variable.
+ 	(auto-fill-mode): Use that instead of constant 'do-auto-fill.
+ 
+ 	* bibtex.el (bibtex-mode): Set normal-auto-fill-function locally;
+ 	don't set auto-fill-function.  Don't turn on Auto Fill mode.
+ 
+ Tue Aug  6 14:28:51 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* rmail.el (rmail-reply-regexp, rmail-message-filter): Doc fix.
+ 	(rmail-reply-regexp): Match Re[2].
+ 
+ Mon Aug  5 03:19:02 1996  Simon Marshall  <simon@spiff.gnu.ai.mit.edu>
+ 
+ 	* help.el (help-font-lock-keywords): Fully undo rms July 26 change.
+ 
+ Mon Aug  5 00:14:17 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* dabbrev.el (dabbrev--last-case-pattern): New variable.
+ 	(dabbrev-expand): Set it for ordinary expansions;
+ 	use it when copying successive words.
+ 
+ Sat Aug  3 17:26:41 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* imenu.el (imenu-update-menubar): Fix code to install the new menu.
+ 
+ 	* info.el (Info-find-node): Use pop-to-buffer.
+ 
+ Fri Aug  2 22:53:56 1996  Paul Eggert  <eggert@twinsun.com>
+ 
+ 	* rmail.el (rmail-unix-mail-delimiter): Allow space or tab as
+ 	first character in mailbox part of `From ' line.
+ 
  Thu Aug  1 18:36:15 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
*************** Tue Jul  2 17:12:20 1996  Barry A. Warsa
*** 406,409 ****
--- 455,469 ----
  
  	* reporter.el: Major rewrite.
+ 	The variable `reporter-prompt-for-summary-p' can take a string value.
+ 
+ 	The variable `mail-user-agent' provides configuration to the end
+ 	user.  This variable contains a symbol indicating which Emacs mail
+ 	package the user would like for composing outgoing mail.
+ 
+ 	Mail package authors now use `define-mail-user-agent' to define
+ 	symbols appropriate for use with `mail-user-agent'.  Three such
+ 	symbols are predefined: `sendmail-user-agent' (for Emacs
+ 	sendmail.el), `vm-user-agent' (for Kyle Jones' VM package), and
+ 	`mh-e-user-agent' (for the MH-E package).
  
  Tue Jul  2 19:36:28 1996  Lars Magne Ingebrigtsen  <larsi@ifi.uio.no>
*************** Wed Nov 22 14:03:08 1995  Geoff Voelker 
*** 4748,4752 ****
  
  	* makefile.nt (install, clean): Don't use switches to del not
! 	supported by Win95.
  
  Tue Nov 21 00:12:36 1995  Richard Stallman  <rms@mole.gnu.ai.mit.edu>
--- 4808,4812 ----
  
  	* makefile.nt (install, clean): Don't use switches to del not
! 	supported by Windows 95.
  
  Tue Nov 21 00:12:36 1995  Richard Stallman  <rms@mole.gnu.ai.mit.edu>
Only in emacs-19.32/lisp: MANIFEST
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/bibtex.el emacs-19.33/lisp/bibtex.el
*** emacs-19.32/lisp/bibtex.el	Thu Jul 11 19:07:04 1996
--- emacs-19.33/lisp/bibtex.el	Fri Aug  9 18:31:58 1996
*************** non-nil."
*** 1488,1493 ****
    (make-local-variable 'comment-start)
    (setq comment-start "%")
!   (auto-fill-mode 1)
!   (setq auto-fill-function 'bibtex-auto-fill-function)
    (set (make-local-variable 'font-lock-defaults)
         '(bibtex-font-lock-keywords
--- 1488,1493 ----
    (make-local-variable 'comment-start)
    (setq comment-start "%")
!   (make-local-variable 'normal-auto-fill-function)
!   (setq normal-auto-fill-function 'bibtex-auto-fill-function)
    (set (make-local-variable 'font-lock-defaults)
         '(bibtex-font-lock-keywords
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/cc-mode.el emacs-19.33/lisp/cc-mode.el
*** emacs-19.32/lisp/cc-mode.el	Wed May 15 10:46:52 1996
--- emacs-19.33/lisp/cc-mode.el	Sun Aug 11 17:01:56 1996
*************** Optional prefix ARG means justify paragr
*** 2333,2339 ****
  	    ;; Move up to first line of this comment.
  	    (while (and (not (bobp))
! 			(looking-at "[ \t]*//"))
  	      (forward-line -1))
! 	    (if (not (looking-at ".*//"))
  		(forward-line 1))
  	    ;; Find the comment start in this line.
--- 2333,2339 ----
  	    ;; Move up to first line of this comment.
  	    (while (and (not (bobp))
! 			(looking-at "[ \t]*//[ \t]*[^ \t\n]"))
  	      (forward-line -1))
! 	    (if (not (looking-at ".*//[ \t]*[^ \t\n]"))
  		(forward-line 1))
  	    ;; Find the comment start in this line.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/dabbrev.el emacs-19.33/lisp/dabbrev.el
*** emacs-19.32/lisp/dabbrev.el	Thu Aug  1 00:52:58 1996
--- emacs-19.33/lisp/dabbrev.el	Mon Aug  5 00:14:16 1996
*************** this list.")
*** 253,256 ****
--- 253,260 ----
  (defvar dabbrev--last-completion-buffer nil)
  
+ ;; Non-nil means we should upcase
+ ;; when copying successive words.
+ (defvar dabbrev--last-case-pattern nil)
+ 
  ;; Same as dabbrev-check-other-buffers, but is set for every expand.
  (defvar dabbrev--check-other-buffers dabbrev-check-other-buffers)
*************** if there is a suitable one already."
*** 314,319 ****
  	 (abbrev (dabbrev--abbrev-at-point))
  	 (ignore-case-p  (and (eval dabbrev-case-fold-search)
! 				(or (not dabbrev-upcase-means-case-search)
! 				    (string= abbrev (downcase abbrev)))))
  	 (my-obarray dabbrev--last-obarray)
  	 init)
--- 318,323 ----
  	 (abbrev (dabbrev--abbrev-at-point))
  	 (ignore-case-p  (and (eval dabbrev-case-fold-search)
! 			      (or (not dabbrev-upcase-means-case-search)
! 				  (string= abbrev (downcase abbrev)))))
  	 (my-obarray dabbrev--last-obarray)
  	 init)
*************** direction of search to backward if set n
*** 415,419 ****
  See also `dabbrev-abbrev-char-regexp' and \\[dabbrev-completion]."
    (interactive "*P")
!   (let (abbrev expansion old direction (orig-point (point)))
      ;; abbrev -- the abbrev to expand
      ;; expansion -- the expansion found (eventually) or nil until then
--- 419,424 ----
  See also `dabbrev-abbrev-char-regexp' and \\[dabbrev-completion]."
    (interactive "*P")
!   (let (abbrev record-case-pattern
! 	       expansion old direction (orig-point (point)))
      ;; abbrev -- the abbrev to expand
      ;; expansion -- the expansion found (eventually) or nil until then
*************** See also `dabbrev-abbrev-char-regexp' an
*** 439,450 ****
  		 (marker-position dabbrev--last-abbrev-location)
  		 (= (point) (1+ dabbrev--last-abbrev-location)))
! 	    (let* ((prev-expansion
! 		    (buffer-substring-no-properties
! 		     (- dabbrev--last-abbrev-location (length dabbrev--last-expansion))
! 		     dabbrev--last-abbrev-location))
! 		   ;; If the previous expansion was upcased.
! 		   ;; upcase this one too.
! 		   (upcase-it
! 		     (equal prev-expansion (upcase prev-expansion))))
  	      ;; The "abbrev" to expand is just the space.
  	      (setq abbrev " ")
--- 444,448 ----
  		 (marker-position dabbrev--last-abbrev-location)
  		 (= (point) (1+ dabbrev--last-abbrev-location)))
! 	    (progn
  	      ;; The "abbrev" to expand is just the space.
  	      (setq abbrev " ")
*************** See also `dabbrev-abbrev-char-regexp' an
*** 467,471 ****
  		      (buffer-substring dabbrev--last-expansion-location
  					(point)))
! 		(if upcase-it
  		    (setq expansion (upcase expansion)))
  
--- 465,469 ----
  		      (buffer-substring dabbrev--last-expansion-location
  					(point)))
! 		(if dabbrev--last-case-pattern
  		    (setq expansion (upcase expansion)))
  
*************** See also `dabbrev-abbrev-char-regexp' an
*** 482,485 ****
--- 480,484 ----
  			    (prefix-numeric-value arg)))
  	  (setq abbrev (dabbrev--abbrev-at-point))
+ 	  (setq record-case-pattern t)
  	  (setq old nil)))
  
*************** See also `dabbrev-abbrev-char-regexp' an
*** 521,524 ****
--- 520,532 ----
        (setq buffer-undo-list (cons orig-point buffer-undo-list))
        (dabbrev--substitute-expansion old abbrev expansion)
+ 
+       ;; If we are not copying successive words now,
+       ;; set dabbrev--last-case-pattern.
+       (and record-case-pattern
+ 	   (setq dabbrev--last-case-pattern
+ 		 (and (eval dabbrev-case-fold-search)
+ 		      (not dabbrev-upcase-means-case-search)
+ 		      (equal abbrev (upcase abbrev)))))
+ 
        ;; Save state for re-expand.
        (setq dabbrev--last-expansion expansion)	
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/help.el emacs-19.33/lisp/help.el
*** emacs-19.32/lisp/help.el	Wed Jul 31 14:15:40 1996
--- emacs-19.33/lisp/help.el	Mon Aug  5 03:18:20 1996
***************
*** 100,105 ****
  	     '(1 (if (match-beginning 3)
  		     font-lock-function-name-face
! 		   font-lock-variable-name-face)
! 		 nil t))
         ;;
         ;; Words inside `' which tend to be symbol names.
--- 100,104 ----
  	     '(1 (if (match-beginning 3)
  		     font-lock-function-name-face
! 		   font-lock-variable-name-face)))
         ;;
         ;; Words inside `' which tend to be symbol names.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/imenu.el emacs-19.33/lisp/imenu.el
*** emacs-19.32/lisp/imenu.el	Wed Jun 12 10:59:57 1996
--- emacs-19.33/lisp/imenu.el	Sat Aug  3 18:57:09 1996
*************** See the command `imenu' for more informa
*** 823,828 ****
  						   t))
  	       (setq old (lookup-key (current-local-map) [menu-bar index]))
! 	       (if (keymapp old)
! 		   (setcdr (nthcdr 2 old) menu1)))))))
  
  (defun imenu--menubar-select (item)
--- 823,827 ----
  						   t))
  	       (setq old (lookup-key (current-local-map) [menu-bar index]))
! 	       (setcdr old (cdr menu1)))))))
  
  (defun imenu--menubar-select (item)
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/info.el emacs-19.33/lisp/info.el
*** emacs-19.32/lisp/info.el	Sun Jun 30 04:11:01 1996
--- emacs-19.33/lisp/info.el	Thu Aug  8 22:08:30 1996
*************** In standalone mode, \\<Info-mode-map>\\[
*** 302,306 ****
  		  Info-history)))
    ;; Go into info buffer.
!   (switch-to-buffer "*info*")
    (buffer-disable-undo (current-buffer))
    (or (eq major-mode 'Info-mode)
--- 302,306 ----
  		  Info-history)))
    ;; Go into info buffer.
!   (pop-to-buffer "*info*")
    (buffer-disable-undo (current-buffer))
    (or (eq major-mode 'Info-mode)
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/isearch.el emacs-19.33/lisp/isearch.el
*** emacs-19.32/lisp/isearch.el	Thu Apr  4 11:38:30 1996
--- emacs-19.33/lisp/isearch.el	Sat Aug 10 20:19:04 1996
*************** If you want to search for just a space, 
*** 1092,1096 ****
    (interactive)
    (if isearch-regexp 
!       (if (and search-whitespace-regexp (not isearch-within-brackets))
  	  (isearch-process-search-string search-whitespace-regexp " ")
  	(isearch-printing-char))
--- 1092,1097 ----
    (interactive)
    (if isearch-regexp 
!       (if (and search-whitespace-regexp (not isearch-within-brackets)
! 	       (not isearch-invalid-regexp))
  	  (isearch-process-search-string search-whitespace-regexp " ")
  	(isearch-printing-char))
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/iso-acc.el emacs-19.33/lisp/iso-acc.el
*** emacs-19.32/lisp/iso-acc.el	Mon May 20 17:02:14 1996
--- emacs-19.33/lisp/iso-acc.el	Thu Aug  8 16:00:05 1996
***************
*** 3,8 ****
  ;; Copyright (C) 1993, 1994, 1996 Free Software Foundation, Inc.
  
! ;; Author: Johan Vromans <jv@mh.nl>
! ;; Version: 1.7 (modified)
  ;; Maintainer: FSF
  ;; Keywords: i18n
--- 3,7 ----
  ;; Copyright (C) 1993, 1994, 1996 Free Software Foundation, Inc.
  
! ;; Author: Johan Vromans
  ;; Maintainer: FSF
  ;; Keywords: i18n
***************
*** 83,95 ****
      
      ("french"
!      (?' (?A . ?\301) (?E . ?\311) (?I . ?\315) (?O . ?\323) (?U . ?\332)
! 	 (?C . ?\307) (?a . ?\341) (?e . ?\351) (?i . ?\355) (?o . ?\363)
! 	 (?u . ?\372) (?c . ?\347) (?\  . ?'))
!      (?` (?A . ?\300) (?E . ?\310) (?a . ?\340) (?e . ?\350) (?\  . ?`))
       (?^ (?A . ?\302) (?E . ?\312) (?I . ?\316) (?O . ?\324) (?U . ?\333)
  	 (?a . ?\342) (?e . ?\352) (?i . ?\356) (?o . ?\364) (?u . ?\373)
  	 (?\  . ?^))
!      (?\" (?U . ?\334) (?u . ?\374) (?\  . ?\"))
!      (?\~ (?A . ?\303) (?O . ?\325) (?a . ?\343) (?o . ?\365) (?\  . ?\~)))
      
      ("latin-2"
--- 82,94 ----
      
      ("french"
!      (?' (?E . ?\311) (?C . ?\307) (?e . ?\351) (?c . ?\347) (?\  . ?'))
!      (?` (?A . ?\300) (?E . ?\310) (?U . ?\331)
!          (?a . ?\340) (?e . ?\350) (?u . ?\371) (?\  . ?`))
       (?^ (?A . ?\302) (?E . ?\312) (?I . ?\316) (?O . ?\324) (?U . ?\333)
  	 (?a . ?\342) (?e . ?\352) (?i . ?\356) (?o . ?\364) (?u . ?\373)
  	 (?\  . ?^))
!      (?\" (?E . ?\313) (?I . ?\317)  
!           (?e . ?\353) (?i . ?\357) (?\  . ?\"))
!      (?\~ (?< . ?\253) (?> . ?\273) (?C . ?\307) (?c . ?\347) (?\  . ?\~)))
      
      ("latin-2"
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/loaddefs.el emacs-19.33/lisp/loaddefs.el
*** emacs-19.32/lisp/loaddefs.el	Thu Aug  1 22:02:09 1996
--- emacs-19.33/lisp/loaddefs.el	Mon Aug 12 21:09:38 1996
*************** Vectors work just like lists.  Nested ba
*** 1008,1012 ****
  ;;;***
  
! ;;;### (autoloads (bibtex-mode) "bibtex" "bibtex.el" (12773 35096))
  ;;; Generated autoloads from bibtex.el
  
--- 1008,1012 ----
  ;;;***
  
! ;;;### (autoloads (bibtex-mode) "bibtex" "bibtex.el" (12811 48222))
  ;;; Generated autoloads from bibtex.el
  
*************** SYNTAX should be \" \", \"w\", \".\" or 
*** 2016,2020 ****
  ;;;***
  
! ;;;### (autoloads (c-set-style java-mode objc-mode c++-mode c-mode) "cc-mode" "cc-mode.el" (12697 61020))
  ;;; Generated autoloads from cc-mode.el
  
--- 2016,2020 ----
  ;;;***
  
! ;;;### (autoloads (c-set-style java-mode objc-mode c++-mode c-mode) "cc-mode" "cc-mode.el" (12814 19012))
  ;;; Generated autoloads from cc-mode.el
  
*************** STYLENAME is a string representing the d
*** 2091,2095 ****
  styles described in the variable `c-style-alist'.  See that variable
  for details of setting up styles." t nil)
! (fset 'set-c-style           'c-set-style)
  
  ;;;***
--- 2091,2095 ----
  styles described in the variable `c-style-alist'.  See that variable
  for details of setting up styles." t nil)
!  (fset 'set-c-style           'c-set-style)
  
  ;;;***
*************** Edit display information for cpp conditi
*** 2331,2335 ****
  ;;;***
  
! ;;;### (autoloads (dabbrev-expand dabbrev-completion) "dabbrev" "dabbrev.el" (12800 14378))
  ;;; Generated autoloads from dabbrev.el
  
--- 2331,2335 ----
  ;;;***
  
! ;;;### (autoloads (dabbrev-expand dabbrev-completion) "dabbrev" "dabbrev.el" (12805 29976))
  ;;; Generated autoloads from dabbrev.el
  
*************** Switches to the buffer `*ielm*', or crea
*** 4766,4770 ****
  ;;;***
  
! ;;;### (autoloads (imenu imenu-add-to-menubar) "imenu" "imenu.el" (12734 56173))
  ;;; Generated autoloads from imenu.el
  
--- 4766,4770 ----
  ;;;***
  
! ;;;### (autoloads (imenu imenu-add-to-menubar) "imenu" "imenu.el" (12803 55621))
  ;;; Generated autoloads from imenu.el
  
*************** of `inferior-lisp-program').  Runs the h
*** 4861,4865 ****
  ;;;***
  
! ;;;### (autoloads (Info-goto-emacs-key-command-node Info-goto-emacs-command-node info-standalone info) "info" "info.el" (12758 13973))
  ;;; Generated autoloads from info.el
   (add-hook 'same-window-buffer-names "*info*")
--- 4861,4865 ----
  ;;;***
  
! ;;;### (autoloads (Info-goto-emacs-key-command-node Info-goto-emacs-command-node info-standalone info) "info" "info.el" (12810 40350))
  ;;; Generated autoloads from info.el
   (add-hook 'same-window-buffer-names "*info*")
*************** For example, invoke \"emacs -batch -f ba
*** 4928,4932 ****
  ;;;***
  
! ;;;### (autoloads (iso-accents-mode) "iso-acc" "iso-acc.el" (12704 56790))
  ;;; Generated autoloads from iso-acc.el
  
--- 4928,4932 ----
  ;;;***
  
! ;;;### (autoloads (iso-accents-mode) "iso-acc" "iso-acc.el" (12810 18245))
  ;;; Generated autoloads from iso-acc.el
  
*************** variable." t nil)
*** 6616,6620 ****
  ;;;***
  
! ;;;### (autoloads (rmail-input rmail-mode rmail) "rmail" "rmail.el" (12786 33193))
  ;;; Generated autoloads from rmail.el
  
--- 6616,6620 ----
  ;;;***
  
! ;;;### (autoloads (rmail-input rmail-mode rmail) "rmail" "rmail.el" (12807 37215))
  ;;; Generated autoloads from rmail.el
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/rmail.el emacs-19.33/lisp/rmail.el
*** emacs-19.32/lisp/rmail.el	Sun Jul 21 15:14:49 1996
--- emacs-19.33/lisp/rmail.el	Tue Aug  6 14:39:27 1996
*************** still the current message in the Rmail b
*** 148,164 ****
  
  (defvar rmail-message-filter nil
!   "If non nil, a filter function for new messages in RMAIL.
! Called with region narrowed to the message, including headers.")
  
  (defvar rmail-reply-prefix "Re: "
    "String to prepend to Subject line when replying to a message.")
  
! ;; Some mailers use "Re(2):" or "Re^2:" or "Re: Re:".
  ;; This pattern should catch all the common variants.
! (defvar rmail-reply-regexp "\\`\\(Re\\(([0-9]+)\\|\\^[0-9]+\\)?: *\\)*"
!   "Regexp to delete from Subject line before inserting rmail-reply-prefix.")
  
  (defvar rmail-display-summary nil
!   "If non nil, the summary buffer is always displayed.")
  
  (defvar rmail-mode-map nil)
--- 148,165 ----
  
  (defvar rmail-message-filter nil
!   "If non-nil, a filter function for new messages in RMAIL.
! Called with region narrowed to the message, including headers,
! before obeying `rmail-ignored-headers'.")
  
  (defvar rmail-reply-prefix "Re: "
    "String to prepend to Subject line when replying to a message.")
  
! ;; Some mailers use "Re(2):" or "Re^2:" or "Re: Re:" or "Re[2]".
  ;; This pattern should catch all the common variants.
! (defvar rmail-reply-regexp "\\`\\(Re\\(([0-9]+)\\|\\[[0-9]+\\]\\|\\^[0-9]+\\)?: *\\)*"
!   "Regexp to delete from Subject line before inserting `rmail-reply-prefix'.")
  
  (defvar rmail-display-summary nil
!   "If non-nil, Rmail always displays the summary buffer.")
  
  (defvar rmail-mode-map nil)
*************** Called with region narrowed to the messa
*** 233,240 ****
       ;;			<joe@y.z>
       ;; can yield `From Joe User Fri Mar 22 08:11:15 1996'.
       ;; We want to match the results of any of these manglings.
       ;; The following regexp rejects names whose first characters are
       ;; obviously bogus, but after that anything goes.
!      "\\([^\0-\r \^?].*\\)? "
  
       ;; The time the message was sent.
--- 234,246 ----
       ;;			<joe@y.z>
       ;; can yield `From Joe User Fri Mar 22 08:11:15 1996'.
+      ;; The mailbox can be removed or be replaced by white space, e.g.
+      ;;		From: "Joe User"{space}{tab}
+      ;;			<joe@y.z>
+      ;; can yield `From {space}{tab} Fri Mar 22 08:11:15 1996',
+      ;; where {space} and {tab} represent the Ascii space and tab characters.
       ;; We want to match the results of any of these manglings.
       ;; The following regexp rejects names whose first characters are
       ;; obviously bogus, but after that anything goes.
!      "\\([^\0-\b\n-\r\^?].*\\)? "
  
       ;; The time the message was sent.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/simple.el emacs-19.33/lisp/simple.el
*** emacs-19.32/lisp/simple.el	Thu Jul  4 14:45:35 1996
--- emacs-19.33/lisp/simple.el	Tue Aug  6 15:11:51 1996
*************** Setting this variable automatically make
*** 2433,2445 ****
  	    ;; No place to break => stop trying.
  	    (setq give-up t))))
!       ;; justify last line
        (justify-current-line justify t t)
        t))) 
  
  (defun auto-fill-mode (&optional arg)
!   "Toggle auto-fill mode.
! With arg, turn Auto-Fill mode on if and only if arg is positive.
! In Auto-Fill mode, inserting a space at a column beyond `current-fill-column'
! automatically breaks the line at a previous space."
    (interactive "P")
    (prog1 (setq auto-fill-function
--- 2433,2452 ----
  	    ;; No place to break => stop trying.
  	    (setq give-up t))))
!       ;; Justify last line.
        (justify-current-line justify t t)
        t))) 
  
+ (defvar normal-auto-fill-function 'do-auto-fill
+   "The function to use for `auto-fill-function' if Auto Fill mode is turned on.
+ Some major modes set this.")
+ 
  (defun auto-fill-mode (&optional arg)
!   "Toggle Auto Fill mode.
! With arg, turn Auto Fill mode on if and only if arg is positive.
! In Auto Fill mode, inserting a space at a column beyond `current-fill-column'
! automatically breaks the line at a previous space.
! 
! The value of `normal-auto-fill-function' specifies the function to use
! for `auto-fill-function' when turning Auto Fill mode on."
    (interactive "P")
    (prog1 (setq auto-fill-function
*************** automatically breaks the line at a previ
*** 2447,2451 ****
  		       (not auto-fill-function)
  		       (> (prefix-numeric-value arg) 0))
! 		   'do-auto-fill
  		   nil))
      (force-mode-line-update)))
--- 2454,2458 ----
  		       (not auto-fill-function)
  		       (> (prefix-numeric-value arg) 0))
! 		   normal-auto-fill-function
  		   nil))
      (force-mode-line-update)))
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lisp/version.el emacs-19.33/lisp/version.el
*** emacs-19.32/lisp/version.el	Thu Aug  1 01:09:09 1996
--- emacs-19.33/lisp/version.el	Sun Aug 11 03:36:56 1996
***************
*** 25,29 ****
  ;;; Code:
  
! (defconst emacs-version "19.32" "\
  Version numbers of this version of Emacs.")
  
--- 25,29 ----
  ;;; Code:
  
! (defconst emacs-version "19.33" "\
  Version numbers of this version of Emacs.")
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lwlib/ChangeLog emacs-19.33/lwlib/ChangeLog
*** emacs-19.32/lwlib/ChangeLog	Wed Jul 31 15:10:20 1996
--- emacs-19.33/lwlib/ChangeLog	Sun Aug 11 16:52:17 1996
***************
*** 1,2 ****
--- 1,19 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
+ 	* lwlib-Xm.c (update_one_menu_entry): Fix previous change:
+ 	When XmIsCascadeButton, don't call XmCreateCascadeButtonGadget,
+ 	just modify the existing one.
+ 	
+ Fri Aug  9 21:16:57 1996  Marcus Daniels  <marcus@sayre.sysc.pdx.edu>
+ 
+ 	* lwlib.c (merge_widget_value): Undo previous change.
+ 	
+ 	* lwlib-Xm.c (update_one_menu_entry): When creating a pulldown
+ 	in an existing but empty menu item, in order to get a new functional
+ 	pulldown, the menu item must be switched from an XmPushButtonGadget
+ 	into a XmCascadeButtonGadget.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lwlib/lwlib-Xm.c emacs-19.33/lwlib/lwlib-Xm.c
*** emacs-19.32/lwlib/lwlib-Xm.c	Wed Jul 31 12:49:52 1996
--- emacs-19.33/lwlib/lwlib-Xm.c	Sun Aug 11 16:47:22 1996
*************** update_one_menu_entry (instance, widget,
*** 510,518 ****
        if (contents)
  	{
! 	  menu = XmCreatePulldownMenu (XtParent (widget), XtName (widget), NULL, 0);
! 	  make_menu_in_widget (instance, menu, contents, 0);
! 	  ac = 0;
! 	  XtSetArg (al [ac], XmNsubMenuId, menu); ac++;
! 	  XtSetValues (widget, al, ac);
  	}
      }
--- 510,557 ----
        if (contents)
  	{
! 	  unsigned int old_num_children, i;
! 	  Widget parent;
! 	  Widget *widget_list;
! 
! 	  parent = XtParent (widget);
! 	  widget_list = XtCompositeChildren (parent, &old_num_children);
! 
! 	  /* Find the widget position within the parent's widget list.  */
! 	  for (i = 0; i < old_num_children; i++)
! 	    if (strcmp (XtName (widget_list[i]), XtName (widget)) == 0)
! 	      break;
! 	  if (i == old_num_children)
! 	    abort ();
! 	  if (XmIsCascadeButton (widget_list[i]))
! 	    {
! 	      menu = XmCreatePulldownMenu (parent, XtName(widget), NULL, 0);
! 	      make_menu_in_widget (instance, menu, contents, 0);
! 	      ac = 0;
! 	      XtSetArg (al [ac], XmNsubMenuId, menu); ac++;
! 	      XtSetValues (widget, al, ac);
! 	    }
! 	  else
! 	    {
! 	      Widget button;
! 	      
! 	      /* The current menuitem is a XmPushButtonGadget, it 
! 		 needs to be replaced by a CascadeButtonGadget */
! 	      XtDestroyWidget (widget_list[i]);
! 	      menu = XmCreatePulldownMenu (parent, val->name, NULL, 0);
! 	      make_menu_in_widget (instance, menu, contents, 0);
! 	      ac = 0;
! 	      XtSetArg (al [ac], XmNsubMenuId, menu); ac++;
! 	      /* Non-zero values don't work reliably in
! 		 conjunction with Emacs' event loop */
! 	      XtSetArg (al [ac], XmNmappingDelay, 0); ac++;
! 	      /* Tell Motif to put it in the right place */
! 	      XtSetArg (al [ac], XmNpositionIndex, i); ac++;
! 	      button = XmCreateCascadeButtonGadget (parent, val->name, al, ac);
! 	      xm_update_label (instance, button, val);
! 	      
! 	      XtAddCallback (button, XmNcascadingCallback, xm_pull_down_callback,
! 			     (XtPointer)instance);
! 	      XtManageChild (button);
! 	    }
  	}
      }
*************** xm_update_menu (instance, widget, val, d
*** 576,580 ****
  	{
  	  if (!cur)
! 	    abort ();
  	  if (children [i]->core.being_destroyed
  	      || strcmp (XtName (children [i]), cur->name))
--- 615,622 ----
  	{
  	  if (!cur)
! 	    {
! 	      num_children_to_keep = i;
! 	      break;
! 	    }
  	  if (children [i]->core.being_destroyed
  	      || strcmp (XtName (children [i]), cur->name))
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/lwlib/lwlib.c emacs-19.33/lwlib/lwlib.c
*** emacs-19.32/lwlib/lwlib.c	Sat Jul 27 12:19:48 1996
--- emacs-19.33/lwlib/lwlib.c	Fri Aug  9 14:45:54 1996
*************** merge_widget_value (val1, val2, level)
*** 527,532 ****
--- 527,534 ----
  		   0, 0);
  	  change = max (change, INVISIBLE_CHANGE);
+ #if 0 /* This was replaced by the August 9 1996 change in lwlib-Xm.c.  */
  #ifdef USE_MOTIF
  	  change = max (merged_contents->change, change);
+ #endif
  #endif
  	}
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/make-dist emacs-19.33/make-dist
*** emacs-19.32/make-dist	Sat Jul 20 13:58:03 1996
--- emacs-19.33/make-dist	Sun Aug  4 16:33:26 1996
*************** echo "Making links to \`msdos'"
*** 308,312 ****
  (cd msdos
   ln  ChangeLog emacs.ico emacs.pif ../${tempdir}/msdos
!  ln mainmake mainmake.v2 sed*.inp ../${tempdir}/msdos
   cd ../${tempdir}/msdos
   rm -f =*)
--- 308,312 ----
  (cd msdos
   ln  ChangeLog emacs.ico emacs.pif ../${tempdir}/msdos
!  ln is_exec.c sigaction.c mainmake mainmake.v2 sed*.inp ../${tempdir}/msdos
   cd ../${tempdir}/msdos
   rm -f =*)
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/ChangeLog emacs-19.33/man/ChangeLog
*** emacs-19.32/man/ChangeLog	Wed Jul 31 15:10:55 1996
--- emacs-19.33/man/ChangeLog	Sun Aug 11 03:39:17 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/abbrevs.texi emacs-19.33/man/abbrevs.texi
*** emacs-19.32/man/abbrevs.texi	Fri May 31 12:01:43 1996
--- emacs-19.33/man/abbrevs.texi	Sun Aug  4 02:32:34 1996
*************** are actually Lisp expressions which are 
*** 392,405 ****
  needs to be made.  If the expression's value is non-@code{nil}, then
  case is ignored in searching, or converted on replacement, respectively.
! If the expression's value is @code{nil}, the action is not done.  The
! default values let the variables @code{case-fold-search} (@pxref{Search
! Case}) and @code{case-replace} (@pxref{Replacement and Case}) control
! what to do.
  
  @vindex dabbrev-abbrev-char-regexp
!   The variable @code{dabbrev-abbrev-char-regexp}, if non-@code{nil}
! controls which characters are part of a word, for dynamic expansion
  purposes.  The regular expression must match just one character, never
! two or more.  The same regular expression also determines what
  characters are part of an expansion.  The value @code{nil} has a special
  meaning: abbreviations are made of word characters, but expansions are
--- 392,405 ----
  needs to be made.  If the expression's value is non-@code{nil}, then
  case is ignored in searching, or converted on replacement, respectively.
! If the expression's value is @code{nil}, case is not ignored or not
! converted.  The default values let the variables @code{case-fold-search}
! (@pxref{Search Case}) and @code{case-replace} (@pxref{Replacement and
! Case}) control what to do.
  
  @vindex dabbrev-abbrev-char-regexp
!   The variable @code{dabbrev-abbrev-char-regexp}, if non-@code{nil},
! controls which characters are considered part of a word, for dynamic expansion
  purposes.  The regular expression must match just one character, never
! two or more.  The same regular expression also determines which
  characters are part of an expansion.  The value @code{nil} has a special
  meaning: abbreviations are made of word characters, but expansions are
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/ack.texi emacs-19.33/man/ack.texi
*** emacs-19.32/man/ack.texi	Thu Jul 11 19:52:18 1996
--- emacs-19.33/man/ack.texi	Sun Aug  4 02:33:34 1996
*************** Simon Marshall wrote:
*** 342,347 ****
  @file{fast-lock.el}, which caches the face data computed by Font Lock mode, and
  @item
! @file{lazy-lock.el}, which makes Font Lock mode fontification become
! demand-driven and/or defer-driven.
  @end itemize
  
--- 342,347 ----
  @file{fast-lock.el}, which caches the face data computed by Font Lock mode, and
  @item
! @file{lazy-lock.el}, which delays fontification in Font Lock mode
! until text is actually displayed.
  @end itemize
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/anti.texi emacs-19.33/man/anti.texi
*** emacs-19.32/man/anti.texi	Wed Jan 24 17:42:33 1996
--- emacs-19.33/man/anti.texi	Tue Aug  6 18:13:49 1996
***************
*** 8,12 ****
    For those users who live backwards in time, here is information about
  downgrading to Emacs version 19.28 or 19.29.  We hope you will enjoy the
! greater simplicity that results from the absence of certain Emacs 19.30
  features.
  
--- 8,12 ----
    For those users who live backwards in time, here is information about
  downgrading to Emacs version 19.28 or 19.29.  We hope you will enjoy the
! greater simplicity that results from the absence of certain Emacs 19.33
  features.
  
*************** you use must appear in this order: @samp
*** 106,119 ****
  
  @item
! Many improvements which make various Emacs command work on MS-DOS are
! gone.  For instance, you cannot print from within Emacs, @samp{Dired}
! doesn't support shell wildcards in filenames, some packages use
! filenames which are illegal in MS-DOS, @samp{display-time} doesn't work,
! @samp{font-lock} won't work unless you create some faces by hand first,
! and @samp{call-process} cannot redirect @code{stderr}.  As an additional
! bonus, you get random characters inserted into the buffer without a
! warning (unless you're smart enough to discover that setting
! @var{visible-bell} makes this problem to go away).  In a word, it's a
! great relief for those who still need proof that MS-DOG isn't an
! operating system for someone who uses Emacs.
  @end itemize
--- 106,124 ----
  
  @item
! Many special-case kludges for MS-DOS have been removed.  This means
! that many features don't work on MS-DOS; however, the code of Emacs
! is much simpler.
! 
! For instance, you cannot print from within Emacs, Dired doesn't support
! shell wildcards in filenames, some Lisp packages won't work because
! their standard filenames are invalid on MS-DOS, @code{display-time}
! doesn't work, Font Lock mode won't work unless you create some faces by
! hand first, and @code{call-process} cannot redirect @code{stderr}.
! 
! As an additional bonus, you get random characters inserted into the
! buffer without a warning (unless you're clever enough to discover that
! setting @code{visible-bell} makes this problem to go away).
! 
! In a word, it's a great relief for those who still need proof that
! MS-DOG isn't a real operating system.
  @end itemize
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/calendar.texi emacs-19.33/man/calendar.texi
*** emacs-19.32/man/calendar.texi	Thu Jul 25 05:57:04 1996
--- emacs-19.33/man/calendar.texi	Tue Aug  6 18:14:48 1996
*************** Generate a Filofax-style two-weeks-at-a-
*** 345,349 ****
  (@code{cal-tex-cursor-filofax-2week}).
  @item t f W
! Generate a Filofax-style one-weeks-at-a-glance calendar
  (@code{cal-tex-cursor-filofax-week}).
  @item t y
--- 345,349 ----
  (@code{cal-tex-cursor-filofax-2week}).
  @item t f W
! Generate a Filofax-style one-week-at-a-glance calendar
  (@code{cal-tex-cursor-filofax-week}).
  @item t y
*************** Their calendar consists of twelve 30-day
*** 640,644 ****
  five day period.  Once every fourth year they add a leap day to this
  extra period to make it six days.  The Ethiopic calendar is identical in
! structure, but has a different year numbers and month names.
  
  @cindex Persian calendar
--- 640,644 ----
  five day period.  Once every fourth year they add a leap day to this
  extra period to make it six days.  The Ethiopic calendar is identical in
! structure, but has different year numbers and month names.
  
  @cindex Persian calendar
*************** Display Ethiopic date for selected day
*** 703,707 ****
  @findex calendar-print-persian-date
  @item p p
! Display Perisan date for selected day
  (@code{calendar-print-persian-date}).
  @findex calendar-print-mayan-date
--- 703,707 ----
  @findex calendar-print-persian-date
  @item p p
! Display Persian date for selected day
  (@code{calendar-print-persian-date}).
  @findex calendar-print-mayan-date
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/cc-mode.texi emacs-19.33/man/cc-mode.texi
*** emacs-19.32/man/cc-mode.texi	Sat Feb 10 02:43:36 1996
--- emacs-19.33/man/cc-mode.texi	Mon Aug  5 00:56:21 1996
*************** Custom indent functions take a single ar
*** 1762,1766 ****
  component cons cell (see @ref{Syntactic Analysis}).  The
  function returns an integer offset value that will be added to the
! running total indentation for the lne.  Note that what actually gets
  returned is the difference between the column that the first stream
  operator is on, and the column of the buffer relative position passed in
--- 1762,1766 ----
  component cons cell (see @ref{Syntactic Analysis}).  The
  function returns an integer offset value that will be added to the
! running total indentation for the line.  Note that what actually gets
  returned is the difference between the column that the first stream
  operator is on, and the column of the buffer relative position passed in
*************** include: @code{knr-argdecl-intro}, @code
*** 2390,2394 ****
  @comment !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  
! C and it's derivative languages are highly complex creatures.  Often,
  ambiguous code situations arise that require @code{cc-mode} to scan
  large portions of the buffer to determine syntactic context.  Some
--- 2390,2394 ----
  @comment !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  
! C and its derivative languages are highly complex creatures.  Often,
  ambiguous code situations arise that require @code{cc-mode} to scan
  large portions of the buffer to determine syntactic context.  Some
*************** at.
*** 2439,2443 ****
  For the latter problem, I would suggest converting to ANSI style
  protocols, and turning the variable @code{c-recognize-knr-p} to
! @code{nil} (this is it's default value for all modes).
  
  @vindex cc-lobotomy-pith-list
--- 2439,2443 ----
  For the latter problem, I would suggest converting to ANSI style
  protocols, and turning the variable @code{c-recognize-knr-p} to
! @code{nil} (this is its default value for all modes).
  
  @vindex cc-lobotomy-pith-list
*************** For the former problem, you might want t
*** 2445,2449 ****
  speed-ups provided for you in the file @file{cc-lobotomy.el}, which
  is part of the canonical @code{cc-mode} distribution.  As mentioned
! previous, @code{cc-mode} always trades accuracy for speed, however it is
  recognized that sometimes you need speed and can sacrifice some accuracy
  in indentation.  The file @file{cc-lobotomy.el} contains hacks that
--- 2445,2449 ----
  speed-ups provided for you in the file @file{cc-lobotomy.el}, which
  is part of the canonical @code{cc-mode} distribution.  As mentioned
! previously, @code{cc-mode} always trades accuracy for speed; however it is
  recognized that sometimes you need speed and can sacrifice some accuracy
  in indentation.  The file @file{cc-lobotomy.el} contains hacks that
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/cmdargs.texi emacs-19.33/man/cmdargs.texi
*** emacs-19.32/man/cmdargs.texi	Mon May  6 18:03:20 1996
--- emacs-19.33/man/cmdargs.texi	Sun Aug  4 02:44:35 1996
*************** These variables are used only on particu
*** 382,405 ****
  On MS-DOS, the name of the command interpreter to use.  This is used to
  make a default value for the @code{SHELL} environment variable.
  @item NAME
  On MS-DOS, this variable defaults to the value of the @code{USER}
  variable.
  @item TEMP
  @itemx TMP
  On MS-DOS, these specify the name of the directory for storing temporary
  files in.
  @item EMACSTEST
! On MS-DOS, this is the name of the file where Emacs writes a full log
! of the internal terminal emulator operation.  Useful when submitting
! bugs.
  @item EMACSCOLORS
! Used on MS-DOS systems to set screen colors early so that the screen
! won't momentarily flash the default colors at startup.  The value of
! this variable should be 2-character encoding of the foreground (the
! first character) and the background (the second character) colors of
! the default face.  Each character should be a hexadecimal code of the
! color on a standard PC text-mode display.  Only 3 lower bits of the
! background color are actually used, because PC display cannot use more
! than 8 background colors.
  @item WINDOW_GFX
  Used when initializing the Sun windows system.
--- 382,412 ----
  On MS-DOS, the name of the command interpreter to use.  This is used to
  make a default value for the @code{SHELL} environment variable.
+ 
  @item NAME
  On MS-DOS, this variable defaults to the value of the @code{USER}
  variable.
+ 
  @item TEMP
  @itemx TMP
  On MS-DOS, these specify the name of the directory for storing temporary
  files in.
+ 
  @item EMACSTEST
! On MS-DOS, this specifies a file to use to log the operation of the
! internal terminal emulator.  This feature is useful for submitting bug
! reports.
! 
  @item EMACSCOLORS
! Used on MS-DOS systems to set screen colors early, so that the screen
! won't momentarily flash the default colors when Emacs starts up.  The
! value of this variable should be two-character encoding of the
! foreground (the first character) and the background (the second
! character) colors of the default face.  Each character should be the
! hexadecimal code for the desired color on a standard PC text-mode
! display.
! 
! Only the low three bits of the background color are actually used,
! because the PC display supports only eight background colors.
! 
  @item WINDOW_GFX
  Used when initializing the Sun windows system.
*************** Color name for text.
*** 885,891 ****
  Window size and position.  Be careful not to specify this resource as
  @samp{emacs*geometry}, because that may affect individual menus as well
! as the Emacs frame itself.  If this resource specifies a position, that
! affects only the initial Emacs frame and frames with explicitly
! specified names; but the size (if specified) applies to all frames.
  
  @item @code{iconName} (class @code{Title})
--- 892,901 ----
  Window size and position.  Be careful not to specify this resource as
  @samp{emacs*geometry}, because that may affect individual menus as well
! as the Emacs frame itself.
! 
! If this resource specifies a position, that position applies only to the
! initial Emacs frame (or, in the case of a resource for a specific frame
! name, only that frame).  However, the size if specified here applies to
! all frames.
  
  @item @code{iconName} (class @code{Title})
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/emacs.texi emacs-19.33/man/emacs.texi
*** emacs-19.32/man/emacs.texi	Thu Jul 11 19:52:53 1996
--- emacs-19.33/man/emacs.texi	Tue Aug  6 18:15:44 1996
***************
*** 4,8 ****
  @c The edition number appears in several places in this file
  This corresponds to the twelfth edition of the @cite{GNU Emacs Manual},
! for Emacs version 19.32.
  @c Please REMEMBER to update edition number in *three* places in this file.
  
--- 4,8 ----
  @c The edition number appears in several places in this file
  This corresponds to the twelfth edition of the @cite{GNU Emacs Manual},
! for Emacs version 19.33.
  @c Please REMEMBER to update edition number in *three* places in this file.
  
*************** original English.
*** 64,68 ****
  @center @titlefont{GNU Emacs Manual}
  @sp 4
! @center Twelfth Edition, Updated for Emacs Version 19.32
  @sp 5
  @center Richard Stallman
--- 64,68 ----
  @center @titlefont{GNU Emacs Manual}
  @sp 4
! @center Twelfth Edition, Updated for Emacs Version 19.33
  @sp 5
  @center Richard Stallman
*************** Copyright @copyright{} 1985, 1986, 1987,
*** 72,79 ****
  @sp 2
  Twelfth Edition @*
! Updated for Emacs Version 19.32, @*
! June 1996
  
! ISBN 1-882114-83-3
  @sp 1
  Published by the Free Software Foundation @*
--- 72,79 ----
  @sp 2
  Twelfth Edition @*
! Updated for Emacs Version 19.33, @*
! August 1996
  
! ISBN 1-882114-05-1
  @sp 1
  Published by the Free Software Foundation @*
*************** Emacs is the extensible, customizable, s
*** 111,115 ****
  display editor.  This Info file describes how to edit with Emacs
  and some of how to customize it, but not how to extend it.  It
! corresponds to GNU Emacs version 19.32.
  
  @end ifinfo
--- 111,115 ----
  display editor.  This Info file describes how to edit with Emacs
  and some of how to customize it, but not how to extend it.  It
! corresponds to GNU Emacs version 19.33.
  
  @end ifinfo
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/files.texi emacs-19.33/man/files.texi
*** emacs-19.32/man/files.texi	Wed Jun 26 15:30:12 1996
--- emacs-19.33/man/files.texi	Thu Aug  8 17:01:03 1996
*************** recover are present in Emacs buffers.  Y
*** 805,817 ****
  this---saving them---updates the files themselves.
  
!   Interrupted sessions are recorded in files named
! @file{.saves-@var{pid}-@var{hostname}} in your home directory.  You can
! turn off the recording of sessions by setting the variable
! @code{auto-save-list-file-name} to @code{nil}.  (Doing that in your
! @file{.emacs} file has no effect---instead, set
! @code{auto-save-list-file-prefix} to @code{nil}).  You can store the
! current session in a different place by setting the variable to a
! different file name, but you'll have to redefine @code{recover-session}
! separately to make it look for the new name.
  
  @node File Aliases
--- 805,817 ----
  this---saving them---updates the files themselves.
  
! @vindex auto-save-list-file-prefix
!   Interrupted sessions are recorded for later recovery in files named
! @file{~/.saves-@var{pid}-@var{hostname}}.  The @samp{~/.saves} portion of
! these names comes from the value of @code{auto-save-list-file-prefix}.
! You can arrange to record sessions in a different place by setting that
! variable in your @file{.emacs} file, but you'll have to redefine
! @code{recover-session} as well to make it look in the new place.  If you
! set @code{auto-save-list-file-prefix} to @code{nil} in your
! @file{.emacs} file, sessions are not recorded for recovery.
  
  @node File Aliases
*************** most recent checked in version.  @kbd{C-
*** 1129,1135 ****
  your work file and buffer to the previous version (the one that precedes
  the version that is deleted).  If you say @kbd{no}, then VC keeps your
! changes in the buffer and locks the file.  It also unexpands version
! headers so that they don't contain wrong information.  @xref{Version
! Headers}.
  
    The no-revert option is useful when you have checked in a change and
--- 1129,1133 ----
  your work file and buffer to the previous version (the one that precedes
  the version that is deleted).  If you say @kbd{no}, then VC keeps your
! changes in the buffer and locks the file.
  
    The no-revert option is useful when you have checked in a change and
*************** headers.
*** 1816,1820 ****
  
    There are many ways of customizing VC.  The variables that control its
! behaviour fall into three categories, described in the following
  sections.
  
--- 1814,1818 ----
  
    There are many ways of customizing VC.  The variables that control its
! behavior fall into three categories, described in the following
  sections.
  
*************** files are always kept.)
*** 1844,1848 ****
  @vindex vc-follow-symlinks
    Editing a version-controlled file through a symbolic link can be
! dangerous.  It bypasses the version control system--you can edit the
  file without checking it out, and fail to check your changes in.  Also,
  your changes might overwrite those of another user.  To protect against
--- 1842,1846 ----
  @vindex vc-follow-symlinks
    Editing a version-controlled file through a symbolic link can be
! dangerous.  It bypasses the version control system---you can edit the
  file without checking it out, and fail to check your changes in.  Also,
  your changes might overwrite those of another user.  To protect against
*************** symbolic link points to a version-contro
*** 1854,1859 ****
  VC only displays a warning message.  If it is @code{t}, VC automatically
  follows the link, and visits the real file instead, telling you about
! this in the echo area.  If the variable is @code{ask} (the default), VC
! asks you each time what to do.
  
  @node VC Status Retrieval
--- 1852,1857 ----
  VC only displays a warning message.  If it is @code{t}, VC automatically
  follows the link, and visits the real file instead, telling you about
! this in the echo area.  If the value is @code{ask} (the default), VC
! asks you each time whether to follow the link.
  
  @node VC Status Retrieval
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/frames.texi emacs-19.33/man/frames.texi
*** emacs-19.32/man/frames.texi	Mon Jul  8 12:25:59 1996
--- emacs-19.33/man/frames.texi	Sun Aug  4 02:59:35 1996
*************** or reserved keywords.
*** 775,780 ****
  @findex font-lock-mode
  @findex turn-on-font-lock
!   The command @kbd{M-x font-lock-mode} turns the mode on or off.  The
! function @code{turn-on-font-lock} unconditionally enables Font Lock
  mode.  This is useful in mode-hook functions.  For example, to enable
  Font Lock mode whenever you edit a C file, you can do this:
--- 775,781 ----
  @findex font-lock-mode
  @findex turn-on-font-lock
!   The command @kbd{M-x font-lock-mode} turns Font Lock mode on or off
! according to the argument, and toggles the mode when it has no argument.
! The function @code{turn-on-font-lock} unconditionally enables Font Lock
  mode.  This is useful in mode-hook functions.  For example, to enable
  Font Lock mode whenever you edit a C file, you can do this:
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/help.texi emacs-19.33/man/help.texi
*** emacs-19.32/man/help.texi	Tue Apr 30 14:26:21 1996
--- emacs-19.33/man/help.texi	Tue Aug  6 18:18:05 1996
*************** matches for the specified regular expres
*** 239,243 ****
  @findex apropos-value
    The @code{apropos-value} command is like @code{apropos} except that it
! searches symbol's values for matches for the specified regular
  expression.  This command does not check function definitions or
  property lists by default; specify a numeric argument if you want it to
--- 239,243 ----
  @findex apropos-value
    The @code{apropos-value} command is like @code{apropos} except that it
! searches symbols' values for matches for the specified regular
  expression.  This command does not check function definitions or
  property lists by default; specify a numeric argument if you want it to
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/mh-e.texi emacs-19.33/man/mh-e.texi
*** emacs-19.32/man/mh-e.texi	Thu Jan  4 15:55:06 1996
--- emacs-19.33/man/mh-e.texi	Sun Aug  4 03:00:29 1996
*************** GNU Emacs and MH@.  Now I'm fully hooked
*** 123,127 ****
  
  The mh-e package is distributed with GNU Emacs, @footnote{Note that mh-e
! is supported with MH 6 and either GNU @w{Emacs 18} or GNU @w{Emacs 19}.
  Reportedly, large parts of it work with @w{MH 5} and also with
  Lucid/XEmacs and Epoch, but there are no guarantees.  It is also
--- 123,127 ----
  
  The mh-e package is distributed with GNU Emacs, @footnote{Note that mh-e
! is supported with MH 6 and either @w{Emacs 18} or @w{Emacs 19}.
  Reportedly, large parts of it work with @w{MH 5} and also with
  Lucid/XEmacs and Epoch, but there are no guarantees.  It is also
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/misc.texi emacs-19.33/man/misc.texi
*** emacs-19.32/man/misc.texi	Mon Jul 15 18:31:07 1996
--- emacs-19.33/man/misc.texi	Tue Aug  6 18:22:30 1996
*************** diversions and amusements.
*** 21,38 ****
  Gnus is an Emacs package primarily designed for reading and posting
  Usenet news.  It can also be used to read and respond to messages from a
! number of other sources -- mail, remote directories, digests, and so
! on. 
! 
! This section introduces Gnus and describes several basic features.
  
  @ifinfo
! @xref{Top, Gnus}.
  @end ifinfo
  @iftex
! For more information, run @kbd{M-x info} and select the Gnus
  manual.
  @end iftex
  
! @findex Gnus
  To start Gnus, type @kbd{M-x gnus @key{RET}}.
  
--- 21,36 ----
  Gnus is an Emacs package primarily designed for reading and posting
  Usenet news.  It can also be used to read and respond to messages from a
! number of other sources---mail, remote directories, digests, and so on.
  
+ Here we introduce Gnus and describe several basic features.
  @ifinfo
! For full details, see @ref{Top, Gnus,, gnus, The Gnus Manual}.
  @end ifinfo
  @iftex
! For full details on Gnus, type @kbd{M-x info} and then select the Gnus
  manual.
  @end iftex
  
! @findex gnus
  To start Gnus, type @kbd{M-x gnus @key{RET}}.
  
*************** a listing of all the groups.  Then type 
*** 81,85 ****
  subscription to groups.
  
! The first time you start Gnus, Gnus will subscribe you to a select few
  groups.  All other groups start out as @dfn{killed groups} for you; you
  can list them with @kbd{A k}.  All new groups that subsequently come to
--- 79,83 ----
  subscription to groups.
  
! The first time you start Gnus, Gnus subscribes you to a few selected
  groups.  All other groups start out as @dfn{killed groups} for you; you
  can list them with @kbd{A k}.  All new groups that subsequently come to
*************** buffer in its small window.
*** 108,114 ****
  @end enumerate
  
!   Each Gnus buffer has its own special commands, but commands that do
! the similar things have similar key bindings.  Here are commands for the
! group and summary buffers:
  
  @table @kbd
--- 106,112 ----
  @end enumerate
  
!   Each Gnus buffer has its own special commands; however, the meanings
! of any given key in the various Gnus buffers are usually analogous, even
! if not identical.  Here are commands for the group and summary buffers:
  
  @table @kbd
*************** an option starting with @samp{-}.  For e
*** 1026,1035 ****
  program to run; the default value depends on your operating system type.
  On most systems, the default is @code{"lpr"}.  The variable
! @code{lpr-headers-switches} similarly specifies the extra switches to use
! to make page headers.  The variable @code{lpr-add-switches} controls
  whether to supply @samp{-T} and @samp{-J} options (suitable for
! @code{lpr}) to the printer program: @code{nil} means don't do
! so.@code{lpr-add-switches} should be @code{nil} if your printer program
! is not like @code{lpr}.
  
  @node Postscript, Sorting, Hardcopy, Top
--- 1024,1033 ----
  program to run; the default value depends on your operating system type.
  On most systems, the default is @code{"lpr"}.  The variable
! @code{lpr-headers-switches} similarly specifies the extra switches to
! use to make page headers.  The variable @code{lpr-add-switches} controls
  whether to supply @samp{-T} and @samp{-J} options (suitable for
! @code{lpr}) to the printer program: @code{nil} means don't add them.
! @code{lpr-add-switches} should be @code{nil} if your printer program is
! not compatible with @code{lpr}.
  
  @node Postscript, Sorting, Hardcopy, Top
*************** buffer.
*** 1310,1315 ****
    There are three ways to enter two-column mode:
  
! @table @kbd
! @item f2 2  or  C-x 6 2
  @kindex f2 2
  @kindex C-x 6 2
--- 1308,1313 ----
    There are three ways to enter two-column mode:
  
! @table @asis
! @item @kbd{f2 2} or @kbd{C-x 6 2}
  @kindex f2 2
  @kindex C-x 6 2
*************** This command is appropriate when the cur
*** 1324,1328 ****
  just one column and you want to add another column.
  
! @item f2 s  or  C-x 6 s
  @kindex f2 s
  @kindex C-x 6 s
--- 1322,1326 ----
  just one column and you want to add another column.
  
! @item @kbd{f2 s} or @kbd{C-x 6 s}
  @kindex f2 s
  @kindex C-x 6 s
*************** This command is appropriate when you hav
*** 1338,1342 ****
  two-column text, and you wish to separate the columns temporarily.
  
! @item f2 b  or  C-x 6 b @var{buffer} @key{RET}
  @kindex f2 b
  @kindex C-x 6 b
--- 1336,1341 ----
  two-column text, and you wish to separate the columns temporarily.
  
! @item @kbd{f2 b @var{buffer} @key{RET}}
! @itemx @kbd{C-x 6 b @var{buffer} @key{RET}}
  @kindex f2 b
  @kindex C-x 6 b
*************** the previous Emacs session had.
*** 1458,1462 ****
  The first time you save the state of the Emacs session, you must do it
  manually, with the command @kbd{M-x desktop-save}.  Once you have done
! that, exiting Emacs will save the state again--not only the present
  Emacs session, but also subsequent sessions.  You can also save the
  state at any time, without exiting Emacs, by typing @kbd{M-x
--- 1457,1461 ----
  The first time you save the state of the Emacs session, you must do it
  manually, with the command @kbd{M-x desktop-save}.  Once you have done
! that, exiting Emacs will save the state again---not only the present
  Emacs session, but also subsequent sessions.  You can also save the
  state at any time, without exiting Emacs, by typing @kbd{M-x
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/msdog.texi emacs-19.33/man/msdog.texi
*** emacs-19.32/man/msdog.texi	Sat Jul  6 21:40:27 1996
--- emacs-19.33/man/msdog.texi	Sun Aug  4 03:41:44 1996
*************** instead, you get behavior much closer to
*** 19,23 ****
  of the manual, including support for long file names, multiple frames,
  scroll bars, mouse menus, and subprocesses.  However, the section on
! text files and binary files does still apply.
  
  @menu
--- 19,25 ----
  of the manual, including support for long file names, multiple frames,
  scroll bars, mouse menus, and subprocesses.  However, the section on
! text files and binary files does still apply.  There are also two
! sections at the end of this chapter which apply specifically for Windows
! NT and 95.
  
  @menu
*************** what colors and faces are available and 
*** 99,104 ****
  overlap, so you only see a single frame at any given moment.  That
  single visible frame occupies the entire screen.  When you run Emacs
! under MS-Windows 3.x, the visible frame can take less than the full 
! screen, but you still cannot see more than a single frame.
  
  @cindex frame size under MS-DOS
--- 101,107 ----
  overlap, so you only see a single frame at any given moment.  That
  single visible frame occupies the entire screen.  When you run Emacs
! under Windows version 3, you can make the visible frame smaller than
! the full screen, but Emacs still cannot display more than a single
! frame at a time.
  
  @cindex frame size under MS-DOS
*************** example, the name of a backup file for @
*** 178,189 ****
  @file{docs.tx~} even if single backup is used.
  
! @cindex file names under Win95 DOS box
! @cindex long filenames on MS-DOS under Win95
!   When Emacs runs as DOS application under Win95, it can support long
! filenames like other Win95 programs.  If long filenames are supported,
! Emacs doesn't truncate and doesn't change filenames you type, but uses
! them verbatim.  It also doesn't convert filenames to lower case.  To get
! long filename support, you should set @code{LFN} to @code{y} in the
! environment before starting Emacs.
  
  @cindex @code{HOME} directory under MS-DOS
--- 181,192 ----
  @file{docs.tx~} even if single backup is used.
  
! @cindex file names under Windows 95/NT
! @cindex long file names on MS-DOS under Windows 95/NT
!   If you run Emacs as a DOS application under Windows 95 or NT, you can
! turn on support for long file names.  If you do that, Emacs doesn't
! truncate file names or convert them to lower case; instead, it uses the
! file names that you specify, verbatim.  To enable long file name
! support, set the environment variable @code{LFN} to @samp{y} before
! starting Emacs.
  
  @cindex @code{HOME} directory under MS-DOS
*************** system.
*** 236,259 ****
  @section Printing and MS-DOS
  
- @vindex dos-printer
    Printing commands, such as @code{lpr-buffer} (@pxref{Hardcopy}) and
  @code{ps-print-buffer} (@pxref{Postscript}) can work in MS-DOS by
! sending the output to one of the printer ports, if Unix-style @code{lpr}
! program is is unavailable.  A few DOS-specific variables determine how
! this works.  If you want to use your local printer in the usual
! DOS-style printing, set the @code{dos-printer} variable to the name of
! the port to which your printer is connected, like @code{"LPT2"} or
! @code{"COM1"} (for serial printers); the default is @code{"PRN"}, the
! default local printer port.  You can set @code{dos-printer} to a name of
! the file, in which case the output will be appended to that file; or you
! can set it to @code{"NUL"} to make the printed output silently disappear
! into the great void.  If you set @code{dos-printer} to a name of a file,
! it's best to make its pathname absolute or relative to the Emacs home
! directory (like @file{"~/printed.dat"}).  That is because Emacs actually
! changes the working directory to the directory of the file you are
! editing, so if the name of the file in @code{dos-printer} is relative,
! you will end up with several such files, each one in the directory of
! the buffer from which the printing was done, which is probably not what
! you wanted.
  
  @findex print-buffer, under MS-DOS
--- 239,264 ----
  @section Printing and MS-DOS
  
    Printing commands, such as @code{lpr-buffer} (@pxref{Hardcopy}) and
  @code{ps-print-buffer} (@pxref{Postscript}) can work in MS-DOS by
! sending the output to one of the printer ports, if a Unix-style @code{lpr}
! program is unavailable.  A few DOS-specific variables control how this
! works.
! 
! @vindex dos-printer
!   If you want to use your local printer, printing on it in the usual DOS
! manner, then set the Lisp variable @code{dos-printer} to the name of the
! printer port---for example. @code{"PRN"}, the usual local printer port
! (that's the default), or @code{"LPT2"} or @code{"COM1"} for a serial
! printer.  You can also set @code{dos-printer} to a file name, in which
! case ``printed'' output is actually appended to that file.  If you set
! @code{dos-printer} to @code{"NUL"}, printed output is silently
! discarded.
! 
!   If you set @code{dos-printer} to a file name, it's best to use an
! absolute file name.  Emacs changes the working directory according to
! the default directory of the current buffer, so if the file name in
! @code{dos-printer} is relative, you will end up with several such files,
! each one in the directory of the buffer from which the printing was
! done.
  
  @findex print-buffer, under MS-DOS
*************** you wanted.
*** 262,274 ****
    The commands @code{print-buffer} and @code{print-region} call the
  @code{pr} program, or use special switches to the @code{lpr} program, to
! produce headers on each printed page.  MS-DOS doesn't have these programs
! usually, so by default, the variable @code{lpr-headers-switches} is set
! so that the requests to print page headers are silently ignored, and
! @code{print-buffer} and @code{print-region} produce the same output as
! @code{lpr-buffer} and @code{lpr-region}, respectively.  If you have a
! port of @code{pr} program (e.g., from GNU Textutils), set
! @code{lpr-headers-switches} to nil; Emacs will then call @code{pr} to
! produce the page headers, and will then write the output to the printer
! port named by @code{dos-printer}.
  
  @vindex print-region-function under MS-DOS
--- 267,279 ----
    The commands @code{print-buffer} and @code{print-region} call the
  @code{pr} program, or use special switches to the @code{lpr} program, to
! produce headers on each printed page.  MS-DOS doesn't normally have
! these programs, so by default, the variable @code{lpr-headers-switches}
! is set so that the requests to print page headers are silently ignored.
! Thus, @code{print-buffer} and @code{print-region} produce the same
! output as @code{lpr-buffer} and @code{lpr-region}, respectively.  If you
! do have a suitable @code{pr} program (e.g., from GNU Textutils), set
! @code{lpr-headers-switches} to @code{nil}; Emacs will then call
! @code{pr} to produce the page headers, and print the resulting output as
! specified by @code{dos-printer}.
  
  @vindex print-region-function under MS-DOS
*************** port named by @code{dos-printer}.
*** 277,284 ****
  @vindex lpr-switches, under MS-DOS
    Finally, if you do have an @code{lpr} work-alike, you can set
! @code{print-region-function} to nil.  This will cause Emacs to use
! @code{lpr} for printing, as it does under Unix.  (If the name of the
! program isn't @code{lpr}, you can set @code{lpr-command} variable and
! @code{lpr-switches} as appropriate.)
  
  @findex ps-print-buffer, under MS-DOS
--- 282,289 ----
  @vindex lpr-switches, under MS-DOS
    Finally, if you do have an @code{lpr} work-alike, you can set
! @code{print-region-function} to @code{nil}.  Then Emacs uses @code{lpr}
! for printing, as on other systems.  (If the name of the program isn't
! @code{lpr}, set the @code{lpr-command} variable to specify where to find
! it.)
  
  @findex ps-print-buffer, under MS-DOS
*************** program isn't @code{lpr}, you can set @c
*** 295,313 ****
    A separate variable, @code{dos-ps-printer}, defines how PostScript
  files should be printed.  If its value is a string, it is used as the
! name of the device (or a file) to which PostScript output is sent, like
  @code{dos-printer} is used for non-PostScript printing.  (These are two
! distinct variables because on MS-DOS, you might have two different
! printers attached to two different ports, only one of which is a
! PostScript printer.)  If @code{dos-ps-printer} is anything else but a
! string, Emacs will use the variables @code{ps-lpr-command} and
! @code{ps-lpr-switches} (@pxref{Postscript}) to print PostScript files.
! Thus, if you have a non-PostScript printer, you can set these variables
! to the name and the switches appropriate for a PostScript interpreter
! program (e.g., Ghostscript).  For example, to use Ghostscript for
! printing on an Epson printer connected to @code{"LPT2"} port, put this
! on your @file{.emacs} file:
  
  @example
! (setq dos-ps-printer t)  ; anything but a string
  (setq ps-lpr-command "c:/gs/gs386")
  (setq ps-lpr-switches '("-q" "-dNOPAUSE"
--- 300,319 ----
    A separate variable, @code{dos-ps-printer}, defines how PostScript
  files should be printed.  If its value is a string, it is used as the
! name of the device (or file) to which PostScript output is sent, just as
  @code{dos-printer} is used for non-PostScript printing.  (These are two
! distinct variables in case you have two printers attached to two
! different ports, and only one of them is a PostScript printer.)  If the
! value of @code{dos-ps-printer} is not a string, then the variables
! @code{ps-lpr-command} and @code{ps-lpr-switches} (@pxref{Postscript})
! control how to print PostScript files.  Thus, if you have a
! non-PostScript printer, you can set these variables to the name and the
! switches appropriate for a PostScript interpreter program (e.g.,
! Ghostscript).
! 
!   For example, to use Ghostscript for printing on an Epson printer
! connected to @samp{LPT2} port, put this on your @file{.emacs} file:
  
  @example
! (setq dos-ps-printer t)  ; @r{Anything but a string.}
  (setq ps-lpr-command "c:/gs/gs386")
  (setq ps-lpr-switches '("-q" "-dNOPAUSE"
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/programs.texi emacs-19.33/man/programs.texi
*** emacs-19.32/man/programs.texi	Fri Jun 28 05:27:33 1996
--- emacs-19.33/man/programs.texi	Thu Aug  8 17:09:18 1996
*************** on the screen.
*** 77,81 ****
  @cindex Tcl mode
    Emacs also has major modes for the programming languages Lisp, Scheme
! (a variant of Lisp), Awk, C, C++, Objective-C, Java, Fortran, Icon,
  Pascal, Perl and Tcl.  There is also a major mode for makefiles, called
  Makefile mode.
--- 77,81 ----
  @cindex Tcl mode
    Emacs also has major modes for the programming languages Lisp, Scheme
! (a variant of Lisp), Awk, C, C++, Fortran, Icon, Java, Objective-C,
  Pascal, Perl and Tcl.  There is also a major mode for makefiles, called
  Makefile mode.
*************** way, a @dfn{substatement} indicates the 
*** 662,671 ****
  statements.
  
    After a line has been analyzed syntactically for indentation, the
  global variable @code{c-syntactic-context} contains a list that
! describes the results.  Each element in this list is a cons cell
! containing a syntactic symbol and (optionally) its corresponding buffer
! position.  There may be more than one element in a component list, and
! syntactic symbols need not always have corresponding buffer positions.
  
  @node Indentation Calculation
--- 662,674 ----
  statements.
  
+ @cindex syntactic component
+ @cindex syntactic symbol
+ @vindex c-syntactic-context
    After a line has been analyzed syntactically for indentation, the
  global variable @code{c-syntactic-context} contains a list that
! describes the results.  Each element in this list is a a @dfn{syntactic
! component}: a cons cell containing a syntactic symbol and (optionally)
! its corresponding buffer position.  There may be several elements in a
! component list; typically only one element has a buffer position.
  
  @node Indentation Calculation
*************** syntactic symbols need not always have c
*** 674,690 ****
  
    The C indentation mechanism calculates the indentation for the current
! line using the list of syntactic components derived from syntactic
! analysis.  Each component contributes to the final total indentation of
! the line in two ways.
! 
!   First, it looks up the syntactic symbol in the @code{c-offsets-alist}
! variable, which is an association list of syntactic symbols and the
! offsets to apply for those symbols.  It then adds the offset
! corresponding to the syntactic symbol to the running total.@refill
! 
!   Second, if the component has a relative buffer position, it adds the
! column number of that position to the running total.  It computes the
! final total indentation for the current line by summing up the offsets
! and columns for each syntactic component on that line.
  
    The following examples demonstrate the workings of the C indentation
--- 677,693 ----
  
    The C indentation mechanism calculates the indentation for the current
! line using the list of syntactic components, @code{c-syntactic-context},
! derived from syntactic analysis.  Each component is a cons cell that
! contains a syntactic symbol and may also contain a pointer to a location
! in the buffer.
! 
!   Each component contributes to the final total indentation of the line
! in two ways.  First, the syntactic symbol identifies an element of
! @code{c-offsets-alist}, which is an association list mapping syntactic
! symbols into indentation offsets.  Each syntactic symbol's offset adds
! to the total indentation.  Second, if the component includes a buffer
! position, the column number of that position adds to the indentation.
! All these offsets and column numbers, added together, give the total
! indentation.
  
    The following examples demonstrate the workings of the C indentation
*************** mechanism:
*** 700,705 ****
  @end example
  
!   Suppose that the point is on line 3 and you type @key{TAB} to reindent
! the line.  Remember that the syntactic component list for that line is:
  
  @example
--- 703,709 ----
  @end example
  
!   Suppose that point is on line 3 and you type @key{TAB} to reindent the
! line.  As explained above (@pxref{Syntactic Analysis}), the syntactic
! component list for that line is:
  
  @example
*************** the line.  Remember that the syntactic c
*** 707,720 ****
  @end example
  
!   So first the indentation engine is going to look up
! @code{defun-block-intro} in the @code{c-offsets-alist} variable.
! Suppose that it finds the integer 2; it adds this to the running total
! (initialized to zero), yielding a running total indentation of 2
! spaces.
! 
!   Next, it goes to buffer position 28 and asks for the current column.
! Since the brace at buffer position 28 is in column zero, it adds 0 to
! the running total, and since there is only one syntactic component on
! the list for this line, the total indentation for the line is 2 spaces.
  
  @example
--- 711,723 ----
  @end example
  
!   In this case, the indentation calculation first looks up
! @code{defun-block-intro} in the @code{c-offsets-alist} alist.  Suppose
! that it finds the integer 2; it adds this to the running total
! (initialized to zero), yielding a updated total indentation of 2 spaces.
! 
!   The next step is to find the column number of buffer position 28.
! Since the brace at buffer position 28 is in column zero, this adds 0 to
! the running total.  Since this line has only one syntactic component,
! the total indentation for the line is 2 spaces.
  
  @example
*************** the list for this line, the total indent
*** 729,748 ****
  @end example
  
!   If you type @key{TAB} on line 4 in the example above, the same basic
! process is performed, despite the differences in the syntactic component
! list.  Remember that the list for this line is:
  
- @c ??? Check this
  @example
  ((substatement-open . 43))
  @end example
  
!    Here, the indentation engine first looks up the
! @code{substatement-open} symbol in @code{c-offsets-alist}.  We assume
! the offset for this symbol is 2.  At this point the running total is 2
! (0 + 2 = 2).  It then goes to buffer position 43, which is the @samp{i}
! in @code{if} on line 3.  This character is in the second column on that
! line, so adding this to the running total yields a total indentation of
! 4 spaces.@refill
  
  @vindex c-strict-syntax-p
--- 732,749 ----
  @end example
  
!   If you type @key{TAB} on line 4, the same process is performed, but
! with different data.  The syntactic component list for this line is:
  
  @example
  ((substatement-open . 43))
  @end example
  
!    Here, the indentation calculation's first job is to look up the
! symbol @code{substatement-open} in @code{c-offsets-alist}.  Let's assume
! that the offset for this symbol is 2.  At this point the running total
! is 2 (0 + 2 = 2).  Then it adds the column number of buffer position 43,
! which is the @samp{i} in @code{if} on line 3.  This character is in
! column 2 on that line.  Adding this yields a total indentation of 4
! spaces.
  
  @vindex c-strict-syntax-p
*************** new indentation offset.
*** 772,780 ****
  @end table
  
!    The @code{c-offsets-alist} variable controls the amount of indentation
! to give to each syntactic component.  Its value is an association list,
! and each element of the list has the form @code{(@var{syntactic-symbol}
! . @var{offset})}.  By changing the offsets for various syntactic
! components, you can customize indentation in fine detail.
  
     Each offset value in @code{c-offsets-alist} can be an integer, a
--- 773,782 ----
  @end table
  
!    The @code{c-offsets-alist} variable controls the amount of
! indentation to give to each syntactic symbol.  Its value is an
! association list, and each element of the list has the form
! @code{(@var{syntactic-symbol} . @var{offset})}.  By changing the offsets
! for various syntactic symbols, you can customize indentation in fine
! detail.
  
     Each offset value in @code{c-offsets-alist} can be an integer, a
*************** function or variable name, or one of the
*** 782,791 ****
  @code{-}, @code{++}, or @code{--}, indicating positive or negative
  multiples of the variable @code{c-basic-offset}.  Thus, if you want to
! change the levels of indentation to be 3 spaces instead of 2 spaces, you
! can probably get this result by setting @code{c-basic-offset} to 3.
  
     Using a function as the offset value provides the ultimate flexibility
  in customizing indentation.  The function is called with a single
! argument containing the @code{cons} of the syntactic element symbol and
  the relative indent point.  The function should return an integer
  offset.
--- 784,793 ----
  @code{-}, @code{++}, or @code{--}, indicating positive or negative
  multiples of the variable @code{c-basic-offset}.  Thus, if you want to
! change the levels of indentation to be 3 spaces instead of 2 spaces, set
! @code{c-basic-offset} to 3.
  
     Using a function as the offset value provides the ultimate flexibility
  in customizing indentation.  The function is called with a single
! argument containing the @code{cons} of the syntactic symbol and
  the relative indent point.  The function should return an integer
  offset.
*************** Symbols}, for a list of valid syntactic 
*** 799,810 ****
  
     The variable @code{c-offsets-alist-default} holds the default settings
! for offsets of syntactic elements.  @emph{Do not change this value!}
  
  @node Syntactic Symbols
  @subsubsection Syntactic Symbols
  
!    Here is the list of valid syntactic element symbols for C mode
! indentation.  Normally most of these symbols are assigned offsets in
! @code{c-offsets-alist}.
  
  @table @code
--- 801,812 ----
  
     The variable @code{c-offsets-alist-default} holds the default settings
! for the offsets of the syntactic symbols.  @emph{Do not change this value!}
  
  @node Syntactic Symbols
  @subsubsection Syntactic Symbols
  
!    Here is a table of valid syntactic symbols for C mode
! indentation, with their syntactic meanings.  Normally, most of these
! symbols are assigned offsets in @code{c-offsets-alist}.
  
  @table @code
*************** On the first line after an @code{if}, @c
*** 903,907 ****
  
  @item substatement-open
! On the brace that opens a @var{substatement} block.
  
  @item case-label
--- 905,909 ----
  
  @item substatement-open
! On the brace that opens a substatement block.
  
  @item case-label
*************** indentation behavior of C mode and relat
*** 968,977 ****
  @item c-offsets-alist
  @vindex c-offsets-alist
! Association list of syntactic element symbols and their indentation
  offsets.  @xref{Changing Indent Style}, for details.
  
  @item c-offsets-alist-default
  @vindex c-offsets-alist-default
! Default settings for offsets of syntactic elements.  @xref{Changing
  Indent Style}.
  
--- 970,979 ----
  @item c-offsets-alist
  @vindex c-offsets-alist
! Association list of syntactic symbols and their indentation
  offsets.  @xref{Changing Indent Style}, for details.
  
  @item c-offsets-alist-default
  @vindex c-offsets-alist-default
! Default settings for the offsets of the syntactic symbols.  @xref{Changing
  Indent Style}.
  
*************** default in C mode and Objective C mode.
*** 998,1003 ****
  @item c-special-indent-hook
  @vindex c-special-indent-hook
! Hook for user-defined special indentation adjustments.  This hook gets
! called after a line is indented by the mode.
  @end table
  
--- 1000,1005 ----
  @item c-special-indent-hook
  @vindex c-special-indent-hook
! Hook for user-defined special indentation adjustments.  This hook is
! called after a line is indented by C mode and related modes.
  @end table
  
*************** files fully.  Emacs can't do anything el
*** 2332,2336 ****
  Perhaps in the future someone will change Emerge to do the comparison in
  the background when the input files are large---then you could keep on
! doing other things with Emacs until Emerge gets ready to accept
  commands.
  
--- 2334,2338 ----
  Perhaps in the future someone will change Emerge to do the comparison in
  the background when the input files are large---then you could keep on
! doing other things with Emacs until Emerge is ready to accept
  commands.
  
*************** Objective-C and Java modes.
*** 2364,2368 ****
  Move point back to the containing preprocessor conditional, leaving the
  mark behind.  A prefix argument acts as a repeat count.  With a negative
! argument, move the point forward to the end of the containing
  preprocessor conditional.  When going backwards, @code{#elif} is treated
  like @code{#else} followed by @code{#if}.  When going forwards,
--- 2366,2370 ----
  Move point back to the containing preprocessor conditional, leaving the
  mark behind.  A prefix argument acts as a repeat count.  With a negative
! argument, move point forward to the end of the containing
  preprocessor conditional.  When going backwards, @code{#elif} is treated
  like @code{#else} followed by @code{#if}.  When going forwards,
*************** argument, move backward.
*** 2387,2391 ****
  @findex c-beginning-of-statement
  Move point to the beginning of the innermost C statement.  If point is
! already at the beginning of a statement, it moves to the beginning of
  the preceding statement.  With prefix argument @var{n}, move back
  @var{n} @minus{} 1 statements.
--- 2389,2393 ----
  @findex c-beginning-of-statement
  Move point to the beginning of the innermost C statement.  If point is
! already at the beginning of a statement, move to the beginning of
  the preceding statement.  With prefix argument @var{n}, move back
  @var{n} @minus{} 1 statements.
*************** style of NamingSymbolsWithMixedCaseAndNo
*** 2422,2428 ****
  begins a section or word.
  
  @item M-x c-forward-into-nomenclature
  @findex c-forward-into-nomenclature
! Move the point forward to end of a C++ nomenclature section or word.
  With prefix argument @var{n}, move @var{n} times.
  @end table
--- 2424,2433 ----
  begins a section or word.
  
+ In the GNU project, we recommend using underscores to separate words
+ within an identifier in C or C++, rather than using case distinctions.
+ 
  @item M-x c-forward-into-nomenclature
  @findex c-forward-into-nomenclature
! Move point forward to end of a C++ nomenclature section or word.
  With prefix argument @var{n}, move @var{n} times.
  @end table
*************** command @kbd{C-c C-a}:
*** 2449,2453 ****
  @kindex C-c C-a @r{(C mode)}
  @findex c-toggle-auto-state
! Toggle the auto-newline feature (@code{c-toggle-auto-state}.  With a
  prefix argument, this command turns the auto-newline feature on if the
  argument is positive, and off if it is negative.
--- 2454,2458 ----
  @kindex C-c C-a @r{(C mode)}
  @findex c-toggle-auto-state
! Toggle the auto-newline feature (@code{c-toggle-auto-state}).  With a
  prefix argument, this command turns the auto-newline feature on if the
  argument is positive, and off if it is negative.
*************** with elements of the following form: @co
*** 2479,2488 ****
  @code{c-offsets-alist} are meaningful here as well.
  
!    The list @var{nl-list} may contain either of the symbols @code{before}
! or @code{after}, or both; or it may be @code{nil}.  When a brace is
! inserted, the syntactic context it defines is looked up in
  @code{c-hanging-braces-alist}; if it is found, the @var{nl-list} is used
! to determine where newlines are inserted.  If not found, the default is
! to insert a newline both before and after braces.
  
     The variable @code{c-hanging-colons-alist} controls the insertion of
--- 2484,2494 ----
  @code{c-offsets-alist} are meaningful here as well.
  
!    The list @var{nl-list} may contain either of the symbols
! @code{before} or @code{after}, or both; or it may be @code{nil}.  When a
! brace is inserted, the syntactic context it defines is looked up in
  @code{c-hanging-braces-alist}; if it is found, the @var{nl-list} is used
! to determine where newlines are inserted: either before the brace,
! after, or both.  If not found, the default is to insert a newline both
! before and after braces.
  
     The variable @code{c-hanging-colons-alist} controls the insertion of
*************** with elements of the following form: @co
*** 2492,2499 ****
  symbols @code{before} or @code{after}, or both; or it may be @code{nil}.
  
!    When a colon is inserted, the language element that it defines is
! looked up in this list, and if found, the @var{nl-list} is used to
! determine where newlines are inserted.  If the language element for the
! colon is not found in this list, no newlines are inserted.
  
     Electric characters can also delete newlines automatically when the
--- 2498,2506 ----
  symbols @code{before} or @code{after}, or both; or it may be @code{nil}.
  
!    When a colon is inserted, the syntactic symbol it defines is looked
! up in this list, and if found, the @var{nl-list} is used to determine
! where newlines are inserted: either before the brace, after, or both.
! If the syntactic symbol is not found in this list, no newlines are
! inserted.
  
     Electric characters can also delete newlines automatically when the
*************** To turn this feature on or off, use @kbd
*** 2546,2550 ****
  @kindex C-c C-d
  @findex c-toggle-hungry-state
! Toggle the hungry-delete feature (@code{c-toggle-hungry-state}.  With a
  prefix argument, this command turns the hungry-delete feature on if the
  argument is positive, and off if it is negative.
--- 2553,2557 ----
  @kindex C-c C-d
  @findex c-toggle-hungry-state
! Toggle the hungry-delete feature (@code{c-toggle-hungry-state}).  With a
  prefix argument, this command turns the hungry-delete feature on if the
  argument is positive, and off if it is negative.
*************** argument is positive, and off if it is n
*** 2554,2561 ****
  @findex c-toggle-auto-hungry-state
  Toggle the auto-newline and hungry-delete features, both at once
! (@code{c-toggle-auto-hungry-state}.
  @end table
  
- @vindex c-delete-function
  @vindex c-hungry-delete-key
     The variable @code{c-hungry-delete-key} controls whether the
--- 2561,2567 ----
  @findex c-toggle-auto-hungry-state
  Toggle the auto-newline and hungry-delete features, both at once
! (@code{c-toggle-auto-hungry-state}).
  @end table
  
  @vindex c-hungry-delete-key
     The variable @code{c-hungry-delete-key} controls whether the
*************** output from this part isn't shown.
*** 2593,2597 ****
  When you are debugging C code that uses macros, sometimes it is hard to
  figure out precisely how the macros expand.  With this command, you
! don't have to figure it out; you can see the results.
  
  @item C-c C-\
--- 2599,2603 ----
  When you are debugging C code that uses macros, sometimes it is hard to
  figure out precisely how the macros expand.  With this command, you
! don't have to figure it out; you can see the expansions.
  
  @item C-c C-\
*************** This variable specifies how to reindent 
*** 2637,2647 ****
  support five styles of block comments:
  
! @example
!  style 1:    style 2 (GNU):    style 3:     style 4:     style 5:
!  /*          /* Blah           /*           /*           /*
!     blah        blah.  */       * blah      ** blah      blah
!     blah                        * blah      ** blah      blah
!     */                          */          */           */
! @end example
  
  @noindent
--- 2643,2653 ----
  support five styles of block comments:
  
! @smallexample
!  style 1:    style 2 (GNU):   style 3:    style 4:    style 5:
!  /*          /* Blah          /*          /*          /*
!     blah        blah.  */      * blah     ** blah     blah
!     blah                       * blah     ** blah     blah
!     */                         */         */          */
! @end smallexample
  
  @noindent
*************** For the styles 1 through 4, @code{c-bloc
*** 2652,2655 ****
--- 2658,2662 ----
  This variable has no effect on the indentation of the comment-start
  itself or on insertion of asterisks when auto-filling C comments.
+ It does not affect @kbd{M-q} either.
  @c ???   In any case, you still have to insert the asterisks
  @c ???   manually.
*************** Just an integer as value is equivalent t
*** 2667,2672 ****
  @item c-comment-start-regexp
  @vindex c-comment-start-regexp
! This buffer-local variable specifies how comments begin.
! @c ???
  
  @item c-hanging-comment-ender-p
--- 2674,2678 ----
  @item c-comment-start-regexp
  @vindex c-comment-start-regexp
! This buffer-local variable specifies how to recognize the start of a comment.
  
  @item c-hanging-comment-ender-p
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/screen.texi emacs-19.33/man/screen.texi
*** emacs-19.32/man/screen.texi	Thu Dec 21 01:13:15 1995
--- emacs-19.33/man/screen.texi	Sun Aug  4 15:28:57 1996
*************** add @samp{done} at the end when they are
*** 140,146 ****
  @ref{Buffers}, for more information about them.)  If you miss a message
  that appears briefly on the screen, you can switch to the
! @samp{*Messages*} buffer to see it again.  Garbage collection messages
! are omitted from @samp{*Messages*}, and successive progress messages are
! often collapsed into one.
  
  @vindex message-log-max
--- 140,145 ----
  @ref{Buffers}, for more information about them.)  If you miss a message
  that appears briefly on the screen, you can switch to the
! @samp{*Messages*} buffer to see it again.  Successive progress messages
! are often collapsed into one.
  
  @vindex message-log-max
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/trouble.texi emacs-19.33/man/trouble.texi
*** emacs-19.32/man/trouble.texi	Fri Jun 28 05:19:20 1996
--- emacs-19.33/man/trouble.texi	Sun Aug  4 15:48:31 1996
*************** point to the one you choose, and type @k
*** 256,260 ****
  
    Then @code{recover-session} asks about each of the files that you were
! editing during that session.  It asks whether to recover each file.  If
  you answer @kbd{y} for a file, it shows the dates of that file and its
  auto-save file, then asks once again whether to recover that file.  For
--- 256,260 ----
  
    Then @code{recover-session} asks about each of the files that you were
! editing during that session; it asks whether to recover that file.  If
  you answer @kbd{y} for a file, it shows the dates of that file and its
  auto-save file, then asks once again whether to recover that file.  For
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/man/viper.texi emacs-19.33/man/viper.texi
*** emacs-19.32/man/viper.texi	Fri Jun 21 22:55:59 1996
--- emacs-19.33/man/viper.texi	Wed Aug  7 13:59:45 1996
***************
*** 12,16 ****
  @titlepage
  @title Viper Is a Package for Emacs Rebels
! @subtitle a Vi emulator for GNU Emacs 19 and XEmacs 19
  @subtitle June 1996, Viper Version 2.90
  
--- 12,16 ----
  @titlepage
  @title Viper Is a Package for Emacs Rebels
! @subtitle a Vi emulator for GNU Emacs
  @subtitle June 1996, Viper Version 2.90
  
*************** and/or a venomous VI PERil.
*** 61,65 ****
  @end example
  
! Technically speaking, Viper is a Vi emulation package for GNU Emacs 19 and
  XEmacs 19. Because of its reliance on minor mode keymaps, Viper will not
  work under Emacs 18. Viper implements most Vi and Ex commands. It gives you
--- 61,65 ----
  @end example
  
! Technically speaking, Viper is a Vi emulation package for Emacs 19 and
  XEmacs 19. Because of its reliance on minor mode keymaps, Viper will not
  work under Emacs 18. Viper implements most Vi and Ex commands. It gives you
*************** and/or a venomous VI PERil.
*** 117,121 ****
  @end example
  
! Technically speaking, Viper is a Vi emulation package for GNU Emacs 19 and
  XEmacs 19. Because of its reliance on minor mode keymaps,
  it will not work under Emacs 18. Viper contains virtually all of
--- 117,121 ----
  @end example
  
! Technically speaking, Viper is a Vi emulation package for Emacs 19 and
  XEmacs 19. Because of its reliance on minor mode keymaps,
  it will not work under Emacs 18. Viper contains virtually all of
*************** Emacs can edit several files at once. A 
*** 190,194 ****
  for other purposes, such as shell interfaces, directory editing, etc.
  @xref{Dired,,Directory Editor,emacs,The
! Gnu Emacs Manual}, for an example.@refill
  
  A buffer has a distinguished position called the @dfn{point}.
--- 190,194 ----
  for other purposes, such as shell interfaces, directory editing, etc.
  @xref{Dired,,Directory Editor,emacs,The
! GNU Emacs Manual}, for an example.@refill
  
  A buffer has a distinguished position called the @dfn{point}.
*************** Changes to @code{vip-syntax-preference} 
*** 1255,1258 ****
--- 1255,1259 ----
  various major modes. Furthermore, for these changes to take effect, you
  should execute @code{(vip-update-alphanumeric-class)} right after changing
+ the value of @code{vip-syntax-preference}.
  
  The above discussion of the meaning of Viper's words concerns only Viper's
*************** The Gnu Emacs Manual}, for more informat
*** 2453,2457 ****
  The following two commands are normally bound to a mouse click and are part
  of Viper. They work only if Emacs runs as an application under X
! Windows (or under some other window system for which a port of GNU Emacs 19
  is available). Clicking the mouse when Emacs is invoked in an Xterm window
  (using @code{emacs -nw}) will do no good.
--- 2454,2458 ----
  The following two commands are normally bound to a mouse click and are part
  of Viper. They work only if Emacs runs as an application under X
! Windows (or under some other window system for which a port of Emacs 19
  is available). Clicking the mouse when Emacs is invoked in an Xterm window
  (using @code{emacs -nw}) will do no good.
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/msdos/ChangeLog emacs-19.33/msdos/ChangeLog
*** emacs-19.32/msdos/ChangeLog	Thu Aug  1 01:11:38 1996
--- emacs-19.33/msdos/ChangeLog	Sun Aug 11 03:39:37 1996
***************
*** 1,5 ****
--- 1,15 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
+ Sun Aug  4 02:14:33 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* is_exec.c: Renamed from is-exec.c.
+ 
  Sat Jul 27 00:14:21 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
  	* Version 19.32 released.
+ 
+ 	* is-exec.c, sigaction.c: New files.
  
  Wed Jul 24 11:04:24 1996  Eli Zaretskii  <eliz@is.elta.co.il>
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/msdos/is_exec.c emacs-19.33/msdos/is_exec.c
*** emacs-19.32/msdos/is_exec.c	Wed Dec 31 19:00:00 1969
--- emacs-19.33/msdos/is_exec.c	Thu Aug  1 16:12:03 1996
***************
*** 0 ****
--- 1,222 ----
+ /* Copyright (C) 1995 DJ Delorie, see COPYING.DJ for details */
+ /* IS_EXEC.C
+  *
+  * Given a filename or a file handle, and the extension of the file,
+  * determine if the file is executable.
+  * First, the file extension is checked in case it uniquely identifies
+  * the file as either an executable or not.  Failing this, the first
+  * two bytes of the file are tested for known signatures of executable
+  * files.
+  *
+  * Copyright (c) 1994 Eli Zaretskii <eliz@is.elta.co.il>
+  *
+  * This software may be used freely so long as this copyright notice is
+  * left intact.  There is no warranty on this software.
+  *
+  */
+ 
+ #include <libc/stubs.h>
+ #include <stdio.h>
+ #include <string.h>
+ #include <ctype.h>
+ #include <errno.h>
+ #include <dpmi.h>
+ #include <go32.h>
+ #include <io.h>
+ #include <libc/farptrgs.h>
+ #include <libc/dosio.h>
+ 
+ extern unsigned short _djstat_flags;
+ unsigned short        _get_magic(const char *, int);
+ int                   _is_executable(const char *, int, const char *);
+ 
+ /*
+  * Read a MAGIC NUMBER from a given file.  These are the first
+  * two bytes of the file, if we look at them as an unsigned short. */
+ 
+ #define _STAT_EXEC_EXT      2   /* get execute bits from file extension? */
+ #define _STAT_EXEC_MAGIC    4   /* get execute bits from magic signature? */
+ 
+ unsigned short
+ _get_magic(const char *s, int fh)
+ {
+   __dpmi_regs          regs;
+   unsigned short       retval;
+   unsigned short       fpos_high = 0, fpos_low = 0;
+   int                  read_fail = 0;
+ 
+   /* If given a pathname, open the file. */
+   if (s)
+   {
+     int handle;
+     if((handle = _open(s,0)) == -1)
+       return 0;
+     regs.x.bx = handle;
+   }
+   /* Else file already open.  Remember its current file position
+      and move to beginning of file. */
+   else
+   {
+     regs.x.ax = 0x4201;		/* set pointer from current position */
+     regs.x.bx = fh;
+     regs.x.cx = regs.x.dx = 0;	/* move 0 bytes (i.e., stay put) */
+     __dpmi_int(0x21, &regs);
+     if (regs.x.flags & 1)
+     {
+       errno = __doserr_to_errno(regs.x.ax);
+       return 0;
+     }
+     fpos_high = regs.x.dx;	/* got current position */
+     fpos_low  = regs.x.ax;
+ 
+     regs.x.ax = 0x4200;		/* set pointer from the beginning of file */
+     regs.x.cx = regs.x.dx = 0;	/* move to beginning of file */
+     __dpmi_int(0x21, &regs);
+     if (regs.x.flags & 1)
+     {
+       errno = __doserr_to_errno(regs.x.ax);
+       return 0;
+     }
+   }
+   regs.x.ds = __tb_segment;
+   regs.x.dx = __tb_offset;
+ 
+   /* Read 2 bytes from the file. */
+   regs.x.ax = 0x3f00;
+   regs.x.cx = 2;
+   __dpmi_int(0x21, &regs);
+ 
+   /* We can either (1) succeed, (2) read less than 2 bytes,
+      or (3) fail to read at all.  */
+   if (regs.x.ax != 2)
+     read_fail = (regs.x.flags & 1) ? regs.x.ax : -1;
+ 
+   /* If called with filename, close the file. */
+   if (s)
+   {
+     regs.x.ax = 0x3e00;
+     __dpmi_int(0x21, &regs);
+     if (regs.x.flags & 1)
+       errno = __doserr_to_errno(regs.x.ax);
+   }
+   /* Else leave file pointer where we found it. */
+   else
+   {
+     regs.x.ax = 0x4200;		/* set pointer from the beginning of file */
+     regs.x.bx = fh;
+     regs.x.cx = fpos_high;
+     regs.x.dx = fpos_low;
+     __dpmi_int(0x21, &regs);
+     if (regs.x.flags & 1)
+     {
+       errno = __doserr_to_errno(regs.x.ax);
+       return 0;
+     }
+   }
+ 
+   if (read_fail == 0)
+     retval = _farpeekw(_dos_ds, __tb);
+   else
+   {
+     /* The file couldn't be read: assume non-executable.  If the file
+        *is* executable, but was passed as a file-handle, and the user
+        opened it in write-only mode, they lose...  */
+     retval = 0;
+     if (read_fail != -1)
+       errno = __doserr_to_errno(read_fail);
+   }
+ 
+   return retval;
+ }
+ 
+ /* A list of extensions which designate executable files.  These
+    are NOT tested for the magic number.  */
+ static char executables[] = "|EXE|COM|BAT|BTM|DLL|VXD|";
+ 
+ /* A list of extensions which belong to files known to NEVER be
+    executables.  These exist to minimize read()'ing files while
+    detecting executables by magic number.  You are welcome to
+    add to this list, but remember: only extensions which could
+    NEVER be present in executables should go here.  */
+ static char non_executables[] = "\
+ |A|A01|A02|A03|A04|A05|ADL|ARC|ARJ|ASC|ASM|AUX|AWK\
+ |BAS|BIB|BGI|BMP\
+ |C|CC|CFG|CGZ|CH3|CHR|CI|CLP|CMF|CPI|CPP|CXX\
+ |DAT|DBF|DIZ|DOC|DVI\
+ |E|EL|ELC\
+ |F77|FN3\
+ |GIF|GZ\
+ |H|HLP|HPP|HXX\
+ |ICO|IN|INC|INF|INI\
+ |JPG\
+ |L|LEX|LF|LIB|LOG|LST|LZH\
+ |M|MAK|MAP|MF|MID|MPG\
+ |O|OBJ\
+ |PAK|PAS|PBM|PCD|PCX|PDS|PIC|PIF|PN3|PRJ|PS\
+ |RAS|RGB|RLE\
+ |S|SND|SY3\
+ |TAR|TAZ|TEX|TGA|TGZ|TIF|TXH|TXI|TXT\
+ |VOC\
+ |WAV|WK1|WK3|WKB|WQ1|WQ3|WQ4|WQ5|WQ6|WQ!\
+ |XBM\
+ |Y\
+ |ZIP|ZOO|";
+ 
+ int
+ _is_executable(const char *filename, int fhandle, const char *extension)
+ {
+   if (!extension && filename)
+   {
+     const char *cp, *ep=0;
+     for (cp=filename; *cp; cp++)
+     {
+       if (*cp == '.')
+ 	ep = cp;
+       if (*cp == '/' || *cp == '\\' || *cp == ':')
+ 	ep = 0;
+     }
+     extension = ep;
+   }
+   if ((_djstat_flags & _STAT_EXEC_EXT) == 0
+       && extension
+       && *extension
+       && strlen(extension) <= ((extension[0]=='.') ? 4 : 3))
+     {
+       /* Search the list of extensions in executables[]. */
+       char tmp_buf[6], *tp = tmp_buf;
+ 
+       *tp++ = '|';
+       if (*extension == '.')
+ 	extension++;
+       while (*extension)
+ 	*tp++ = toupper (*extension++);
+       *tp++ = '|';
+       *tp = '\0';
+       if (strstr(non_executables, tmp_buf))
+         return 0;
+       else if (strstr(executables, tmp_buf))
+         return 1;
+     }
+ 
+   /* No extension, or extension doesn't define execute
+      bits unambiguously.  We are in for some dirty work.
+      Read the first two bytes of the file and see if they
+      are any of the known magic numbers which designate
+      executable files.
+      Unix-like shells, which have executable shell scripts
+      without extensions and DON'T have "#!" as their FIRST
+      TWO CHARACTERS, lose here.  Sorry, folks.  */
+   if ( (_djstat_flags & _STAT_EXEC_MAGIC) == 0 )
+     {
+       switch (_get_magic(filename, fhandle))
+         {
+           case 0x5a4d:      /* "MZ" */
+           case 0x010b:
+           case 0x014c:
+           case 0x2123:      /* "#!" */
+               return 1;
+         }
+     }
+ 
+   return 0;
+ }
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/msdos/sed1.inp emacs-19.33/msdos/sed1.inp
*** emacs-19.32/msdos/sed1.inp	Wed Apr 17 14:35:53 1996
--- emacs-19.33/msdos/sed1.inp	Mon Aug  5 17:27:56 1996
***************
*** 4,8 ****
  #
  # In case src/Makefile needs to rebuild `make-doc.exe' (might happen under
! # Win95), make sure it gets built with commands that DOS
  # understands (one command per line).
  s/^#.*//
--- 4,8 ----
  #
  # In case src/Makefile needs to rebuild `make-doc.exe' (might happen under
! # Windows 95), make sure it gets built with commands that DOS
  # understands (one command per line).
  s/^#.*//
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/msdos/sigaction.c emacs-19.33/msdos/sigaction.c
*** emacs-19.32/msdos/sigaction.c	Wed Dec 31 19:00:00 1969
--- emacs-19.33/msdos/sigaction.c	Thu Aug  1 16:12:14 1996
***************
*** 0 ****
--- 1,38 ----
+ /* Copyright (C) 1995 DJ Delorie, see COPYING.DJ for details */
+ #include <signal.h>
+ #include <errno.h>
+ 
+ int
+ sigaction(int _sig, const struct sigaction *_act, struct sigaction *_oact)
+ {
+   int retval = 0;
+ 
+   if (_oact)
+   {
+     void (*installed_sig)(int) = signal (_sig, SIG_IGN);
+ 
+     /* FIXME */
+     if (installed_sig == SIG_ERR)
+     {
+       retval = -1;
+       errno = EINVAL;
+     }
+     else
+       signal (_sig, installed_sig);
+     _oact->sa_handler = installed_sig;
+     retval = sigemptyset (&_oact->sa_mask);
+     _oact->sa_flags = 0;
+   }
+   if (_act)
+   {
+     if (signal (_sig, _act->sa_handler) == SIG_ERR)
+     {
+       retval = -1;
+       errno = EINVAL;
+     }
+   }
+   return 0;
+ }
+ 
+ 
+ 
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/nt/ChangeLog emacs-19.33/nt/ChangeLog
*** emacs-19.32/nt/ChangeLog	Thu Aug  1 01:11:25 1996
--- emacs-19.33/nt/ChangeLog	Sun Aug 11 03:40:00 1996
***************
*** 1,2 ****
--- 1,10 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
+ Fri Aug  9 10:55:29 1996  Geoff Voelker  <voelker@cs.washington.edu>
+ 
+ 	* runemacs.c (WinMain): Put a space between the binary and its args.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/nt/runemacs.c emacs-19.33/nt/runemacs.c
*** emacs-19.32/nt/runemacs.c	Mon Jun  3 11:44:27 1996
--- emacs-19.33/nt/runemacs.c	Fri Aug  9 14:40:01 1996
*************** WinMain (HINSTANCE hSelf, HINSTANCE hPre
*** 59,63 ****
      HANDLE fh;
      p = new_cmdline + strlen (new_cmdline);
!     strcpy (p, "\\emacs*.exe");
      fh = FindFirstFile (new_cmdline, &wfd);
      if (fh == INVALID_HANDLE_VALUE)
--- 59,63 ----
      HANDLE fh;
      p = new_cmdline + strlen (new_cmdline);
!     strcpy (p, "\\emacs*.exe ");
      fh = FindFirstFile (new_cmdline, &wfd);
      if (fh == INVALID_HANDLE_VALUE)
*************** WinMain (HINSTANCE hSelf, HINSTANCE hPre
*** 80,84 ****
    }
  #else
!   strcat (new_cmdline, "\\emacs.exe");
  #endif
  
--- 80,84 ----
    }
  #else
!   strcat (new_cmdline, "\\emacs.exe ");
  #endif
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/oldXMenu/ChangeLog emacs-19.33/oldXMenu/ChangeLog
*** emacs-19.32/oldXMenu/ChangeLog	Wed Jul 31 15:10:45 1996
--- emacs-19.33/oldXMenu/ChangeLog	Sun Aug 11 03:39:06 1996
***************
*** 1,2 ****
--- 1,6 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/ChangeLog emacs-19.33/src/ChangeLog
*** emacs-19.32/src/ChangeLog	Thu Aug  1 01:09:22 1996
--- emacs-19.33/src/ChangeLog	Sun Aug 11 03:38:11 1996
***************
*** 1,2 ****
--- 1,81 ----
+ Sun Aug 11 03:36:03 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* Version 19.33 released.
+ 
+ Sat Aug 10 19:40:45 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* s/sco5.h (POSIX_SIGNALS): Don't define it, #undef instead.
+ 	(NO_SOCKETS_IN_FILE_SYSTEM): Definition deleted.
+ 	(sigblock): New definition.
+ 
+ Sat Aug 10 14:53:42 1996  Marcus Daniels  <marcus@sayre.sysc.pdx.edu>
+ 
+ 	* m/sequent-ptx.h (LOAD_AVE_TYPE, FSCALE, LOAD_AVE_CVT):
+ 	Undef them before defining.
+ 
+ 	* s/ptx4.h: Fix include file name.
+  	(NO_FILIO_H): Move definition.
+ 
+ Fri Aug  9 18:04:00 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* m/alpha.h [__ELF__] (UNEXEC): Use unexelf1.c.
+ 
+ Fri Aug 9 13:57:53 1996 David Mosberger-Tang  <davidm@azstarnet.com>
+ 
+ 	* unexelf1.c: New file, copied from unexelf.c.
+ 	[__alpha__]: Include <sym.h> to get COFF debugging
+  	info declarations for .mdebug section.
+ 	[__GNU_LIBRARY__ - 0 >= 6]: Include <link.h>.
+ 	[notdef ElfW]: Define backwards compatible ElfW macro.
+ 	(unexec) [__alpha__]: Add code to update Alpha COFF symbol table
+  	(.mdebug section).
+ 	(unexec) [__alpha__]: Work around binutils-2.7 bug: for Alpha ELF
+  	sometimes unneeded data relocs do not get elided properly which
+  	results in reloc entries that contain all zeroes.
+ 
+ 	* m/alpha.h [__ELF__ && __GNUC__] (C_SWITCH_MACHINE): Add -fno-common.
+ 	(TEXT_START, DATA_START, DATA_SEG_BITS, UNEXEC): Define only if
+  	__ELF__ is not defined.
+ 	(LINUX_SBRK_BUG): Define only if LINUX and __GNU_LIBRARY__ < 6.
+ 	(NO_TERMIO): Always define this.  No Alpha system should need
+  	termio.
+ 	(COFF, DATA_END): Define only if __ELF__ is not defined.
+ 
+ Thu Aug  8 16:04:53 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* s/usg5-4.h: Don't include filio.h if NO_FILIO_H.
+ 
+ 	* s/ptx4.h: New file.
+ 
+ 	* config.in (GETTIMEOFDAY_ONE_ARGUMENT): Conditionalize on
+ 	HAVE_GETTIMEOFDAY.
+ 
+ Wed Aug  7 15:01:42 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* xmenu.c (xmenu_show): Set dummy.state.
+   	Set dummy.button appropriately.
+ 	(popup_get_selection) [USE_MOTIF]: Set event.xbutton.button.
+ 
+ 	* s/osf1.h (LD_SWITCH_SYSTEM): New definition.
+ 
+ Tue Aug  6 00:31:20 1996  Paul Eggert  <eggert@twinsun.com>
+ 
+ 	* editfns.c (set_time_zone_rule): Don't put a string literal
+ 	"TZ=..." in environ.
+ 
+ Mon Aug  5 00:31:20 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* minibuf.c (Fread_from_minibuffer): Make position 0 in the initial
+ 	input mean the beginning.
+ 
+ Sun Aug  4 17:56:02 1996  Eli Zaretskii  <eliz@is.elta.co.il>
+ 
+ 	* callproc.c (Fcall_process_region) [DOS_NT]: Avoid downcasing
+ 	the `X' characters in the template passed to `mktemp'.
+ 
+ Fri Aug  2 21:38:54 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
+ 
+ 	* widget.c (EmacsFrameSetCharSize): Call do_pending_window_change.
+ 
  Wed Jul 31 13:52:46 1996  Richard Stallman  <rms@psilocin.gnu.ai.mit.edu>
  
*************** Sun May 12 11:32:48 1996  Eli Zaretskii 
*** 891,895 ****
  
  	* dosfns.c (init_dosfns) [DJGPP >= 2]: Make `opendir' preserve
! 	filename case (under Win95) and find hidden files.
  
  	* msdos.c (Fmsdos_downcase_filename): Don't change the argument,
--- 970,974 ----
  
  	* dosfns.c (init_dosfns) [DJGPP >= 2]: Make `opendir' preserve
! 	filename case (under Windows 95) and find hidden files.
  
  	* msdos.c (Fmsdos_downcase_filename): Don't change the argument,
*************** Sat May 11 02:37:28 1996  Geoff Voelker 
*** 926,930 ****
  
  	* ntheap.c (allocate_heap): Bump heap base up to 27MB to
! 	satisfy Win95.
  
  Fri May 10 20:47:16 1996  Richard Stallman  <rms@delasyd.gnu.ai.mit.edu>
--- 1005,1009 ----
  
  	* ntheap.c (allocate_heap): Bump heap base up to 27MB to
! 	satisfy Windows 95.
  
  Fri May 10 20:47:16 1996  Richard Stallman  <rms@delasyd.gnu.ai.mit.edu>
*************** Fri May  3 14:30:22 1996  Andrw Innes <a
*** 1060,1065 ****
  	already non-inheritable).
  
! 	(get_emacs_configuration): Detect Windows flavour (Win95 or NT) at
! 	run-time.  Change OS name for Windows 95 to be "win95".
  
  	(fd_info): New variable. Array of extra info for file descriptors
--- 1139,1144 ----
  	already non-inheritable).
  
! 	(get_emacs_configuration): Detect Windows flavour (Windows 95 or
! 	NT) at run-time.  Change OS name for Windows 95 to be "win95".
  
  	(fd_info): New variable. Array of extra info for file descriptors
*************** Fri May  3 14:30:22 1996  Andrw Innes <a
*** 1136,1140 ****
  	(create_child): Add child_process and parent PID arguments.
  	Don't create input event or thread structures here.
! 	Fixup Win95 negative process IDs.
  	(register_child): Don't set consumed event; instead, set thread
  	status so that select will release it.
--- 1215,1219 ----
  	(create_child): Add child_process and parent PID arguments.
  	Don't create input event or thread structures here.
! 	Fixup Windows 95 negative process IDs.
  	(register_child): Don't set consumed event; instead, set thread
  	status so that select will release it.
*************** Sat Jan 20 19:18:03 1996  Geoff Voelker 
*** 2544,2548 ****
  
  	* ntterm.c (clear_frame): Use FillConsoleOutput* calls instead of
! 	ScrollConsoleScreenBuffer (which has a bug on Win95).
  
  	* ntinevt.c (WIN32_KEY_SHIFTED): Macro undefined.
--- 2623,2627 ----
  
  	* ntterm.c (clear_frame): Use FillConsoleOutput* calls instead of
! 	ScrollConsoleScreenBuffer (which has a bug on Windows 95).
  
  	* ntinevt.c (WIN32_KEY_SHIFTED): Macro undefined.
*************** Wed Nov 22 13:58:36 1995  Geoff Voelker 
*** 3311,3315 ****
  
  	* makefile.nt (DOC, clean): Don't use switches to del not supported
! 	by Win95.
  
  Wed Nov 22 07:35:25 1995  Richard Stallman  <rms@mole.gnu.ai.mit.edu>
--- 3390,3394 ----
  
  	* makefile.nt (DOC, clean): Don't use switches to del not supported
! 	by Windows 95.
  
  Wed Nov 22 07:35:25 1995  Richard Stallman  <rms@mole.gnu.ai.mit.edu>
*************** Mon Nov 6 15:52:37 1995  Kevin Gallo  <k
*** 3642,3646 ****
  	(LIBS, TEMACS): Use TLASTLIB.
  	(LIBS) [NTGUI]: Use TLIBW32 and GUI libs.
! 	(EMACS): Remove Win95 conditional.
  	(clean): Remove paths.h.
  
--- 3721,3725 ----
  	(LIBS, TEMACS): Use TLASTLIB.
  	(LIBS) [NTGUI]: Use TLIBW32 and GUI libs.
! 	(EMACS): Remove Windows 95 conditional.
  	(clean): Remove paths.h.
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/ChangeLog.5 emacs-19.33/src/ChangeLog.5
*** emacs-19.32/src/ChangeLog.5	Fri Jan  5 02:57:00 1996
--- emacs-19.33/src/ChangeLog.5	Mon Aug  5 17:29:22 1996
*************** Fri May 26 01:23:03 1995  Geoff Voelker 
*** 534,538 ****
  	(sbrk): Use allocate_heap.
  
! 	* ntterm.c (set_terminal_modes): Set cursor size appropriate for Win95.
  	(write_glyphs): Don't memset attrs, which is a word array.
  
--- 534,539 ----
  	(sbrk): Use allocate_heap.
  
! 	* ntterm.c (set_terminal_modes): Set cursor size appropriate for
! 	Windows 95.
  	(write_glyphs): Don't memset attrs, which is a word array.
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/callproc.c emacs-19.33/src/callproc.c
*** emacs-19.32/src/callproc.c	Sat Jul  6 15:49:32 1996
--- emacs-19.33/src/callproc.c	Sun Aug  4 21:15:03 1996
*************** If you quit, the process is killed with 
*** 651,654 ****
--- 651,658 ----
    if (!IS_DIRECTORY_SEP (tempfile[strlen (tempfile) - 1]))
      strcat (tempfile, "/");
+   if ('/' == DIRECTORY_SEP)
+     dostounix_filename (tempfile);
+   else
+     unixtodos_filename (tempfile);
  #ifdef WINDOWSNT
    strcat (tempfile, "emXXXXXX");
*************** If you quit, the process is killed with 
*** 656,663 ****
    strcat (tempfile, "detmp.XXX");
  #endif
-   if ('/' == DIRECTORY_SEP)
-     dostounix_filename (tempfile);
-   else
-     unixtodos_filename (tempfile);
  #else /* not DOS_NT */
  
--- 660,663 ----
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/config.in emacs-19.33/src/config.in
*** emacs-19.32/src/config.in	Sat Jul 20 14:05:18 1996
--- emacs-19.33/src/config.in	Mon Aug  5 17:20:10 1996
*************** Boston, MA 02111-1307, USA.  */
*** 136,140 ****
--- 136,145 ----
  
  #undef HAVE_GETTIMEOFDAY
+ /* If we don't have gettimeofday,
+    the test for GETTIMEOFDAY_ONE_ARGUMENT may succeed,
+    but we should ignore it.  */
+ #ifdef HAVE_GETTIMEOFDAY
  #undef GETTIMEOFDAY_ONE_ARGUMENT
+ #endif
  #undef HAVE_GETHOSTNAME
  #undef HAVE_DUP2
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/editfns.c emacs-19.33/src/editfns.c
*** emacs-19.32/src/editfns.c	Wed Jul 24 00:12:11 1996
--- emacs-19.33/src/editfns.c	Tue Aug  6 04:16:40 1996
*************** If TZ is nil, use implementation-defined
*** 937,940 ****
--- 937,951 ----
  }
  
+ /* These two values are known to load tz files in buggy implementations.
+    Their values shouldn't matter in non-buggy implementations.
+    We don't use string literals for these strings, 
+    since if a string in the environment is in readonly
+    storage, it runs afoul of bugs in SVR4 and Solaris 2.3.
+    See Sun bugs 1113095 and 1114114, ``Timezone routines
+    improperly modify environment''.  */
+ 
+ static char set_time_zone_rule_tz1[] = "TZ=GMT0";
+ static char set_time_zone_rule_tz2[] = "TZ=GMT1";
+ 
  /* Set the local time zone rule to TZSTRING.
     This allocates memory into `environ', which it is the caller's
*************** set_time_zone_rule (tzstring)
*** 987,995 ****
         The following code works around these bugs.  */
  
-     /* These two values are known to load tz files in buggy implementations.
-        Their values shouldn't matter in non-buggy implementations.  */
-     char *tz1 = "TZ=GMT0";
-     char *tz2 = "TZ=GMT1";
- 
      if (tzstring)
        {
--- 998,1001 ----
*************** set_time_zone_rule (tzstring)
*** 997,1001 ****
  	   and that differs from tzstring.  */
  	char *tz = *newenv;
! 	*newenv = strcmp (tzstring, tz1 + 3) == 0 ? tz2 : tz1;
  	tzset ();
  	*newenv = tz;
--- 1003,1008 ----
  	   and that differs from tzstring.  */
  	char *tz = *newenv;
! 	*newenv = (strcmp (tzstring, set_time_zone_rule_tz1 + 3) == 0
! 		   ? set_time_zone_rule_tz2 : set_time_zone_rule_tz1);
  	tzset ();
  	*newenv = tz;
*************** set_time_zone_rule (tzstring)
*** 1005,1012 ****
  	/* The implied tzstring is unknown, so temporarily set TZ to
  	   two different values that each load a tz file.  */
! 	*to = tz1;
  	to[1] = 0;
  	tzset ();
! 	*to = tz2;
  	tzset ();
  	*to = 0;
--- 1012,1019 ----
  	/* The implied tzstring is unknown, so temporarily set TZ to
  	   two different values that each load a tz file.  */
! 	*to = set_time_zone_rule_tz1;
  	to[1] = 0;
  	tzset ();
! 	*to = set_time_zone_rule_tz2;
  	tzset ();
  	*to = 0;
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/m/alpha.h emacs-19.33/src/m/alpha.h
*** emacs-19.32/src/m/alpha.h	Tue Jul 16 18:26:43 1996
--- emacs-19.33/src/m/alpha.h	Fri Aug  9 18:03:36 1996
*************** NOTE-END
*** 140,143 ****
--- 140,163 ----
  
  
+ #ifdef __ELF__
+ /* With ELF, make sure that all common symbols get allocated to in the
+    data section.  Otherwise, the dump of temacs may miss variables in
+    the shared library that have been initialized.  For example, with
+    GNU libc, __malloc_initialized would normally be resolved to the
+    shared library's .bss section, which is fatal.  */
+ # ifdef __GNUC__
+ #  define C_SWITCH_MACHINE	-fno-common
+ # else
+ #  error What gives?  Fix me if DEC Unix supports ELF now.
+ # endif
+ #endif
+ 
+ #ifdef __ELF__
+ #undef UNEXEC
+ #define UNEXEC unexelf1.o
+ #endif
+ 
+ #ifndef __ELF__
+ 
  /* Describe layout of the address space in an executing process.  */
  
*************** NOTE-END
*** 150,153 ****
--- 170,179 ----
  #define DATA_SEG_BITS 0x140000000
  
+ /* The program to be used for unexec. */
+ 
+ #define UNEXEC unexalpha.o
+ 
+ #endif /* notdef __ELF__ */
+ 
  #ifdef OSF1
  #define ORDINARY_LINK
*************** NOTE-END
*** 176,188 ****
  #endif
  
! #ifdef LINUX
  /* This controls a conditional in main.  */
  #define LINUX_SBRK_BUG
  #endif
  
- /* The program to be used for unexec. */
- 
- #define UNEXEC unexalpha.o
- 
  
  #define PNTR_COMPARISON_TYPE unsigned long
--- 202,210 ----
  #endif
  
! #if defined (LINUX) && __GNU_LIBRARY__ - 0 < 6
  /* This controls a conditional in main.  */
  #define LINUX_SBRK_BUG
  #endif
  
  
  #define PNTR_COMPARISON_TYPE unsigned long
*************** extern void r_alloc_free ();
*** 274,284 ****
  #endif
  
! #ifdef linux
! #define COFF
! /* Linux/Alpha doesn't like it if termio.h and termios.h get included
!    simultaneously.  */
  #define NO_TERMIO
  
! #define TEXT_END ({ extern int _etext; &_etext; })
! #define DATA_END ({ extern int _EDATA; &_EDATA; })
  #endif
--- 296,308 ----
  #endif
  
! /* On the Alpha it's best to avoid including TERMIO since struct
!    termio and struct termios are mutually incompatible.  */
  #define NO_TERMIO
  
! #ifdef LINUX
! # define TEXT_END ({ extern int _etext; &_etext; })
! # ifndef __ELF__
! #  define COFF
! #  define DATA_END ({ extern int _EDATA; &_EDATA; })
! # endif /* notdef __ELF__ */
  #endif
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/m/sequent-ptx.h emacs-19.33/src/m/sequent-ptx.h
*** emacs-19.32/src/m/sequent-ptx.h	Mon Jan 15 04:15:02 1996
--- emacs-19.33/src/m/sequent-ptx.h	Sat Aug 10 14:56:47 1996
*************** Boston, MA 02111-1307, USA.  */
*** 60,68 ****
--- 60,71 ----
  /* Data type of load average, as read out of kmem.  */
  
+ #undef LOAD_AVE_TYPE
  #define LOAD_AVE_TYPE unsigned long
  
  /* Convert that into an integer that is 100 for a load average of 1.0  */
  
+ #undef FSCALE
  #define	FSCALE	1000.0
+ #undef LOAD_AVE_CVT
  #define LOAD_AVE_CVT(x) (int) (((double) (x)) * 100.0 / FSCALE)
  
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/minibuf.c emacs-19.33/src/minibuf.c
*** emacs-19.32/src/minibuf.c	Mon Jun 10 17:03:57 1996
--- emacs-19.33/src/minibuf.c	Mon Aug  5 00:30:48 1996
*************** If optional second arg INITIAL-CONTENTS 
*** 494,498 ****
    to be inserted into the minibuffer before reading input.\n\
    If INITIAL-CONTENTS is (STRING . POSITION), the initial input\n\
!   is STRING, but point is placed POSITION characters into the string.\n\
  Third arg KEYMAP is a keymap to use whilst reading;\n\
    if omitted or nil, the default is `minibuffer-local-map'.\n\
--- 494,498 ----
    to be inserted into the minibuffer before reading input.\n\
    If INITIAL-CONTENTS is (STRING . POSITION), the initial input\n\
!   is STRING, but point is placed at position POSITION in the minibuffer.\n\
  Third arg KEYMAP is a keymap to use whilst reading;\n\
    if omitted or nil, the default is `minibuffer-local-map'.\n\
*************** DEFUN ("read-from-minibuffer", Fread_fro
*** 532,536 ****
  	  CHECK_NUMBER (position, 0);
  	  /* Convert to distance from end of input.  */
! 	  pos = XINT (position) - 1 - XSTRING (initial_contents)->size;
  	}
      }
--- 532,540 ----
  	  CHECK_NUMBER (position, 0);
  	  /* Convert to distance from end of input.  */
! 	  if (XINT (position) < 1)
! 	    /* A number too small means the beginning of the string.  */
! 	    pos =  - XSTRING (initial_contents)->size;
! 	  else
! 	    pos = XINT (position) - 1 - XSTRING (initial_contents)->size;
  	}
      }
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/regex.c emacs-19.33/src/regex.c
*** emacs-19.32/src/regex.c	Tue Jul  9 05:10:23 1996
--- emacs-19.33/src/regex.c	Fri Aug  9 06:44:20 1996
*************** static const char *re_error_msgid[] =
*** 1011,1015 ****
  /* 4400 was enough to cause a crash on Alpha OSF/1,
     whose default stack limit is 2mb.  */
! int re_max_failures = 4000;
  #else
  int re_max_failures = 2000;
--- 1011,1015 ----
  /* 4400 was enough to cause a crash on Alpha OSF/1,
     whose default stack limit is 2mb.  */
! int re_max_failures = 20000;
  #else
  int re_max_failures = 2000;
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/s/osf1.h emacs-19.33/src/s/osf1.h
*** emacs-19.32/src/s/osf1.h	Mon May 29 02:32:01 1995
--- emacs-19.33/src/s/osf1.h	Thu Aug  8 16:25:26 1996
***************
*** 28,29 ****
--- 28,34 ----
  
  #define COFF
+ 
+ /* Here is how to find X Windows.  LD_SWITCH_X_SITE_AUX gives an -R option
+    says where to find X windows at run time.  We convert it to a -rpath option
+    which is what OSF1 uses.  */
+ #define LD_SWITCH_SYSTEM `echo LD_SWITCH_X_SITE_AUX | sed -e 's/-R/-Wl,-rpath,/'`
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/s/ptx4.h emacs-19.33/src/s/ptx4.h
*** emacs-19.32/src/s/ptx4.h	Wed Dec 31 19:00:00 1969
--- emacs-19.33/src/s/ptx4.h	Sat Aug 10 14:52:14 1996
***************
*** 0 ****
--- 1,15 ----
+ /* s/ file for Sequent "ptx 4", which is a modified SVR5.4.  */
+ 
+ /* Tell usg5-4.h not to include filio.h.  */
+ #define NO_FILIO_H
+ 
+ #include "usg5-4.h"
+ 
+ /* Marcus Daniels <marcus@sysc.pdx.edu> says that SIGINFO is defined
+    on ptx4 but it is not a signal.  Prevent process.c from doing the
+    wrong thing.  */
+ #undef SIGINFO
+ 
+ /* Marcus Daniels <marcus@sysc.pdx.edu> says vfork does exist.  */
+ #define HAVE_VFORK
+ 
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/s/sco5.h emacs-19.33/src/s/sco5.h
*** emacs-19.32/src/s/sco5.h	Sat Jul 20 14:02:19 1996
--- emacs-19.33/src/s/sco5.h	Sat Aug 10 19:40:25 1996
*************** Boston, MA 02111-1307, USA.  */
*** 130,141 ****
  #define PREFER_VSUSP
  
! /* wjs@wang.com (William Smith) says this is needed on 3.2.4.2.  */
! #define POSIX_SIGNALS
! 
! /* wjs@wiis.wang.com says SCO 3.2 v4.2 "has sockets",
!    but only for network connections.
!    It doesn't have the kind of sockets that emacsclient.c
!    and emacsserver.c would use.  */
! #define NO_SOCKETS_IN_FILE_SYSTEM
  
  #ifndef PENDING_OUTPUT_COUNT
--- 130,137 ----
  #define PREFER_VSUSP
  
! /* SCO Unix has Posix signals, but in 3.2.5 something broken that causes
!  * all keyboard-quit signals to be lost after the first one. */
! #undef POSIX_SIGNALS
! #define sigblock(sig) (sigprocmask (SIG_BLOCK, SIGEMPTYMASK | sig, NULL))
  
  #ifndef PENDING_OUTPUT_COUNT
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/s/usg5-4.h emacs-19.33/src/s/usg5-4.h
*** emacs-19.32/src/s/usg5-4.h	Mon Jan 15 04:16:40 1996
--- emacs-19.33/src/s/usg5-4.h	Thu Aug  8 22:51:22 1996
*************** Boston, MA 02111-1307, USA.  */
*** 87,91 ****
--- 87,93 ----
  
  #ifdef emacs
+ #ifndef NO_FILIO_H
  #include <sys/filio.h>
+ #endif
  #include <termio.h>
  #include <sys/ttold.h>
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/unexelf1.c emacs-19.33/src/unexelf1.c
*** emacs-19.32/src/unexelf1.c	Wed Dec 31 19:00:00 1969
--- emacs-19.33/src/unexelf1.c	Fri Aug  9 17:56:52 1996
***************
*** 0 ****
--- 1,952 ----
+ /* Copyright (C) 1985, 1986, 1987, 1988, 1990, 1992
+    Free Software Foundation, Inc.
+ 
+ This file is part of GNU Emacs.
+ 
+ GNU Emacs is free software; you can redistribute it and/or modify
+ it under the terms of the GNU General Public License as published by
+ the Free Software Foundation; either version 2, or (at your option)
+ any later version.
+ 
+ GNU Emacs is distributed in the hope that it will be useful,
+ but WITHOUT ANY WARRANTY; without even the implied warranty of
+ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ GNU General Public License for more details.
+ 
+ You should have received a copy of the GNU General Public License
+ along with GNU Emacs; see the file COPYING.  If not, write to
+ the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ Boston, MA 02111-1307, USA.
+ 
+ In other words, you are welcome to use, share and improve this program.
+ You are forbidden to forbid anyone else to use, share and improve
+ what you give them.   Help stamp out software-hoarding!  */
+ 
+ 
+ /*
+  * unexec.c - Convert a running program into an a.out file.
+  *
+  * Author:	Spencer W. Thomas
+  * 		Computer Science Dept.
+  * 		University of Utah
+  * Date:	Tue Mar  2 1982
+  * Modified heavily since then.
+  *
+  * Synopsis:
+  *	unexec (new_name, a_name, data_start, bss_start, entry_address)
+  *	char *new_name, *a_name;
+  *	unsigned data_start, bss_start, entry_address;
+  *
+  * Takes a snapshot of the program and makes an a.out format file in the
+  * file named by the string argument new_name.
+  * If a_name is non-NULL, the symbol table will be taken from the given file.
+  * On some machines, an existing a_name file is required.
+  *
+  * The boundaries within the a.out file may be adjusted with the data_start
+  * and bss_start arguments.  Either or both may be given as 0 for defaults.
+  *
+  * Data_start gives the boundary between the text segment and the data
+  * segment of the program.  The text segment can contain shared, read-only
+  * program code and literal data, while the data segment is always unshared
+  * and unprotected.  Data_start gives the lowest unprotected address.
+  * The value you specify may be rounded down to a suitable boundary
+  * as required by the machine you are using.
+  *
+  * Specifying zero for data_start means the boundary between text and data
+  * should not be the same as when the program was loaded.
+  * If NO_REMAP is defined, the argument data_start is ignored and the
+  * segment boundaries are never changed.
+  *
+  * Bss_start indicates how much of the data segment is to be saved in the
+  * a.out file and restored when the program is executed.  It gives the lowest
+  * unsaved address, and is rounded up to a page boundary.  The default when 0
+  * is given assumes that the entire data segment is to be stored, including
+  * the previous data and bss as well as any additional storage allocated with
+  * break (2).
+  *
+  * The new file is set up to start at entry_address.
+  *
+  * If you make improvements I'd like to get them too.
+  * harpo!utah-cs!thomas, thomas@Utah-20
+  *
+  */
+ 
+ /* Even more heavily modified by james@bigtex.cactus.org of Dell Computer Co.
+  * ELF support added.
+  *
+  * Basic theory: the data space of the running process needs to be
+  * dumped to the output file.  Normally we would just enlarge the size
+  * of .data, scooting everything down.  But we can't do that in ELF,
+  * because there is often something between the .data space and the
+  * .bss space.
+  *
+  * In the temacs dump below, notice that the Global Offset Table
+  * (.got) and the Dynamic link data (.dynamic) come between .data1 and
+  * .bss.  It does not work to overlap .data with these fields.
+  *
+  * The solution is to create a new .data segment.  This segment is
+  * filled with data from the current process.  Since the contents of
+  * various sections refer to sections by index, the new .data segment
+  * is made the last in the table to avoid changing any existing index.
+ 
+  * This is an example of how the section headers are changed.  "Addr"
+  * is a process virtual address.  "Offset" is a file offset.
+ 
+ raid:/nfs/raid/src/dist-18.56/src> dump -h temacs
+ 
+ temacs:
+ 
+            **** SECTION HEADER TABLE ****
+ [No]    Type    Flags   Addr         Offset       Size          Name
+         Link    Info    Adralgn      Entsize
+ 
+ [1]     1       2       0x80480d4    0xd4         0x13          .interp
+         0       0       0x1          0
+ 
+ [2]     5       2       0x80480e8    0xe8         0x388         .hash
+         3       0       0x4          0x4
+ 
+ [3]     11      2       0x8048470    0x470        0x7f0         .dynsym
+         4       1       0x4          0x10
+ 
+ [4]     3       2       0x8048c60    0xc60        0x3ad         .dynstr
+         0       0       0x1          0
+ 
+ [5]     9       2       0x8049010    0x1010       0x338         .rel.plt
+         3       7       0x4          0x8
+ 
+ [6]     1       6       0x8049348    0x1348       0x3           .init
+         0       0       0x4          0
+ 
+ [7]     1       6       0x804934c    0x134c       0x680         .plt
+         0       0       0x4          0x4
+ 
+ [8]     1       6       0x80499cc    0x19cc       0x3c56f       .text
+         0       0       0x4          0
+ 
+ [9]     1       6       0x8085f3c    0x3df3c      0x3           .fini
+         0       0       0x4          0
+ 
+ [10]    1       2       0x8085f40    0x3df40      0x69c         .rodata
+         0       0       0x4          0
+ 
+ [11]    1       2       0x80865dc    0x3e5dc      0xd51         .rodata1
+         0       0       0x4          0
+ 
+ [12]    1       3       0x8088330    0x3f330      0x20afc       .data
+         0       0       0x4          0
+ 
+ [13]    1       3       0x80a8e2c    0x5fe2c      0x89d         .data1
+         0       0       0x4          0
+ 
+ [14]    1       3       0x80a96cc    0x606cc      0x1a8         .got
+         0       0       0x4          0x4
+ 
+ [15]    6       3       0x80a9874    0x60874      0x80          .dynamic
+         4       0       0x4          0x8
+ 
+ [16]    8       3       0x80a98f4    0x608f4      0x449c        .bss
+         0       0       0x4          0
+ 
+ [17]    2       0       0            0x608f4      0x9b90        .symtab
+         18      371     0x4          0x10
+ 
+ [18]    3       0       0            0x6a484      0x8526        .strtab
+         0       0       0x1          0
+ 
+ [19]    3       0       0            0x729aa      0x93          .shstrtab
+         0       0       0x1          0
+ 
+ [20]    1       0       0            0x72a3d      0x68b7        .comment
+         0       0       0x1          0
+ 
+ raid:/nfs/raid/src/dist-18.56/src> dump -h xemacs
+ 
+ xemacs:
+ 
+            **** SECTION HEADER TABLE ****
+ [No]    Type    Flags   Addr         Offset       Size          Name
+         Link    Info    Adralgn      Entsize
+ 
+ [1]     1       2       0x80480d4    0xd4         0x13          .interp
+         0       0       0x1          0
+ 
+ [2]     5       2       0x80480e8    0xe8         0x388         .hash
+         3       0       0x4          0x4
+ 
+ [3]     11      2       0x8048470    0x470        0x7f0         .dynsym
+         4       1       0x4          0x10
+ 
+ [4]     3       2       0x8048c60    0xc60        0x3ad         .dynstr
+         0       0       0x1          0
+ 
+ [5]     9       2       0x8049010    0x1010       0x338         .rel.plt
+         3       7       0x4          0x8
+ 
+ [6]     1       6       0x8049348    0x1348       0x3           .init
+         0       0       0x4          0
+ 
+ [7]     1       6       0x804934c    0x134c       0x680         .plt
+         0       0       0x4          0x4
+ 
+ [8]     1       6       0x80499cc    0x19cc       0x3c56f       .text
+         0       0       0x4          0
+ 
+ [9]     1       6       0x8085f3c    0x3df3c      0x3           .fini
+         0       0       0x4          0
+ 
+ [10]    1       2       0x8085f40    0x3df40      0x69c         .rodata
+         0       0       0x4          0
+ 
+ [11]    1       2       0x80865dc    0x3e5dc      0xd51         .rodata1
+         0       0       0x4          0
+ 
+ [12]    1       3       0x8088330    0x3f330      0x20afc       .data
+         0       0       0x4          0
+ 
+ [13]    1       3       0x80a8e2c    0x5fe2c      0x89d         .data1
+         0       0       0x4          0
+ 
+ [14]    1       3       0x80a96cc    0x606cc      0x1a8         .got
+         0       0       0x4          0x4
+ 
+ [15]    6       3       0x80a9874    0x60874      0x80          .dynamic
+         4       0       0x4          0x8
+ 
+ [16]    8       3       0x80c6800    0x7d800      0             .bss
+         0       0       0x4          0
+ 
+ [17]    2       0       0            0x7d800      0x9b90        .symtab
+         18      371     0x4          0x10
+ 
+ [18]    3       0       0            0x87390      0x8526        .strtab
+         0       0       0x1          0
+ 
+ [19]    3       0       0            0x8f8b6      0x93          .shstrtab
+         0       0       0x1          0
+ 
+ [20]    1       0       0            0x8f949      0x68b7        .comment
+         0       0       0x1          0
+ 
+ [21]    1       3       0x80a98f4    0x608f4      0x1cf0c       .data
+         0       0       0x4          0
+ 
+  * This is an example of how the file header is changed.  "Shoff" is
+  * the section header offset within the file.  Since that table is
+  * after the new .data section, it is moved.  "Shnum" is the number of
+  * sections, which we increment.
+  *
+  * "Phoff" is the file offset to the program header.  "Phentsize" and
+  * "Shentsz" are the program and section header entries sizes respectively.
+  * These can be larger than the apparent struct sizes.
+ 
+ raid:/nfs/raid/src/dist-18.56/src> dump -f temacs
+ 
+ temacs:
+ 
+                     **** ELF HEADER ****
+ Class        Data       Type         Machine     Version
+ Entry        Phoff      Shoff        Flags       Ehsize
+ Phentsize    Phnum      Shentsz      Shnum       Shstrndx
+ 
+ 1            1          2            3           1
+ 0x80499cc    0x34       0x792f4      0           0x34
+ 0x20         5          0x28         21          19
+ 
+ raid:/nfs/raid/src/dist-18.56/src> dump -f xemacs
+ 
+ xemacs:
+ 
+                     **** ELF HEADER ****
+ Class        Data       Type         Machine     Version
+ Entry        Phoff      Shoff        Flags       Ehsize
+ Phentsize    Phnum      Shentsz      Shnum       Shstrndx
+ 
+ 1            1          2            3           1
+ 0x80499cc    0x34       0x96200      0           0x34
+ 0x20         5          0x28         22          19
+ 
+  * These are the program headers.  "Offset" is the file offset to the
+  * segment.  "Vaddr" is the memory load address.  "Filesz" is the
+  * segment size as it appears in the file, and "Memsz" is the size in
+  * memory.  Below, the third segment is the code and the fourth is the
+  * data: the difference between Filesz and Memsz is .bss
+ 
+ raid:/nfs/raid/src/dist-18.56/src> dump -o temacs
+ 
+ temacs:
+  ***** PROGRAM EXECUTION HEADER *****
+ Type        Offset      Vaddr       Paddr
+ Filesz      Memsz       Flags       Align
+ 
+ 6           0x34        0x8048034   0
+ 0xa0        0xa0        5           0
+ 
+ 3           0xd4        0           0
+ 0x13        0           4           0
+ 
+ 1           0x34        0x8048034   0
+ 0x3f2f9     0x3f2f9     5           0x1000
+ 
+ 1           0x3f330     0x8088330   0
+ 0x215c4     0x25a60     7           0x1000
+ 
+ 2           0x60874     0x80a9874   0
+ 0x80        0           7           0
+ 
+ raid:/nfs/raid/src/dist-18.56/src> dump -o xemacs
+ 
+ xemacs:
+  ***** PROGRAM EXECUTION HEADER *****
+ Type        Offset      Vaddr       Paddr
+ Filesz      Memsz       Flags       Align
+ 
+ 6           0x34        0x8048034   0
+ 0xa0        0xa0        5           0
+ 
+ 3           0xd4        0           0
+ 0x13        0           4           0
+ 
+ 1           0x34        0x8048034   0
+ 0x3f2f9     0x3f2f9     5           0x1000
+ 
+ 1           0x3f330     0x8088330   0
+ 0x3e4d0     0x3e4d0     7           0x1000
+ 
+ 2           0x60874     0x80a9874   0
+ 0x80        0           7           0
+ 
+ 
+  */
+ 
+ /* Modified by wtien@urbana.mcd.mot.com of Motorola Inc.
+  *
+  * The above mechanism does not work if the unexeced ELF file is being
+  * re-layout by other applications (such as `strip'). All the applications
+  * that re-layout the internal of ELF will layout all sections in ascending
+  * order of their file offsets. After the re-layout, the data2 section will
+  * still be the LAST section in the section header vector, but its file offset
+  * is now being pushed far away down, and causes part of it not to be mapped
+  * in (ie. not covered by the load segment entry in PHDR vector), therefore
+  * causes the new binary to fail.
+  *
+  * The solution is to modify the unexec algorithm to insert the new data2
+  * section header right before the new bss section header, so their file
+  * offsets will be in the ascending order. Since some of the section's (all
+  * sections AFTER the bss section) indexes are now changed, we also need to
+  * modify some fields to make them point to the right sections. This is done
+  * by macro PATCH_INDEX. All the fields that need to be patched are:
+  *
+  * 1. ELF header e_shstrndx field.
+  * 2. section header sh_link and sh_info field.
+  * 3. symbol table entry st_shndx field.
+  *
+  * The above example now should look like:
+ 
+            **** SECTION HEADER TABLE ****
+ [No]    Type    Flags   Addr         Offset       Size          Name
+         Link    Info    Adralgn      Entsize
+ 
+ [1]     1       2       0x80480d4    0xd4         0x13          .interp
+         0       0       0x1          0
+ 
+ [2]     5       2       0x80480e8    0xe8         0x388         .hash
+         3       0       0x4          0x4
+ 
+ [3]     11      2       0x8048470    0x470        0x7f0         .dynsym
+         4       1       0x4          0x10
+ 
+ [4]     3       2       0x8048c60    0xc60        0x3ad         .dynstr
+         0       0       0x1          0
+ 
+ [5]     9       2       0x8049010    0x1010       0x338         .rel.plt
+         3       7       0x4          0x8
+ 
+ [6]     1       6       0x8049348    0x1348       0x3           .init
+         0       0       0x4          0
+ 
+ [7]     1       6       0x804934c    0x134c       0x680         .plt
+         0       0       0x4          0x4
+ 
+ [8]     1       6       0x80499cc    0x19cc       0x3c56f       .text
+         0       0       0x4          0
+ 
+ [9]     1       6       0x8085f3c    0x3df3c      0x3           .fini
+         0       0       0x4          0
+ 
+ [10]    1       2       0x8085f40    0x3df40      0x69c         .rodata
+         0       0       0x4          0
+ 
+ [11]    1       2       0x80865dc    0x3e5dc      0xd51         .rodata1
+         0       0       0x4          0
+ 
+ [12]    1       3       0x8088330    0x3f330      0x20afc       .data
+         0       0       0x4          0
+ 
+ [13]    1       3       0x80a8e2c    0x5fe2c      0x89d         .data1
+         0       0       0x4          0
+ 
+ [14]    1       3       0x80a96cc    0x606cc      0x1a8         .got
+         0       0       0x4          0x4
+ 
+ [15]    6       3       0x80a9874    0x60874      0x80          .dynamic
+         4       0       0x4          0x8
+ 
+ [16]    1       3       0x80a98f4    0x608f4      0x1cf0c       .data
+         0       0       0x4          0
+ 
+ [17]    8       3       0x80c6800    0x7d800      0             .bss
+         0       0       0x4          0
+ 
+ [18]    2       0       0            0x7d800      0x9b90        .symtab
+         19      371     0x4          0x10
+ 
+ [19]    3       0       0            0x87390      0x8526        .strtab
+         0       0       0x1          0
+ 
+ [20]    3       0       0            0x8f8b6      0x93          .shstrtab
+         0       0       0x1          0
+ 
+ [21]    1       0       0            0x8f949      0x68b7        .comment
+         0       0       0x1          0
+ 
+  */
+ 
+ #include <sys/types.h>
+ #include <stdio.h>
+ #include <sys/stat.h>
+ #include <memory.h>
+ #include <string.h>
+ #include <errno.h>
+ #include <unistd.h>
+ #include <fcntl.h>
+ #include <elf.h>
+ #include <sys/mman.h>
+ 
+ #ifdef __alpha__
+ # include <sym.h>	/* get COFF debugging symbol table declaration */
+ #endif
+ 
+ #if __GNU_LIBRARY__ - 0 >= 6
+ # include <link.h>	/* get ElfW etc */
+ #endif
+ 
+ #ifndef ElfW
+ # ifdef __STDC__
+ #  define ElfW(type)	Elf32_##type
+ # else
+ #  define ElfW(type)	Elf32_/**/type
+ # endif
+ #endif
+ 
+ #ifndef emacs
+ #define fatal(a, b, c) fprintf (stderr, a, b, c), exit (1)
+ #else
+ #include <config.h>
+ extern void fatal (char *, ...);
+ #endif
+ 
+ #ifndef ELF_BSS_SECTION_NAME
+ #define ELF_BSS_SECTION_NAME ".bss"
+ #endif
+ 
+ /* Get the address of a particular section or program header entry,
+  * accounting for the size of the entries.
+  */
+ /* 
+    On PPC Reference Platform running Solaris 2.5.1
+    the plt section is also of type NOBI like the bss section.
+    (not really stored) and therefore sections after the bss
+    section start at the plt offset. The plt section is always
+    the one just before the bss section.
+    Thus, we modify the test from
+       if (NEW_SECTION_H (nn).sh_offset >= new_data2_offset)
+    to
+       if (NEW_SECTION_H (nn).sh_offset >= 
+                OLD_SECTION_H (old_bss_index-1).sh_offset)
+    This is just a hack. We should put the new data section
+    before the .plt section.
+    And we should not have this routine at all but use
+    the libelf library to read the old file and create the new
+    file.
+    The changed code is minimal and depends on prep set in m/prep.h
+    Erik Deumens
+    Quantum Theory Project
+    University of Florida
+    deumens@qtp.ufl.edu
+    Apr 23, 1996
+    */
+ 
+ #define OLD_SECTION_H(n) \
+      (*(ElfW(Shdr) *) ((byte *) old_section_h + old_file_h->e_shentsize * (n)))
+ #define NEW_SECTION_H(n) \
+      (*(ElfW(Shdr) *) ((byte *) new_section_h + new_file_h->e_shentsize * (n)))
+ #define OLD_PROGRAM_H(n) \
+      (*(ElfW(Phdr) *) ((byte *) old_program_h + old_file_h->e_phentsize * (n)))
+ #define NEW_PROGRAM_H(n) \
+      (*(ElfW(Phdr) *) ((byte *) new_program_h + new_file_h->e_phentsize * (n)))
+ 
+ #define PATCH_INDEX(n) \
+   do { \
+ 	 if ((int) (n) >= old_bss_index) \
+ 	   (n)++; } while (0)
+ typedef unsigned char byte;
+ 
+ /* Round X up to a multiple of Y.  */
+ 
+ int
+ round_up (x, y)
+      int x, y;
+ {
+   int rem = x % y;
+   if (rem == 0)
+     return x;
+   return x - rem + y;
+ }
+ 
+ /* ****************************************************************
+  * unexec
+  *
+  * driving logic.
+  *
+  * In ELF, this works by replacing the old .bss section with a new
+  * .data section, and inserting an empty .bss immediately afterwards.
+  *
+  */
+ void
+ unexec (new_name, old_name, data_start, bss_start, entry_address)
+      char *new_name, *old_name;
+      unsigned data_start, bss_start, entry_address;
+ {
+   int new_file, old_file, new_file_size;
+ 
+   /* Pointers to the base of the image of the two files. */
+   caddr_t old_base, new_base;
+ 
+   /* Pointers to the file, program and section headers for the old and new
+    * files.
+    */
+   ElfW(Ehdr) *old_file_h, *new_file_h;
+   ElfW(Phdr) *old_program_h, *new_program_h;
+   ElfW(Shdr) *old_section_h, *new_section_h;
+ 
+   /* Point to the section name table in the old file */
+   char *old_section_names;
+ 
+   ElfW(Addr) old_bss_addr, new_bss_addr;
+   ElfW(Word) old_bss_size, new_data2_size;
+   ElfW(Off)  new_data2_offset;
+   ElfW(Addr) new_data2_addr;
+ 
+   int n, nn, old_bss_index, old_data_index, new_data2_index;
+   struct stat stat_buf;
+ 
+   /* Open the old file & map it into the address space. */
+ 
+   old_file = open (old_name, O_RDONLY);
+ 
+   if (old_file < 0)
+     fatal ("Can't open %s for reading: errno %d\n", old_name, errno);
+ 
+   if (fstat (old_file, &stat_buf) == -1)
+     fatal ("Can't fstat (%s): errno %d\n", old_name, errno);
+ 
+   old_base = mmap (0, stat_buf.st_size, PROT_READ, MAP_SHARED, old_file, 0);
+ 
+   if (old_base == (caddr_t) -1)
+     fatal ("Can't mmap (%s): errno %d\n", old_name, errno);
+ 
+ #ifdef DEBUG
+   fprintf (stderr, "mmap (%s, %x) -> %x\n", old_name, stat_buf.st_size,
+ 	   old_base);
+ #endif
+ 
+   /* Get pointers to headers & section names */
+ 
+   old_file_h = (ElfW(Ehdr) *) old_base;
+   old_program_h = (ElfW(Phdr) *) ((byte *) old_base + old_file_h->e_phoff);
+   old_section_h = (ElfW(Shdr) *) ((byte *) old_base + old_file_h->e_shoff);
+   old_section_names = (char *) old_base
+     + OLD_SECTION_H (old_file_h->e_shstrndx).sh_offset;
+ 
+   /* Find the old .bss section.  Figure out parameters of the new
+    * data2 and bss sections.
+    */
+ 
+   for (old_bss_index = 1; old_bss_index < (int) old_file_h->e_shnum;
+        old_bss_index++)
+     {
+ #ifdef DEBUG
+       fprintf (stderr, "Looking for .bss - found %s\n",
+ 	       old_section_names + OLD_SECTION_H (old_bss_index).sh_name);
+ #endif
+       if (!strcmp (old_section_names + OLD_SECTION_H (old_bss_index).sh_name,
+ 		   ELF_BSS_SECTION_NAME))
+ 	break;
+     }
+   if (old_bss_index == old_file_h->e_shnum)
+     fatal ("Can't find .bss in %s.\n", old_name, 0);
+ 
+   old_bss_addr = OLD_SECTION_H (old_bss_index).sh_addr;
+   old_bss_size = OLD_SECTION_H (old_bss_index).sh_size;
+ #if defined(emacs) || !defined(DEBUG)
+   new_bss_addr = (ElfW(Addr)) sbrk (0);
+ #else
+   new_bss_addr = old_bss_addr + old_bss_size + 0x1234;
+ #endif
+   new_data2_addr = old_bss_addr;
+   new_data2_size = new_bss_addr - old_bss_addr;
+   new_data2_offset = OLD_SECTION_H (old_bss_index).sh_offset;
+ 
+ #ifdef DEBUG
+   fprintf (stderr, "old_bss_index %d\n", old_bss_index);
+   fprintf (stderr, "old_bss_addr %x\n", old_bss_addr);
+   fprintf (stderr, "old_bss_size %x\n", old_bss_size);
+   fprintf (stderr, "new_bss_addr %x\n", new_bss_addr);
+   fprintf (stderr, "new_data2_addr %x\n", new_data2_addr);
+   fprintf (stderr, "new_data2_size %x\n", new_data2_size);
+   fprintf (stderr, "new_data2_offset %x\n", new_data2_offset);
+ #endif
+ 
+   if ((unsigned) new_bss_addr < (unsigned) old_bss_addr + old_bss_size)
+     fatal (".bss shrank when undumping???\n", 0, 0);
+ 
+   /* Set the output file to the right size and mmap it.  Set
+    * pointers to various interesting objects.  stat_buf still has
+    * old_file data.
+    */
+ 
+   new_file = open (new_name, O_RDWR | O_CREAT, 0666);
+   if (new_file < 0)
+     fatal ("Can't creat (%s): errno %d\n", new_name, errno);
+ 
+   new_file_size = stat_buf.st_size + old_file_h->e_shentsize + new_data2_size;
+ 
+   if (ftruncate (new_file, new_file_size))
+     fatal ("Can't ftruncate (%s): errno %d\n", new_name, errno);
+ 
+ #ifdef UNEXEC_USE_MAP_PRIVATE
+   new_base = mmap (0, new_file_size, PROT_READ | PROT_WRITE, MAP_PRIVATE,
+ 		   new_file, 0);
+ #else
+   new_base = mmap (0, new_file_size, PROT_READ | PROT_WRITE, MAP_SHARED,
+ 		   new_file, 0);
+ #endif
+ 
+   if (new_base == (caddr_t) -1)
+     fatal ("Can't mmap (%s): errno %d\n", new_name, errno);
+ 
+   new_file_h = (ElfW(Ehdr) *) new_base;
+   new_program_h = (ElfW(Phdr) *) ((byte *) new_base + old_file_h->e_phoff);
+   new_section_h = (ElfW(Shdr) *)
+     ((byte *) new_base + old_file_h->e_shoff + new_data2_size);
+ 
+   /* Make our new file, program and section headers as copies of the
+    * originals.
+    */
+ 
+   memcpy (new_file_h, old_file_h, old_file_h->e_ehsize);
+   memcpy (new_program_h, old_program_h,
+ 	  old_file_h->e_phnum * old_file_h->e_phentsize);
+ 
+   /* Modify the e_shstrndx if necessary. */
+   PATCH_INDEX (new_file_h->e_shstrndx);
+ 
+   /* Fix up file header.  We'll add one section.  Section header is
+    * further away now.
+    */
+ 
+   new_file_h->e_shoff += new_data2_size;
+   new_file_h->e_shnum += 1;
+ 
+ #ifdef DEBUG
+   fprintf (stderr, "Old section offset %x\n", old_file_h->e_shoff);
+   fprintf (stderr, "Old section count %d\n", old_file_h->e_shnum);
+   fprintf (stderr, "New section offset %x\n", new_file_h->e_shoff);
+   fprintf (stderr, "New section count %d\n", new_file_h->e_shnum);
+ #endif
+ 
+   /* Fix up a new program header.  Extend the writable data segment so
+    * that the bss area is covered too. Find that segment by looking
+    * for a segment that ends just before the .bss area.  Make sure
+    * that no segments are above the new .data2.  Put a loop at the end
+    * to adjust the offset and address of any segment that is above
+    * data2, just in case we decide to allow this later.
+    */
+ 
+   for (n = new_file_h->e_phnum - 1; n >= 0; n--)
+     {
+       /* Compute maximum of all requirements for alignment of section.  */
+       int alignment = (NEW_PROGRAM_H (n)).p_align;
+       if ((OLD_SECTION_H (old_bss_index)).sh_addralign > alignment)
+ 	alignment = OLD_SECTION_H (old_bss_index).sh_addralign;
+ 
+       if (NEW_PROGRAM_H (n).p_vaddr + NEW_PROGRAM_H (n).p_filesz > old_bss_addr)
+ 	fatal ("Program segment above .bss in %s\n", old_name, 0);
+ 
+       if (NEW_PROGRAM_H (n).p_type == PT_LOAD
+ 	  && (round_up ((NEW_PROGRAM_H (n)).p_vaddr
+ 			+ (NEW_PROGRAM_H (n)).p_filesz,
+ 			alignment)
+ 	      == round_up (old_bss_addr, alignment)))
+ 	break;
+     }
+   if (n < 0)
+     fatal ("Couldn't find segment next to .bss in %s\n", old_name, 0);
+ 
+   NEW_PROGRAM_H (n).p_filesz += new_data2_size;
+   NEW_PROGRAM_H (n).p_memsz = NEW_PROGRAM_H (n).p_filesz;
+ 
+ #if 0 /* Maybe allow section after data2 - does this ever happen? */
+   for (n = new_file_h->e_phnum - 1; n >= 0; n--)
+     {
+       if (NEW_PROGRAM_H (n).p_vaddr
+ 	  && NEW_PROGRAM_H (n).p_vaddr >= new_data2_addr)
+ 	NEW_PROGRAM_H (n).p_vaddr += new_data2_size - old_bss_size;
+ 
+       if (NEW_PROGRAM_H (n).p_offset >= new_data2_offset)
+ 	NEW_PROGRAM_H (n).p_offset += new_data2_size;
+     }
+ #endif
+ 
+   /* Fix up section headers based on new .data2 section.  Any section
+    * whose offset or virtual address is after the new .data2 section
+    * gets its value adjusted.  .bss size becomes zero and new address
+    * is set.  data2 section header gets added by copying the existing
+    * .data header and modifying the offset, address and size.
+    */
+   for (old_data_index = 1; old_data_index < (int) old_file_h->e_shnum;
+        old_data_index++)
+     if (!strcmp (old_section_names + OLD_SECTION_H (old_data_index).sh_name,
+ 		 ".data"))
+       break;
+   if (old_data_index == old_file_h->e_shnum)
+     fatal ("Can't find .data in %s.\n", old_name, 0);
+ 
+   /* Walk through all section headers, insert the new data2 section right
+      before the new bss section. */
+   for (n = 1, nn = 1; n < (int) old_file_h->e_shnum; n++, nn++)
+     {
+       caddr_t src;
+       /* If it is bss section, insert the new data2 section before it. */
+       if (n == old_bss_index)
+ 	{
+ 	  /* Steal the data section header for this data2 section. */
+ 	  memcpy (&NEW_SECTION_H (nn), &OLD_SECTION_H (old_data_index),
+ 		  new_file_h->e_shentsize);
+ 
+ 	  NEW_SECTION_H (nn).sh_addr = new_data2_addr;
+ 	  NEW_SECTION_H (nn).sh_offset = new_data2_offset;
+ 	  NEW_SECTION_H (nn).sh_size = new_data2_size;
+ 	  /* Use the bss section's alignment. This will assure that the
+ 	     new data2 section always be placed in the same spot as the old
+ 	     bss section by any other application. */
+ 	  NEW_SECTION_H (nn).sh_addralign = OLD_SECTION_H (n).sh_addralign;
+ 
+ 	  /* Now copy over what we have in the memory now. */
+ 	  memcpy (NEW_SECTION_H (nn).sh_offset + new_base,
+ 		  (caddr_t) OLD_SECTION_H (n).sh_addr,
+ 		  new_data2_size);
+ 	  nn++;
+ 	}
+ 
+       memcpy (&NEW_SECTION_H (nn), &OLD_SECTION_H (n),
+ 	      old_file_h->e_shentsize);
+ 
+       /* The new bss section's size is zero, and its file offset and virtual
+ 	 address should be off by NEW_DATA2_SIZE. */
+       if (n == old_bss_index)
+ 	{
+ 	  /* NN should be `old_bss_index + 1' at this point. */
+ 	  NEW_SECTION_H (nn).sh_offset += new_data2_size;
+ 	  NEW_SECTION_H (nn).sh_addr += new_data2_size;
+ 	  /* Let the new bss section address alignment be the same as the
+ 	     section address alignment followed the old bss section, so
+ 	     this section will be placed in exactly the same place. */
+ 	  NEW_SECTION_H (nn).sh_addralign = OLD_SECTION_H (nn).sh_addralign;
+ 	  NEW_SECTION_H (nn).sh_size = 0;
+ 	}
+       else
+ 	{
+ 	  /* Any section that was original placed AFTER the bss
+ 	     section should now be off by NEW_DATA2_SIZE. */
+ #ifdef SOLARIS_POWERPC
+ 	  /* On PPC Reference Platform running Solaris 2.5.1
+ 	     the plt section is also of type NOBI like the bss section.
+ 	     (not really stored) and therefore sections after the bss
+ 	     section start at the plt offset. The plt section is always
+ 	     the one just before the bss section.
+ 	     It would be better to put the new data section before
+ 	     the .plt section, or use libelf instead.
+ 	     Erik Deumens, deumens@qtp.ufl.edu.  */
+ 	  if (NEW_SECTION_H (nn).sh_offset
+ 	      >= OLD_SECTION_H (old_bss_index-1).sh_offset)
+ 	    NEW_SECTION_H (nn).sh_offset += new_data2_size;
+ #else
+ 	  if (round_up (NEW_SECTION_H (nn).sh_offset,
+ 			OLD_SECTION_H (old_bss_index).sh_addralign)
+ 	      >= new_data2_offset)
+ 	    NEW_SECTION_H (nn).sh_offset += new_data2_size;
+ #endif
+ 	  /* Any section that was originally placed after the section
+ 	     header table should now be off by the size of one section
+ 	     header table entry.  */
+ 	  if (NEW_SECTION_H (nn).sh_offset > new_file_h->e_shoff)
+ 	    NEW_SECTION_H (nn).sh_offset += new_file_h->e_shentsize;
+ 	}
+ 
+       /* If any section hdr refers to the section after the new .data
+ 	 section, make it refer to next one because we have inserted
+ 	 a new section in between.  */
+ 
+       PATCH_INDEX (NEW_SECTION_H (nn).sh_link);
+       /* For symbol tables, info is a symbol table index,
+ 	 so don't change it.  */
+       if (NEW_SECTION_H (nn).sh_type != SHT_SYMTAB
+ 	  && NEW_SECTION_H (nn).sh_type != SHT_DYNSYM)
+ 	PATCH_INDEX (NEW_SECTION_H (nn).sh_info);
+ 
+       /* Now, start to copy the content of sections.  */
+       if (NEW_SECTION_H (nn).sh_type == SHT_NULL
+ 	  || NEW_SECTION_H (nn).sh_type == SHT_NOBITS)
+ 	continue;
+ 
+       /* Write out the sections. .data and .data1 (and data2, called
+ 	 ".data" in the strings table) get copied from the current process
+ 	 instead of the old file.  */
+       if (!strcmp (old_section_names + NEW_SECTION_H (n).sh_name, ".data")
+ 	  || !strcmp ((old_section_names + NEW_SECTION_H (n).sh_name),
+ 		      ".data1"))
+ 	src = (caddr_t) OLD_SECTION_H (n).sh_addr;
+       else
+ 	src = old_base + OLD_SECTION_H (n).sh_offset;
+ 
+       memcpy (NEW_SECTION_H (nn).sh_offset + new_base, src,
+ 	      NEW_SECTION_H (nn).sh_size);
+ 
+ #ifdef __alpha__
+       /* Update Alpha COFF symbol table: */
+       if (strcmp (old_section_names + OLD_SECTION_H (n).sh_name, ".mdebug")
+ 	  == 0)
+ 	{
+ 	  pHDRR symhdr = (pHDRR) (NEW_SECTION_H (nn).sh_offset + new_base);
+ 
+ 	  symhdr->cbLineOffset += new_data2_size;
+ 	  symhdr->cbDnOffset += new_data2_size;
+ 	  symhdr->cbPdOffset += new_data2_size;
+ 	  symhdr->cbSymOffset += new_data2_size;
+ 	  symhdr->cbOptOffset += new_data2_size;
+ 	  symhdr->cbAuxOffset += new_data2_size;
+ 	  symhdr->cbSsOffset += new_data2_size;
+ 	  symhdr->cbSsExtOffset += new_data2_size;
+ 	  symhdr->cbFdOffset += new_data2_size;
+ 	  symhdr->cbRfdOffset += new_data2_size;
+ 	  symhdr->cbExtOffset += new_data2_size;
+ 	}
+ #endif /* __alpha__ */
+ 
+       /* If it is the symbol table, its st_shndx field needs to be patched.  */
+       if (NEW_SECTION_H (nn).sh_type == SHT_SYMTAB
+ 	  || NEW_SECTION_H (nn).sh_type == SHT_DYNSYM)
+ 	{
+ 	  ElfW(Shdr) *spt = &NEW_SECTION_H (nn);
+ 	  unsigned int num = spt->sh_size / spt->sh_entsize;
+ 	  ElfW(Sym) * sym = (ElfW(Sym) *) (NEW_SECTION_H (nn).sh_offset +
+ 					   new_base);
+ 	  for (; num--; sym++)
+ 	    {
+ 	      if ((sym->st_shndx == SHN_UNDEF)
+ 		  || (sym->st_shndx == SHN_ABS)
+ 		  || (sym->st_shndx == SHN_COMMON))
+ 		continue;
+ 
+ 	      PATCH_INDEX (sym->st_shndx);
+ 	    }
+ 	}
+     }
+ 
+   /* Update the symbol values of _edata and _end.  */
+   for (n = new_file_h->e_shnum - 1; n; n--)
+     {
+       byte *symnames;
+       ElfW(Sym) *symp, *symendp;
+ 
+       if (NEW_SECTION_H (n).sh_type != SHT_DYNSYM
+ 	  && NEW_SECTION_H (n).sh_type != SHT_SYMTAB)
+ 	continue;
+ 
+       symnames = ((byte *) new_base
+ 		  + NEW_SECTION_H (NEW_SECTION_H (n).sh_link).sh_offset);
+       symp = (ElfW(Sym) *) (NEW_SECTION_H (n).sh_offset + new_base);
+       symendp = (ElfW(Sym) *) ((byte *)symp + NEW_SECTION_H (n).sh_size);
+ 
+       for (; symp < symendp; symp ++)
+ 	if (strcmp ((char *) (symnames + symp->st_name), "_end") == 0
+ 	    || strcmp ((char *) (symnames + symp->st_name), "_edata") == 0)
+ 	  memcpy (&symp->st_value, &new_bss_addr, sizeof (new_bss_addr));
+     }
+ 
+   /* This loop seeks out relocation sections for the data section, so
+      that it can undo relocations performed by the runtime linker.  */
+   for (n = new_file_h->e_shnum - 1; n; n--)
+     {
+       ElfW(Shdr) section = NEW_SECTION_H (n);
+       switch (section.sh_type) {
+       default:
+ 	break;
+       case SHT_REL:
+       case SHT_RELA:
+ 	/* This code handles two different size structs, but there should
+ 	   be no harm in that provided that r_offset is always the first
+ 	   member.  */
+ 	nn = section.sh_info;
+ 	if (!strcmp (old_section_names + NEW_SECTION_H (nn).sh_name, ".data")
+ 	    || !strcmp ((old_section_names + NEW_SECTION_H (nn).sh_name),
+ 			".data1"))
+ 	  {
+ 	    ElfW(Addr) offset = NEW_SECTION_H (nn).sh_addr -
+ 	      NEW_SECTION_H (nn).sh_offset;
+ 	    caddr_t reloc = old_base + section.sh_offset, end;
+ 	    for (end = reloc + section.sh_size; reloc < end;
+ 		 reloc += section.sh_entsize)
+ 	      {
+ 		ElfW(Addr) addr = ((ElfW(Rel) *) reloc)->r_offset - offset;
+ #ifdef __alpha__
+ 		/* The Alpha ELF binutils currently have a bug that
+ 		   sometimes results in relocs that contain all
+ 		   zeroes.  Work around this for now...  */
+ 		if (((ElfW(Rel) *) reloc)->r_offset == 0)
+ 		    continue;
+ #endif
+ 		memcpy (new_base + addr, old_base + addr, sizeof(ElfW(Addr)));
+ 	      }
+ 	  }
+ 	break;
+       }
+     }
+ 
+ #ifdef UNEXEC_USE_MAP_PRIVATE
+   if (lseek (new_file, 0, SEEK_SET) == -1)
+     fatal ("Can't rewind (%s): errno %d\n", new_name, errno);
+ 
+   if (write (new_file, new_base, new_file_size) != new_file_size)
+     fatal ("Can't write (%s): errno %d\n", new_name, errno);
+ #endif
+ 
+   /* Close the files and make the new file executable.  */
+ 
+   if (close (old_file))
+     fatal ("Can't close (%s): errno %d\n", old_name, errno);
+ 
+   if (close (new_file))
+     fatal ("Can't close (%s): errno %d\n", new_name, errno);
+ 
+   if (stat (new_name, &stat_buf) == -1)
+     fatal ("Can't stat (%s): errno %d\n", new_name, errno);
+ 
+   n = umask (777);
+   umask (n);
+   stat_buf.st_mode |= 0111 & ~n;
+   if (chmod (new_name, stat_buf.st_mode) == -1)
+     fatal ("Can't chmod (%s): errno %d\n", new_name, errno);
+ }
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/widget.c emacs-19.33/src/widget.c
*** emacs-19.32/src/widget.c	Thu Apr 18 00:13:15 1996
--- emacs-19.33/src/widget.c	Fri Aug  2 13:38:49 1996
*************** EmacsFrameSetCharSize (widget, columns, 
*** 952,955 ****
--- 952,957 ----
        update_wm_hints (ew);
  
+       do_pending_window_change ();
+ 
        /* These seem to get clobbered.  I don't know why. - rms.  */
        f->output_data.x->widget->core.x = old_left;
diff -2rcpP --exclude=*.elc --exclude=*.aux --exclude=*.cps --exclude=*.fns --exclude=*.kys --exclude=*.vrs emacs-19.32/src/xmenu.c emacs-19.33/src/xmenu.c
*** emacs-19.32/src/xmenu.c	Mon Jul 29 00:20:01 1996
--- emacs-19.33/src/xmenu.c	Wed Aug  7 23:32:28 1996
*************** popup_get_selection (initial_event, dpyi
*** 1116,1119 ****
--- 1116,1125 ----
            dpyinfo->grabbed &= ~(1 << event.xbutton.button);
            popup_activated_flag = 0;
+ #ifdef USE_MOTIF /* Pretending that the event came from a 
+ 		    Btn1Down seems the only way to convince Motif to
+ 		    activate its callbacks; setting the XmNmenuPost
+ 		    isn't working. --marcus@sysc.pdx.edu.  */
+ 	  event.xbutton.button = 1;
+ #endif
          }
        /* If the user presses a key, deactivate the menu.
*************** free_frame_menubar (f)
*** 1874,1878 ****
     X and Y are the frame-relative specified position,
     relative to the inside upper left corner of the frame F.
!    FOR_CLICK if this menu was invoked for a mouse click.
     KEYMAPS is 1 if this menu was specified with keymaps;
      in that case, we return a list containing the chosen item's value
--- 1880,1884 ----
     X and Y are the frame-relative specified position,
     relative to the inside upper left corner of the frame F.
!    FOR_CLICK is nonzero if this menu was invoked for a mouse click.
     KEYMAPS is 1 if this menu was specified with keymaps;
      in that case, we return a list containing the chosen item's value
*************** xmenu_show (f, x, y, for_click, keymaps,
*** 2111,2115 ****
    dummy.display = FRAME_X_DISPLAY (f);
    dummy.time = CurrentTime;
-   dummy.button = 0;
    dummy.root = FRAME_X_DISPLAY_INFO (f)->root_window;
    dummy.window = dummy.root;
--- 2117,2120 ----
*************** xmenu_show (f, x, y, for_click, keymaps,
*** 2119,2122 ****
--- 2124,2132 ----
    dummy.x = x;
    dummy.y = y;
+   dummy.state = (FRAME_X_DISPLAY_INFO (f)->grabbed >> 1) * Button1Mask;
+   dummy.button = 0;
+   for (i = 0; i < 5; i++)
+     if (FRAME_X_DISPLAY_INFO (f)->grabbed & (1 << i))
+       dummy.button = i;
  
    /* Don't allow any geometry request from the user.  */
